/*****************************************************************************************
* VBECS Patch	(Build 1.5.0.4) 01
*****************************************************************************************/

USE VBECS_V1_TEST
GO

/*****************************************************************************************
* 	NEW TABLES
*****************************************************************************************/
/*****************************************************************************************
   Create the new Interface table
*****************************************************************************************/
CREATE TABLE dbo.Interface
(
	InterfaceId tinyint NOT NULL IDENTITY (1, 1),
	InterfaceName varchar (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	FieldSeparator char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	EncodingCharacters char (4) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	InterfaceApplicationId varchar (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	VbecsApplicationId varchar (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	VersionId varchar (8) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	ApplicationAckType char (2) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
	LastUpdateDate datetime NOT NULL,
	LastUpdateUser varchar(30) NOT NULL,
	[RowVersion] timestamp NOT NULL,
	LastUpdateFunctionId int NOT NULL CONSTRAINT DF_Interface_LastUpdateFunctionId DEFAULT 0
)  ON [PRIMARY]
GO


sp_addextendedproperty N'MS_Description', N'Identifies a specific interface in VBECS.', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'InterfaceId'
GO
sp_addextendedproperty N'MS_Description', N'The name of the interface. [for example: CPRS]', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'InterfaceName'
GO
sp_addextendedproperty N'MS_Description', N'Defines the character to be used as a separator for the message.', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'FieldSeparator'
GO
sp_addextendedproperty N'MS_Description', N'This field contains the four characters in the following order: the component separator, repetition separator, escape character, and subcomponent separator.', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'EncodingCharacters'
GO
sp_addextendedproperty N'MS_Description', N'Uniquely identifies the sending application.  In the case of an OMG_O19 message generated from CPRS, this field would be defined as ORDER ENTRY.', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'InterfaceApplicationId'
GO
sp_addextendedproperty N'MS_Description', N'Uniquely identifies the receiving application.  In the case of an ORM message generated from CPRS, this field would be defined as VBECS.', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'VbecsApplicationId'
GO
sp_addextendedproperty N'MS_Description', N'This field is matched by the receiving system to its own version to be sure the message will be interpreted correctly.', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'VersionId'
GO
sp_addextendedproperty N'MS_Description', N'This field identifies the conditions under which accept acknowledgments are required to be returned in response to this message.', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'ApplicationAckType'
GO
sp_addextendedproperty N'MS_Description', N'The date and time the record was last updated.', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'LastUpdateDate'
GO
sp_addextendedproperty N'MS_Description', N'The logon id of the user who performed the last update.', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'LastUpdateUser'
GO
sp_addextendedproperty N'MS_Description', N'This is used in the C# code as a mechanism for version-stamping table rows, which provides a means for concurrency control.', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'RowVersion'
GO
sp_addextendedproperty N'MS_Description', N'The identifier of the VBECS function that performed the last update.', 'USER', N'dbo', 'TABLE', N'Interface', 'COLUMN', N'LastUpdateFunctionId'
GO

ALTER TABLE dbo.Interface 
	ADD CONSTRAINT PK_Interface PRIMARY KEY CLUSTERED 
	(
		InterfaceId
	) ON [PRIMARY]

GO

/*****************************************************************************************
   Load the new Interface table
*****************************************************************************************/
SET IDENTITY_INSERT Interface ON

INSERT INTO dbo.Interface 
		(InterfaceId, InterfaceName, FieldSeparator, EncodingCharacters, InterfaceApplicationId, VbecsApplicationId, VersionId, 
				ApplicationAckType, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId)
	  VALUES(1, 'CPRS', '|', '^~\&', 'OERR', 'VBECS', '2.4', 'AL', '2008-12-29 15:18:57.537', 'vhaishsmithm', 0)

INSERT INTO dbo.Interface 
		(InterfaceId, InterfaceName, FieldSeparator, EncodingCharacters, InterfaceApplicationId, VbecsApplicationId, VersionId, 
				ApplicationAckType, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId)
	  VALUES(2, 'PatientUpdate', '^', '~|\&', 'VAFC PIMS', 'VBECS ADT', '2.3', 'NE', '2008-12-29 15:18:57.537', 'vhaishsmithm', 0)

INSERT INTO dbo.Interface 
		(InterfaceId, InterfaceName, FieldSeparator, EncodingCharacters, InterfaceApplicationId, VbecsApplicationId, VersionId, 
				ApplicationAckType, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId)
	  VALUES(3, 'PatientMerge', '^', '~|\&', 'MPIF TRIGGER', 'VBECS ADT', '2.4', 'AL', '2008-12-29 15:18:57.537', 'vhaishsmithm', 0)
GO
SET IDENTITY_INSERT Interface OFF
GO

/*****************************************************************************************
* 	TABLE CHANGES
*****************************************************************************************/
/*****************************************************************************************
   Create a temporary VbecsVersion table and save the original data
*****************************************************************************************/
if object_id(N'tempdb..#tmpVbecsVersion') IS NOT NULL
	DROP TABLE #tmpVbecsVersion
GO

CREATE TABLE #tmpVbecsVersion (
	VbecsVersionId int NOT NULL ,
	Version varchar (25) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	LastUpdateDate datetime NOT NULL ,
	LastUpdateUser varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	LastUpdateFunctionId int NOT NULL
)
GO

INSERT INTO #tmpVbecsVersion
SELECT VbecsVersionId, Version, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
FROM dbo.VbecsVersion
GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.VbecsVersion') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
DROP TABLE dbo.VbecsVersion
GO

CREATE TABLE dbo.VbecsVersion 
(
	VbecsVersionId int  NOT NULL IDENTITY(1, 1),
	Version varchar(25) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	PatchSuccessfulIndicator bit NOT NULL CONSTRAINT DF_VbecsVersion_PatchSuccessfulIndicator DEFAULT 0,
	LastUpdateDate datetime NOT NULL,
	LastUpdateUser varchar(30) NOT NULL,
	[RowVersion] timestamp NOT NULL,
	LastUpdateFunctionId int NOT NULL CONSTRAINT DF_VbecsVersion_LastUpdateFunctionId DEFAULT 0
)  ON [PRIMARY]
GO

sp_addextendedproperty N'MS_Description', N'A unique identifier for the VBECS version.', 'USER', N'dbo', 'TABLE', N'VbecsVersion', 'COLUMN', N'VbecsVersionId'
GO
sp_addextendedproperty N'MS_Description', N'Identifies a specific version of the VBECS patch.', 'USER', N'dbo', 'TABLE', N'VbecsVersion', 'COLUMN', N'Version'
GO
sp_addextendedproperty N'MS_Description', N'Indicates if the patch was installed successfully.', 'USER', N'dbo', 'TABLE', N'VbecsVersion', 'COLUMN', N'PatchSuccessfulIndicator'
GO
sp_addextendedproperty N'MS_Description', N'The date and time the record was last updated.', 'USER', N'dbo', 'TABLE', N'VbecsVersion', 'COLUMN', N'LastUpdateDate'
GO
sp_addextendedproperty N'MS_Description', N'The logon id of the user who performed the last update.', 'USER', N'dbo', 'TABLE', N'VbecsVersion', 'COLUMN', N'LastUpdateUser'
GO
sp_addextendedproperty N'MS_Description', N'This is used in the C# code as a mechanism for version-stamping table rows, which provides a means for concurrency control.', 'USER', N'dbo', 'TABLE', N'VbecsVersion', 'COLUMN', N'RowVersion'
GO
sp_addextendedproperty N'MS_Description', N'The identifier of the VBECS function that performed the last update.', 'USER', N'dbo', 'TABLE', N'VbecsVersion', 'COLUMN', N'LastUpdateFunctionId'
GO

ALTER TABLE dbo.VbecsVersion 
	ADD CONSTRAINT PK_VbecsVersion PRIMARY KEY CLUSTERED 
	(
		VbecsVersionId
	)  WITH FILLFACTOR = 90 ON [PRIMARY]

GO

/*****************************************************************************************
*	Reload the original VbecsVersion data into the updated table
*****************************************************************************************/
SET IDENTITY_INSERT VbecsVersion ON

INSERT INTO dbo.VbecsVersion
(
	VbecsVersionId, Version, PatchSuccessfulIndicator, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
)
SELECT VbecsVersionId, Version, 1, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
FROM #tmpVbecsVersion
GO

SET IDENTITY_INSERT VbecsVersion OFF

DROP TABLE #tmpVbecsVersion
GO

/*****************************************************************************************
   Create a temporary PatientChange table and save the original data
*****************************************************************************************/
if object_id(N'tempdb..#tmpPatientChange') IS NOT NULL
	DROP TABLE #tmpPatientChange
GO

CREATE TABLE #tmpPatientChange (
	PatientChangeGuid uniqueidentifier NOT NULL ,
	FromPatientGuid uniqueidentifier NULL ,
	FromPatientSsn char (9) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromSsnPseudoIndicator bit NULL ,
	FromPatientIcn varchar (23) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientLastName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientFirstName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientMIddleName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientDob datetime NULL ,
	FromPatientDeathDate datetime NULL ,
	FromPatientSexCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientGuid uniqueidentifier NULL ,
	ToPatientSsn char (9) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToSsnPseudoIndicator bit NULL ,
	ToPatientIcn varchar (23) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientLastName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientFirstName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientMIddleName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientDob datetime NULL ,
	ToPatientDeathDate datetime NULL ,
	ToPatientSexCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	MergeFromVistaPatientId bigint NULL ,
	MergeToVistaPatientId bigint NULL ,
	PatientChangeStatusCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	NotificationReceivedDate datetime NOT NULL,
	LastUpdateDate datetime NOT NULL ,
	LastUpdateUser varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	LastUpdateFunctionId int NOT NULL
)
GO

INSERT INTO #tmpPatientChange
SELECT PC1.PatientChangeGuid, FromPatientGuid, FromPatientSsn, FromSsnPseudoIndicator, FromPatientIcn, FromPatientLastName, FromPatientFirstName, FromPatientMIddleName, FromPatientDob,
	FromPatientDeathDate, FromPatientSexCode, ToPatientGuid, ToPatientSsn, ToSsnPseudoIndicator, ToPatientIcn, ToPatientLastName, ToPatientFirstName, ToPatientMIddleName, 
	ToPatientDob, ToPatientDeathDate, ToPatientSexCode, MergeFromVistaPatientId, MergeToVistaPatientId, PatientChangeStatusCode, PC2.LastUpdateDate, PC1.LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
FROM VBECS_V1_TEST.dbo.PatientChange PC1
	JOIN (SELECT PatientChangeGuid, MIN(LastUpdateDate) LastUpdateDate
		FROM VBECS_V1_TEST_MIRROR.dbo.V_PatientChange
		GROUP BY PatientChangeGuid) PC2
		ON PC1.PatientChangeGuid = PC2.PatientChangeGuid
GO

/*****************************************************************************************
   Create a temporary InterfaceControl table and save the original data
*****************************************************************************************/
if object_id(N'tempdb..#tmpInterfaceControl') IS NOT NULL
	DROP TABLE #tmpInterfaceControl
GO

CREATE TABLE #tmpInterfaceControl (
	InterfaceControlId int NOT NULL ,
	InterfaceName varchar (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	FieldSeparator char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	EncodingCharacters char (4) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	InterfaceApplicationId varchar (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	InterfaceFacilityId varchar (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	InterfacePortNumber int NULL ,
	InterfaceIPAddress char (15) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	InterfaceDomainName varchar (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
	VbecsApplicationId varchar (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	VbecsFacilityId varchar (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ProcessingId char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	VersionId varchar (8) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	ApplicationAckType char (2) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	VbecsPortNumber int NULL ,
	VbecsIPAddress char (15) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	AckTimeout int NOT NULL CONSTRAINT DF_InterfaceControl_AckTimeout DEFAULT (10),
	ReTransmitAttempts tinyint NOT NULL CONSTRAINT DF_InterfaceControl_ReTransmitAttempts DEFAULT (5),
	InterfaceAdministratorName varchar (90) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	PurgeSuccessfulMessage tinyint NOT NULL CONSTRAINT DF_InterfaceControl_PurgeSuccessfulMessage DEFAULT (7),
	PurgeUnSuccessfulMessage tinyint NOT NULL CONSTRAINT DF_InterfaceControl_PurgeUnSuccessfulMessage DEFAULT (7),
	LogEventsIndicator bit NOT NULL CONSTRAINT DF_InterfaceControl_LogEventsIndicator DEFAULT (1),
	LastUpdateDate datetime NOT NULL ,
	LastUpdateUser varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	LastUpdateFunctionId int NOT NULL CONSTRAINT DF_InterfaceControl_LastUpdateFunctionId DEFAULT (0)
)
GO

INSERT INTO #tmpInterfaceControl
SELECT InterfaceControlId, InterfaceName, FieldSeparator, EncodingCharacters, InterfaceApplicationId, InterfaceFacilityId, InterfacePortNumber, InterfaceIPAddress, InterfaceDomainName, 
	VbecsApplicationId, VbecsFacilityId, ProcessingId, VersionId, ApplicationAckType, VbecsPortNumber, VbecsIPAddress, AckTimeout, ReTransmitAttempts, InterfaceAdministratorName, 
	PurgeSuccessfulMessage, PurgeUnSuccessfulMessage, LogEventsIndicator, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
FROM VBECS_V1_TEST.dbo.InterfaceControl
GO

USE VBECS_V1_TEST_MIRROR
/*****************************************************************************************
*	Create a temporary PatientChange Mirror table and save the original data
*****************************************************************************************/
if object_id(N'tempdb..#tmpMirrorPatientChange') IS NOT NULL
	DROP TABLE #tmpMirrorPatientChange
GO

CREATE TABLE #tmpMirrorPatientChange (
	MirrorId int NOT NULL ,
	PatientChangeGuid uniqueidentifier NOT NULL ,
	FromPatientGuid uniqueidentifier NULL ,
	FromPatientSsn char (9) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromSsnPseudoIndicator bit NULL ,
	FromPatientIcn varchar (23) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientLastName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientFirstName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientMIddleName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientDob datetime NULL ,
	FromPatientDeathDate datetime NULL ,
	FromPatientSexCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientGuid uniqueidentifier NULL ,
	ToPatientSsn char (9) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToSsnPseudoIndicator bit NULL ,
	ToPatientIcn varchar (23) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientLastName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientFirstName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientMIddleName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientDob datetime NULL ,
	ToPatientDeathDate datetime NULL ,
	ToPatientSexCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	MergeFromVistaPatientId bigint NULL ,
	MergeToVistaPatientId bigint NULL ,
	PatientChangeStatusCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	LastUpdateDate datetime NOT NULL ,
	LastUpdateUser varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[RowVersion] binary (8) NULL ,
	LastUpdateFunctionId int NOT NULL ,
	MirrorDate datetime NOT NULL 
)
GO

INSERT INTO #tmpMirrorPatientChange
SELECT MirrorId, PatientChangeGuid, FromPatientGuid, FromPatientSsn, FromSsnPseudoIndicator, FromPatientIcn, FromPatientLastName, FromPatientFirstName, FromPatientMIddleName, FromPatientDob,
	FromPatientDeathDate, FromPatientSexCode, ToPatientGuid, ToPatientSsn, ToSsnPseudoIndicator, ToPatientIcn, ToPatientLastName, ToPatientFirstName, ToPatientMIddleName, ToPatientDob, 
	ToPatientDeathDate, ToPatientSexCode, MergeFromVistaPatientId, MergeToVistaPatientId, PatientChangeStatusCode, LastUpdateDate, LastUpdateUser, [RowVersion], LastUpdateFunctionId, MirrorDate
FROM PatientChange
GO

/*****************************************************************************************
* 	Create the new PatientChange Mirror table
*****************************************************************************************/

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.PatientChange') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table dbo.PatientChange
GO

CREATE TABLE dbo.PatientChange (
	MirrorId int IDENTITY (1, 1) NOT NULL ,
	PatientChangeGuid uniqueidentifier NOT NULL ,
	FromPatientGuid uniqueidentifier NULL ,
	FromPatientSsn char (9) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromSsnPseudoIndicator bit NULL ,
	FromPatientIcn varchar (23) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientLastName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientFirstName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientMIddleName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientDob datetime NULL ,
	FromPatientDeathDate datetime NULL ,
	FromPatientSexCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientGuid uniqueidentifier NULL ,
	ToPatientSsn char (9) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToSsnPseudoIndicator bit NULL ,
	ToPatientIcn varchar (23) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientLastName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientFirstName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientMIddleName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientDob datetime NULL ,
	ToPatientDeathDate datetime NULL ,
	ToPatientSexCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	MergeFromVistaPatientId bigint NULL ,
	MergeToVistaPatientId bigint NULL ,
	PatientChangeStatusCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	NotificationReceivedDate datetime NOT NULL ,
	LastUpdateDate datetime NOT NULL ,
	LastUpdateUser varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[RowVersion] binary (8) NULL ,
	LastUpdateFunctionId int NOT NULL ,
	MirrorDate datetime NOT NULL 
) ON [PRIMARY]
GO


ALTER TABLE dbo.PatientChange
	ADD CONSTRAINT PK_PatientChange PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO


/*****************************************************************************************
*	Reload the original PatientChange Mirror data into the updated table
*****************************************************************************************/

SET IDENTITY_INSERT PatientChange ON

INSERT INTO dbo.PatientChange
(
	MirrorId, PatientChangeGuid, FromPatientGuid, FromPatientSsn, FromSsnPseudoIndicator, FromPatientIcn, FromPatientLastName, FromPatientFirstName, FromPatientMIddleName, FromPatientDob,
	FromPatientDeathDate, FromPatientSexCode, ToPatientGuid, ToPatientSsn, ToSsnPseudoIndicator, ToPatientIcn, ToPatientLastName, ToPatientFirstName, ToPatientMIddleName, ToPatientDob, 
	ToPatientDeathDate, ToPatientSexCode, MergeFromVistaPatientId, MergeToVistaPatientId, PatientChangeStatusCode, NotificationReceivedDate, LastUpdateDate, LastUpdateUser, [RowVersion], 
	LastUpdateFunctionId, MirrorDate
)
SELECT MirrorId, PC1.PatientChangeGuid, FromPatientGuid, FromPatientSsn, FromSsnPseudoIndicator, FromPatientIcn, FromPatientLastName, FromPatientFirstName, FromPatientMIddleName, FromPatientDob,
	FromPatientDeathDate, FromPatientSexCode, ToPatientGuid, ToPatientSsn, ToSsnPseudoIndicator, ToPatientIcn, ToPatientLastName, ToPatientFirstName, ToPatientMIddleName, ToPatientDob, 
	ToPatientDeathDate, ToPatientSexCode, MergeFromVistaPatientId, MergeToVistaPatientId, PatientChangeStatusCode, PC2.LastUpdateDate, PC1.LastUpdateDate, LastUpdateUser, [RowVersion], 
	LastUpdateFunctionId, MirrorDate
FROM #tmpMirrorPatientChange PC1
	JOIN (SELECT PatientChangeGuid, MIN(LastUpdateDate) LastUpdateDate
		FROM #tmpMirrorPatientChange
		GROUP BY PatientChangeGuid) PC2
		ON PC1.PatientChangeGuid = PC2.PatientChangeGuid
GO

SET IDENTITY_INSERT PatientChange OFF
GO

DROP TABLE #tmpMirrorPatientChange
GO

/*****************************************************************************************
*	Create a temporary InterfaceControl Mirror table and save the original data
*****************************************************************************************/
if object_id(N'tempdb..#tmpMirrorInterfaceControl') IS NOT NULL
	DROP TABLE #tmpMirrorInterfaceControl
GO

CREATE TABLE #tmpMirrorInterfaceControl (
	MirrorId int NOT NULL ,
	InterfaceControlId int NOT NULL ,
	InterfaceName varchar (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	FieldSeparator char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	EncodingCharacters char (4) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	InterfaceApplicationId varchar (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	InterfaceFacilityId varchar (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	InterfacePortNumber int NULL ,
	InterfaceIPAddress char (15) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	InterfaceDomainName varchar (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
	VbecsApplicationId varchar (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	VbecsFacilityId varchar (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ProcessingId char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	VersionId varchar (8) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	ApplicationAckType char (2) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	VbecsPortNumber int NULL ,
	VbecsIPAddress char (15) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	AckTimeout int NOT NULL ,
	ReTransmitAttempts tinyint NOT NULL ,
	InterfaceAdministratorName varchar (90) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	PurgeSuccessfulMessage tinyint NOT NULL ,
	PurgeUnSuccessfulMessage tinyint NOT NULL ,
	LogEventsIndicator bit NOT NULL ,
	LastUpdateDate datetime NOT NULL ,
	LastUpdateUser varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[RowVersion] binary (8) NULL ,
	LastUpdateFunctionId int NOT NULL ,
	MirrorDate datetime NOT NULL 
)
GO

INSERT INTO #tmpMirrorInterfaceControl
SELECT MirrorId, InterfaceControlId, InterfaceName, FieldSeparator, EncodingCharacters, InterfaceApplicationId, InterfaceFacilityId, InterfacePortNumber, InterfaceIPAddress, InterfaceDomainName, 
	VbecsApplicationId, VbecsFacilityId, ProcessingId, VersionId, ApplicationAckType, VbecsPortNumber, VbecsIPAddress, AckTimeout, ReTransmitAttempts, InterfaceAdministratorName, 
	PurgeSuccessfulMessage, PurgeUnSuccessfulMessage, LogEventsIndicator, LastUpdateDate, LastUpdateUser, [RowVersion], LastUpdateFunctionId, MirrorDate
FROM InterfaceControl
GO


/*****************************************************************************************
* 	Create the new InterfaceControl Mirror table
*****************************************************************************************/

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.InterfaceControl') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table dbo.InterfaceControl
GO

CREATE TABLE dbo.InterfaceControl (
	MirrorId int IDENTITY (1, 1) NOT NULL ,
	InterfaceControlId int NOT NULL ,
	InterfaceId tinyint NOT NULL ,
	InterfaceFacilityId varchar (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	InterfacePortNumber int NULL ,
	InterfaceIPAddress char (15) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	InterfaceDomainName varchar (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	VbecsFacilityId varchar (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ProcessingId char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	VbecsPortNumber int NULL ,
	VbecsIPAddress char (15) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	AckTimeout int NOT NULL ,
	ReTransmitAttempts tinyint NOT NULL ,
	InterfaceAdministratorName varchar (90) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	PurgeSuccessfulMessage tinyint NOT NULL ,
	PurgeUnSuccessfulMessage tinyint NOT NULL ,
	LogEventsIndicator bit NOT NULL ,
	LastUpdateDate datetime NOT NULL ,
	LastUpdateUser varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[RowVersion] binary (8) NULL ,
	LastUpdateFunctionId int NOT NULL ,
	MirrorDate datetime NOT NULL 
) ON [PRIMARY]
GO


ALTER TABLE dbo.InterfaceControl
	ADD CONSTRAINT PK_InterfaceControl PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]

GO

/*****************************************************************************************
*	Reload the original InterfaceControl Mirror data into the updated table
*****************************************************************************************/

SET IDENTITY_INSERT InterfaceControl ON

INSERT INTO dbo.InterfaceControl
(
	MirrorId, InterfaceControlId, InterfaceId, InterfaceFacilityId, InterfacePortNumber, InterfaceIPAddress, InterfaceDomainName, VbecsFacilityId, ProcessingId, VbecsPortNumber, VbecsIPAddress, AckTimeout, ReTransmitAttempts, InterfaceAdministratorName, PurgeSuccessfulMessage, PurgeUnSuccessfulMessage, LogEventsIndicator, LastUpdateDate, LastUpdateUser, [RowVersion], LastUpdateFunctionId, MirrorDate
)
SELECT MirrorId, InterfaceControlId, InterfaceId, InterfaceFacilityId, InterfacePortNumber, InterfaceIPAddress, InterfaceDomainName, VbecsFacilityId, ProcessingId, VbecsPortNumber, VbecsIPAddress, AckTimeout, ReTransmitAttempts, InterfaceAdministratorName, PurgeSuccessfulMessage, PurgeUnSuccessfulMessage, LogEventsIndicator, T.LastUpdateDate, T.LastUpdateUser, T.[RowVersion], T.LastUpdateFunctionId, MirrorDate
FROM #tmpMirrorInterfaceControl T
	JOIN VBECS_V1_TEST.dbo.Interface I
		ON T.InterfaceName = I.InterfaceName
GO

SET IDENTITY_INSERT InterfaceControl OFF

DROP TABLE #tmpMirrorInterfaceControl
GO

USE VBECS_V1_TEST
/*****************************************************************************************
* 	Create the new PatientChange table
*****************************************************************************************/

ALTER TABLE dbo.PatientChange
	DROP CONSTRAINT PK_PatientChange
GO

DROP TRIGGER dbo.trMirrorPatientChange
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.PatientChange') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table dbo.PatientChange
GO

CREATE TABLE dbo.PatientChange (
	PatientChangeGuid uniqueidentifier NOT NULL ,
	FromPatientGuid uniqueidentifier NULL ,
	FromPatientSsn char (9) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromSsnPseudoIndicator bit NULL ,
	FromPatientIcn varchar (23) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientLastName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientFirstName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientMIddleName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	FromPatientDob datetime NULL ,
	FromPatientDeathDate datetime NULL ,
	FromPatientSexCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientGuid uniqueidentifier NULL ,
	ToPatientSsn char (9) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToSsnPseudoIndicator bit NULL ,
	ToPatientIcn varchar (23) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientLastName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientFirstName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientMIddleName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	ToPatientDob datetime NULL ,
	ToPatientDeathDate datetime NULL ,
	ToPatientSexCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	MergeFromVistaPatientId bigint NULL ,
	MergeToVistaPatientId bigint NULL ,
	PatientChangeStatusCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	NotificationReceivedDate datetime NOT NULL ,
	LastUpdateDate datetime NOT NULL ,
	LastUpdateUser varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[RowVersion] timestamp NOT NULL ,
	LastUpdateFunctionId int NOT NULL CONSTRAINT DF_PatientChange_LastUpdateFunctionId DEFAULT 0
) ON [PRIMARY]
GO

sp_addextendedproperty N'MS_Description', N'Identifies one patient change from VistA.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'PatientChangeGuid'
GO
sp_addextendedproperty N'MS_Description', N'A unique identifier for a patient generated by VBECS.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'FromPatientGuid'
GO
sp_addextendedproperty N'MS_Description', N'The social security number of the merge-from patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'FromPatientSsn'
GO
sp_addextendedproperty N'MS_Description', N'Indicates that a pseudo character, P, has been added to the SSN when displayed.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'FromSsnPseudoIndicator'
GO
sp_addextendedproperty N'MS_Description', N'An integration control number (ICN) for the patient inherited from the VistA system.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'FromPatientIcn'
GO
sp_addextendedproperty N'MS_Description', N'The last name of the patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'FromPatientLastName'
GO
sp_addextendedproperty N'MS_Description', N'The first name of the patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'FromPatientFirstName'
GO
sp_addextendedproperty N'MS_Description', N'The middle name of the patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'FromPatientMIddleName'
GO
sp_addextendedproperty N'MS_Description', N'The birth date of the patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'FromPatientDob'
GO
sp_addextendedproperty N'MS_Description', N'The date of death for a deceased patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'FromPatientDeathDate'
GO
sp_addextendedproperty N'MS_Description', N'The gender of the patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'FromPatientSexCode'
GO
sp_addextendedproperty N'MS_Description', N'A unique identifier for a patient generated by VBECS.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'ToPatientGuid'
GO
sp_addextendedproperty N'MS_Description', N'The social security number of the merge-to patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'ToPatientSsn'
GO
sp_addextendedproperty N'MS_Description', N'Indicates that a pseudo character, P, has been added to the SSN when displayed.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'ToSsnPseudoIndicator'
GO
sp_addextendedproperty N'MS_Description', N'An integration control number (ICN) for the patient inherited from the VistA system.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'ToPatientIcn'
GO
sp_addextendedproperty N'MS_Description', N'The last name of the patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'ToPatientLastName'
GO
sp_addextendedproperty N'MS_Description', N'The first name of the patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'ToPatientFirstName'
GO
sp_addextendedproperty N'MS_Description', N'The middle name of the patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'ToPatientMIddleName'
GO
sp_addextendedproperty N'MS_Description', N'The birth date of the patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'ToPatientDob'
GO
sp_addextendedproperty N'MS_Description', N'The date of death for a deceased patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'ToPatientDeathDate'
GO
sp_addextendedproperty N'MS_Description', N'The gender of the patient.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'ToPatientSexCode'
GO
sp_addextendedproperty N'MS_Description', N'The old patient ID in VistA in a merge.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'MergeFromVistaPatientId'
GO
sp_addextendedproperty N'MS_Description', N'The new patient ID in VistA in a merge.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'MergeToVistaPatientId'
GO
sp_addextendedproperty N'MS_Description', N'Describes a state of processing a patient merge or update.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'PatientChangeStatusCode'
GO
sp_addextendedproperty N'MS_Description', N'The date and time the notification record was processed in VBECS.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'NotificationReceivedDate'
GO
sp_addextendedproperty N'MS_Description', N'The date and time the record was last updated.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'LastUpdateDate'
GO
sp_addextendedproperty N'MS_Description', N'The logon id of the user who performed the last update.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'LastUpdateUser'
GO
sp_addextendedproperty N'MS_Description', N'This is used in the C# code as a mechanism for version-stamping table rows, which provides a means for concurrency control.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'RowVersion'
GO
sp_addextendedproperty N'MS_Description', N'The identifier of the VBECS function that performed the last update.', 'USER', N'dbo', 'TABLE', N'PatientChange', 'COLUMN', N'LastUpdateFunctionId'
GO

/*****************************************************************************************
*	Reload the original PatientChange data into the updated table
*****************************************************************************************/
INSERT INTO dbo.PatientChange
(
	PatientChangeGuid, FromPatientGuid, FromPatientSsn, FromSsnPseudoIndicator, FromPatientIcn, FromPatientLastName, FromPatientFirstName, FromPatientMIddleName, FromPatientDob,
	FromPatientDeathDate, FromPatientSexCode, ToPatientGuid, ToPatientSsn, ToSsnPseudoIndicator, ToPatientIcn, ToPatientLastName, ToPatientFirstName, ToPatientMIddleName, ToPatientDob, 
	ToPatientDeathDate, ToPatientSexCode, MergeFromVistaPatientId, MergeToVistaPatientId, PatientChangeStatusCode, NotificationReceivedDate, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
)
SELECT PatientChangeGuid, FromPatientGuid, FromPatientSsn, FromSsnPseudoIndicator, FromPatientIcn, FromPatientLastName, FromPatientFirstName, FromPatientMIddleName, FromPatientDob,
	FromPatientDeathDate, FromPatientSexCode, ToPatientGuid, ToPatientSsn, ToSsnPseudoIndicator, ToPatientIcn, ToPatientLastName, ToPatientFirstName, ToPatientMIddleName, ToPatientDob, 
	ToPatientDeathDate, ToPatientSexCode, MergeFromVistaPatientId, MergeToVistaPatientId, PatientChangeStatusCode, NotificationReceivedDate, LastUpdateDate, LastUpdateUser, ISNULL(LastUpdateFunctionId, 0)
FROM #tmpPatientChange
GO

DROP TABLE #tmpPatientChange
GO


/*****************************************************************************************
*	Add the PatientChange constraints
*****************************************************************************************/
GO

ALTER TABLE dbo.PatientChange 
	ADD CONSTRAINT PK_PatientChange PRIMARY KEY CLUSTERED 
	(
		PatientChangeGuid
	) WITH FILLFACTOR=90 ON [PRIMARY]
GO

/*****************************************************************************************
   Apply the changes to the PatientChange table to allow NULL in the FromPatientGuid
   and ToPatientGuid columns.
*****************************************************************************************/
CREATE NONCLUSTERED INDEX IX_PatientChange_FromPatientGuid ON dbo.PatientChange (FromPatientGuid) WITH FILLFACTOR=90 ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX IX_PatientChange_ToPatientGuid ON dbo.PatientChange (ToPatientGuid) WITH FILLFACTOR=90 ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX IX_PatientChange_PatientChangeStatusCode ON dbo.PatientChange (PatientChangeStatusCode) WITH FILLFACTOR=90 ON [PRIMARY]
GO

ALTER TABLE dbo.PatientChange
	ADD CONSTRAINT FK_PatientChange_PatientChangeStatus FOREIGN KEY 
	(
		PatientChangeStatusCode
	) 
	REFERENCES dbo.PatientChangeStatus 
	(
		PatientChangeStatusCode
	)
GO

CREATE TRIGGER dbo.trMirrorPatientChange
ON dbo.PatientChange
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientChange
	SELECT *, GETUTCDATE()
	FROM DELETED
END
GO

/*****************************************************************************************
* 	Create the updated InterfaceControl table
*****************************************************************************************/

ALTER TABLE dbo.MessageType
	DROP CONSTRAINT FK_MessageType_InterfaceControl
GO
ALTER TABLE dbo.MessageLog
	DROP CONSTRAINT FK_MessageLog_InterfaceControl
GO

ALTER TABLE dbo.InterfaceControl
	DROP CONSTRAINT PK_InterfaceControl,
	     CONSTRAINT DF_InterfaceControl_AckTimeout,
	     CONSTRAINT DF_InterfaceControl_ReTransmitAttempts,
	     CONSTRAINT DF_InterfaceControl_PurgeSuccessfulMessage,
	     CONSTRAINT DF_InterfaceControl_PurgeUnSuccessfulMessage,
	     CONSTRAINT DF_InterfaceControl_LogEventsIndicator,
	     CONSTRAINT DF_InterfaceControl_LastUpdateFunctionId
GO

DROP TRIGGER dbo.trMirrorInterfaceControl
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.InterfaceControl') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
DROP TABLE dbo.InterfaceControl
GO

CREATE TABLE dbo.InterfaceControl
(
	InterfaceControlId int NOT NULL,
	InterfaceId tinyint NOT NULL,
	InterfaceFacilityId varchar (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
	InterfacePortNumber int NULL,
	InterfaceIPAddress char (15) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
	InterfaceDomainName varchar (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
	VbecsFacilityId varchar (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
	ProcessingId char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	VbecsPortNumber int NULL,
	VbecsIPAddress char (15) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
	AckTimeout int NOT NULL CONSTRAINT DF_InterfaceControl_AckTimeout DEFAULT (10),
	ReTransmitAttempts tinyint NOT NULL CONSTRAINT DF_InterfaceControl_ReTransmitAttempts DEFAULT (5),
	InterfaceAdministratorName varchar (90) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	PurgeSuccessfulMessage tinyint NOT NULL CONSTRAINT DF_InterfaceControl_PurgeSuccessfulMessage DEFAULT (7),
	PurgeUnSuccessfulMessage tinyint NOT NULL CONSTRAINT DF_InterfaceControl_PurgeUnSuccessfulMessage DEFAULT (7),
	LogEventsIndicator bit NOT NULL CONSTRAINT DF_InterfaceControl_LogEventsIndicator DEFAULT (1),
	LastUpdateDate datetime NOT NULL,
	LastUpdateUser varchar(30) NOT NULL,
	[RowVersion] timestamp NOT NULL,
	LastUpdateFunctionId int NOT NULL CONSTRAINT DF_InterfaceControl_LastUpdateFunctionId DEFAULT 0
)  ON [PRIMARY]
GO

sp_addextendedproperty N'MS_Description', N'Identifies a specific interface control record.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'InterfaceControlId'
GO
sp_addextendedproperty N'MS_Description', N'Identifies a specific interface in VBECS.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'InterfaceId'
GO
sp_addextendedproperty N'MS_Description', N'The division number of the Sending Application', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'InterfaceFacilityId'
GO
sp_addextendedproperty N'MS_Description', N'The port number of the Sending Application.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'InterfacePortNumber'
GO
sp_addextendedproperty N'MS_Description', N'The IP address of the Sending Application.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'InterfaceIPAddress'
GO
sp_addextendedproperty N'MS_Description', N'The fully qualified server name of the Sending Application.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'InterfaceDomainName'
GO
sp_addextendedproperty N'MS_Description', N'The division number of the Receiving Application.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'VbecsFacilityId'
GO
sp_addextendedproperty N'MS_Description', N'The TCP/IP Port Number for the VBECS interface.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'VbecsPortNumber'
GO
sp_addextendedproperty N'MS_Description', N'Identifies the current status of the interface.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'ProcessingId'
GO
sp_addextendedproperty N'MS_Description', N'The IP address of the VBECS interface.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'VbecsIPAddress'
GO
sp_addextendedproperty N'MS_Description', N'The elapsed time of no activity, in seconds, that will cause the application to drop the interface connection.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'AckTimeout'
GO
sp_addextendedproperty N'MS_Description', N'The number of times the interface will attempt to retransmit a message before it quits.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'ReTransmitAttempts'
GO
sp_addextendedproperty N'MS_Description', N'The name of the interface administrator.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'InterfaceAdministratorName'
GO
sp_addextendedproperty N'MS_Description', N'The Purge criteria for successful HL7 messages.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'PurgeSuccessfulMessage'
GO
sp_addextendedproperty N'MS_Description', N'The Purge criteria for unsuccessful HL7 messages.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'PurgeUnSuccessfulMessage'
GO
sp_addextendedproperty N'MS_Description', N'Indicates whether the interface will enter events in the event log.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'LogEventsIndicator'
GO
sp_addextendedproperty N'MS_Description', N'The date and time the record was last updated.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'LastUpdateDate'
GO
sp_addextendedproperty N'MS_Description', N'The logon id of the user who performed the last update.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'LastUpdateUser'
GO
sp_addextendedproperty N'MS_Description', N'This is used in the C# code as a mechanism for version-stamping table rows, which provides a means for concurrency control.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'RowVersion'
GO
sp_addextendedproperty N'MS_Description', N'The identifier of the VBECS function that performed the last update.', 'USER', N'dbo', 'TABLE', N'InterfaceControl', 'COLUMN', N'LastUpdateFunctionId'
GO

/*****************************************************************************************
*	Reload the original InterfaceControl data into the updated table
*****************************************************************************************/
INSERT INTO dbo.InterfaceControl
(
	InterfaceControlId, InterfaceId, InterfaceFacilityId, InterfacePortNumber, InterfaceIPAddress, InterfaceDomainName, VbecsFacilityId, ProcessingId, VbecsPortNumber, VbecsIPAddress, AckTimeout, ReTransmitAttempts, InterfaceAdministratorName, PurgeSuccessfulMessage, PurgeUnSuccessfulMessage, LogEventsIndicator, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
)
SELECT InterfaceControlId, InterfaceId, InterfaceFacilityId, InterfacePortNumber, InterfaceIPAddress, InterfaceDomainName, VbecsFacilityId, ProcessingId, VbecsPortNumber, VbecsIPAddress, AckTimeout, ReTransmitAttempts, InterfaceAdministratorName, PurgeSuccessfulMessage, PurgeUnSuccessfulMessage, LogEventsIndicator, T.LastUpdateDate, T.LastUpdateUser, T.LastUpdateFunctionId
FROM #tmpInterfaceControl T
	JOIN VBECS_V1_TEST.dbo.Interface I
		ON T.InterfaceName = I.InterfaceName
GO

DROP TABLE #tmpInterfaceControl
GO


/*****************************************************************************************
*	Add the InterfaceControl constraints
*****************************************************************************************/
GO
ALTER TABLE dbo.InterfaceControl 
	ADD CONSTRAINT PK_InterfaceControl PRIMARY KEY CLUSTERED 
	(
		InterfaceControlId
	)  WITH FILLFACTOR = 90 ON [PRIMARY]

GO

ALTER TABLE dbo.MessageLog WITH NOCHECK 
	ADD CONSTRAINT FK_MessageLog_InterfaceControl FOREIGN KEY
	(
		InterfaceControlId
	) 
	REFERENCES dbo.InterfaceControl
	(
		InterfaceControlId
	)
GO

ALTER TABLE dbo.MessageType WITH NOCHECK 
	ADD CONSTRAINT FK_MessageType_InterfaceControl FOREIGN KEY
	(
		InterfaceControlId
	) 
	REFERENCES dbo.InterfaceControl
	(
		InterfaceControlId
	)
GO

ALTER TABLE dbo.InterfaceControl  
	ADD CONSTRAINT FK_InterfaceControl_Interface FOREIGN KEY
	(
		InterfaceId
	) 
	REFERENCES dbo.Interface
	(
		InterfaceId
	)
GO
CREATE NONCLUSTERED INDEX IX_InterfaceControl_InterfaceId ON dbo.InterfaceControl (InterfaceId) WITH FILLFACTOR=90 ON [PRIMARY]
GO

/*****************************************************************************************
*	Recreate the InterfaceControl mirror trigger
*****************************************************************************************/
GO
CREATE TRIGGER dbo.trMirrorInterfaceControl
ON dbo.InterfaceControl
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.InterfaceControl
	SELECT *, GETUTCDATE()
	FROM DELETED
END
GO

/*****************************************************************************************
*	Add the missing defaults to the LastUpdateFunctionId field
*****************************************************************************************/
UPDATE dbo.AntibodyAntigen
   SET LastUpdateFunctionId = 0
 WHERE LastUpdateFunctionId IS NULL

ALTER TABLE dbo.AntibodyAntigen
	ALTER COLUMN LastUpdateFunctionId int NOT NULL

ALTER TABLE dbo.AntibodyAntigen
	ADD CONSTRAINT DF_AntibodyAntigen_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO
UPDATE dbo.BloodProduct
   SET LastUpdateFunctionId = 0
 WHERE LastUpdateFunctionId IS NULL

ALTER TABLE dbo.BloodProduct
	ALTER COLUMN LastUpdateFunctionId int NOT NULL

ALTER TABLE dbo.BloodProduct
	ADD CONSTRAINT DF_BloodProduct_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO
UPDATE dbo.BloodTestType
   SET LastUpdateFunctionId = 0
 WHERE LastUpdateFunctionId IS NULL

ALTER TABLE dbo.BloodTestType
	ALTER COLUMN LastUpdateFunctionId int NOT NULL

ALTER TABLE dbo.BloodTestType
	ADD CONSTRAINT DF_BloodTestType_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO
ALTER TABLE dbo.DailyQcWorklist DISABLE TRIGGER trMirrorDailyQcWorklist

UPDATE dbo.DailyQcWorklist
   SET LastUpdateFunctionId = 0
 WHERE LastUpdateFunctionId IS NULL

ALTER TABLE dbo.DailyQcWorklist ENABLE TRIGGER trMirrorDailyQcWorklist

ALTER TABLE dbo.DailyQcWorklist
	ALTER COLUMN LastUpdateFunctionId int NOT NULL

ALTER TABLE dbo.DailyQcWorklist
	ADD CONSTRAINT DF_DailyQcWorklist_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO
ALTER TABLE dbo.MessageStatus DISABLE TRIGGER trMirrorMessageStatus

UPDATE dbo.MessageStatus
   SET LastUpdateFunctionId = 0
 WHERE LastUpdateFunctionId IS NULL

ALTER TABLE dbo.MessageStatus ENABLE TRIGGER trMirrorMessageStatus

ALTER TABLE dbo.MessageStatus
	ALTER COLUMN LastUpdateFunctionId int NOT NULL

ALTER TABLE dbo.MessageStatus
	ADD CONSTRAINT DF_MessageStatus_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO
ALTER TABLE dbo.PatientChangeStatus
	ALTER COLUMN LastUpdateFunctionId int NOT NULL

ALTER TABLE dbo.PatientChangeStatus
	ADD CONSTRAINT DF_PatientChangeStatus_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO
ALTER TABLE dbo.ProductAttribute
	ADD CONSTRAINT DF_ProductAttribute_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO
UPDATE dbo.ScheduledReport
   SET LastUpdateFunctionId = 0
 WHERE LastUpdateFunctionId IS NULL

ALTER TABLE dbo.ScheduledReport
	ALTER COLUMN LastUpdateFunctionId int NOT NULL

ALTER TABLE dbo.ScheduledReport
	ADD CONSTRAINT DF_ScheduledReport_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO
ALTER TABLE dbo.SupplyType DISABLE TRIGGER trMirrorSupplyType

UPDATE dbo.SupplyType
   SET LastUpdateFunctionId = 0
 WHERE LastUpdateFunctionId IS NULL

ALTER TABLE dbo.SupplyType ENABLE TRIGGER trMirrorSupplyType

ALTER TABLE dbo.SupplyType
	ALTER COLUMN LastUpdateFunctionId int NOT NULL

ALTER TABLE dbo.SupplyType
	ADD CONSTRAINT DF_SupplyType_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO
ALTER TABLE dbo.TransfusionReaction DISABLE TRIGGER trMirrorTransfusionReaction

UPDATE dbo.TransfusionReaction
   SET LastUpdateFunctionId = 0
 WHERE LastUpdateFunctionId IS NULL

ALTER TABLE dbo.TransfusionReaction ENABLE TRIGGER trMirrorTransfusionReaction

ALTER TABLE dbo.TransfusionReaction
	ALTER COLUMN LastUpdateFunctionId int NOT NULL

ALTER TABLE dbo.TransfusionReaction
	ADD CONSTRAINT DF_TransfusionReaction_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO
ALTER TABLE dbo.WorkloadEventStatus
	ADD CONSTRAINT DF_WorkloadEventStatus_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO
UPDATE dbo.VistaCache
   SET LastUpdateFunctionId = 0
 WHERE LastUpdateFunctionId IS NULL

ALTER TABLE dbo.VistaCache
	ALTER COLUMN LastUpdateFunctionId int NOT NULL

ALTER TABLE dbo.VistaCache
	ADD CONSTRAINT DF_VistaCache_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO

ALTER TABLE dbo.VistaLinkControl
	ADD CONSTRAINT DF_VistaLinkControl_LastUpdateFunctionId
		DEFAULT 0 FOR LastUpdateFunctionId
GO

/*****************************************************************************************
*	Changes to increase patient name from varchar 20 to varchar 30 
*****************************************************************************************/
DROP INDEX dbo.Patient.IX_Patient_LastName
GO

ALTER TABLE dbo.Patient ALTER COLUMN PatientLastName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL
ALTER TABLE dbo.Patient ALTER COLUMN PatientFirstName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL
ALTER TABLE dbo.Patient ALTER COLUMN PatientMiddleName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
GO

CREATE NONCLUSTERED INDEX IX_Patient_LastName ON dbo.Patient (PatientLastName) WITH FILLFACTOR=90 ON [PRIMARY]
GO

/*****************************************************************************************
*	Add dbo to all the triggers
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorAddress]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorAddress
GO
CREATE TRIGGER dbo.trMirrorAddress
ON dbo.Address
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.Address
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorAntibodyParameter]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorAntibodyParameter
GO
CREATE TRIGGER dbo.trMirrorAntibodyParameter
ON dbo.AntibodyParameter
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.AntibodyParameter
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorAntigenTest]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorAntigenTest
GO
CREATE TRIGGER dbo.trMirrorAntigenTest
ON dbo.AntigenTest
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.AntigenTest
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorAntigenType]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorAntigenType
GO
CREATE TRIGGER dbo.trMirrorAntigenType
ON dbo.AntigenType
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.AntigenType
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorAntiseraOrderedTest]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorAntiseraOrderedTest
GO
CREATE TRIGGER dbo.trMirrorAntiseraOrderedTest
ON dbo.AntiseraOrderedTest
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.AntiseraOrderedTest
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorAntiseraUnitTest]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorAntiseraUnitTest
GO
CREATE TRIGGER dbo.trMirrorAntiseraUnitTest
ON dbo.AntiseraUnitTest
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.AntiseraUnitTest
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorAntiseraWorklist]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorAntiseraWorklist
GO
CREATE TRIGGER dbo.trMirrorAntiseraWorklist
ON dbo.AntiseraWorklist
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.AntiseraWorklist
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorAntiseraWorklistTyping]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorAntiseraWorklistTyping
GO
CREATE TRIGGER dbo.trMirrorAntiseraWorklistTyping
ON dbo.AntiseraWorklistTyping
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.AntiseraWorklistTyping
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorAssociatedInstitution]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorAssociatedInstitution
GO
CREATE TRIGGER dbo.trMirrorAssociatedInstitution
ON dbo.AssociatedInstitution
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.AssociatedInstitution
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trBloodUnitInsert]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trBloodUnitInsert
GO
CREATE TRIGGER dbo.trBloodUnitInsert
ON dbo.BloodUnit
FOR INSERT
AS
INSERT INTO dbo.BloodUnitCurrentShipment
(
    BloodUnitCurrentShipmentGuid, 
    BloodUnitGuid, 
    IncomingShipmentGuid, 
    OutgoingShipmentGuid, 
    LastUpdateDate, 
    LastUpdateUser, 
    LastUpdateFunctionId
)
SELECT 
    NEWID(), 
    BloodUnitGuid, 
    NULL, 
    NULL, 
    LastUpdateDate, 
    LastUpdateUser, 
    LastUpdateFunctionId
FROM 
    inserted



GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorBloodUnit]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorBloodUnit
GO
CREATE TRIGGER dbo.trMirrorBloodUnit
ON dbo.BloodUnit
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.BloodUnit
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorBloodUnitAntigen]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorBloodUnitAntigen
GO
CREATE TRIGGER dbo.trMirrorBloodUnitAntigen
ON dbo.BloodUnitAntigen
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.BloodUnitAntigen
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorBloodUnitCurrentShipment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorBloodUnitCurrentShipment
GO
CREATE TRIGGER dbo.trMirrorBloodUnitCurrentShipment
ON dbo.BloodUnitCurrentShipment
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.BloodUnitCurrentShipment
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorBloodUnitFinance]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorBloodUnitFinance
GO
CREATE TRIGGER dbo.trMirrorBloodUnitFinance
ON dbo.BloodUnitFinance
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.BloodUnitFinance
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorBloodUnitMedia]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorBloodUnitMedia
GO
CREATE TRIGGER dbo.trMirrorBloodUnitMedia
ON dbo.BloodUnitMedia
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.BloodUnitMedia
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorBloodUnitModification]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorBloodUnitModification
GO
CREATE TRIGGER dbo.trMirrorBloodUnitModification
ON dbo.BloodUnitModification
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.BloodUnitModification
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trBloodUnitShipmentUpdateCurrentShipment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trBloodUnitShipmentUpdateCurrentShipment
GO
CREATE TRIGGER dbo.trBloodUnitShipmentUpdateCurrentShipment 
ON dbo.BloodUnitShipment
FOR INSERT, UPDATE, DELETE
AS
UPDATE
	dbo.BloodUnitCurrentShipment
SET
	IncomingShipmentGuid = 
		(
			SELECT TOP 1 
					IncomingShipmentGuid 
			FROM
					dbo.BloodUnitShipment
			WHERE
					IncomingShipmentGuid IS NOT NULL 
				AND BloodUnitShipment.RecordStatusCode IN ('A','M')
				AND BloodUnitShipment.BloodUnitGuid = AffectedRecords.BloodUnitGuid 
			ORDER BY
					BloodUnitShipment.LastUpdateDate DESC
		),
	OutgoingShipmentGuid = 
		(
			SELECT TOP 1 
					OutgoingShipmentGuid 
			FROM
					dbo.BloodUnitShipment
			WHERE
					OutgoingShipmentGuid IS NOT NULL 
				AND BloodUnitShipment.RecordStatusCode IN ('A')
				AND BloodUnitShipment.BloodUnitGuid = AffectedRecords.BloodUnitGuid 
			ORDER BY
					BloodUnitShipment.LastUpdateDate DESC
		)
FROM
	( 
		SELECT BloodUnitGuid FROM inserted 
		UNION 
		SELECT BloodUnitGuid FROM deleted 
	) AS AffectedRecords
WHERE
	BloodUnitCurrentShipment.BloodUnitGuid = AffectedRecords.BloodUnitGuid




GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorBloodUnitShipment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorBloodUnitShipment
GO
CREATE TRIGGER dbo.trMirrorBloodUnitShipment
ON dbo.BloodUnitShipment
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.BloodUnitShipment
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorBloodUnitStatus]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorBloodUnitStatus
GO
CREATE TRIGGER dbo.trMirrorBloodUnitStatus
ON dbo.BloodUnitStatus
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.BloodUnitStatus
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorBloodUnitTest]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorBloodUnitTest
GO
CREATE TRIGGER dbo.trMirrorBloodUnitTest
ON dbo.BloodUnitTest
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.BloodUnitTest
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorCannedComment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorCannedComment
GO
CREATE TRIGGER dbo.trMirrorCannedComment
ON dbo.CannedComment
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.CannedComment
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorComponentClassCompatibility]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorComponentClassCompatibility
GO
CREATE TRIGGER dbo.trMirrorComponentClassCompatibility
ON dbo.ComponentClassCompatibility
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ComponentClassCompatibility
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorComponentClassParameter]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorComponentClassParameter
GO
CREATE TRIGGER dbo.trMirrorComponentClassParameter
ON dbo.ComponentClassParameter
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ComponentClassParameter
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorComponentRequirement]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorComponentRequirement
GO
CREATE TRIGGER dbo.trMirrorComponentRequirement
ON dbo.ComponentRequirement
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ComponentRequirement
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorConfirmationWorklistUnit]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorConfirmationWorklistUnit
GO
CREATE TRIGGER dbo.trMirrorConfirmationWorklistUnit
ON dbo.ConfirmationWorklistUnit
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ConfirmationWorklistUnit
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorDailyControl]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorDailyControl
GO
CREATE TRIGGER dbo.trMirrorDailyControl
ON dbo.DailyControl
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.DailyControl
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorDailyQcWorklist]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorDailyQcWorklist
GO
CREATE TRIGGER dbo.trMirrorDailyQcWorklist
ON dbo.DailyQcWorklist
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.DailyQcWorklist
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorDaylightSavingsType]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorDaylightSavingsType
GO
CREATE TRIGGER dbo.trMirrorDaylightSavingsType 
ON dbo.DaylightSavingsType
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.DaylightSavingsType 
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorEquipment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorEquipment
GO
CREATE TRIGGER dbo.trMirrorEquipment
ON dbo.Equipment
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.Equipment
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorEquipmentMaintenance]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorEquipmentMaintenance
GO
CREATE TRIGGER dbo.trMirrorEquipmentMaintenance
ON dbo.EquipmentMaintenance
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.EquipmentMaintenance
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorExceptionType]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorExceptionType
GO
CREATE TRIGGER dbo.trMirrorExceptionType
ON dbo.ExceptionType
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ExceptionType
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorHcpcsAssignment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorHcpcsAssignment
GO
CREATE TRIGGER dbo.trMirrorHcpcsAssignment
ON dbo.HcpcsAssignment
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.HcpcsAssignment
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorHemolysisInspection]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorHemolysisInspection
GO
CREATE TRIGGER dbo.trMirrorHemolysisInspection
ON dbo.HemolysisInspection
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.HemolysisInspection
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorInformationMessage]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorInformationMessage
GO
CREATE TRIGGER dbo.trMirrorInformationMessage
ON dbo.InformationMessage
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.InformationMessage
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorIssuedUnit]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorIssuedUnit
GO
CREATE TRIGGER dbo.trMirrorIssuedUnit
ON dbo.IssuedUnit
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.IssuedUnit
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorIssuedUnitComment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorIssuedUnitComment
GO
CREATE TRIGGER dbo.trMirrorIssuedUnitComment
ON dbo.IssuedUnitComment
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.IssuedUnitComment
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorLocalSupplier]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorLocalSupplier
GO
CREATE TRIGGER dbo.trMirrorLocalSupplier
ON dbo.LocalSupplier
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.LocalSupplier
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorLoginMessage]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorLoginMessage
GO
CREATE TRIGGER dbo.trMirrorLoginMessage
ON dbo.LoginMessage
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.LoginMessage
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorMessageStatus]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorMessageStatus
GO
CREATE TRIGGER dbo.trMirrorMessageStatus
ON dbo.MessageStatus
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.MessageStatus
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorModificationEquipment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorModificationEquipment
GO
CREATE TRIGGER dbo.trMirrorModificationEquipment
ON dbo.ModificationEquipment
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ModificationEquipment
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorModificationSupply]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorModificationSupply
GO
CREATE TRIGGER dbo.trMirrorModificationSupply
ON dbo.ModificationSupply
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ModificationSupply
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorMsbos]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorMsbos
GO
CREATE TRIGGER dbo.trMirrorMsbos
ON dbo.Msbos
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.Msbos
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorMsbosComponentClass]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorMsbosComponentClass
GO
CREATE TRIGGER dbo.trMirrorMsbosComponentClass
ON dbo.MsbosComponentClass
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.MsbosComponentClass
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorOrderAlertType]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorOrderAlertType
GO
CREATE TRIGGER dbo.trMirrorOrderAlertType
ON dbo.OrderAlertType
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.OrderAlertType
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorOrderedComponent]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorOrderedComponent
GO
CREATE TRIGGER dbo.trMirrorOrderedComponent
ON dbo.OrderedComponent
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.OrderedComponent
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorOrderedTest]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorOrderedTest
GO
CREATE TRIGGER dbo.trMirrorOrderedTest
ON dbo.OrderedTest
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.OrderedTest
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorOrderedUnit]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorOrderedUnit
GO
CREATE TRIGGER dbo.trMirrorOrderedUnit
ON dbo.OrderedUnit
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.OrderedUnit
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorOrderedUnitComment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorOrderedUnitComment
GO
CREATE TRIGGER dbo.trMirrorOrderedUnitComment
ON dbo.OrderedUnitComment
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.OrderedUnitComment
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatient]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatient
GO
CREATE TRIGGER dbo.trMirrorPatient
ON dbo.Patient
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.Patient
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientChangeStatus]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientChangeStatus
GO
CREATE TRIGGER dbo.trMirrorPatientChangeStatus
ON dbo.PatientChangeStatus
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientChangeStatus
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientOrder]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientOrder
GO
CREATE TRIGGER dbo.trMirrorPatientOrder
ON dbo.PatientOrder
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientOrder
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientSpecialInstruction]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientSpecialInstruction
GO
CREATE TRIGGER dbo.trMirrorPatientSpecialInstruction
ON dbo.PatientSpecialInstruction
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientSpecialInstruction
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientSpecimen]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientSpecimen
GO
CREATE TRIGGER dbo.trMirrorPatientSpecimen
ON dbo.PatientSpecimen
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientSpecimen
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientSymptom]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientSymptom
GO
CREATE TRIGGER dbo.trMirrorPatientSymptom
ON dbo.PatientSymptom
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientSymptom
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientTest]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientTest
GO
CREATE TRIGGER dbo.trMirrorPatientTest
ON dbo.PatientTest
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientTest
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientTransfusion]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientTransfusion
GO
CREATE TRIGGER dbo.trMirrorPatientTransfusion
ON dbo.PatientTransfusion
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientTransfusion
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientTransfusionComment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientTransfusionComment
GO
CREATE TRIGGER dbo.trMirrorPatientTransfusionComment
ON dbo.PatientTransfusionComment
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientTransfusionComment
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientTransfusionReaction]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientTransfusionReaction
GO
CREATE TRIGGER dbo.trMirrorPatientTransfusionReaction
ON dbo.PatientTransfusionReaction
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientTransfusionReaction
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientTransfusionReactionSymptom]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientTransfusionReactionSymptom
GO
CREATE TRIGGER dbo.trMirrorPatientTransfusionReactionSymptom
ON dbo.PatientTransfusionReactionSymptom
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientTransfusionReactionSymptom
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientTransfusionRequirement]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientTransfusionRequirement
GO
CREATE TRIGGER dbo.trMirrorPatientTransfusionRequirement
ON dbo.PatientTransfusionRequirement
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientTransfusionRequirement
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPatientTreatment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPatientTreatment
GO
CREATE TRIGGER dbo.trMirrorPatientTreatment
ON dbo.PatientTreatment
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PatientTreatment
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorPermittedProductModification]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorPermittedProductModification
GO
CREATE TRIGGER dbo.trMirrorPermittedProductModification
ON dbo.PermittedProductModification
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.PermittedProductModification
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorProductModification]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorProductModification
GO
CREATE TRIGGER dbo.trMirrorProductModification
ON dbo.ProductModification
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ProductModification
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorProductModificationParameter]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorProductModificationParameter
GO
CREATE TRIGGER dbo.trMirrorProductModificationParameter
ON dbo.ProductModificationParameter
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ProductModificationParameter
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorProductShipper]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorProductShipper
GO
CREATE TRIGGER dbo.trMirrorProductShipper
ON dbo.ProductShipper
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ProductShipper
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorRack]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorRack
GO
CREATE TRIGGER dbo.trMirrorRack
ON dbo.Rack
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.Rack
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorRackLot]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorRackLot
GO
CREATE TRIGGER dbo.trMirrorRackLot
ON dbo.RackLot
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.RackLot
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorRackTest]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorRackTest
GO
CREATE TRIGGER dbo.trMirrorRackTest
ON dbo.RackTest
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.RackTest
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorReagent]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorReagent
GO
CREATE TRIGGER dbo.trMirrorReagent
ON dbo.Reagent
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.Reagent
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorReagentChange]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorReagentChange
GO
CREATE TRIGGER dbo.trMirrorReagentChange
ON dbo.ReagentChange
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ReagentChange
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorReagentTestParameter]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorReagentTestParameter
GO
CREATE TRIGGER dbo.trMirrorReagentTestParameter
ON dbo.ReagentTestParameter
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ReagentTestParameter
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorReagentTypeParameter]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorReagentTypeParameter
GO
CREATE TRIGGER dbo.trMirrorReagentTypeParameter
ON dbo.ReagentTypeParameter
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ReagentTypeParameter
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorReOrderTest]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorReOrderTest
GO
CREATE TRIGGER dbo.trMirrorReOrderTest
ON dbo.ReOrderTest
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.ReOrderTest
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorRestrictionType]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorRestrictionType
GO
CREATE TRIGGER dbo.trMirrorRestrictionType
ON dbo.RestrictionType
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.RestrictionType
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorShipment]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorShipment
GO
CREATE TRIGGER dbo.trMirrorShipment
ON dbo.Shipment
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.Shipment
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorSpecimenTest]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorSpecimenTest
GO
CREATE TRIGGER dbo.trMirrorSpecimenTest
ON dbo.SpecimenTest
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.SpecimenTest
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorSpecimenTestThreshold]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorSpecimenTestThreshold
GO
CREATE TRIGGER dbo.trMirrorSpecimenTestThreshold
ON dbo.SpecimenTestThreshold
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.SpecimenTestThreshold
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorSupply]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorSupply
GO
CREATE TRIGGER dbo.trMirrorSupply
ON dbo.Supply
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.Supply
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorSupplyType]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorSupplyType
GO
CREATE TRIGGER dbo.trMirrorSupplyType
ON dbo.SupplyType
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.SupplyType
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorTimeZone]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorTimeZone
GO
CREATE TRIGGER dbo.trMirrorTimeZone
ON dbo.TimeZone
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.TimeZone
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorTransfusionReaction]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorTransfusionReaction
GO
CREATE TRIGGER dbo.trMirrorTransfusionReaction
ON dbo.TransfusionReaction
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.TransfusionReaction
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorTreatingSpecialty]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorTreatingSpecialty
GO
CREATE TRIGGER dbo.trMirrorTreatingSpecialty
ON dbo.TreatingSpecialty
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.TreatingSpecialty
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorVamcDivision]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorVamcDivision
GO
CREATE TRIGGER dbo.trMirrorVamcDivision
ON dbo.VamcDivision
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.VamcDivision
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorVbecsProcess]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorVbecsProcess
GO
CREATE TRIGGER dbo.trMirrorVbecsProcess
ON dbo.VbecsProcess
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.VbecsProcess
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorVbecsUser]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorVbecsUser
GO
CREATE TRIGGER dbo.trMirrorVbecsUser
ON dbo.VbecsUser
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.VbecsUser
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorVbecsUserDivisionRole]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorVbecsUserDivisionRole
GO
CREATE TRIGGER dbo.trMirrorVbecsUserDivisionRole
ON dbo.VbecsUserDivisionRole
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.VbecsUserDivisionRole
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorVistaLinkControl]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorVistaLinkControl
GO
CREATE TRIGGER dbo.trMirrorVistaLinkControl
ON dbo.VistaLinkControl
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.VistaLinkControl
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorWorkloadEvent]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorWorkloadEvent
GO
CREATE TRIGGER dbo.trMirrorWorkloadEvent
ON dbo.WorkloadEvent
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.WorkloadEvent
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorWorkloadEventStatus]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorWorkloadEventStatus
GO
CREATE TRIGGER dbo.trMirrorWorkloadEventStatus
ON dbo.WorkloadEventStatus
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.WorkloadEventStatus
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trMirrorWorkloadProcess]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger dbo.trMirrorWorkloadProcess
GO
CREATE TRIGGER dbo.trMirrorWorkloadProcess
ON dbo.WorkloadProcess
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_TEST_MIRROR.dbo.WorkloadProcess
	SELECT *, GETUTCDATE()
	FROM DELETED
END


GO


USE VBECS_V1_TEST_MIRROR

/*****************************************************************************************
*	Changes to increase patient name from varchar 20 to varchar 30 
*****************************************************************************************/

ALTER TABLE dbo.Patient ALTER COLUMN PatientLastName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL
ALTER TABLE dbo.Patient ALTER COLUMN PatientFirstName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL
ALTER TABLE dbo.Patient ALTER COLUMN PatientMiddleName varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
GO

/*****************************************************************************************
*	Add the primary keys and indexes to the mirror tables
*****************************************************************************************/
ALTER TABLE dbo.Address 
	ADD CONSTRAINT PK_Address PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.AntibodyParameter.IX_AntibodyParameter_MirrorId
GO
ALTER TABLE dbo.AntibodyParameter 
	ADD CONSTRAINT PK_AntibodyParameter PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.AntigenTest 
	ADD CONSTRAINT PK_AntigenTest PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.AntigenType 
	ADD CONSTRAINT PK_AntigenType PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.AntiseraOrderedTest 
	ADD CONSTRAINT PK_AntiseraOrderedTest PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.AntiseraUnitTest 
	ADD CONSTRAINT PK_AntiseraUnitTest PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.AntiseraWorklist 
	ADD CONSTRAINT PK_AntiseraWorklist PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.AntiseraWorklistTyping 
	ADD CONSTRAINT PK_AntiseraWorklistTyping PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.AssociatedInstitution 
	ADD CONSTRAINT PK_AssociatedInstitution PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO
if not exists (select * from sysindexes
  		where id=object_id('dbo.AssociatedInstitution') and name='IX_AssociatedInstitution')
CREATE CLUSTERED INDEX IX_AssociatedInstitution ON dbo.AssociatedInstitution (AssociatedInstitutionGuid) WITH FILLFACTOR=80 ON [PRIMARY]
GO
if not exists (select * from sysindexes
  		where id=object_id('dbo.AssociatedInstitution') and name='IX_AssociatedInstitution_DivisionCode')
CREATE NONCLUSTERED INDEX IX_AssociatedInstitution_DivisionCode ON dbo.AssociatedInstitution (DivisionCode) WITH FILLFACTOR=80 ON [PRIMARY]
GO
if not exists (select * from sysindexes
  		where id=object_id('dbo.AssociatedInstitution') and name='IX_AssociatedInstitution_MirrorDate')
CREATE NONCLUSTERED INDEX IX_AssociatedInstitution_MirrorDate ON dbo.AssociatedInstitution (MirrorDate) WITH FILLFACTOR=80 ON [PRIMARY]
GO
if exists (select * from sysindexes
  		where id=object_id('dbo.AssociatedInstitution') and name='IX_AssociatedInstitution_MirrorId')
DROP INDEX dbo.AssociatedInstitution.IX_AssociatedInstitution_MirrorId
GO

DROP INDEX dbo.BloodUnit.IX_BloodUnit_MirrorId
GO
ALTER TABLE dbo.BloodUnit 
	ADD CONSTRAINT PK_BloodUnit PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.BloodUnitAntigen.IX_BloodUnitAntigen_MirrorId
GO
ALTER TABLE dbo.BloodUnitAntigen 
	ADD CONSTRAINT PK_BloodUnitAntigen PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.BloodUnitCurrentShipment 
	ADD CONSTRAINT PK_BloodUnitCurrentShipment PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.BloodUnitFinance.IX_BloodUnitFinance_MirrorId
GO
ALTER TABLE dbo.BloodUnitFinance 
	ADD CONSTRAINT PK_BloodUnitFinance PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.BloodUnitMedia.IX_BloodUnitMedia_MirrorId
GO
ALTER TABLE dbo.BloodUnitMedia 
	ADD CONSTRAINT PK_BloodUnitMedia PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.BloodUnitModification 
	ADD CONSTRAINT PK_BloodUnitModification PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO


if exists (select * from sysindexes
  		where id=object_id('dbo.BloodUnitShipment') and name='IX_BloodUnitShipment_LoginBloodProductGuid')
DROP INDEX dbo.BloodUnitShipment.IX_BloodUnitShipment_LoginBloodProductGuid
GO
if exists (select * from sysindexes
  		where id=object_id('dbo.BloodUnitShipment') and name='IX_BloodUnitShipment')
DROP INDEX dbo.BloodUnitShipment.IX_BloodUnitShipment
GO
if exists (select * from sysindexes
  		where id=object_id('dbo.BloodUnitShipment') and name='IX_BloodUnitShipment_BloodUnitGuid')
DROP INDEX dbo.BloodUnitShipment.IX_BloodUnitShipment_BloodUnitGuid
GO
if exists (select * from sysindexes
  		where id=object_id('dbo.BloodUnitShipment') and name='IX_BloodUnitShipment_OutGoingShipmentGuid')
DROP INDEX dbo.BloodUnitShipment.IX_BloodUnitShipment_OutGoingShipmentGuid
GO
if exists (select * from sysindexes
  		where id=object_id('dbo.BloodUnitShipment') and name='IX_BloodUnitShipment_RecordStatusCode')
DROP INDEX dbo.BloodUnitShipment.IX_BloodUnitShipment_RecordStatusCode
GO
ALTER TABLE dbo.BloodUnitShipment 
	ADD CONSTRAINT PK_BloodUnitShipment PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO
CREATE CLUSTERED INDEX IX_BloodUnitShipment ON dbo.BloodUnitShipment (BloodUnitShipmentGuid) WITH FILLFACTOR=80 ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX IX_BloodUnitShipment_BloodUnitGuid ON dbo.BloodUnitShipment (BloodUnitGuid) WITH FILLFACTOR=80 ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX IX_BloodUnitShipment_OutGoingShipmentGuid ON dbo.BloodUnitShipment (OutgoingShipmentGuid) WITH FILLFACTOR=80 ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX IX_BloodUnitShipment_RecordStatusCode ON dbo.BloodUnitShipment (RecordStatusCode) WITH FILLFACTOR=80 ON [PRIMARY]
GO

DROP INDEX dbo.BloodUnitStatus.IX_BloodUnitStatus_MirrorId
GO
ALTER TABLE dbo.BloodUnitStatus 
	ADD CONSTRAINT PK_BloodUnitStatus PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.BloodUnitTest.IX_BloodUnitTest_MirrorId
GO
ALTER TABLE dbo.BloodUnitTest 
	ADD CONSTRAINT PK_BloodUnitTest PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.CannedComment 
	ADD CONSTRAINT PK_CannedComment PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.ComponentClassCompatibility 
	ADD CONSTRAINT PK_ComponentClassCompatibility PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.ComponentClassParameter.IX_ComponentClassParameter_MirrorId
GO
ALTER TABLE dbo.ComponentClassParameter 
	ADD CONSTRAINT PK_ComponentClassParameter PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.ComponentRequirement 
	ADD CONSTRAINT PK_ComponentRequirement PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.ConfirmationWorklistUnit 
	ADD CONSTRAINT PK_ConfirmationWorklistUnit PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.DailyControl.IX_DailyControl_MirrorID
GO
ALTER TABLE dbo.DailyControl 
	ADD CONSTRAINT PK_DailyControl PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.DailyQcWorklist 
	ADD CONSTRAINT PK_DailyQcWorklist PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.DaylightSavingsType 
	ADD CONSTRAINT PK_DaylightSavingsType PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.Equipment 
	ADD CONSTRAINT PK_Equipment PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.EquipmentMaintenance 
	ADD CONSTRAINT PK_EquipmentMaintenance PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.ExceptionType 
	ADD CONSTRAINT PK_ExceptionType PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.HcpcsAssignment.IX_HcpcsAssignment_MirrorID
GO
ALTER TABLE dbo.HcpcsAssignment 
	ADD CONSTRAINT PK_HcpcsAssignment PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.HemolysisInspection 
	ADD CONSTRAINT PK_HemolysisInspection PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.InformationMessage 
	ADD CONSTRAINT PK_InformationMessage PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.IssuedUnit 
	ADD CONSTRAINT PK_IssuedUnit PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.IssuedUnitComment 
	ADD CONSTRAINT PK_IssuedUnitComment PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.LocalSupplier.IX_LocalSupplier_MirrorId
GO
ALTER TABLE dbo.LocalSupplier 
	ADD CONSTRAINT PK_LocalSupplier PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.LoginMessage 
	ADD CONSTRAINT PK_LoginMessage PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.MessageStatus 
	ADD CONSTRAINT PK_MessageStatus PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.ModificationEquipment 
	ADD CONSTRAINT PK_ModificationEquipment PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.ModificationSupply 
	ADD CONSTRAINT PK_ModificationSupply PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.Msbos.IX_Msbos_MirrorId
GO
ALTER TABLE dbo.Msbos 
	ADD CONSTRAINT PK_Msbos PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.MsbosComponentClass.IX_MsbosComponentClass_MirrorId
GO
ALTER TABLE dbo.MsbosComponentClass 
	ADD CONSTRAINT PK_MsbosComponentClass PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.OrderAlertType 
	ADD CONSTRAINT PK_OrderAlertType PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.OrderedComponent.IX_OrderedComponent_MirrorId
GO
ALTER TABLE dbo.OrderedComponent 
	ADD CONSTRAINT PK_OrderedComponent PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.OrderedTest 
	ADD CONSTRAINT PK_OrderedTest PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.OrderedUnit.IX_OrderedUnit_MirrorID
GO
ALTER TABLE dbo.OrderedUnit 
	ADD CONSTRAINT PK_OrderedUnit PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.OrderedUnitComment 
	ADD CONSTRAINT PK_OrderedUnitComment PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.Patient.IX_Patient_MirrorId
GO
ALTER TABLE dbo.Patient 
	ADD CONSTRAINT PK_Patient PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.PatientChangeStatus 
	ADD CONSTRAINT PK_PatientChangeStatus PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.PatientOrder 
	ADD CONSTRAINT PK_PatientOrder PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.PatientSpecialInstruction 
	ADD CONSTRAINT PK_PatientSpecialInstruction PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.PatientSpecimen 
	ADD CONSTRAINT PK_PatientSpecimen PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.PatientSymptom 
	ADD CONSTRAINT PK_PatientSymptom PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.PatientTest 
	ADD CONSTRAINT PK_PatientTest PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.PatientTransfusion 
	ADD CONSTRAINT PK_PatientTransfusion PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.PatientTransfusionComment 
	ADD CONSTRAINT PK_PatientTransfusionComment PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.PatientTransfusionReaction.IX_PatientTransfusionReaction_MirrorID
GO
ALTER TABLE dbo.PatientTransfusionReaction 
	ADD CONSTRAINT PK_PatientTransfusionReaction PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.PatientTransfusionReactionSymptom 
	ADD CONSTRAINT PK_PatientTransfusionReactionSymptom PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.PatientTransfusionRequirement.IX_PatientTransfusionRequirement_MirrorId
GO
ALTER TABLE dbo.PatientTransfusionRequirement 
	ADD CONSTRAINT PK_PatientTransfusionRequirement PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.PatientTreatment 
	ADD CONSTRAINT PK_PatientTreatment PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.PermittedProductModification 
	ADD CONSTRAINT PK_PermittedProductModification PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.ProductModification 
	ADD CONSTRAINT PK_ProductModification PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.ProductModificationParameter.IX_ProductModificationParameter_MirrorId
GO
ALTER TABLE dbo.ProductModificationParameter 
	ADD CONSTRAINT PK_ProductModificationParameter PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.ProductShipper.IX_ProductShipper_MirrorId
GO
ALTER TABLE dbo.ProductShipper 
	ADD CONSTRAINT PK_ProductShipper PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.Rack 
	ADD CONSTRAINT PK_Rack PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.RackLot 
	ADD CONSTRAINT PK_RackLot PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.RackTest 
	ADD CONSTRAINT PK_RackTest PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.Reagent 
	ADD CONSTRAINT PK_Reagent PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.ReagentChange 
	ADD CONSTRAINT PK_ReagentChange PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO


DROP INDEX dbo.ReagentTestParameter.IX_ReagentTestParameter_MirrorId
GO
ALTER TABLE dbo.ReagentTestParameter 
	ADD CONSTRAINT PK_ReagentTestParameter PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.ReagentTypeParameter.IX_ReagentTypeParameter_MirrorId
GO
ALTER TABLE dbo.ReagentTypeParameter 
	ADD CONSTRAINT PK_ReagentTypeParameter PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.ReOrderTest 
	ADD CONSTRAINT PK_ReOrderTest PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.RestrictionType 
	ADD CONSTRAINT PK_RestrictionType PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.SpecimenTest.IX_SpecimenTest_MirrorId
GO
ALTER TABLE dbo.SpecimenTest 
	ADD CONSTRAINT PK_SpecimenTest PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.SpecimenTestThreshold.IX_SpecimenTestThreshold_MirrorId
GO
ALTER TABLE dbo.SpecimenTestThreshold 
	ADD CONSTRAINT PK_SpecimenTestThreshold PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.Shipment 
	ADD CONSTRAINT PK_Shipment PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.Supply 
	ADD CONSTRAINT PK_Supply PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.SupplyType 
	ADD CONSTRAINT PK_SupplyType PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.TimeZone 
	ADD CONSTRAINT PK_TimeZone PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.TransfusionReaction 
	ADD CONSTRAINT PK_TransfusionReaction PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.TreatingSpecialty 
	ADD CONSTRAINT PK_TreatingSpecialty PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.VamcDivision.IX_VamcDivision
GO
DROP INDEX dbo.VamcDivision.IX_VamcDivision_AntibodyScreenDisplayCode
GO
DROP INDEX dbo.VamcDivision.IX_VamcDivision_FacilityGuid
GO
DROP INDEX dbo.VamcDivision.IX_VamcDivision_MedicalDirectorName
GO
DROP INDEX dbo.VamcDivision.IX_VamcDivision_MirrorDate
GO
DROP INDEX dbo.VamcDivision.IX_VamcDivision_MirrorId
GO
ALTER TABLE dbo.VamcDivision 
	ADD CONSTRAINT PK_VamcDivision PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]

GO
CREATE CLUSTERED INDEX IX_VamcDivision ON dbo.VamcDivision (DivisionCode) WITH FILLFACTOR=80 ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX IX_VamcDivision_AntibodyScreenDisplayCode ON dbo.VamcDivision (AntibodyScreenDisplayCode) WITH FILLFACTOR=80 ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX IX_VamcDivision_FacilityGuid ON dbo.VamcDivision (FacilityGuid) WITH FILLFACTOR=80 ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX IX_VamcDivision_MedicalDirectorName ON dbo.VamcDivision (MedicalDirectorName) WITH FILLFACTOR=80 ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX IX_VamcDivision_MirrorDate ON dbo.VamcDivision (MirrorDate) WITH FILLFACTOR=80 ON [PRIMARY]
GO

ALTER TABLE dbo.VbecsProcess 
	ADD CONSTRAINT PK_VbecsProcess PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.VbecsUser 
	ADD CONSTRAINT PK_VbecsUser PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.VbecsUserDivisionRole.IX_VbecsUserDivisionRole_MirrorId
GO
ALTER TABLE dbo.VbecsUserDivisionRole 
	ADD CONSTRAINT PK_VbecsUserDivisionRole PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.VistaLinkControl.IX_VistaLinkControl
GO
DROP INDEX dbo.VistaLinkControl.IX_VistaLinkControl_MirrorDate
GO
DROP INDEX dbo.VistaLinkControl.IX_VistaLinkControl_MirrorId
GO
ALTER TABLE dbo.VistaLinkControl 
	ADD CONSTRAINT PK_VistaLinkControl PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO
CREATE CLUSTERED INDEX IX_VistaLinkControl ON dbo.VistaLinkControl (ServerAppHandle) WITH FILLFACTOR=80 ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX IX_VistaLinkControl_MirrorDate ON dbo.VistaLinkControl (MirrorDate) WITH FILLFACTOR=80 ON [PRIMARY]
GO

ALTER TABLE dbo.WorkloadEvent 
	ADD CONSTRAINT PK_WorkloadEvent PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

ALTER TABLE dbo.WorkloadEventStatus 
	ADD CONSTRAINT PK_WorkloadEventStatus PRIMARY KEY CLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO

DROP INDEX dbo.WorkloadProcess.IX_WorkloadProcess_MirrorId
GO
ALTER TABLE dbo.WorkloadProcess 
	ADD CONSTRAINT PK_WorkloadProcess PRIMARY KEY NONCLUSTERED 
	(
		MirrorId
	) ON [PRIMARY]
GO


/*****************************************************************************************
*	Recreate the views with dbo. prefix on the mirror database
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_Address]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_Address
GO
CREATE VIEW dbo.V_Address
AS 
SELECT Source='MIRROR', MirrorId, AddressGuid, AddressLine1, AddressLine2, AddressLine3, AddressCity, StateCode, AddressZipCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.Address
UNION ALL 
SELECT Source='ACTIVE', 0, AddressGuid, AddressLine1, AddressLine2, AddressLine3, AddressCity, StateCode, AddressZipCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.Address

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_AntibodyParameter]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_AntibodyParameter
GO
CREATE VIEW dbo.V_AntibodyParameter
AS 
SELECT Source='MIRROR', MirrorId, AntibodyParameterGuid, AntibodyTypeId, HigherLevelOverrideIndicator, CanChangeIndicator, CompatibilityPercentage, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.AntibodyParameter
UNION ALL 
SELECT Source='ACTIVE', 0, AntibodyParameterGuid, AntibodyTypeId, HigherLevelOverrideIndicator, CanChangeIndicator, CompatibilityPercentage, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.AntibodyParameter

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_AntigenTest]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_AntigenTest
GO
CREATE VIEW dbo.V_AntigenTest
AS 
SELECT Source='MIRROR', MirrorId, AntigenTestId, AntigenTypeId, BloodTestTypeId, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.AntigenTest
UNION ALL 
SELECT Source='ACTIVE', 0, AntigenTestId, AntigenTypeId, BloodTestTypeId, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.AntigenTest

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_AntigenType]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_AntigenType
GO
CREATE VIEW dbo.V_AntigenType
AS 
SELECT Source='MIRROR', MirrorId, AntigenTypeId, AntigenTypeName, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.AntigenType
UNION ALL 
SELECT Source='ACTIVE', 0, AntigenTypeId, AntigenTypeName, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.AntigenType

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_AntiseraOrderedTest]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_AntiseraOrderedTest
GO
CREATE VIEW dbo.V_AntiseraOrderedTest
AS 
SELECT Source='MIRROR', MirrorId, AntiseraOrderedTestGuid, OrderedTestGuid, RackLotGuid, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.AntiseraOrderedTest
UNION ALL 
SELECT Source='ACTIVE', 0, AntiseraOrderedTestGuid, OrderedTestGuid, RackLotGuid, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.AntiseraOrderedTest

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_AntiseraUnitTest]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_AntiseraUnitTest
GO
CREATE VIEW dbo.V_AntiseraUnitTest
AS 
SELECT Source='MIRROR', MirrorId, AntiseraUnitTestGuid, AntiseraWorklistTypingGuid, RackLotGuid, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.AntiseraUnitTest
UNION ALL 
SELECT Source='ACTIVE', 0, AntiseraUnitTestGuid, AntiseraWorklistTypingGuid, RackLotGuid, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.AntiseraUnitTest

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_AntiseraWorklist]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_AntiseraWorklist
GO
CREATE VIEW dbo.V_AntiseraWorklist
AS 
SELECT Source='MIRROR', MirrorId, AntiseraWorklistGuid, WorklistName, WorklistCreateDate, TaskStatusCode, AutoInstrumentName, TestingMethodCode, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.AntiseraWorklist
UNION ALL 
SELECT Source='ACTIVE', 0, AntiseraWorklistGuid, WorklistName, WorklistCreateDate, TaskStatusCode, AutoInstrumentName, TestingMethodCode, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.AntiseraWorklist

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_AntiseraWorklistTyping]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_AntiseraWorklistTyping
GO
CREATE VIEW dbo.V_AntiseraWorklistTyping
AS 
SELECT Source='MIRROR', MirrorId, AntiseraWorklistTypingGuid, AntiseraWorklistGuid, OrderableTestId, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.AntiseraWorklistTyping
UNION ALL 
SELECT Source='ACTIVE', 0, AntiseraWorklistTypingGuid, AntiseraWorklistGuid, OrderableTestId, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.AntiseraWorklistTyping

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_AssociatedInstitution]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_AssociatedInstitution
GO
CREATE VIEW dbo.V_AssociatedInstitution
AS 
SELECT Source='MIRROR', MirrorId, AssociatedInstitutionGuid, InstitutionDivisionCode, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.AssociatedInstitution
UNION ALL 
SELECT Source='ACTIVE', 0, AssociatedInstitutionGuid, InstitutionDivisionCode, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.AssociatedInstitution

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_BloodUnit]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnit
GO
CREATE VIEW dbo.V_BloodUnit
AS 
SELECT Source='MIRROR', MirrorId, BloodUnitGuid, UnitProductCode, OriginalVolume, DiscardedPlasmaVolume, UnitInDate, UnitFdaRegistrationNumber, UnitContainerLotNumber, DonationTypeId, UnitDivisionId, LabelTypeCode, LabelUnitId, EyeReadableUnitId, BloodProductGuid, DivisionCode, EntryMethodCode, ProcessingTechId, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.BloodUnit
UNION ALL 
SELECT Source='ACTIVE', 0, BloodUnitGuid, UnitProductCode, OriginalVolume, DiscardedPlasmaVolume, UnitInDate, UnitFdaRegistrationNumber, UnitContainerLotNumber, DonationTypeId, UnitDivisionId, LabelTypeCode, LabelUnitId, EyeReadableUnitId, BloodProductGuid, DivisionCode, EntryMethodCode, ProcessingTechId, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.BloodUnit

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_BloodUnitAntigen]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnitAntigen
GO
CREATE VIEW dbo.V_BloodUnitAntigen
AS 
SELECT Source='MIRROR', MirrorId, BloodUnitGuid, AntigenTypeId, Positive, Comments, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.BloodUnitAntigen
UNION ALL 
SELECT Source='ACTIVE', 0, BloodUnitGuid, AntigenTypeId, Positive, Comments, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.BloodUnitAntigen

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_BloodUnitCurrentShipment]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnitCurrentShipment
GO
CREATE VIEW dbo.V_BloodUnitCurrentShipment
AS 
SELECT Source='MIRROR', MirrorId, BloodUnitCurrentShipmentGuid, BloodUnitGuid, IncomingShipmentGuid, OutgoingShipmentGuid, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.BloodUnitCurrentShipment
UNION ALL 
SELECT Source='ACTIVE', 0, BloodUnitCurrentShipmentGuid, BloodUnitGuid, IncomingShipmentGuid, OutgoingShipmentGuid, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.BloodUnitCurrentShipment

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_BloodUnitFinance]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnitFinance
GO
CREATE VIEW dbo.V_BloodUnitFinance
AS 
SELECT Source='MIRROR', MirrorId, BloodUnitFinanceGuid, BloodUnitGuid, UnitCost, SpecialTestingCost, ReturnCreditAmount, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.BloodUnitFinance
UNION ALL 
SELECT Source='ACTIVE', 0, BloodUnitFinanceGuid, BloodUnitGuid, UnitCost, SpecialTestingCost, ReturnCreditAmount, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.BloodUnitFinance

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_BloodUnitMedia]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnitMedia
GO
CREATE VIEW dbo.V_BloodUnitMedia
AS 
SELECT Source='MIRROR', MirrorId, BloodUnitMediaGuid, BloodUnitGuid, BloodTypeCode, RhFactorCode, UnitExpirationDate, TestingStatusId, DirectedPatientGuid, RemoveRestrictionDate, RemoveRestrictionTechId, Comments, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.BloodUnitMedia
UNION ALL 
SELECT Source='ACTIVE', 0, BloodUnitMediaGuid, BloodUnitGuid, BloodTypeCode, RhFactorCode, UnitExpirationDate, TestingStatusId, DirectedPatientGuid, RemoveRestrictionDate, RemoveRestrictionTechId, Comments, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.BloodUnitMedia

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_BloodUnitModification]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnitModification
GO
CREATE VIEW dbo.V_BloodUnitModification
AS 
SELECT Source='MIRROR', MirrorId, BloodUnitModificationGuid, FromBloodUnitGuid, ToBloodUnitGuid, ProductModificationCode, ModificationDate, ModificationTechId, ModificationMethodCode, NewContainerWeldIndicator, NewLabelVerificationDatetime, PoolEditedIndicator, FromOriginalVolume, FromBloodProductGuid, FromUnitExpirationDate, FromProductShipperGuid, Comments, OriginalUnitIndicator, ModificationCost, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.BloodUnitModification
UNION ALL 
SELECT Source='ACTIVE', 0, BloodUnitModificationGuid, FromBloodUnitGuid, ToBloodUnitGuid, ProductModificationCode, ModificationDate, ModificationTechId, ModificationMethodCode, NewContainerWeldIndicator, NewLabelVerificationDatetime, PoolEditedIndicator, FromOriginalVolume, FromBloodProductGuid, FromUnitExpirationDate, FromProductShipperGuid, Comments, OriginalUnitIndicator, ModificationCost, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.BloodUnitModification

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_BloodUnitShipment]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnitShipment
GO
CREATE VIEW dbo.V_BloodUnitShipment
AS 
SELECT Source='MIRROR', MirrorId, BloodUnitShipmentGuid, BloodUnitGuid, IncomingShipmentGuid, OutgoingShipmentGuid, LoginBloodProductGuid, LoginFullProductCode, LoginValues, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.BloodUnitShipment
UNION ALL 
SELECT Source='ACTIVE', 0, BloodUnitShipmentGuid, BloodUnitGuid, IncomingShipmentGuid, OutgoingShipmentGuid, LoginBloodProductGuid, LoginFullProductCode, LoginValues, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.BloodUnitShipment

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_BloodUnitStatus]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnitStatus
GO
CREATE VIEW dbo.V_BloodUnitStatus
AS 
SELECT Source='MIRROR', MirrorId, BloodUnitStatusGuid, BloodUnitGUID, UnitStatusCode, UnitStatusDate, UnitStatusComments, DiscardCannedCommentGuid, BiohazardousWarningIndicator, QuarantineIndicator, QuarantineCannedCommentGuid, PresumedTransfusedIndicator, EmergencyIssueIndicator, TestingLimitIndicator, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.BloodUnitStatus
UNION ALL 
SELECT Source='ACTIVE', 0, BloodUnitStatusGuid, BloodUnitGUID, UnitStatusCode, UnitStatusDate, UnitStatusComments, DiscardCannedCommentGuid, BiohazardousWarningIndicator, QuarantineIndicator, QuarantineCannedCommentGuid, PresumedTransfusedIndicator, EmergencyIssueIndicator, TestingLimitIndicator, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.BloodUnitStatus

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_BloodUnitTest]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnitTest
GO
CREATE VIEW dbo.V_BloodUnitTest
AS 
SELECT Source='MIRROR', MirrorId, BloodUnitTestGuid, BloodUnitGuid, BloodTestTypeId, TestDate, TestTechId, TestResultId, EntryTechId, EntryMethodCode, TestingMethodCode, TestComments, CorrectedResultIndicator, AntiseraWorklistTypingGuid, ConfirmationWorklistUnitGuid, OrderedTestGuid, OrderedComponentGuid, OrderedUnitGuid, InactivateDate, InactivateUser, PatientTransfusionReactionGuid, RackGuid, AutoInstrumentName, ReactivityPhaseCode, RecordStatusCode, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.BloodUnitTest
UNION ALL 
SELECT Source='ACTIVE', 0, BloodUnitTestGuid, BloodUnitGuid, BloodTestTypeId, TestDate, TestTechId, TestResultId, EntryTechId, EntryMethodCode, TestingMethodCode, TestComments, CorrectedResultIndicator, AntiseraWorklistTypingGuid, ConfirmationWorklistUnitGuid, OrderedTestGuid, OrderedComponentGuid, OrderedUnitGuid, InactivateDate, InactivateUser, PatientTransfusionReactionGuid, RackGuid, AutoInstrumentName, ReactivityPhaseCode, RecordStatusCode, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.BloodUnitTest

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_CannedComment]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_CannedComment
GO
CREATE VIEW dbo.V_CannedComment
AS 
SELECT Source='MIRROR', MirrorId, CannedCommentGuid, CannedCommentText, CannedCommentCategoryCode, SortColumn, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.CannedComment
UNION ALL 
SELECT Source='ACTIVE', 0, CannedCommentGuid, CannedCommentText, CannedCommentCategoryCode, SortColumn, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.CannedComment

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ComponentClassCompatibility]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ComponentClassCompatibility
GO
CREATE VIEW dbo.V_ComponentClassCompatibility
AS 
SELECT Source='MIRROR', MirrorId, ComponentClassId, CompatibilityId, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ComponentClassCompatibility
UNION ALL 
SELECT Source='ACTIVE', 0, ComponentClassId, CompatibilityId, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ComponentClassCompatibility

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ComponentClassParameter]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ComponentClassParameter
GO
CREATE VIEW dbo.V_ComponentClassParameter
AS 
SELECT Source='MIRROR', MirrorId, ComponentClassParameterGuid, ComponentClassId, DivisionCode, OrderableIndicator, SpecimenRequiredIndicator, MaximumTransfusionTime, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ComponentClassParameter
UNION ALL 
SELECT Source='ACTIVE', 0, ComponentClassParameterGuid, ComponentClassId, DivisionCode, OrderableIndicator, SpecimenRequiredIndicator, MaximumTransfusionTime, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ComponentClassParameter

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ComponentRequirement]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ComponentRequirement
GO
CREATE VIEW dbo.V_ComponentRequirement
AS 
SELECT Source='MIRROR', MirrorId, ComponentRequirementId, ComponentRequirementText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ComponentRequirement
UNION ALL 
SELECT Source='ACTIVE', 0, ComponentRequirementId, ComponentRequirementText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ComponentRequirement

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ConfirmationWorklistUnit]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ConfirmationWorklistUnit
GO
CREATE VIEW dbo.V_ConfirmationWorklistUnit
AS 
SELECT Source='MIRROR', MirrorId, ConfirmationWorklistUnitGuid, RackGuid, BloodUnitGuid, AutoInstrumentName, AutoInstrumentQcIndicator, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ConfirmationWorklistUnit
UNION ALL 
SELECT Source='ACTIVE', 0, ConfirmationWorklistUnitGuid, RackGuid, BloodUnitGuid, AutoInstrumentName, AutoInstrumentQcIndicator, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ConfirmationWorklistUnit

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_DailyControl]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_DailyControl
GO
CREATE VIEW dbo.V_DailyControl
AS 
SELECT Source='MIRROR', MirrorId, DailyControlGuid, NumberOfRacks, RackNamesIndicator, DailyAlertTime, CommercialTemplateIndicator, PrimaryEnhancementMediaId, SecondaryEnhancementMediaId, Comments, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.DailyControl
UNION ALL 
SELECT Source='ACTIVE', 0, DailyControlGuid, NumberOfRacks, RackNamesIndicator, DailyAlertTime, CommercialTemplateIndicator, PrimaryEnhancementMediaId, SecondaryEnhancementMediaId, Comments, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.DailyControl

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_DailyQcWorklist]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_DailyQcWorklist
GO
CREATE VIEW dbo.V_DailyQcWorklist
AS 
SELECT Source='MIRROR', MirrorId, DailyQcWorklistGuid, DailyQcExpirationDate, DailyUseIndicator, PartiallyTestedIndicator, RackGuid, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.DailyQcWorklist
UNION ALL 
SELECT Source='ACTIVE', 0, DailyQcWorklistGuid, DailyQcExpirationDate, DailyUseIndicator, PartiallyTestedIndicator, RackGuid, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.DailyQcWorklist

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_DaylightSavingsType]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_DaylightSavingsType
GO
CREATE VIEW dbo.V_DaylightSavingsType 
AS 
SELECT Source='MIRROR', MirrorId, DaylightSavingsTypeId, DaylightSavingsTypeText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.DaylightSavingsType 
UNION ALL 
SELECT Source='ACTIVE', 0, DaylightSavingsTypeId, DaylightSavingsTypeText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.DaylightSavingsType 

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_Equipment]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_Equipment
GO
CREATE VIEW dbo.V_Equipment
AS 
SELECT Source='MIRROR', MirrorId, EquipmentGuid, EquipmentName, EquipmentType, ManufacturerName, AddressGuid, ManufacturerPhoneNumber, SerialNumber, ReceiptDate, ReceiptTechId, InvoiceNumber, LocalIdentifier, MaintenanceContractNumber, MaintenanceContractDate, InspectionIndicator, Comments, NextMaintenanceText, OutOfServiceIndicator, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.Equipment
UNION ALL 
SELECT Source='ACTIVE', 0, EquipmentGuid, EquipmentName, EquipmentType, ManufacturerName, AddressGuid, ManufacturerPhoneNumber, SerialNumber, ReceiptDate, ReceiptTechId, InvoiceNumber, LocalIdentifier, MaintenanceContractNumber, MaintenanceContractDate, InspectionIndicator, Comments, NextMaintenanceText, OutOfServiceIndicator, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.Equipment

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_EquipmentMaintenance]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_EquipmentMaintenance
GO
CREATE VIEW dbo.V_EquipmentMaintenance
AS 
SELECT Source='MIRROR', MirrorId, EquipmentMaintenanceGuid, EquipmentGuid, MaintenanceType, MaintenanceDate, MaintenanceResults, PendingIssues, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.EquipmentMaintenance
UNION ALL 
SELECT Source='ACTIVE', 0, EquipmentMaintenanceGuid, EquipmentGuid, MaintenanceType, MaintenanceDate, MaintenanceResults, PendingIssues, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.EquipmentMaintenance

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ExceptionType]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ExceptionType
GO
CREATE VIEW dbo.V_ExceptionType
AS 
SELECT Source='MIRROR', MirrorId, ExceptionTypeId, ExceptionTypeName, BusinessRule, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ExceptionType
UNION ALL 
SELECT Source='ACTIVE', 0, ExceptionTypeId, ExceptionTypeName, BusinessRule, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ExceptionType

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_HcpcsAssignment]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_HcpcsAssignment
GO
CREATE VIEW dbo.V_HcpcsAssignment
AS 
SELECT Source='MIRROR', MirrorId, HcpcsAssignmentGuid, BloodProductGuid, HcpcsCode, AssignedDate, UnAssignedDate, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.HcpcsAssignment
UNION ALL 
SELECT Source='ACTIVE', 0, HcpcsAssignmentGuid, BloodProductGuid, HcpcsCode, AssignedDate, UnAssignedDate, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.HcpcsAssignment

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_HemolysisInspection]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_HemolysisInspection
GO
CREATE VIEW dbo.V_HemolysisInspection
AS 
SELECT Source='MIRROR', MirrorId, HemolysisInspectionCode, HemolysisInspectionText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.HemolysisInspection
UNION ALL 
SELECT Source='ACTIVE', 0, HemolysisInspectionCode, HemolysisInspectionText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.HemolysisInspection

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_InformationMessage]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_InformationMessage
GO
CREATE VIEW dbo.V_InformationMessage
AS 
SELECT Source='MIRROR', MirrorId, InformationMessageId, InformationMessageText, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.InformationMessage
UNION ALL 
SELECT Source='ACTIVE', 0, InformationMessageId, InformationMessageText, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.InformationMessage

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_InterfaceControl]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_InterfaceControl
GO
CREATE VIEW dbo.V_InterfaceControl
AS 
SELECT Source='MIRROR', MirrorId, InterfaceControlId, InterfaceId, InterfaceFacilityId, InterfacePortNumber, InterfaceIPAddress, InterfaceDomainName, VbecsFacilityId, ProcessingId, VbecsPortNumber, VbecsIPAddress, AckTimeout, ReTransmitAttempts, InterfaceAdministratorName, PurgeSuccessfulMessage, PurgeUnSuccessfulMessage, LogEventsIndicator, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.InterfaceControl
UNION ALL 
SELECT Source='ACTIVE', 0, InterfaceControlId, InterfaceId,  InterfaceFacilityId, InterfacePortNumber, InterfaceIPAddress, InterfaceDomainName, VbecsFacilityId, ProcessingId, VbecsPortNumber, VbecsIPAddress, AckTimeout, ReTransmitAttempts, InterfaceAdministratorName, PurgeSuccessfulMessage, PurgeUnSuccessfulMessage, LogEventsIndicator, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate
FROM VBECS_V1_TEST.dbo.InterfaceControl

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_IssuedUnit]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_IssuedUnit
GO
CREATE VIEW dbo.V_IssuedUnit
AS 
SELECT Source='MIRROR', MirrorId, IssuedUnitGuid, BloodUnitGuid, IssueDateTime, IssueTechId, PhysicianName, TransporterName, PatientGuid, IssueToLocationName, LocationIen, InPatientLocationIndicator, IssueSatisfactoryIndicator, RemoteStorageIndicator, RemoteStorageText, ReturnDateTime, ReturnTechId, ReturnFromLocationName, ReturnSatisfactoryIndicator, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.IssuedUnit
UNION ALL 
SELECT Source='ACTIVE', 0, IssuedUnitGuid, BloodUnitGuid, IssueDateTime, IssueTechId, PhysicianName, TransporterName, PatientGuid, IssueToLocationName, LocationIen, InPatientLocationIndicator, IssueSatisfactoryIndicator, RemoteStorageIndicator, RemoteStorageText, ReturnDateTime, ReturnTechId, ReturnFromLocationName, ReturnSatisfactoryIndicator, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.IssuedUnit

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_IssuedUnitComment]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_IssuedUnitComment
GO
CREATE VIEW dbo.V_IssuedUnitComment
AS 
SELECT Source='MIRROR', MirrorId, IssuedUnitCommentGuid, IssuedUnitGuid, IssuedUnitCommentText, EntryDate, EntryTechId, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.IssuedUnitComment
UNION ALL 
SELECT Source='ACTIVE', 0, IssuedUnitCommentGuid, IssuedUnitGuid, IssuedUnitCommentText, EntryDate, EntryTechId, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.IssuedUnitComment

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_LocalSupplier]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_LocalSupplier
GO
CREATE VIEW dbo.V_LocalSupplier
AS 
SELECT Source='MIRROR', MirrorId, LocalSupplierGuid, FacilityGuid, FacilityName, FdaRegistrationNumber, IccbbaRegistrationNumber, FacilityPrefix, AddressGuid, LabelUnitIdTrimIndicator, PhoneNumber, FaxNumber, TestingIndicator, CollectionIndicator, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.LocalSupplier
UNION ALL 
SELECT Source='ACTIVE', 0, LocalSupplierGuid, FacilityGuid, FacilityName, FdaRegistrationNumber, IccbbaRegistrationNumber, FacilityPrefix, AddressGuid, LabelUnitIdTrimIndicator, PhoneNumber, FaxNumber, TestingIndicator, CollectionIndicator, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.LocalSupplier

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_LoginMessage]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_LoginMessage
GO
CREATE VIEW dbo.V_LoginMessage
AS 
SELECT Source='MIRROR', MirrorId, LoginMessageGuid, LoginMessageText, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.LoginMessage
UNION ALL 
SELECT Source='ACTIVE', 0, LoginMessageGuid, LoginMessageText, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.LoginMessage

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_MessageStatus]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_MessageStatus
GO
CREATE VIEW dbo.V_MessageStatus
AS 
SELECT Source='MIRROR', MirrorId, MessageStatusCode, MessageStatusText, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.MessageStatus
UNION ALL 
SELECT Source='ACTIVE', 0, MessageStatusCode, MessageStatusText, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.MessageStatus

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ModificationEquipment]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ModificationEquipment
GO
CREATE VIEW dbo.V_ModificationEquipment
AS 
SELECT Source='MIRROR', MirrorId, ModificationEquipmentGuid, BloodUnitModificationGuid, EquipmentGuid, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ModificationEquipment
UNION ALL 
SELECT Source='ACTIVE', 0, ModificationEquipmentGuid, BloodUnitModificationGuid, EquipmentGuid, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ModificationEquipment

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ModificationSupply]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ModificationSupply
GO
CREATE VIEW dbo.V_ModificationSupply
AS 
SELECT Source='MIRROR', MirrorId, ModificationSupplyGuid, BloodUnitModificationGuid, SupplyGuid, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ModificationSupply
UNION ALL 
SELECT Source='ACTIVE', 0, ModificationSupplyGuid, BloodUnitModificationGuid, SupplyGuid, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ModificationSupply

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_Msbos]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_Msbos
GO
CREATE VIEW dbo.V_Msbos
AS 
SELECT Source='MIRROR', MirrorId, MsbosGuid, SurgeryName, TypeAndScreenIndicator, NoBloodRequiredIndicator, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.Msbos
UNION ALL 
SELECT Source='ACTIVE', 0, MsbosGuid, SurgeryName, TypeAndScreenIndicator, NoBloodRequiredIndicator, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.Msbos

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_MsbosComponentClass]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_MsbosComponentClass
GO
CREATE VIEW dbo.V_MsbosComponentClass
AS 
SELECT Source='MIRROR', MirrorId, MsbosComponentClassGuid, MsbosGuid, ComponentClassId, MaximumSetupUnitQuantity, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.MsbosComponentClass
UNION ALL 
SELECT Source='ACTIVE', 0, MsbosComponentClassGuid, MsbosGuid, ComponentClassId, MaximumSetupUnitQuantity, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.MsbosComponentClass

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_OrderAlertType]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_OrderAlertType
GO
CREATE VIEW dbo.V_OrderAlertType
AS 
SELECT Source='MIRROR', MirrorId, OrderAlertTypeCode, OrderAlertTypeText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.OrderAlertType
UNION ALL 
SELECT Source='ACTIVE', 0, OrderAlertTypeCode, OrderAlertTypeText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.OrderAlertType

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_OrderedComponent]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_OrderedComponent
GO
CREATE VIEW dbo.V_OrderedComponent
AS 
SELECT Source='MIRROR', MirrorId, OrderedComponentGuid, PatientOrderGuid, ComponentClassId, CprsOrderNumber, VbecsOrderNumber, RequiredUnitQuantity, SpecimenRequiredIndicator, SpecimenAccessionNumber, SpecimenWorkloadUid, PatientSpecimenGuid, SpecimenStatusCode, PreOpIndicator, OrderStatusCode, OrderUrgencyCode, RequiredDatetime, OrderSpecialInstructions, ImmediateTransfusionIndicator, OrderedComponentComments, InappropriateRequestIndicator, NoInappropriateReportText, TaskStatusCode, CancellationCannedCommentGuid, CancellationText, LabOrderNumber, LabTestId, EmergencyOrderIndicator, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.OrderedComponent
UNION ALL 
SELECT Source='ACTIVE', 0, OrderedComponentGuid, PatientOrderGuid, ComponentClassId, CprsOrderNumber, VbecsOrderNumber, RequiredUnitQuantity, SpecimenRequiredIndicator, SpecimenAccessionNumber, SpecimenWorkloadUid, PatientSpecimenGuid, SpecimenStatusCode, PreOpIndicator, OrderStatusCode, OrderUrgencyCode, RequiredDatetime, OrderSpecialInstructions, ImmediateTransfusionIndicator, OrderedComponentComments, InappropriateRequestIndicator, NoInappropriateReportText, TaskStatusCode, CancellationCannedCommentGuid, CancellationText, LabOrderNumber, LabTestId, EmergencyOrderIndicator, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.OrderedComponent

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_OrderedTest]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_OrderedTest
GO
CREATE VIEW dbo.V_OrderedTest
AS 
SELECT Source='MIRROR', MirrorId, OrderedTestGuid, PatientOrderGuid, CprsOrderNumber, VbecsOrderNumber, RelatedComponentGuid, SpecimenRequiredIndicator, SpecimenAccessionNumber, SpecimenWorkloadUid, PatientSpecimenGuid, OrderStatusCode, OrderUrgencyCode, OrderedTestComments, RequiredResultsDate, OrderableTestId, TestInterpretation, TestInterpretationComments, AutoInstrumentName, TaskStatusCode, RelatedTestGuid, CancellationCannedCommentGuid, CancellationText, LabOrderNumber, LabTestId, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.OrderedTest
UNION ALL 
SELECT Source='ACTIVE', 0, OrderedTestGuid, PatientOrderGuid, CprsOrderNumber, VbecsOrderNumber, RelatedComponentGuid, SpecimenRequiredIndicator, SpecimenAccessionNumber, SpecimenWorkloadUid, PatientSpecimenGuid, OrderStatusCode, OrderUrgencyCode, OrderedTestComments, RequiredResultsDate, OrderableTestId, TestInterpretation, TestInterpretationComments, AutoInstrumentName, TaskStatusCode, RelatedTestGuid, CancellationCannedCommentGuid, CancellationText, LabOrderNumber, LabTestId, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.OrderedTest

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_OrderedUnit]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_OrderedUnit
GO
CREATE VIEW dbo.V_OrderedUnit
AS 
SELECT Source='MIRROR', MirrorId, OrderedUnitGuid, OrderedComponentGuid, OrderedTestGuid, BloodUnitGuid, SelectedDate, SelectedTechId, CrossmatchRequiredIndicator, CrossmatchDate, CrossmatchResultCode, CrossmatchTechId, ReleaseDate, ReleaseTechId, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.OrderedUnit
UNION ALL 
SELECT Source='ACTIVE', 0, OrderedUnitGuid, OrderedComponentGuid, OrderedTestGuid, BloodUnitGuid, SelectedDate, SelectedTechId, CrossmatchRequiredIndicator, CrossmatchDate, CrossmatchResultCode, CrossmatchTechId, ReleaseDate, ReleaseTechId, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.OrderedUnit

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_OrderedUnitComment]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_OrderedUnitComment
GO
CREATE VIEW dbo.V_OrderedUnitComment
AS 
SELECT Source='MIRROR', MirrorId, OrderedUnitCommentGuid, OrderedUnitGuid, CannedCommentGuid, OrderedUnitCommentText, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.OrderedUnitComment
UNION ALL 
SELECT Source='ACTIVE', 0, OrderedUnitCommentGuid, OrderedUnitGuid, CannedCommentGuid, OrderedUnitCommentText, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.OrderedUnitComment

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_Patient]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_Patient
GO
CREATE VIEW dbo.V_Patient
AS 
SELECT Source='MIRROR', MirrorId, PatientGuid, VistaPatientId, DisplayVistaPatientId, PatientSsn, PatientIcn, BloodTypeCode, RhFactorCode, AboRhChangeIndicator, PatientLastName, PatientFirstName, PatientMiddleName, PatientNamePrefix, PatientNameSuffix, PatientDob, PatientDobCode, PatientSexCode, PatientServiceBranch, SsnPrefix, SsnPseudoIndicator, PatientDeathDate, MergeFromPatient, MergeToPatient, PatientMergeDate, FinalMergeToPatient, PatientMergeGroup, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.Patient
UNION ALL 
SELECT Source='ACTIVE', 0, PatientGuid, VistaPatientId, DisplayVistaPatientId, PatientSsn, PatientIcn, BloodTypeCode, RhFactorCode, AboRhChangeIndicator, PatientLastName, PatientFirstName, PatientMiddleName, PatientNamePrefix, PatientNameSuffix, PatientDob, PatientDobCode, PatientSexCode, PatientServiceBranch, SsnPrefix, SsnPseudoIndicator, PatientDeathDate, MergeFromPatient, MergeToPatient, PatientMergeDate, FinalMergeToPatient, PatientMergeGroup, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.Patient

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientChange]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientChange
GO
CREATE VIEW dbo.V_PatientChange
AS 
SELECT Source='MIRROR', MirrorId, PatientChangeGuid, FromPatientGuid, FromPatientSsn, FromSsnPseudoIndicator, FromPatientIcn, FromPatientLastName, FromPatientFirstName, FromPatientMIddleName, FromPatientDob, FromPatientDeathDate, FromPatientSexCode, ToPatientGuid, ToPatientSsn, ToSsnPseudoIndicator, ToPatientIcn, ToPatientLastName, ToPatientFirstName, ToPatientMIddleName, ToPatientDob, ToPatientDeathDate, ToPatientSexCode, MergeFromVistaPatientId, MergeToVistaPatientId, PatientChangeStatusCode, NotificationReceivedDate, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientChange
UNION ALL 
SELECT Source='ACTIVE', 0, PatientChangeGuid, FromPatientGuid, FromPatientSsn, FromSsnPseudoIndicator, FromPatientIcn, FromPatientLastName, FromPatientFirstName, FromPatientMIddleName, FromPatientDob, FromPatientDeathDate, FromPatientSexCode, ToPatientGuid, ToPatientSsn, ToSsnPseudoIndicator, ToPatientIcn, ToPatientLastName, ToPatientFirstName, ToPatientMIddleName, ToPatientDob, ToPatientDeathDate, ToPatientSexCode, MergeFromVistaPatientId, MergeToVistaPatientId, PatientChangeStatusCode, NotificationReceivedDate, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientChange

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientChangeStatus]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientChangeStatus
GO
CREATE VIEW dbo.V_PatientChangeStatus
AS 
SELECT Source='MIRROR', MirrorId, PatientChangeStatusCode, PatientChangeStatusText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientChangeStatus
UNION ALL 
SELECT Source='ACTIVE', 0, PatientChangeStatusCode, PatientChangeStatusText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientChangeStatus

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientOrder]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientOrder
GO
CREATE VIEW dbo.V_PatientOrder
AS 
SELECT Source='MIRROR', MirrorId, PatientOrderGuid, PatientTreatmentGuid, OrderGroupNumber, OrderPlacedDatetime, OrderReceivedDatetime, OrderingProviderId, OrderingProviderLastName, OrderingProviderFirstName, OrderingProviderMiddleInitial, OrderingHospitalLocation, OrderEnteredById, OrderEnteredByLastName, OrderEnteredByFirstName, OrderEnteredByMiddleInitial, RequestReason, SpecimenRequiredIndicator, OrderComments, InformedConsentIndicator, SurgeryName, DivisionCode, InstitutionDivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientOrder
UNION ALL 
SELECT Source='ACTIVE', 0, PatientOrderGuid, PatientTreatmentGuid, OrderGroupNumber, OrderPlacedDatetime, OrderReceivedDatetime, OrderingProviderId, OrderingProviderLastName, OrderingProviderFirstName, OrderingProviderMiddleInitial, OrderingHospitalLocation, OrderEnteredById, OrderEnteredByLastName, OrderEnteredByFirstName, OrderEnteredByMiddleInitial, RequestReason, SpecimenRequiredIndicator, OrderComments, InformedConsentIndicator, SurgeryName, DivisionCode, InstitutionDivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientOrder

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientSpecialInstruction]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientSpecialInstruction
GO
CREATE VIEW dbo.V_PatientSpecialInstruction
AS 
SELECT Source='MIRROR', MirrorId, PatientSpecialInstructionGuid, PatientGuid, PatientSpecialInstructions, CreateDate, CreateUser, VistaConversionIndicator, InactivationComment, InactivateDate, InactivateUser, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientSpecialInstruction
UNION ALL 
SELECT Source='ACTIVE', 0, PatientSpecialInstructionGuid, PatientGuid, PatientSpecialInstructions, CreateDate, CreateUser, VistaConversionIndicator, InactivationComment, InactivateDate, InactivateUser, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientSpecialInstruction

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientSpecimen]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientSpecimen
GO
CREATE VIEW dbo.V_PatientSpecimen
AS 
SELECT Source='MIRROR', MirrorId, PatientSpecimenGuid, PatientGuid, SpecimenUid, SpecimenAccessionNumber, VbecsSpecimenNumber, SpecimenCollectionDate, SpecimenReceivedDate, SpecimenSource, PhlebotomistId, SpecimenExpirationDate, MaintainableSpecimenIndicator, SpecimenStatusCode, UnacceptableSpecimenIndicator, PostTransfusionIndicator, EntryTechId, SpecimenComments, CannedCommentGuid, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientSpecimen
UNION ALL 
SELECT Source='ACTIVE', 0, PatientSpecimenGuid, PatientGuid, SpecimenUid, SpecimenAccessionNumber, VbecsSpecimenNumber, SpecimenCollectionDate, SpecimenReceivedDate, SpecimenSource, PhlebotomistId, SpecimenExpirationDate, MaintainableSpecimenIndicator, SpecimenStatusCode, UnacceptableSpecimenIndicator, PostTransfusionIndicator, EntryTechId, SpecimenComments, CannedCommentGuid, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientSpecimen

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientSymptom]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientSymptom
GO
CREATE VIEW dbo.V_PatientSymptom
AS 
SELECT Source='MIRROR', MirrorId, PatientSymptomId, PatientSymptomName, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientSymptom
UNION ALL 
SELECT Source='ACTIVE', 0, PatientSymptomId, PatientSymptomName, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientSymptom

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientTest]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientTest
GO
CREATE VIEW dbo.V_PatientTest
AS 
SELECT Source='MIRROR', MirrorId, PatientTestGuid, PatientGuid, PatientOrderGuid, OrderableTestId, LabTestId, TestDate, TestResult, ResultDateTime, TestComments, LabTestNormalRange, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientTest
UNION ALL 
SELECT Source='ACTIVE', 0, PatientTestGuid, PatientGuid, PatientOrderGuid, OrderableTestId, LabTestId, TestDate, TestResult, ResultDateTime, TestComments, LabTestNormalRange, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientTest

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientTransfusion]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientTransfusion
GO
CREATE VIEW dbo.V_PatientTransfusion
AS 
SELECT Source='MIRROR', MirrorId, PatientTransfusionGuid, PatientGuid, PatientSpecimenGuid, TransfusionLocation, LocationIen, TransfusionStartDateTime, TransfusionEndDateTime, BloodUnitGuid, BedsideVerificationDate, Transfusionist1Id, Transfusionist2Id, TransfusedVolume, TransfusionPooledUnitsCount, PhlebotomistId, InterruptionIndicator, InterruptionDateTime, InterruptionComment, ReactionIndicator, ReactionSymptoms, OtherDifficultyIndicator, OtherDifficultyText, DssExtractSuccessIndicator, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientTransfusion
UNION ALL 
SELECT Source='ACTIVE', 0, PatientTransfusionGuid, PatientGuid, PatientSpecimenGuid, TransfusionLocation, LocationIen, TransfusionStartDateTime, TransfusionEndDateTime, BloodUnitGuid, BedsideVerificationDate, Transfusionist1Id, Transfusionist2Id, TransfusedVolume, TransfusionPooledUnitsCount, PhlebotomistId, InterruptionIndicator, InterruptionDateTime, InterruptionComment, ReactionIndicator, ReactionSymptoms, OtherDifficultyIndicator, OtherDifficultyText, DssExtractSuccessIndicator, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientTransfusion

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientTransfusionComment]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientTransfusionComment
GO
CREATE VIEW dbo.V_PatientTransfusionComment
AS 
SELECT Source='MIRROR', MirrorId, PatientTransfusionCommentGuid, PatientTransfusionGuid, PatientTransfusionReactionGuid, CannedCommentGuid, CommentCategoryCode, PatientTransfusionCommentText, PreTransfusionIndicator, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientTransfusionComment
UNION ALL 
SELECT Source='ACTIVE', 0, PatientTransfusionCommentGuid, PatientTransfusionGuid, PatientTransfusionReactionGuid, CannedCommentGuid, CommentCategoryCode, PatientTransfusionCommentText, PreTransfusionIndicator, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientTransfusionComment

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientTransfusionReaction]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientTransfusionReaction
GO
CREATE VIEW dbo.V_PatientTransfusionReaction
AS 
SELECT Source='MIRROR', MirrorId, PatientTransfusionReactionGuid, PatientGuid, NotedDateTime, InvestigatedDateTime, TransfusionReactionTypeCode, EntryTechId, EntryDateTime, MedicalDirectorName, OrderedTestGuid, PreSpecimenGuid, PostSpecimenGuid, PreSpecimenNotAvailableIndicator, PostSpecimenNotAvailableIndicator, PreSpecimenClericalChecksOkIndicator, PostSpecimenClericalChecksOkIndicator, PreSpecimenHemolysisInspectionCode, PostSpecimenHemolysisInspectionCode, PartialSaveId, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientTransfusionReaction
UNION ALL 
SELECT Source='ACTIVE', 0, PatientTransfusionReactionGuid, PatientGuid, NotedDateTime, InvestigatedDateTime, TransfusionReactionTypeCode, EntryTechId, EntryDateTime, MedicalDirectorName, OrderedTestGuid, PreSpecimenGuid, PostSpecimenGuid, PreSpecimenNotAvailableIndicator, PostSpecimenNotAvailableIndicator, PreSpecimenClericalChecksOkIndicator, PostSpecimenClericalChecksOkIndicator, PreSpecimenHemolysisInspectionCode, PostSpecimenHemolysisInspectionCode, PartialSaveId, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientTransfusionReaction

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientTransfusionReactionSymptom]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientTransfusionReactionSymptom
GO
CREATE VIEW dbo.V_PatientTransfusionReactionSymptom
AS 
SELECT Source='MIRROR', MirrorId, PatientTransfusionReactionGuid, PatientSymptomId, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientTransfusionReactionSymptom
UNION ALL 
SELECT Source='ACTIVE', 0, PatientTransfusionReactionGuid, PatientSymptomId, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientTransfusionReactionSymptom

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientTransfusionRequirement]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientTransfusionRequirement
GO
CREATE VIEW dbo.V_PatientTransfusionRequirement
AS 
SELECT Source='MIRROR', MirrorId, PatientTransfusionRequirementGuid, PatientGuid, ComponentRequirementId, TransfusionRequirementText, TransfusionRequirementCategoryCode, CreateDate, CreateUser, CreateDivisionCode, VistaConversionIndicator, AntigenTypeId, AntibodyTypeId, AntibodyLastLocation, InactivationComment, InactivateDate, InactivateUser, InactivateDivisionCode, SpecimenTestGuid, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientTransfusionRequirement
UNION ALL 
SELECT Source='ACTIVE', 0, PatientTransfusionRequirementGuid, PatientGuid, ComponentRequirementId, TransfusionRequirementText, TransfusionRequirementCategoryCode, CreateDate, CreateUser, CreateDivisionCode, VistaConversionIndicator, AntigenTypeId, AntibodyTypeId, AntibodyLastLocation, InactivationComment, InactivateDate, InactivateUser, InactivateDivisionCode, SpecimenTestGuid, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientTransfusionRequirement

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PatientTreatment]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PatientTreatment
GO
CREATE VIEW dbo.V_PatientTreatment
AS 
SELECT Source='MIRROR', MirrorId, PatientTreatmentGuid, PatientGuid, PatientTreatingFacility, TreatingSpecialtyCode, PatientLocation, PatientRoomBed, InPatientIndicator, PatientAdmittingDiagnosis, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PatientTreatment
UNION ALL 
SELECT Source='ACTIVE', 0, PatientTreatmentGuid, PatientGuid, PatientTreatingFacility, TreatingSpecialtyCode, PatientLocation, PatientRoomBed, InPatientIndicator, PatientAdmittingDiagnosis, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PatientTreatment

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_PermittedProductModification]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_PermittedProductModification
GO
CREATE VIEW dbo.V_PermittedProductModification
AS 
SELECT Source='MIRROR', MirrorId, PermittedProductModificationGuid, ProductModificationCode, MethodSelect, AddTargetAttribute, FromProductTypeCode, FromCoreCondition, ToProductTypeCode, ToCoreCondition, ExpirationDateRule, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.PermittedProductModification
UNION ALL 
SELECT Source='ACTIVE', 0, PermittedProductModificationGuid, ProductModificationCode, MethodSelect, AddTargetAttribute, FromProductTypeCode, FromCoreCondition, ToProductTypeCode, ToCoreCondition, ExpirationDateRule, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.PermittedProductModification

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ProductModification]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ProductModification
GO
CREATE VIEW dbo.V_ProductModification
AS 
SELECT Source='MIRROR', MirrorId, ProductModificationCode, ProductModificationText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ProductModification
UNION ALL 
SELECT Source='ACTIVE', 0, ProductModificationCode, ProductModificationText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ProductModification

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ProductModificationParameter]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ProductModificationParameter
GO
CREATE VIEW dbo.V_ProductModificationParameter
AS 
SELECT Source='MIRROR', MirrorId, ProductModificationParameterGuid, ProductModificationCode, ProductModificationCost, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ProductModificationParameter
UNION ALL 
SELECT Source='ACTIVE', 0, ProductModificationParameterGuid, ProductModificationCode, ProductModificationCost, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ProductModificationParameter

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ProductShipper]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ProductShipper
GO
CREATE  VIEW dbo.V_ProductShipper
AS 
SELECT Source='MIRROR', MirrorId, ProductShipperGuid, BloodProductGuid, DivisionCode, LocalSupplierGuid, RecordStatusCode, ProductCost, ReturnCreditPercentage, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ProductShipper
UNION ALL 
SELECT Source='ACTIVE', 0, ProductShipperGuid, BloodProductGuid, DivisionCode, LocalSupplierGuid, RecordStatusCode, ProductCost, ReturnCreditPercentage, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ProductShipper

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_Rack]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_Rack
GO
CREATE VIEW dbo.V_Rack
AS 
SELECT Source='MIRROR', MirrorId, RackGuid, DailyControlGuid, RackName, SortColumn, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.Rack
UNION ALL 
SELECT Source='ACTIVE', 0, RackGuid, DailyControlGuid, RackName, SortColumn, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.Rack

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_RackLot]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_RackLot
GO
CREATE VIEW dbo.V_RackLot
AS 
SELECT Source='MIRROR', MirrorId, RackLotGuid, DailyQcWorklistGuid, RackGuid, ReagentGuid, LotUseDate, LotVialNumber, ControlCellId, TestWithName, TestWithId, TestingMethodCode, ExpectedMinimumReactions, ReactivityPhaseCode, SatisfactoryResultIndicator, Comments, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.RackLot
UNION ALL 
SELECT Source='ACTIVE', 0, RackLotGuid, DailyQcWorklistGuid, RackGuid, ReagentGuid, LotUseDate, LotVialNumber, ControlCellId, TestWithName, TestWithId, TestingMethodCode, ExpectedMinimumReactions, ReactivityPhaseCode, SatisfactoryResultIndicator, Comments, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.RackLot

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_RackTest]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_RackTest
GO
CREATE VIEW dbo.V_RackTest
AS 
SELECT Source='MIRROR', MirrorId, RackTestGuid, RackLotGuid, TestDate, TestTechId, RackTestResultTypeCode, RackTestResult, ReagentAmount, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.RackTest
UNION ALL 
SELECT Source='ACTIVE', 0, RackTestGuid, RackLotGuid, TestDate, TestTechId, RackTestResultTypeCode, RackTestResult, ReagentAmount, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.RackTest

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_Reagent]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_Reagent
GO
CREATE VIEW dbo.V_Reagent
AS 
SELECT Source='MIRROR', MirrorId, ReagentGuid, ReagentTypeId, ReagentName, ReagentManufacturerName, ReceiptDate, ReceiptTechId, InvoiceNumber, LotNumber, LotExpirationDate, NumberVialsReceived, NumberVialsAvailable, InventoryChangeDate, InspectionIndicator, Comments, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.Reagent
UNION ALL 
SELECT Source='ACTIVE', 0, ReagentGuid, ReagentTypeId, ReagentName, ReagentManufacturerName, ReceiptDate, ReceiptTechId, InvoiceNumber, LotNumber, LotExpirationDate, NumberVialsReceived, NumberVialsAvailable, InventoryChangeDate, InspectionIndicator, Comments, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.Reagent

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ReagentChange]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ReagentChange
GO
CREATE VIEW dbo.V_ReagentChange
AS 
SELECT Source='MIRROR', MirrorId, ReagentChangeGuid, ReagentGuid, ReagentChangeDetailCode, Comments, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ReagentChange
UNION ALL 
SELECT Source='ACTIVE', 0, ReagentChangeGuid, ReagentGuid, ReagentChangeDetailCode, Comments, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ReagentChange

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ReagentTestParameter]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ReagentTestParameter
GO
CREATE VIEW dbo.V_ReagentTestParameter
AS 
SELECT Source='MIRROR', MirrorId, ReagentTestParameterGuid, ReagentTypeId, CommercialIndicator, DailyUseIndicator, MustUseIndicator, CanChangeIndicator, TestWithName, TestWithId, ReactivityPhaseCode, ExpectedMinimumReactions, SetVialId, DivisionCode, RecordStatusCode, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ReagentTestParameter
UNION ALL 
SELECT Source='ACTIVE', 0, ReagentTestParameterGuid, ReagentTypeId, CommercialIndicator, DailyUseIndicator, MustUseIndicator, CanChangeIndicator, TestWithName, TestWithId, ReactivityPhaseCode, ExpectedMinimumReactions, SetVialId, DivisionCode, RecordStatusCode, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ReagentTestParameter

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ReagentTypeParameter]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ReagentTypeParameter
GO
CREATE VIEW dbo.V_ReagentTypeParameter
AS 
SELECT Source='MIRROR', MirrorId, ReagentTypeParameterGuid, ReagentTypeId, MinimumStockLevel, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ReagentTypeParameter
UNION ALL 
SELECT Source='ACTIVE', 0, ReagentTypeParameterGuid, ReagentTypeId, MinimumStockLevel, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ReagentTypeParameter

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_ReOrderTest]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_ReOrderTest
GO
CREATE VIEW dbo.V_ReOrderTest
AS 
SELECT Source='MIRROR', MirrorId, OrderableTestId, ReOrderTestId, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.ReOrderTest
UNION ALL 
SELECT Source='ACTIVE', 0, OrderableTestId, ReOrderTestId, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.ReOrderTest

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_RestrictionType]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_RestrictionType
GO
CREATE VIEW dbo.V_RestrictionType
AS 
SELECT Source='MIRROR', MirrorId, RestrictionTypeCode, RestrictionTypeText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.RestrictionType
UNION ALL 
SELECT Source='ACTIVE', 0, RestrictionTypeCode, RestrictionTypeText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.RestrictionType

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_Shipment]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_Shipment
GO
CREATE VIEW dbo.V_Shipment
AS 
SELECT Source='MIRROR', MirrorId, ShipmentGuid, LocalSupplierGuid, ProductShipperGuid, InvoiceNumber, ShipmentDate, ShipmentDirection, ShipmentTypeCode, ShipmentTemperature, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.Shipment
UNION ALL 
SELECT Source='ACTIVE', 0, ShipmentGuid, LocalSupplierGuid, ProductShipperGuid, InvoiceNumber, ShipmentDate, ShipmentDirection, ShipmentTypeCode, ShipmentTemperature, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.Shipment

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_SpecimenTest]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_SpecimenTest
GO
CREATE VIEW dbo.V_SpecimenTest
AS 
SELECT Source='MIRROR', MirrorId, SpecimenTestGuid, RackGuid, OrderedTestGuid, PatientSpecimenGuid, BloodTestTypeId, TestDate, TestTechId, TestResultId, EntryTechId, TestingMethodCode, AutoInstrumentName, AutoInstrumentQCIndicator, OffsiteIndicator, OffsiteLocation, OffsiteCost, TestComments, AntibodyTypeId, CorrectedResultIndicator, CannedCommentGuid, AboRhChangeIndicator, AboRhChangeJustification, InactivateDate, InactivateUser, PatientTransfusionReactionGuid, ReactivityPhaseCode, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.SpecimenTest
UNION ALL 
SELECT Source='ACTIVE', 0, SpecimenTestGuid, RackGuid, OrderedTestGuid, PatientSpecimenGuid, BloodTestTypeId, TestDate, TestTechId, TestResultId, EntryTechId, TestingMethodCode, AutoInstrumentName, AutoInstrumentQCIndicator, OffsiteIndicator, OffsiteLocation, OffsiteCost, TestComments, AntibodyTypeId, CorrectedResultIndicator, CannedCommentGuid, AboRhChangeIndicator, AboRhChangeJustification, InactivateDate, InactivateUser, PatientTransfusionReactionGuid, ReactivityPhaseCode, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.SpecimenTest

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_SpecimenTestThreshold]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_SpecimenTestThreshold
GO
CREATE VIEW dbo.V_SpecimenTestThreshold
AS 
SELECT Source='MIRROR', MirrorId, SpecimenTestThresholdGuid, ComponentClassId, VistaLaboratoryTestName, SpecimenTypeCode, LabTestId, WorkloadCode, ThresholdResult, ReportTypeId, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.SpecimenTestThreshold
UNION ALL 
SELECT Source='ACTIVE', 0, SpecimenTestThresholdGuid, ComponentClassId, VistaLaboratoryTestName, SpecimenTypeCode, LabTestId, WorkloadCode, ThresholdResult, ReportTypeId, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.SpecimenTestThreshold

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_Supply]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_Supply
GO
CREATE VIEW dbo.V_Supply
AS 
SELECT Source='MIRROR', MirrorId, SupplyGuid, SupplyTypeId, SupplyName, ManufacturerName, ReceiptDate, ReceiptTechId, InvoiceNumber, LotNumber, LotExpirationDate, LotQuantity, SatisfactoryIndicator, AvailableQuantity, InventoryChangeDate, Comments, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.Supply
UNION ALL 
SELECT Source='ACTIVE', 0, SupplyGuid, SupplyTypeId, SupplyName, ManufacturerName, ReceiptDate, ReceiptTechId, InvoiceNumber, LotNumber, LotExpirationDate, LotQuantity, SatisfactoryIndicator, AvailableQuantity, InventoryChangeDate, Comments, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.Supply

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_SupplyType]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_SupplyType
GO
CREATE VIEW dbo.V_SupplyType
AS 
SELECT Source='MIRROR', MirrorId, SupplyTypeId, SupplyTypeText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.SupplyType
UNION ALL 
SELECT Source='ACTIVE', 0, SupplyTypeId, SupplyTypeText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.SupplyType

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_TimeZone]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_TimeZone
GO
CREATE VIEW dbo.V_TimeZone
AS 
SELECT Source='MIRROR', MirrorId, TimeZoneId, TimeZoneName, StandardTimeText, TimeZoneBias, DaylightTimeName, DaylightTimeText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.TimeZone
UNION ALL 
SELECT Source='ACTIVE', 0, TimeZoneId, TimeZoneName, StandardTimeText, TimeZoneBias, DaylightTimeName, DaylightTimeText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.TimeZone

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_TransfusionReaction]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_TransfusionReaction
GO
CREATE VIEW dbo.V_TransfusionReaction
AS 
SELECT Source='MIRROR', MirrorId, TransfusionReactionGuid, PatientTransfusionGuid, PatientTransfusionReactionGuid, BagHemolysisInspectionCode, BagReturnedIndicator, BagClericalChecksOkIndicator, PreClericalChecksOkIndicator, PostClericalChecksOkIndicator, TagNotScannedIndicator, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.TransfusionReaction
UNION ALL 
SELECT Source='ACTIVE', 0, TransfusionReactionGuid, PatientTransfusionGuid, PatientTransfusionReactionGuid, BagHemolysisInspectionCode, BagReturnedIndicator, BagClericalChecksOkIndicator, PreClericalChecksOkIndicator, PostClericalChecksOkIndicator, TagNotScannedIndicator, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.TransfusionReaction

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_TreatingSpecialty]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_TreatingSpecialty
GO
CREATE VIEW dbo.V_TreatingSpecialty
AS 
SELECT Source='MIRROR', MirrorId, TreatingSpecialtyCode, TreatingSpecialtyName, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.TreatingSpecialty
UNION ALL 
SELECT Source='ACTIVE', 0, TreatingSpecialtyCode, TreatingSpecialtyName, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.TreatingSpecialty

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_VamcDivision]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_VamcDivision
GO
CREATE VIEW dbo.V_VamcDivision
AS 
SELECT Source='MIRROR', MirrorId, DivisionCode, DivisionGuid, DivisionName, ServiceTypeIndicator, IccbbaRegistrationNumber, ElectronicCrossmatchIndicator, FacilityGuid, LocalSupplierGuid, AntibodyScreenDisplayCode, MaximumSpecimenExpirationDays, AutomatedInstrumentIndicator, LabelPrinterUseIndicator, LabelPrinterComPortNumber, LabelPrinterIPAddress, LabelPrinterTcpPortNumber, TimeZoneId, DaylightSavingsTypeId, PrinterName, PrinterAlertsIndicator, PrinterAlertsPrinterName, PrinterOrderAlertTypeCode, PrinterOrdersNeededHours, IconAlertsIndicator, IconOrderAlertTypeCode, IconOrdersNeededHours, IconRefreshRate, LoginMessageText, InvoiceTemplateText, MedicalDirectorName, UsaIndicator, LockInactivityTimeoutMin, AccessionAreaId, DaylightSavingsStartDate, DaylightSavingsEndDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.VamcDivision
UNION ALL 
SELECT Source='ACTIVE', 0, DivisionCode, DivisionGuid, DivisionName, ServiceTypeIndicator, IccbbaRegistrationNumber, ElectronicCrossmatchIndicator, FacilityGuid, LocalSupplierGuid, AntibodyScreenDisplayCode, MaximumSpecimenExpirationDays, AutomatedInstrumentIndicator, LabelPrinterUseIndicator, LabelPrinterComPortNumber, LabelPrinterIPAddress, LabelPrinterTcpPortNumber, TimeZoneId, DaylightSavingsTypeId, PrinterName, PrinterAlertsIndicator, PrinterAlertsPrinterName, PrinterOrderAlertTypeCode, PrinterOrdersNeededHours, IconAlertsIndicator, IconOrderAlertTypeCode, IconOrdersNeededHours, IconRefreshRate, LoginMessageText, InvoiceTemplateText, MedicalDirectorName, UsaIndicator, LockInactivityTimeoutMin, AccessionAreaId, DaylightSavingsStartDate, DaylightSavingsEndDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.VamcDivision

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_VbecsProcess]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_VbecsProcess
GO
CREATE VIEW dbo.V_VbecsProcess
AS 
SELECT Source='MIRROR', MirrorId, VbecsProcessId, VbecsProcessGuid, VbecsProcessName, TransactionType, RecordStatusCode, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.VbecsProcess
UNION ALL 
SELECT Source='ACTIVE', 0, VbecsProcessId, VbecsProcessGuid, VbecsProcessName, TransactionType, RecordStatusCode, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.VbecsProcess

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_VbecsUser]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_VbecsUser
GO
CREATE VIEW dbo.V_VbecsUser
AS 
SELECT Source='MIRROR', MirrorId, VbecsUserId, VbecsUserGuid, UserDUZ, UserName, UserInitials, VistaUserName, UserEmail, SystemUserIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.VbecsUser
UNION ALL 
SELECT Source='ACTIVE', 0, VbecsUserId, VbecsUserGuid, UserDUZ, UserName, UserInitials, VistaUserName, UserEmail, SystemUserIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.VbecsUser

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_VbecsUserDivisionRole]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_VbecsUserDivisionRole
GO
CREATE VIEW dbo.V_VbecsUserDivisionRole
AS 
SELECT Source='MIRROR', MirrorId, VbecsUserId, DivisionCode, UserRoleId, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.VbecsUserDivisionRole
UNION ALL 
SELECT Source='ACTIVE', 0, VbecsUserId, DivisionCode, UserRoleId, RecordStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.VbecsUserDivisionRole

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_VistaLinkControl]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_VistaLinkControl
GO
CREATE VIEW dbo.V_VistaLinkControl
AS 			
SELECT Source='MIRROR', MirrorId, ServerAppHandle, ServerAlias, VistaIpAddress, VistaDomainName, VistaPortNumber, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.VistaLinkControl
UNION ALL 
SELECT Source='ACTIVE', 0, ServerAppHandle, ServerAlias, VistaIpAddress, VistaDomainName, VistaPortNumber, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate
FROM VBECS_V1_TEST.dbo.VistaLinkControl
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_WorkloadEvent]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_WorkloadEvent
GO
CREATE VIEW dbo.V_WorkloadEvent
AS 
SELECT Source='MIRROR', MirrorId, WorkloadEventGuid, WorkloadEventDate, WorkloadProcessGuid, BloodUnitGuid, PatientGuid, MiscellaneousGuid, OrderedComponentGuid, OrderedTestGuid, WorkloadEventStatusCode, RecordSentIndicator, ProcessedDate, ErrorText, PceEncounterNumber, WeightMultiplier, VistaTechId, RecordStatusCode, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.WorkloadEvent
UNION ALL 
SELECT Source='ACTIVE', 0, WorkloadEventGuid, WorkloadEventDate, WorkloadProcessGuid, BloodUnitGuid, PatientGuid, MiscellaneousGuid, OrderedComponentGuid, OrderedTestGuid, WorkloadEventStatusCode, RecordSentIndicator, ProcessedDate, ErrorText, PceEncounterNumber, WeightMultiplier, VistaTechId, RecordStatusCode, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.WorkloadEvent

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_WorkloadEventStatus]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_WorkloadEventStatus
GO
CREATE VIEW dbo.V_WorkloadEventStatus
AS 
SELECT Source='MIRROR', MirrorId, WorkloadEventStatusCode, WorkloadEventStatusText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.WorkloadEventStatus
UNION ALL 
SELECT Source='ACTIVE', 0, WorkloadEventStatusCode, WorkloadEventStatusText, SortColumn, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.WorkloadEventStatus

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[V_WorkloadProcess]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_WorkloadProcess
GO
CREATE VIEW dbo.V_WorkloadProcess
AS 
SELECT Source='MIRROR', MirrorId, WorkloadProcessGuid, WorkloadCode, WorkloadProcedure, VbecsProcessId, AssignedDate, UnAssignedDate, WeightMultiplier, RecordStatusCode, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM dbo.WorkloadProcess
UNION ALL 
SELECT Source='ACTIVE', 0, WorkloadProcessGuid, WorkloadCode, WorkloadProcedure, VbecsProcessId, AssignedDate, UnAssignedDate, WeightMultiplier, RecordStatusCode, DivisionCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate 
FROM VBECS_V1_TEST.dbo.WorkloadProcess

GO

/*****************************************************************************************
*	Grant permissions on tables
*****************************************************************************************/
GRANT SELECT, INSERT ON dbo.InterfaceControl TO VbecsAppMirrorUser
GRANT SELECT, INSERT ON dbo.PatientChange TO VbecsAppMirrorUser

/*****************************************************************************************
*	Grant permissions on views
*****************************************************************************************/
GRANT SELECT ON dbo.V_Address TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_AntibodyParameter TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_AntigenTest TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_AntigenType TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_AntiseraOrderedTest TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_AntiseraUnitTest TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_AntiseraWorklist TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_AntiseraWorklistTyping TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_AssociatedInstitution TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_BloodUnit TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_BloodUnitAntigen TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_BloodUnitCurrentShipment TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_BloodUnitFinance TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_BloodUnitMedia TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_BloodUnitModification TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_BloodUnitShipment TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_BloodUnitStatus TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_BloodUnitTest TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_CannedComment TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ComponentClassCompatibility TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ComponentClassParameter TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ComponentRequirement TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ConfirmationWorklistUnit TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_DailyControl TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_DailyQcWorklist TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_DaylightSavingsType TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_Equipment TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_EquipmentMaintenance TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ExceptionType TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_HcpcsAssignment TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_HemolysisInspection TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_InformationMessage TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_InterfaceControl TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_IssuedUnit TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_IssuedUnitComment TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_LocalSupplier TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_LoginMessage TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_MessageStatus TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ModificationEquipment TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ModificationSupply TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_Msbos TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_MsbosComponentClass TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_OrderAlertType TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_OrderedComponent TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_OrderedTest TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_OrderedUnit TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_OrderedUnitComment TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_Patient TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientChange TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientChangeStatus TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientOrder TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientSpecialInstruction TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientSpecimen TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientSymptom TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientTest TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientTransfusion TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientTransfusionComment TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientTransfusionReaction TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientTransfusionReactionSymptom TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientTransfusionRequirement TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PatientTreatment TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_PermittedProductModification TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ProductModification TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ProductModificationParameter TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ProductShipper TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_Rack TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_RackLot TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_RackTest TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_Reagent TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ReagentChange TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ReagentTestParameter TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ReagentTypeParameter TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_ReOrderTest TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_RestrictionType TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_Shipment TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_SpecimenTest TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_SpecimenTestThreshold TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_Supply TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_SupplyType TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_TimeZone TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_TransfusionReaction TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_TreatingSpecialty TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_VamcDivision TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_VbecsProcess TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_VbecsUser TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_VbecsUserDivisionRole TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_VistaLinkControl TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_WorkloadEvent TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_WorkloadEventStatus TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_WorkloadProcess TO VbecsAppMirrorUser


USE VBECS_V1_TEST
GO

/*****************************************************************************************
*	Update the data in the table
*****************************************************************************************/

-- Update 1 row in dbo.ProductAttribute
UPDATE dbo.ProductAttribute SET ProductAttributePrintName = 'NaCit', LastUpdateDate = '20081201 15:49:48.483' WHERE ProductAttributeId = '@CH'

-- Update 1 row in dbo.BrokenRule
UPDATE dbo.BrokenRule SET ValidationMessage = 'VistA user DUZ selected is not unique - VistA user with this DUZ is already associated with some VBECS user. Please use another VistA account.', LastUpdateDate = '20090203 00:00:00.000', LastUpdateUser = 'vhaishjensec' WHERE FormName = 'VbecsUser' AND  FieldName = 'UserDuzIsNotUnique'

-- Update 1 row in dbo.UserRoleFunction
UPDATE dbo.UserRoleFunction SET RoleFunctionId = 19, UserRoleId = 4,  LastUpdateDate = '20081216 00:00:00.000', LastUpdateUser = 'VHAISHASKEWD',  LastUpdateFunctionId = 0 WHERE RoleFunctionId = 19 AND UserRoleId = 2

-- Update 1971 rows in dbo.BloodProduct
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'002b6ca1-3712-43fc-b4fa-6e0fe6c39bda'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0039fd51-e5cc-486b-ad5e-637f862f2e98'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.100' WHERE BloodProductGuid=N'007cb83c-91e5-4fb8-99bc-aac7b8865ad4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'00a20666-d95f-4eea-a0a6-08e93e9289f5'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.037', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'00c7729c-668b-4b2f-ae81-67d6daf93e5a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.583' WHERE BloodProductGuid=N'00e4b0b5-344b-44a7-a902-4e94a270993b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.740' WHERE BloodProductGuid=N'00fd0d3e-9026-4d53-81b4-b3ab84ffcb6e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.740' WHERE BloodProductGuid=N'0178eb66-21e4-4cd0-8268-749da5e29a69'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'018c1924-7017-406f-afe1-38500db61c1b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'01a08784-04fc-4d57-a496-987c98c26f25'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'01a2a5da-1777-4240-b676-a153d22d9804'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.833' WHERE BloodProductGuid=N'01bc17c1-c1f6-48d3-859d-e99f2a098b9d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'01c09bac-60df-4d1f-b05d-3d1bfef203ed'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.897' WHERE BloodProductGuid=N'01d2c607-32c3-483b-9ec5-0985e75ab7fc'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'01dd8113-d0fd-483a-b3fa-c151380781cc'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'01f323b2-b87e-460f-a09e-633fd44d85fc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'01fb37f8-2b75-4e13-870d-df092bf29c21'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.380' WHERE BloodProductGuid=N'025403cc-983e-4b4a-a45b-d6b35713cb44'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'025aea72-1ac1-40c4-a3d6-0ae052d1eb98'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0282cc83-4769-4056-ab5e-1af5148c03ee'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.757' WHERE BloodProductGuid=N'028997c4-bb3d-4123-b44c-e7edf21b313f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'029d322b-7401-4af1-9d2d-d518f5068a96'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'02c44b6e-9b8e-44a4-a88d-5ec3fb1fc3cb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'02ce1e6d-0439-4001-bb61-68c826fd4c7b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'02e1b106-c5c3-4fbc-8e56-2d1db5fb052b'
UPDATE dbo.BloodProduct SET ProductVolume=300, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'02e52764-8dc7-41f5-b818-df6044a8946d'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'02f51180-8890-4178-83f2-c3815c83d943'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'02fafe1c-8f76-486c-925b-1d92f47b5a3e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.413' WHERE BloodProductGuid=N'032d1112-2160-49c6-b26a-6e9606fdb4e0'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.490' WHERE BloodProductGuid=N'0381a2f8-9a0e-4345-85fe-baf5cc236a06'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0388e487-8bff-4169-bb25-93692974a426'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'038b68ca-fbd0-4bf9-b2cf-eac647f777a0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'03a026d0-93b2-4e15-abe3-610cd64f235d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'03c44190-c427-4280-ba26-97ecd8c0670c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'03db73d3-7c6f-4dbc-a449-ee4f6e33ece6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'03fc7c85-fffd-432e-ac06-602af22f12d0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'03feabc4-24fe-4370-a81f-6f7e9fd90e21'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'04334df2-b855-4e77-9da1-62647963596c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'04842478-bd39-4ebc-b181-0b3fb1423a2c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0496a077-534e-4787-8120-53ad4046f956'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.867' WHERE BloodProductGuid=N'04bcbb56-349c-47b5-b36e-075728c11dae'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'050684ad-f2c0-45a3-b48f-bc63816c307e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'05244089-e384-4fb4-b6f7-8f68a2c1ece4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0558dff1-9926-4b80-bbf4-d2c6f7b92a0a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'05a455ab-b9c8-42ac-bb95-20cb67a69741'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'05b4a598-8af2-434b-b498-1cb48315fc4f'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.880' WHERE BloodProductGuid=N'05c50772-210a-4730-b0c4-85a0af1a9680'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'05c8c694-4fd1-4975-b084-5530550f5cb8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'05e3a4e2-cbfc-47e6-8656-99abdbd7fac5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.537' WHERE BloodProductGuid=N'060aeeb8-1ea4-4870-b6a0-1efb304c470b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'060d9201-333a-43d6-bfb5-be18e022e610'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0650eeff-2345-43ee-b1e8-c28d40866263'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'06709155-fa60-46d9-8529-03f1d8783c1d'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'067d933c-9363-4691-8086-a2f9cb6c7986'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'06b9a8e8-70f9-4a13-8e5d-e50316c77156'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'06be1488-3731-42a2-84af-13015ad39f9d'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'06dc39c6-0c65-4e3f-91c1-950294a7452e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.320' WHERE BloodProductGuid=N'070708af-4559-4ab5-822d-31984ad96122'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'070c4a92-b0e2-4407-bac6-8eac2726539c'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.833' WHERE BloodProductGuid=N'07456b83-79fa-45c2-ae09-6a5425bf2783'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0778109c-efe1-44cb-8f1c-cd2ed884056e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.053' WHERE BloodProductGuid=N'077e0471-1cbd-4b80-b6d3-7ff5d14f1f1a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'077eb07d-bbf5-4258-a890-b79e36f09d43'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'07a2014a-c448-4db2-a841-378d5d115bd8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'07c10503-31da-4494-9e37-4a3c9e74d0c1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.570' WHERE BloodProductGuid=N'0839092b-df37-4e26-a203-e865f45d941f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'08888411-b47f-4802-bf11-a32477c2a8f4'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'08f4556c-ae35-4c8e-8314-19a8619fea55'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'08fb91b6-2f08-4e44-a5bf-8aede0d16881'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.007' WHERE BloodProductGuid=N'0943ec68-3b14-4099-ba9d-9340ee5788c1'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'094bb002-ba82-49c0-88df-ff66f24f91a2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'097605c5-d534-4014-80a5-4e6a1502c15c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'098f3ca1-ae7c-44b6-bacd-430245cb5a0d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.570' WHERE BloodProductGuid=N'09fb04d7-e24f-4d7b-a610-bf92b9008cd9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0a16b675-31bf-4973-905f-ac1737ac6cd5'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.803' WHERE BloodProductGuid=N'0a2bc861-db6c-4629-b79b-b901abd69f28'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0a33947c-5e6b-496c-ab24-450f1f6bdfb2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.617', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'0a35ad07-8166-4168-8bea-bee975e7b592'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.320' WHERE BloodProductGuid=N'0af35230-ba93-45ec-803b-840e177c48ec'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0b1b8000-da34-4b60-bdd1-a3da69e8ce5e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0b1ba3b3-a2ac-4203-893a-b9e60d0082da'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.913' WHERE BloodProductGuid=N'0b1be1ec-9c48-4c8d-872a-56e273925ca9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0b3add9a-0477-4b28-88d5-f3d1fbc24a15'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.320' WHERE BloodProductGuid=N'0b85dde0-9bba-48be-88e9-873e4a9d5c03'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.583' WHERE BloodProductGuid=N'0b9faf1e-9413-43ad-9954-2e8a7cdf611e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0be3f88f-1d1d-409e-a556-bf00318e27ed'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0bec07bd-1a3c-4d28-a4d3-c176fa32c08f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0bfa350a-0ecb-4f12-9685-eb7a6f4133e7'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.820' WHERE BloodProductGuid=N'0c1bdefb-75d0-4217-a0bf-a128a2726769'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0c22c83f-53dd-4727-bb6e-c27abba6a4f5'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.130' WHERE BloodProductGuid=N'0c51c51f-0c4f-466b-a12b-57b09d63077b'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0c6afcae-4225-4e3c-8088-d3f9f11c772f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0c775437-1741-42fc-95b7-e0dd0fcc9868'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0c7ac9dd-513a-423e-af4c-83e2e134c5f9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0ca318d0-6de4-43ef-baaf-8fc46c368ea4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0cc068d0-fd99-4aff-bbc3-f64b12deafb2'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.227' WHERE BloodProductGuid=N'0cc3d421-308b-44b8-9875-9ae23dd552b5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0cfea8df-8c47-48b2-b8b1-b92f32090cf0'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.757' WHERE BloodProductGuid=N'0d61466e-ad69-4471-88bd-30b1da76e16a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.193' WHERE BloodProductGuid=N'0d742a06-62f3-4ee2-a774-d80879beb70e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.210' WHERE BloodProductGuid=N'0d75cd4e-558e-44c4-8b9b-d6173a4e637d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.333' WHERE BloodProductGuid=N'0d93d8b2-9fc9-4b28-ba85-232832b4df1c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0da40803-8bc8-4eb4-ab3b-fbd63403e15f'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.583' WHERE BloodProductGuid=N'0daa94a6-c7bf-4466-a944-eb4a82e9d89e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0deb9544-999d-491d-a674-e174f540bd10'
UPDATE dbo.BloodProduct SET ProductVolume=15, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0dfa11cb-2a4f-4d38-a4a9-0a74a97365ba'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0e302ba7-176f-4567-982b-f994a7c75e4d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0e4685df-df3b-42d4-a5c4-13b4013e09f2'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'0e704672-1a70-4742-8ff0-ecf151696434'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0e9da76f-e5b2-4a81-a1cc-3baf0dd6660c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0eb5f2a4-73f8-472e-b2e9-7372297e880b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0ec15260-8d96-493e-a3d0-733e193b32a1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0ed13a70-4ad2-420e-a1f6-fe9c8e8228d3'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.397' WHERE BloodProductGuid=N'0eddc40d-e6e5-4c65-b085-febef1408c21'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0f017c49-8605-410f-9f53-e17ae14ae948'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0f20e6d5-a096-4c3c-bbfb-1f66bb014c13'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0f2b6684-060c-4ab3-b36e-2e6e9b0be71f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'0f4b303d-7718-42c1-ab77-900f392720bc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0f4f545d-40c5-4714-b0c4-e3aa3748238c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'0f62b616-3e73-4534-a554-872d6f01110b'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0f7831a9-9633-47ab-9da8-9b75c3f6287c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0f8cc761-051d-4d49-b9b3-5ba2df7ce04b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.180' WHERE BloodProductGuid=N'0f923d51-fa28-4456-a2ff-66d4769edc47'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0f9fc41d-b6d3-4dae-afa9-f6db2066db10'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'0fb552fc-08d9-40a0-bfd3-b9689557ed38'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.257' WHERE BloodProductGuid=N'0ff344f2-aee2-4dc1-998a-75d0c4b1f6de'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.023' WHERE BloodProductGuid=N'101a4ee5-b215-48b3-a030-d66f2950cbee'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'10570291-67fa-4abb-be86-e7153f596dfd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1069bda2-3abc-4030-b5a1-0d6f6ee44d56'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'10770a38-f9d8-4a0c-8202-26dd54c2f825'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.070' WHERE BloodProductGuid=N'10a96980-6e9b-4e41-90fa-3c5074206f36'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'10b45771-a8d8-44a9-95c4-589cd23d3eea'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'10ca41e6-89f9-4aff-b597-80346c057acb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.180', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'11021993-e49d-4c18-af3f-60ef3d2caa25'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'112eab53-ecdb-4453-af47-a592674f1e1b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.630' WHERE BloodProductGuid=N'116129f9-ffa7-4a6f-9840-bf8d8ea0e1ac'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1169610f-2f46-4180-974c-76c1c030b7bd'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'118c89ef-5584-430c-8311-f0b44848671f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.460' WHERE BloodProductGuid=N'11a33d78-21a7-4664-8221-4e59de8a8ad9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'11adad87-b981-4151-bb3c-94e72ce66047'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'11b2ad7a-8758-4bf7-a065-6ddd23a22577'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'11bb33ef-6a0d-46fa-b475-5869ba87ece6'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.833' WHERE BloodProductGuid=N'11c29961-fc12-4362-9a45-0b50e6ff7b47'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.287' WHERE BloodProductGuid=N'1236b1a7-e17c-471b-a903-ee10c2767fb0'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'124cde93-1dbd-4567-a134-f68a7d0f8991'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.333' WHERE BloodProductGuid=N'125938c7-48fe-482f-888e-37941521b72f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'12748001-3571-439f-b545-e32d014cdfca'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'128fff9a-9887-4a4c-a7bc-1883ecb224f1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'129e675d-321f-43de-9d58-1dd6f3135646'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'12a84d9b-d70f-4001-8148-a5da9cf09200'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'12c47211-3748-4864-aa1e-88d2b45150ed'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'12cbe42c-0683-40e4-ade2-abbdaac24902'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'12d096f6-38ac-4eba-a6f9-778c39b83199'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'12ed4920-33f5-436a-bcef-4103786f2f93'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.070' WHERE BloodProductGuid=N'12f0262b-837d-4f7e-a55e-1c01cf957db1'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1306c9b1-feac-4074-b386-a1ded47d0949'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.787' WHERE BloodProductGuid=N'130761d9-b4d7-4d26-adf0-102130211394'
UPDATE dbo.BloodProduct SET ProductVolume=15, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'13177e20-72d1-4948-921d-1b9d1dd8213b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:57.897' WHERE BloodProductGuid=N'132e9cb3-6755-4d25-8b97-ff4b060b8f9e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'13320291-4e07-495c-bbc1-080b69d0cb0f'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.757' WHERE BloodProductGuid=N'135da8d2-2ac9-4b0b-9531-87962f30c5c2'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'13660bdf-39dd-433e-9a04-a853fcc12856'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'136e7765-915f-4717-8246-db3069c464f5'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.413' WHERE BloodProductGuid=N'138bc1b4-55a4-42a3-986f-1189e7b5db0f'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'13a50535-a8ee-4f82-84f4-4810bfacf89c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'13b61f93-eab2-42db-94d9-364009636d4e'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.600' WHERE BloodProductGuid=N'13f910b3-ff97-4060-9024-7c03eae6fa7c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'140b757a-ae2d-4dc8-a73c-0d4b473e755f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'141b8688-7713-4d1c-a88a-648ee0778c8a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'144358b8-5679-492b-baef-62a81cee8c52'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'144cff86-221f-49c2-8b4d-4bbe09923600'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.930' WHERE BloodProductGuid=N'14a18236-3dd1-4f39-a466-6de509961115'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'15203cd9-f8c3-41e3-8217-8b257410d89b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.740' WHERE BloodProductGuid=N'15245415-6e28-469c-a099-aaa8f8fa620a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.070' WHERE BloodProductGuid=N'155fd515-7c17-46ed-ad28-f4755b871528'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1566e03d-dcf5-4104-af51-4ffb23ab7280'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'157416a3-a621-473c-8fbb-a2f282515e9d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'15c940e3-3b3b-41e2-9774-a161937d2c7d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.880' WHERE BloodProductGuid=N'15cac4be-17a7-40d7-9a97-b6d0143c719a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'15e099bb-c7d4-439d-bcb0-0945ae3bc894'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'15e64de6-1b6a-411a-9908-931f6dfa276f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'16025c93-db0e-4fdc-a6c1-0f8dd3b79547'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'162135fe-945d-475e-a035-292d0d15159e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1623591d-b1d6-4c07-b70f-6b30c4088be2'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'163f7ee1-0d2f-4648-9fcb-8abdffc53e9e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'16532084-5a3b-4582-9556-85fcd73631b8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.460' WHERE BloodProductGuid=N'16a2f7c9-ac4c-4629-9883-7f35188495a9'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'16d0cbf2-f22e-4b9b-b403-57fcfa60223c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'16d5ca2e-560d-4599-9e12-3d47cc9f020b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.977' WHERE BloodProductGuid=N'16d74f5b-6e99-4bc4-a918-3cbb5034682e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.477', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'175cffd7-b7eb-4d9a-b95a-1f74688a01e5'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.537' WHERE BloodProductGuid=N'17c52a68-bc55-47ab-b9ed-c08853672534'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.273' WHERE BloodProductGuid=N'18002e5f-a595-4f50-b0f7-0f086ce5b20b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.930' WHERE BloodProductGuid=N'1801b881-7672-4262-9738-29bf2d845c40'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.680' WHERE BloodProductGuid=N'18063190-1b8f-44e3-a478-cd166afc810c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'18776dbc-cce7-4c81-ba45-09fa4815f6f0'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'187f207d-ea36-4b76-960c-cd586ecf3868'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.960' WHERE BloodProductGuid=N'18989835-bdc7-400f-ae4a-649ccb8bdf8d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'18ac9930-e6a9-456f-a095-e595e96029f8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'18c242c0-f629-4e26-a318-520d1f2feaed'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.960' WHERE BloodProductGuid=N'18dd8541-3f55-461b-bcca-157fcf52eba3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'18e27f36-917d-4fa8-820d-473afbd8ad7d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.227' WHERE BloodProductGuid=N'18eb955c-5825-4bb3-b28a-eb276a05d2b4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'18f1a6b1-b75b-4117-81f0-32416dcbd117'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'19053c2c-5d95-4cb0-a2f1-b525f097807d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.070' WHERE BloodProductGuid=N'19168b9b-2b06-473a-9b3e-b628d15b2fe5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1934f194-86a1-4b42-a0e0-2de743c0cd39'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'19759eea-31a1-46bb-a757-c382fc7c97cb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'198d0929-2a42-46f7-b841-dd0b863329c6'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'19a94be8-0c7d-4266-b137-b5c70b44bf1a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'19c49ace-c1bb-4edc-bc4b-01e653771bec'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.647' WHERE BloodProductGuid=N'19d94820-0c21-4b72-920c-3b1bcda8cc82'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'19f96430-398b-449e-bd31-2466683e32f1'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1a057c2d-55b0-4c58-9a7b-ac1cdee3ce0b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1a0d467c-eaad-4c80-a002-92fd8944ddea'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1a5ec54a-a544-47e7-87fa-bfd67c9fcd3d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1a7afe2b-68e0-4c54-8c6d-67448720dc00'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1aac7056-42dd-41b7-ae10-dfad7bcf851f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1ad4e417-a684-47bc-8efa-f9e90f49959f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1ad64285-6f21-4f32-bf0f-7575410408df'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.773' WHERE BloodProductGuid=N'1b06194d-e258-4eb8-8e10-8ef631232e89'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1b07471a-8b08-4fad-9081-c315f4153e62'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1b62b663-9c74-4004-8427-5dc07c1d6e7c'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1b8b3739-b013-4ad1-b418-674d1c1632dd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.100' WHERE BloodProductGuid=N'1b9d1bbb-fb85-468d-aa7e-8f6998ed8a00'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1bedcb65-35f2-478a-9624-36f55334d30d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1c2b9664-db31-4e07-ab10-6b0ffb6808ff'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1c3372ec-8ce8-4e52-80db-06161cc023ff'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.193' WHERE BloodProductGuid=N'1c552948-0c72-48bd-bf63-a065443556e6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.773' WHERE BloodProductGuid=N'1c7a3056-5e3a-4b52-b886-524e0b2b1e35'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1c8eccab-27e8-4830-98f4-a5ef7ad1210d'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1cd02088-0ba7-46c5-bd52-fef80ed93f7c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1cd29dd4-d6c6-476b-bbbe-eb9a477af367'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1cf1e5d7-dc03-44ed-b72f-66a4ba4a2fdd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.600' WHERE BloodProductGuid=N'1d3a485e-c89e-4ebd-ad4d-1d9e114533f0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.617' WHERE BloodProductGuid=N'1d54f9e7-b104-462a-b437-c856830d018b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1d661b24-cfaa-4750-ad59-af1109597462'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1d70de6c-50bf-41af-99f2-6ad7734b010d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.147' WHERE BloodProductGuid=N'1d95880f-42ed-43a9-9375-c6b603a8cedb'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1de1a884-9a90-4c27-b44b-13b94c90e05a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:58.053' WHERE BloodProductGuid=N'1deaed29-91f2-47fd-a0fb-7c6c981d1ab7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1e198730-e33f-4e98-8287-2c04d527a6f2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1e707147-2dfc-4a4e-8064-fd640c5149ba'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.537' WHERE BloodProductGuid=N'1e90c2cd-3dd7-4b03-b51b-fc6e56ebaf78'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1e9aa382-15fc-41d4-ab75-b1c454debc30'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1ea684d9-6036-4610-a6b1-9112cc87f67d'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1eb9091e-4b64-45cd-923c-5b7e7657bc9a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1ec781d2-be49-44d2-8323-485fc7866fe0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1eeae06d-4661-4209-9049-41d2b583987d'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1ef36612-14c6-45f1-b5c9-ce25949524d1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1ef6823a-4a89-4629-befc-1f38cf1d8cea'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1f02bc07-616f-4257-a607-c50f648a2118'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1f0c073e-be52-46af-b059-cf012ef8e0fb'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1f1a158c-a90c-412e-b820-75b6b6a5c1da'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1f5143d7-c111-4447-9114-6f618e62fe0c'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1f5b0b08-a976-412f-954e-6523a726e8f8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'1f9e39d7-e229-4882-b4e3-d58ee5a00ef1'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.727' WHERE BloodProductGuid=N'1fd99b1e-74cd-430e-8cb2-c3cd3b83ec7f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.117' WHERE BloodProductGuid=N'20003ffb-2cae-4b70-b479-d9512c28bd43'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'200ee710-5f9f-4518-8205-4af242bf7942'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.460' WHERE BloodProductGuid=N'202f609f-0524-4624-b1ef-ce2842b5b5f1'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.960' WHERE BloodProductGuid=N'206b44d6-2029-4a97-8beb-990e9688941c'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.100' WHERE BloodProductGuid=N'208b3f92-8957-4d5a-84f3-92038b1d5b26'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'21139cbf-39ec-4cd9-89fc-782e7283a6fb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'216b5f32-1929-42cd-9c2f-7c9d5064909c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'218e98a0-88c9-46e1-9f07-f3aa64df6d82'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'21962841-a3cc-42de-a660-80be428ec281'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2199adc9-bfb8-44eb-a172-b58b2095a3a6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'21e33da9-c779-4d0b-9a2c-8e5390f3463e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'220f9b56-21fb-41de-b211-1bee298f0473'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.053' WHERE BloodProductGuid=N'221e7807-eb7d-4e7b-81d6-4102da71f59f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2223add1-1272-4d23-ba1e-acb3d464e7fb'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.210' WHERE BloodProductGuid=N'2247349b-da6f-4b10-b80e-8818e62328bf'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.757' WHERE BloodProductGuid=N'22654020-f8ff-4467-bc74-a17cf0ca2f35'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'2283e002-8334-4afd-a516-9c6fae334462'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'22b23c43-ebfb-43f3-b279-4c6571e3a1cc'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'22de93fd-bf8f-40ec-bb26-cb8579227a76'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.180' WHERE BloodProductGuid=N'23221036-c095-477b-95a7-9a6a398e29d3'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.537' WHERE BloodProductGuid=N'23269258-6abd-4856-92c1-a9b8cd89fa3e'
UPDATE dbo.BloodProduct SET ProductName=N'POOLED PLATELET-RICH BUFFY COAT|CPD/XX/20-24C|Irradiated', MaximumStorageTime=4, LastUpdateDate='20090501 09:30:02.240' WHERE BloodProductGuid=N'2341670f-35ea-44c7-95d7-e509599be935'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.367' WHERE BloodProductGuid=N'2362a3d2-adfc-49ff-9f7a-ce63efd03518'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'236de902-16d0-4289-8cb2-8588e507b72e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'238e0673-1855-4dd4-9430-188cc914d9b1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.163' WHERE BloodProductGuid=N'23be97ac-a34a-4f02-8ade-ac8f2f642d04'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'23df5bf6-3834-4a97-a202-5595f8097e19'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'24586a20-fb04-451e-aef2-5d3195a50cac'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'245b75f2-6278-4ae6-bec9-0b1f86750e72'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.443' WHERE BloodProductGuid=N'245ea715-8697-4517-ab73-72ec69f271a1'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'247531c8-144c-4af6-aa54-1364cb499307'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'248890be-66e6-4dc9-a2d8-24033b2b1f86'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'248ba832-1399-4a81-9ed4-eb3287e245c4'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.820' WHERE BloodProductGuid=N'249e1ded-8295-4485-9bc9-d8cf8d39cb69'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'24f56ba1-b2d2-4b7d-a4e1-72f6089f3258'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:57.960' WHERE BloodProductGuid=N'252632de-877c-4991-80ed-9e628d42109d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.507' WHERE BloodProductGuid=N'264e5325-fcd0-4b85-8195-157c746c6051'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'26753e6b-559b-4395-86bb-8ea6978ba72f'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2694c9a3-92f9-4f12-a35b-fee3f882113d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'26a01855-1470-4b35-9032-cb95eec25c6d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'26a3b44d-e7a0-4ca5-89e3-11aa90071aa3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'26b87e3d-894b-4fbe-812e-4c7c943d8f84'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'270eb14b-b143-472f-bd9b-7c3a05f29cd8'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.850' WHERE BloodProductGuid=N'272f2c08-3c3b-4762-8f67-9db8a85a6ee4'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'27326a28-fe22-4e8f-8548-ed9c357666aa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.303' WHERE BloodProductGuid=N'277fe3ab-c037-4020-a8c9-2213c23e0cb4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'27b123d9-35ce-401f-99ae-54b662aecdd6'
UPDATE dbo.BloodProduct SET ProductName=N'Washed PLATELETS POOLED -5d LEUKOCYTES REDUCED', LastUpdateDate='20090501 09:30:00.367' WHERE BloodProductGuid=N'27c476f5-666b-467c-bd90-99069baad9fa'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.757' WHERE BloodProductGuid=N'27d6efc5-7d64-41f3-8aa4-06836453cfca'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'27e0f56a-0474-4547-babb-9fec5d587733'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'282205e5-9aed-47e4-8149-70fd6373d9a3'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'28268463-2edb-424c-b1e4-6c3cf101311c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'283e918b-cf13-4cb8-b5ae-19ee2d095491'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.630' WHERE BloodProductGuid=N'28b13245-c82d-49f2-95ea-755ea66cdd19'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'28c9d2ee-db63-4285-bded-333e72fd7d8d'
UPDATE dbo.BloodProduct SET ProductName=N'RECOVERED PLASMA THAWED AND REFROZEN (MNF USE -NONINJECTABLE)(under Short Supply if used in a licensed product)', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'28cabc30-1e13-4d62-92fb-119704bf13bf'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.460' WHERE BloodProductGuid=N'28dee929-2774-443e-b525-a8299afd7f9e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.787' WHERE BloodProductGuid=N'293972a2-a3d5-4983-b020-4b3c466f6ba0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2941a2cf-84b9-4a43-b538-0fa06964e094'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.960' WHERE BloodProductGuid=N'295ec0ef-ae98-490d-ab04-459484b9062a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2976fb4f-cb18-4ea9-ac22-bd60bff6e02b'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'29db2565-fdfe-4746-9770-c84cd520cd37'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'29f451cc-e31f-4e42-a7c5-e9069054f184'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'29f459f6-7595-4a65-99df-424ec368c5bc'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2a0add34-af26-4c0a-bf02-ff72b8db87a0'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.757' WHERE BloodProductGuid=N'2a10b502-9368-4da3-9229-d209a4996af2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.523' WHERE BloodProductGuid=N'2a1e1f39-2c43-42e3-94bd-a03f40e3ae89'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2a48529e-5012-44c6-a34a-44b60063f307'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2a4c6b45-a0ac-4b8d-bbe6-c26e0f1f9d64'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.210' WHERE BloodProductGuid=N'2a569276-3f03-480e-917c-6ecc27ee4873'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2a770faa-15df-40cd-a9a7-054631366598'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2a928198-280b-42c4-9bb5-38a7ca4dca54'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2aa3dbe4-1235-47b0-8ad8-b030bc11010a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2adff9b8-ee4e-4212-9627-ad9d08f75f9d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.977' WHERE BloodProductGuid=N'2aeb13aa-61a7-451a-ad22-ef3ec7d2c4c3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.070' WHERE BloodProductGuid=N'2b51af57-5089-460d-95e4-f842c4d77040'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2b5d4fa6-f940-474f-b9d9-4e448950b5ca'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:57.880' WHERE BloodProductGuid=N'2b5e5236-3fac-46ac-a1e4-9e1406aa93e8'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.647' WHERE BloodProductGuid=N'2b6eac79-7025-4166-b18e-b9eb795e86bd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2bb528e3-ac7d-4d2e-a8d8-ac4033df2cc6'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.413' WHERE BloodProductGuid=N'2bca9206-881a-4d5e-ab80-02b6a17b34fa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2be0d6f0-a111-4aae-8bb6-8b1c2e42e11f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2c0ef873-3a31-4ba3-b96d-1f74b75766ca'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2c5fbd4b-40b6-4e9a-83f6-c2c3515cf702'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2c7047a0-54c4-4986-9d6f-f00716260732'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2c709e7e-eef8-4bc3-a5a4-49e05243494d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.600' WHERE BloodProductGuid=N'2c8727db-c6e3-422e-bf13-a5164346eeee'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2c8f6ac3-0475-40e8-becc-c2a1f4b85523'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.273' WHERE BloodProductGuid=N'2caee226-7e71-40ac-8a8c-d930f72cc668'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2cbafc9c-0328-41b9-835d-7d362534804b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2cddceb2-e259-4a15-a707-bc342b02dfd8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.680' WHERE BloodProductGuid=N'2cf213b4-2655-4cfc-b1e1-97dedf772ba1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2d21d941-28ea-4560-885d-721f5bad2386'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2d363217-beed-403b-ad31-62e9ccba8fe1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2d8af4dd-11d1-414a-8140-53200767f8de'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2d9489f0-3027-49e8-bf52-2e77824e3b56'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2d99659e-e298-4de2-b3ed-ee6217d05191'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'2dbbbfc8-6de8-4a28-8f53-928942328256'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.083' WHERE BloodProductGuid=N'2deb4d14-3fe0-48a0-b110-fb818c28f843'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.430' WHERE BloodProductGuid=N'2df21edc-9dff-4e3e-b040-c1aa59e09ede'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2e04f633-3f7f-44bc-ac72-467318690a00'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2e162291-d71c-4529-89ee-922422f56308'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20090211 08:15:31.933' WHERE BloodProductGuid=N'2e390961-0284-438e-984a-82963532fd71'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2e431b77-de0e-40a5-a541-070000ab89a9'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2e5fc214-4b71-499b-a3f8-e8051159807c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2e6d6a78-0b1c-43fe-9bac-c9ac23728153'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.990' WHERE BloodProductGuid=N'2e6fee38-d231-40ac-bc2d-c1fd726abb8a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.523' WHERE BloodProductGuid=N'2e878018-940d-447a-8c37-a89c396a8132'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2e88b206-59fc-480d-8ca5-65111cbf3c99'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2e906a86-211e-4e4d-afbb-b229a51831c9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2e95d487-3cb2-47b6-995b-4f8f2e6c7a67'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.117' WHERE BloodProductGuid=N'2e98c0b8-eff9-4474-a522-1f58371683ea'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.663' WHERE BloodProductGuid=N'2ecbe557-5a35-4d41-a0b2-e8d44bafc9e6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2efd8127-2fe0-4b20-aa28-599e4185aaa6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2efea195-9699-4aa5-b1ab-e69872e18e39'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2f12baea-05ae-4f89-94a8-a9513081777e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2f5d55a3-da57-4127-b289-1c2a59521b2e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2f6e56d5-7c6e-4e5e-bea0-198740c6507d'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=672, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2f7a1517-940f-4819-b94a-8628b06f54a9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2f85405c-54e7-4fb1-b1ea-4a6995a3a103'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'2f9835f2-86cb-4117-ae21-dd56e59bb390'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.273' WHERE BloodProductGuid=N'2fad6f6b-deda-40d0-aaa7-562f55b7161b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.240' WHERE BloodProductGuid=N'2fe14a2a-5147-456b-99ca-99e944c09a0a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.773' WHERE BloodProductGuid=N'2fef18d3-b0d4-4c32-a2c9-3c4767895d89'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'30225682-0d52-44c2-a97c-302aeb5a5f8c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3059bf0c-e109-4a32-a838-d184b42cb9e2'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'30779567-0823-4a12-9a7d-9797969174fc'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.803' WHERE BloodProductGuid=N'308c362f-5a7d-413c-8824-3c6516b21a09'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.553' WHERE BloodProductGuid=N'30ab7c8a-3658-4eca-ad92-7041d6faa9e1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'31810906-edbe-4458-990d-888b86df2f1f'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.367' WHERE BloodProductGuid=N'31c1c4fd-7ac5-4ea4-9c87-ba7163778bb5'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'32071c03-57a1-4d68-b29f-3b6808ca6146'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'320b18ab-a7ac-4eba-8e55-c4556c18bf16'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'322241d0-4461-4393-823c-687154c3329f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'324dd403-6012-43ce-b510-2ee49a04be1b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'32607a74-0802-4baa-a521-32da91723a17'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.180' WHERE BloodProductGuid=N'32639b20-3ff4-4025-aa90-afb15fa1be22'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.100' WHERE BloodProductGuid=N'327029cf-42ea-4832-b2fb-5798c8a8e15f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3272894f-b971-4aa9-919d-4b0b3fe7069d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.037' WHERE BloodProductGuid=N'32d814b5-2abc-4e68-9c4a-94747e2cd179'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'32e3edb7-9d9f-45c5-ac0a-cdae2c56f0d0'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.333' WHERE BloodProductGuid=N'3321d571-2959-4db1-96c2-f8ebd81166ac'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'332279d9-fceb-4126-b6a4-40858e7231c4'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'3332a172-ebb2-4140-85f6-5a9865c9dc56'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'333f725a-d062-424c-a38e-b746ef95cf5e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3355ac27-6a95-4254-85aa-4371180a9411'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3369b33d-7ab9-4e1e-a248-9b3bfb4ed68e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.380' WHERE BloodProductGuid=N'33d6cf37-4501-41c5-ad6e-2d54621007ba'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'33e07775-017f-4953-baa0-98560af044b2'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'34026fda-8bf8-4f53-90e3-6f6ee912edc1'
UPDATE dbo.BloodProduct SET ProductName=N'CRYOPRECIPITATE|None/XX/<=-18C|Irradiated', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'340ebcf6-424c-4f23-b492-8b8f80dc5a5b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.820' WHERE BloodProductGuid=N'3486836f-7626-4e4f-bfd6-7c7b4ebd8bef'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3491c4bd-027c-499b-b9a5-900a544e38a5'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'34a171f0-936d-45b3-b312-d10c2b42fd77'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'34ca7763-7307-4534-b829-ebd6f956dedc'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'34dd011d-53ae-43f0-a88b-7ff076bb7aa5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'34dfae01-f1fb-4c8c-be58-9ba86b7b5d67'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'350bc9f1-04f7-4ca3-a309-89e5cbd1fe1d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3513e8ee-e3a4-4da7-9731-30563b5c2b49'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'351ee22a-9457-459d-b8dc-d1fc9dbc94d0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.430' WHERE BloodProductGuid=N'354305df-d758-4978-bc40-3643cf232786'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3562c298-f702-4704-aa6a-4b0f33f751cc'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.850' WHERE BloodProductGuid=N'3562e5f8-f7d8-4546-a1a0-95d3274d3a9a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.930' WHERE BloodProductGuid=N'356c36bc-6ed5-482e-9d07-22c176180044'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'35aa9cb5-846d-41be-b466-cd6f56a0b1aa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'35e768fc-17d1-46ba-ad6e-430e5241c8d5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'360b3120-0cd6-438c-b377-e734ecbfe28d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.333' WHERE BloodProductGuid=N'3615970e-29ea-4e5d-9d92-c2bd3caca143'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'361b08f3-0a47-454f-9fe6-776592114465'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'36420e85-cfe3-41b1-aef5-8c2fd83db504'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3643828a-7742-4898-b9ba-62a4939567c4'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'36456102-5529-42ee-9560-9ec617e734b7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3651f160-8753-4028-9629-2ecaa598a114'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.350' WHERE BloodProductGuid=N'3664e118-47e6-492e-ac94-f99daac20f8c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'36668e05-789f-44e2-b89f-ec5c9d568c78'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'368f5d45-db9c-42e2-9c79-b11f62047306'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.443' WHERE BloodProductGuid=N'36a0ff79-8cd6-4627-ac7b-aeba47e58906'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.583', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'36b8b83d-323d-4ba6-a179-f765d8fd90fe'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.630' WHERE BloodProductGuid=N'36bb2f47-75be-41dd-87cf-0b4334f16f1b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'36fbe125-bc66-4185-a368-0d0e430b2f78'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'371074a8-c2f0-4cae-8ef5-10707e902d87'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.443' WHERE BloodProductGuid=N'3726f905-daf6-4783-8b0d-8479ef948f3d'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'37c361ca-bd93-4e42-8159-6c0f8d8fd57a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.083' WHERE BloodProductGuid=N'37f8e400-eb87-4477-b474-74a3b2a91952'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'380bc79e-85a5-4bde-94eb-fa7b8a707eae'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'38107b24-9bd0-4a55-9995-cccd903c3aa3'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'38643514-2b25-485d-a482-070819602bae'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.553' WHERE BloodProductGuid=N'386f2344-eab9-4d8d-b879-f3d4da67013d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'38da1efc-2ba1-4b07-a3ec-fff77aba82ec'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'38f3db0c-f563-4bf8-8e71-e0cb85c04c5a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'391cfb8b-8029-4784-9e06-99dcac90dadf'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.617' WHERE BloodProductGuid=N'39255f80-5186-47a8-a7fd-f07dc0a81c2d'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.897' WHERE BloodProductGuid=N'392f1e63-f80c-4cd1-8165-e13251bdc749'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'393f999c-a171-4058-8e2d-de71a85ff455'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3954a3ee-ec84-4637-a516-fb27f2d5301f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3996963d-ad36-44ef-ab61-fafe1db86f95'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'39af71f7-ed04-43f5-8d3a-c6bbfd375c7a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.913' WHERE BloodProductGuid=N'39b1349e-7bb5-4fca-8e3c-987fe97059c7'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.227' WHERE BloodProductGuid=N'39bd5148-c581-4434-9698-1edfbb4bf215'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'39ee3594-c18f-422c-864e-b9e494bb7e2d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.083' WHERE BloodProductGuid=N'39fbefa4-8974-4a75-8131-3cf0da3236c0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3a128b61-53f5-45d6-b4a7-b5855c6e5ebb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3a12af27-418d-48f6-931e-a0ec391b042d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.757' WHERE BloodProductGuid=N'3a9461b7-3d25-4d9c-87dd-06e07fd58f98'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3aa74b6f-2324-4598-ba6b-e6fa96f118bc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3b01d3e0-c69a-474c-8f2d-8beedd1b8832'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3b17c4f9-9a32-4424-8abb-812bba469608'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3b71e033-71c2-4658-8e50-efd8a6ca1ddf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.350', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'3b7759cd-839e-44ad-9b01-13164f586934'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3b8effc7-3631-4863-bb7d-14180c84e29b'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3b9d07f3-75bf-41b6-9b29-057f6ff6dd2e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3bb2b4f1-4ff3-4c78-a8a9-9464719228eb'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3bbbb83e-c615-4d4f-aa7f-48deffb17ea2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.943' WHERE BloodProductGuid=N'3bda9e16-aa99-4fd2-96f4-50068b051cf4'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.570' WHERE BloodProductGuid=N'3bec6317-1aa3-48e9-824a-0c3c6b5ee681'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3bf8b415-cd48-48a4-8607-8887ddda1f0f'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3c03d975-e447-46be-acce-cfd0ea70bc8b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.663' WHERE BloodProductGuid=N'3c1e6078-5707-4346-aa7b-30f41fc89696'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.727' WHERE BloodProductGuid=N'3c1ed1c5-e237-494d-9e9c-7ed62544c0a7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3c2ddb5a-76c4-46a3-8c33-ed27bc04fa2d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3c326cea-b961-401a-917e-c5dcdafa09a2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3c3c7077-3a5d-4cda-a657-9b84fa15d609'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.537' WHERE BloodProductGuid=N'3c3e2dcf-8859-4860-9f2c-589a14e2a1e8'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.287' WHERE BloodProductGuid=N'3c42dc86-915c-4a39-aeef-473d8c038fe6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3c52fcf4-a559-4618-bad6-20ae230dfc79'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3c6c9fda-598c-4a3e-bb86-579d048ec729'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.773' WHERE BloodProductGuid=N'3ca31adf-080b-4f8a-97de-2b9594263df6'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3cc30e54-2e18-4e3b-b8a1-7dcde97e5f57'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3cc467c9-59fe-49c3-9cf9-d6f762d5a85d'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3cd3b4d6-cea5-4941-8413-393b2a113bcd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3d183c31-6e4a-4312-9db6-108fe33c5de3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'3d31de04-e922-4ccf-81e4-77fe5b334898'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3d500879-85ba-4cae-bf78-5bb14d1f2277'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3dcdfc40-f757-4021-b3f5-a8d32fa148c6'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.350' WHERE BloodProductGuid=N'3df3181d-d139-4a7a-889d-1df0b10e1ca6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.227' WHERE BloodProductGuid=N'3df49eec-0d81-4e39-85dd-9bb14ac23cc3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3e01f254-a331-4c57-ae87-7af6aa69544b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3e09bad3-bbc5-4ff7-9e5c-068c405a1ae8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3e208512-7043-4b7c-8ba1-69190096a267'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3e2d54dd-0f29-4e23-a7a6-733925a20879'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3e5447ed-96f1-43e4-a6bd-bb58d47e203e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.523' WHERE BloodProductGuid=N'3e67c1c8-1ac7-4405-a0a0-79955e601deb'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3e7afa35-5e08-47d1-9583-3d6f75f3af1b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3e95ffa2-ef67-43bd-96c3-d49f00e4e1da'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3ecf8ead-7b4e-461a-8864-3d8af391e72a'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3ed6bdca-8bb2-476b-ad99-404526c77f1a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.443' WHERE BloodProductGuid=N'3ede4435-ce16-4363-ac87-5d138e46512a'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3eef2675-5097-41c5-a9ff-f4903ad5e537'
UPDATE dbo.BloodProduct SET ProductVolume=50, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3f3c7bfd-fca9-4d86-8e40-ba16bf46748d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20090501 09:30:02.287' WHERE BloodProductGuid=N'3f873c3a-e477-486d-9941-9bb213417186'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3fa4b3d4-381d-4eb2-82a0-08a008cdb185'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'3fb2121b-7d19-484e-9521-49b50bf0739a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.257' WHERE BloodProductGuid=N'401a17e6-b346-452c-b2d6-a3a7c9a28c09'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'401be781-3b69-469f-bf63-c39fd084c16a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20090501 09:29:57.710' WHERE BloodProductGuid=N'403c9ec1-f0d1-4c52-b3f7-12ba1565b8dd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4054a915-7151-431f-aecb-ab304b163d30'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'406a4922-9623-4314-9c04-a24346985516'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'406ef830-0fd9-4f8f-ba01-5345ac1b253b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4078b56b-4de5-46cd-afb1-fe0212027e6b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'40b0937a-557c-4115-99cb-61702159e816'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.943', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'412651c4-0a68-488f-a16d-173bdb002040'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.600' WHERE BloodProductGuid=N'41285d4e-7c14-40ee-b242-e97a1f989293'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4139adea-f82e-4fd1-b8ed-d6eba6af5de2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'413c8514-fa95-4455-94b6-e240aab546fe'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'415c75b6-fdd9-4caf-928b-ac0d1ac1adc3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'417cf047-87c2-4c02-a6cf-0ef0b1648327'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'418485ab-9ff9-487c-9469-8ffb15b54abb'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'41888622-6f2f-4996-8e8a-c51bc75071bf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'41b77610-bf6a-4294-a457-cc5a59d10c16'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'41cfda4f-fe14-4961-9e95-73aeefb424d8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:58.007' WHERE BloodProductGuid=N'42168024-9fac-4109-84de-40b78de2aca6'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'423e3fa6-1ba1-4ace-aaee-c236b94afaa4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:57.990' WHERE BloodProductGuid=N'424f1f27-ec47-4ba4-af0a-c2a1ecaf2c7c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'42578a5e-3b7e-4c5b-a297-ac2fe4884c80'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP CPDA-1 IRD LUKOPR', ProductAttributeForm=N'@BK C2 D5', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'426a103c-8e10-49ad-a1cc-3675c77bc3cc'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4275c9d7-4a3e-440c-8aac-292c4238aa97'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'42c056b2-b28a-484d-b70b-c6b029119d6e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'42c95e45-cbbf-4d14-9a6a-afc1dd7dcba3'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'42d2d69c-6841-4716-a874-80a98cfbbc33'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4317fe01-af0d-4b8b-88d9-c702ab17e9cb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'433059cd-f746-441a-9926-7cc82d3e4985'
UPDATE dbo.BloodProduct SET ProductVolume=15, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4345dc19-99c1-4c96-b997-40a43fd1ed54'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.507' WHERE BloodProductGuid=N'436779e0-5f74-41be-9d00-50ea8a5cc5bb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.303' WHERE BloodProductGuid=N'43a02027-028c-4e1f-9044-a6cbbc416c01'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'43a11276-c106-42b7-bc83-5ebce42603d5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.943' WHERE BloodProductGuid=N'43c17dab-57a9-4d0f-87e2-179e99de2c47'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.990' WHERE BloodProductGuid=N'43e3728b-f86e-4da0-9eeb-8aede3c0c594'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'442da798-eb6b-4581-adcc-1583a1a2d66c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'44a31411-76f8-4dc9-a9ae-66759d01d446'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.053' WHERE BloodProductGuid=N'44bb136f-d268-4c0e-a6f1-37becd5858f7'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'44f3d7f0-266e-435c-9414-793459d9e96d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'451a00fe-7ad6-4a27-8d07-4628a2d44136'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4561e0f1-1106-45cd-a6bd-0d30c239e816'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'456ab147-1a68-403e-bcd7-ecc8f7763df4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'457ce649-b6d3-424d-aac0-4fafef37c4b2'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'45d0036d-67da-4a7a-83cd-877ef7da3007'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'46112c71-a3a1-481a-a7fb-7f772d7554a7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'462c9483-b68b-4db8-aae8-2b0b5608090c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'462fd622-c6f2-4880-8ba7-9a293d547928'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'462fe04e-f9b7-4e5d-b6c5-de7671d5fffa'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4645843a-a708-4554-b589-a329408493e9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'464b189a-a928-4895-952b-33b1c6c9b0a0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.553', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'4671abf1-77f9-49c5-b7c1-d23aa8d3de19'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'46a94c0b-fb3a-411d-bbe3-54603098f524'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.023' WHERE BloodProductGuid=N'47078ada-48e8-46e1-9d76-bae70d0ed4d3'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.570' WHERE BloodProductGuid=N'471139e8-6c08-4f7d-a053-f9b5a53ce529'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'471c351d-e99e-42e1-8e42-31e9f1954020'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'472b3eda-bd0c-4d70-9984-128ae0cfc0e4'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'472fd5b1-1a81-4402-ae9f-3fd681e69b65'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'478cd783-aa91-49c3-a07e-67ad4269d3e7'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.257' WHERE BloodProductGuid=N'478d7db8-f205-4fab-acf3-94c7a8cc0aba'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'47901fda-1f0f-472a-ac71-f6e796f7203b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4797b761-093f-4967-a261-39945fbb5e99'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.430' WHERE BloodProductGuid=N'47a37d36-63a2-40b7-aa55-ea8d7b75c90e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'47cbe092-3780-4a9c-9f8f-e9edabc687f6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'47d9b89f-bb33-44bd-ac57-69599874599e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.163' WHERE BloodProductGuid=N'47e4d46c-522f-451f-bfff-aef02629281b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'480e44f6-c930-47cd-a594-72033f5da812'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'48194490-82c2-4b2d-847b-26030647d818'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4825f31f-73b0-497a-8d3d-d47d80b1b011'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'483d77d5-1765-4dae-be3f-0f2aafe7495e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.477' WHERE BloodProductGuid=N'4860425a-3ae7-4ab8-abcd-629302dc446f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'48745f31-24a8-478c-a058-c34d229e4948'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'488f008a-2991-4d88-98b2-180c76b4544b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.553' WHERE BloodProductGuid=N'48ce2daa-1cd8-4395-9e13-e1f1f4fbe386'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'48f62174-3b4a-4ef6-aa82-c233f2d14276'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20090211 08:15:31.933' WHERE BloodProductGuid=N'4922b12b-6d99-45ea-918c-ede2b7a120bf'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'495357ac-8120-41dc-9287-616fd5920d1d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.680' WHERE BloodProductGuid=N'496bf7f3-df40-4eee-ab1c-7e2161e27582'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'497ca44d-aac8-4046-9628-562a966e1d40'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'49e1ffe1-7dfd-46da-a782-8deb9c724df3'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.553' WHERE BloodProductGuid=N'4a15ae10-9aa6-4e4d-befb-0f25b3460f64'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'4a497c6c-7b8a-4870-9aec-46c21c9dc8f5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4a5b9f3f-60c2-4189-97c7-7f78d0d1c55e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4a5e82d4-ad74-416b-9f51-3970cda8d3fb'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4aa4de66-508b-4688-941d-06768995d96e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4aaaeae4-9ca9-4ee5-aa50-d827f2ce6d03'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20090501 09:29:57.380' WHERE BloodProductGuid=N'4aaf25e0-429b-4a08-9bd2-8751f0bc84b6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.443' WHERE BloodProductGuid=N'4acb02cb-9a95-45d6-aa94-45e27c2e5150'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4ad8e61e-3ee0-4fe5-9bd8-fa2951805a48'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.600' WHERE BloodProductGuid=N'4adaccd2-0afd-4327-8f72-29c0a8af068b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4ae4bf71-636a-4a78-b3b0-e16d1997c4fd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4ae62bcf-5f56-4bce-983c-4373e870f8f1'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.477' WHERE BloodProductGuid=N'4aed736d-272f-4e8b-8727-7ea994f6e851'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4b223fd8-84c3-450d-9826-24fcb4b469d6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'4b62f44c-1d88-4573-98aa-fc6391174c6a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.663' WHERE BloodProductGuid=N'4b6bcd04-0a4a-48c3-ad9c-605548ecc7b1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4b820582-5979-4757-9b03-584387d7b2b2'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4bb3705b-54d2-4456-be6d-89edf1f24ac5'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4bc990f3-0738-4207-9dea-bb677ec20dd2'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4bd51b93-b91e-4130-9f64-a882c95a7606'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4c192ac6-f21e-45e4-b81f-062baeead28f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4c354ad5-09bd-48b0-864a-6273b7ef3db3'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.397' WHERE BloodProductGuid=N'4c56cd1c-0c4f-434b-8b4c-b306db578dfe'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4c810b72-5f8d-4ed2-a5ef-8d4afb2e1b7b'
UPDATE dbo.BloodProduct SET ProductVolume=15, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4ca0f6bb-ab5e-4061-9452-e0cc41d330b9'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.163' WHERE BloodProductGuid=N'4cb497c4-9ded-42e2-8f54-5092b7f11cb1'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4cbfce73-6bf2-4dfc-8237-5f2361e7bac6'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.773' WHERE BloodProductGuid=N'4cd46c12-7f95-45bf-9d03-196c2534fb6f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4ce2bdca-e640-4b4b-8454-cc7c6407e631'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4d1569fe-1f22-4766-b9bc-3b555bc83336'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4d503c75-86e8-4c68-8226-f36638c2058b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.867' WHERE BloodProductGuid=N'4d564687-07ba-4d03-bdb4-3a38a2800f4f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4d687de0-dac6-481e-a184-32b34f6111aa'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4d72e117-f1a5-446e-b80f-ae280467a168'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4d7f9381-d147-40ed-b083-2f6cd5595f6e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.740' WHERE BloodProductGuid=N'4db99aed-5555-42bf-a595-485ebf6c1b1e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4e29e1dc-b81e-4c2c-974b-60362f46095b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4e4beef6-3882-4275-94db-50519ab737ea'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.600' WHERE BloodProductGuid=N'4ebf8b74-b207-44b5-b03c-96d6115dd084'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.960' WHERE BloodProductGuid=N'4edf00bd-8267-4ab1-ba6b-ab983649d249'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4f07b2e7-a570-4a5b-a8ac-425e5686cf0e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4f0cadb6-b070-4192-8fbe-29f6f0887c3f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4f411ce7-b54b-4409-a91d-6ff7978a0105'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4f4cfd52-f4ed-4d15-9f17-fdf88bba6ae1'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.117' WHERE BloodProductGuid=N'4f5e011f-ba52-4aaf-9e70-f9973686fd30'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4fa78d9e-6ce9-45f6-8e84-fe494501177e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4fbdaa0f-0a9b-4c3a-9310-414586e76ea2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4fcbcd10-9811-48ae-9685-726c78542128'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.333' WHERE BloodProductGuid=N'4fd22a2d-9df4-4bc6-a9dc-e19a95b34e71'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4fe295ff-9c76-4f74-8b68-8aae53554468'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'4ff36c51-91ad-4556-913f-8a99df3fc2d0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'4ffe5ba0-9c14-4dad-81a8-9157e2f2ea44'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.897' WHERE BloodProductGuid=N'5041684d-f5d8-4240-beb2-4e6cc4d78090'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'50510f87-af12-4300-a9db-a76d71c99bb2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'50542f78-ad6c-4cb4-92b4-79d08f653adc'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.163' WHERE BloodProductGuid=N'50548ece-396e-4a1e-beec-28c7f0f7d180'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLASMA CPDA-1', ProductAttributeForm=N'@BK', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5074833c-6cf8-4800-8050-a87de320979d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'50f12786-8c7f-4385-861e-c55fd56e1eaf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.257' WHERE BloodProductGuid=N'50f78f7d-8a0d-4b84-a031-06845a3e4fbc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5150eece-8f41-496c-893c-5037560f173b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5172e848-6897-4c08-9f55-3b664dcc1866'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.070' WHERE BloodProductGuid=N'519c9b63-18d4-454f-b432-d37219d4ec4c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'51b88715-8cd7-4eaf-8ac8-0b495224c0fa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.240' WHERE BloodProductGuid=N'51fd2a37-e15b-4a43-861a-ceb93b3f8f71'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.600' WHERE BloodProductGuid=N'52165cff-20ca-4e76-a074-0dc378a0d86e'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5222b688-5bf9-441a-bf6f-30f9d6975dcd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5259610e-b12f-496e-afe3-b64197117319'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'526fc96a-0806-4bb9-8655-dfe16eaad166'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'529f54ea-c758-4474-84a7-72a0921d0be8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'52a6bd70-aecd-4933-a2b4-e40ac21ce196'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.117' WHERE BloodProductGuid=N'52b71650-fc98-4d3f-b8e7-1008eff40988'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.287' WHERE BloodProductGuid=N'5332a014-c81e-45eb-a1e4-7fa35d2c9359'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.070' WHERE BloodProductGuid=N'5340cb0d-85f6-48c8-887c-8005ffd9cf0a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'534c0bfd-3d69-447d-95b3-55ede3a2e4f4'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.287' WHERE BloodProductGuid=N'53aa4a86-d561-49aa-80cd-a131d269c136'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'53b92072-0290-469b-93e8-f67a872081f8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.523', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'53c303a4-a21f-49f5-8fe8-19ffbc203313'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'53ff38d9-969f-43f6-9e8d-48df7c609b8d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5429b2ac-1c89-4fb3-aa98-a41e5296fc8f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'542dec5d-fcd6-412b-b0fc-97d35b39b732'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5473e61b-7b8f-4acc-90cc-77cac2508f7a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'54d7a051-0cac-4f01-9308-84f05051700f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'54e3d5ba-8351-4927-9dbf-036bb1282a4e'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=672, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'54f4c09e-1547-4fe9-bbfa-17cf40f6a596'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.100' WHERE BloodProductGuid=N'54f57f0c-3925-4365-ab28-83cd92c35ea3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5512895e-a9ae-4d38-8120-cce553d5d91d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'556c6848-14a8-48ec-b2e8-ff59e04b6a23'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'557c69ca-10be-46e1-a331-fa130763d96d'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'55d0d421-8295-40f1-90c7-5cff402cd7de'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.553' WHERE BloodProductGuid=N'561fcab9-074d-43f2-930d-7176c557a57a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'56457c48-9c31-443e-97cf-1f4a673828e5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'56479fac-59d4-4200-b1f9-eedebf5c8b64'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'567aee49-b127-4e2e-a635-45c545c09daa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'57280ed4-feb2-4c01-a713-304d28229162'
UPDATE dbo.BloodProduct SET ProductName=N'POOLED PLASMA|CPDA-1/XX/refg|Open|Cryo reduced', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5767d786-1231-4971-9342-60e3bbd0f82b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'57bb5731-e9eb-4ba2-a013-2005286ebb70'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.397' WHERE BloodProductGuid=N'57c9c494-f3e2-47a7-a5ce-fbffbd7af415'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.023' WHERE BloodProductGuid=N'57ea31b3-2ed5-4c6c-b82c-3c031e447b6e'
UPDATE dbo.BloodProduct SET ProductVolume=15, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'57f23570-f7be-49b2-b9c2-63f9f93cf1bf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.537' WHERE BloodProductGuid=N'57fa72a1-aef0-452e-9339-cf3fed0c476f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'583cde55-def1-4fcd-9e28-e85881c6c431'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'587ed4e4-769e-4488-aca1-cd72a4e0dd6a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5882aa53-6eec-4eac-8b3b-2d0d7a5a5a98'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'589a23c0-d4c1-441b-b3ea-cf9ae2c7f587'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'58b56027-6a77-458b-8f72-9a11e435827b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'58b8e5be-3a5f-479d-b849-cf9515bdbfb4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'58f27cdf-79f2-4b46-8af9-323a93f7e1db'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5913f76c-5e60-4000-95a8-c8ddf1d59d11'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'59377097-44bb-4235-9756-832369b4e673'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.880' WHERE BloodProductGuid=N'5963331a-d11b-4ebc-88d7-696e08df0919'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'596e9e2c-8ace-44ed-a572-939329d941d6'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.630' WHERE BloodProductGuid=N'59ac0695-dffd-49a0-b0da-395692721940'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.303' WHERE BloodProductGuid=N'59ce083c-88a7-453a-8037-7f5142a05d58'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'59d6985c-b413-401b-9bfd-d6c0517bc5ea'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'59e74c66-e4c5-44c9-9e9b-cbc1fe526906'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5a03a62d-fcbc-43df-89b1-270772b7c8bb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5a12bca5-ea77-4509-9637-96bc49616a35'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5a1c24d7-fcc2-4b5e-83c0-69ae4f432204'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5a36f0f9-8da7-4972-ae8a-09d2cd8c8ccf'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5a4d3905-f384-480c-9925-a0211303fddb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5a876de1-baf0-4fe4-bae1-7af9bb7c02aa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.880' WHERE BloodProductGuid=N'5ad9b71a-c1d6-4bb0-a7fe-5db909b7e8f0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5ae93d72-6587-4c8b-8545-7920386a3295'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5b167d66-f7ec-4056-984a-a272b5d7dfce'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5b1e5238-ef0d-4bd2-b3c5-dad5e9b693db'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5b2379ab-2f74-4e24-a960-fa5c4d2ee381'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5b3cdf78-8d18-4439-93df-bb1709eed03a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5b54c213-d405-4ef4-903f-e570239879bd'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.943' WHERE BloodProductGuid=N'5b75a177-f5cf-40cc-9263-c060e122f658'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5b959b0b-b44a-49f4-8237-90623d4af7dc'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.583' WHERE BloodProductGuid=N'5ba47932-a0b1-49c9-aae6-befa6e13da2b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5bcbc8a5-6fa5-4554-9f80-52d8b5db8810'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5bf1c214-615f-43ec-8597-4ea9010a1764'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5c00703a-9da6-4eb6-86fb-9e09e44731a6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.477' WHERE BloodProductGuid=N'5c18be1b-e163-4717-b0c7-3f9b9f71e200'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5c2538f8-8324-46c8-81ec-4f665853bd9e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.693', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'5c6c8b19-9384-4091-b749-669158b69025'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5c708aa9-1879-4b8d-b814-dd076a6bb504'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5c7983c6-50ea-4a2f-8a4d-7cb54c144f89'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5c871769-1867-43bb-b5d3-c72f4d532cdf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.007' WHERE BloodProductGuid=N'5cb7f952-08df-4db3-a520-32f7e1f385ac'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5d294fe0-b4a8-4522-9175-97d8b2de9304'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5d5b188a-0ddd-4918-a2cf-d9d15659739d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5d61a9e1-6489-40e8-b9b3-e4faa0dacfb6'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5d6255a6-937e-427a-bf2b-50fa9397be61'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5d716384-1e0e-4fdf-8ebf-8c6b0e66e49b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5d7b12c4-e201-4079-a007-6e2d587c60eb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.007' WHERE BloodProductGuid=N'5d8268eb-4b57-4f3c-8104-033499299fb7'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5d91c42b-1cd8-4c4e-9cb9-da2fd6a60f26'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5d9d3efe-edde-44b3-934d-5df329608808'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5dc5b8e9-7079-4b65-acd8-4a9af64ab4c8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5ea59b61-4882-4b09-bbe3-6811efc9dd3c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5ebafebc-bbff-4b0d-88c6-efbc7428a0ad'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5eec17f6-0a26-4baa-bbdc-12e23f20dae0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5f029b2b-96a0-4748-a084-a2a9f51a7b3f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5f14a5fc-f532-4d60-a7ee-09e9eb213010'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5f29dcb2-be23-4465-93c5-0b2fe80c6f5f'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.740' WHERE BloodProductGuid=N'5f4ae902-82b3-4bbb-970c-edec6e801cf3'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.430' WHERE BloodProductGuid=N'5f5f4844-48cc-44ce-b117-080a1272246a'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5f6ed5ea-2e8f-4b7b-be46-70eceea22de0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5f6ff6ca-7bd5-47dc-b2e0-7688e7cd5f0f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5f76098e-119d-4b25-a9b9-e30fc3e72e42'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5f9ed39b-b95d-4ef4-8692-ea6f12aed96b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'5fd8cabf-49cb-407c-bcd0-b2da5503097f'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.630' WHERE BloodProductGuid=N'5ff9dd7c-9d19-4dac-8efd-bce83d4495a7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.583' WHERE BloodProductGuid=N'6001d5cf-89d4-441a-823a-6da600a4df3a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'600b8bca-e53e-440d-94ac-497b90c980f6'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6039562a-e54a-46f3-9f88-e51c787e37f6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'604e6f70-61e4-4d83-b474-974287a91b8f'
UPDATE dbo.BloodProduct SET ProductName=N'CRYOPRECIPITATE|None/XX/<=-18C', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'608fb4fb-2454-4da2-be25-0ff88cd10fb7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'60e06132-ae56-47de-b5c9-22d318a85410'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'610c8bbc-3896-4f4d-bd13-93f526ad72bf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6125da4d-48a0-4b8d-84d9-d99377172c91'
UPDATE dbo.BloodProduct SET ProductVolume=15, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6134090f-9418-48f8-a729-195effb6af0c'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.180' WHERE BloodProductGuid=N'619f9cda-c631-43ef-9104-fa1671b03ea2'
UPDATE dbo.BloodProduct SET ProductVolume=15, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'619fa05e-e374-43e7-b5dc-3d7894fe55da'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'61cc0e12-e56e-440b-b242-4fdb93fadc87'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'61dd8ad3-8fe9-4fb4-8d5f-40913ec7b36b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'61e557a2-2e66-4228-b3c0-62c7bd8d5c88'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'61ecb831-5487-4e7a-a93e-42ac8a3a0be3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6223668a-ebc4-4275-acb4-f9657401f023'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.537' WHERE BloodProductGuid=N'62320d5e-859c-4311-afd9-281677507638'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6236aa69-7adb-46f6-85d7-7ab7bf39236a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6242f94b-dd55-4a87-bb77-520eb573a230'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.787' WHERE BloodProductGuid=N'6251129e-6980-4b52-bbc0-423a535daf0e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6262534f-e535-49f1-8b2d-f7727b0384d3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'626ff696-773b-44b3-9913-cf1699a23320'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.273' WHERE BloodProductGuid=N'6272d8c1-181a-490a-8b8b-e3acb9e79095'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'627ac4cb-7be9-4edb-80d9-27d07ad80e48'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.273' WHERE BloodProductGuid=N'627cf93b-30ec-4b45-b288-db1e052e35fd'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.570' WHERE BloodProductGuid=N'62a76363-c321-4a12-ac07-3574861ab99e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'62b77679-a13c-4b76-96ba-593d2c83f283'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.240' WHERE BloodProductGuid=N'62efa443-b480-4b71-8d44-79d1474393cb'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.443' WHERE BloodProductGuid=N'63032cf2-b092-4c0e-9d61-7d50b3d43d92'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'631bc5af-83c3-44fa-ab35-c4ecc2346544'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6331ea13-bcc4-4b03-ac91-dcb09f543835'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.977' WHERE BloodProductGuid=N'6341e3d4-1830-467c-bd72-4386c8d7e9eb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.240' WHERE BloodProductGuid=N'6369979e-9344-4818-8ddf-70fec7aa74c6'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6394685a-083c-43a9-b207-c2c2334bf295'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'639735a3-8561-46a3-8577-e5eca9bdfa37'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'63d4e7e8-8499-42fa-84da-5aa2e09d9815'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'63fab6f6-b440-4f45-a067-6c95982fa1c2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'640b8052-d41c-4cd4-8b19-ed7db214d21d'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'641afce4-0cd6-47a5-a827-ce36c17a79a9'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'64562dba-754e-4126-b8a4-7d2686d70988'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'64969fb4-0d92-414b-953d-621abd221707'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'64ad2874-1efd-4a56-ae47-ae756790d178'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'64ae2340-f61b-4912-98bf-1e0d95128c6a'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'652ba6ce-69a2-4685-ba65-a486f96b1b2f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'653808de-331f-43a6-9e73-5cf53342c27e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'654f7037-20eb-4f07-a313-6835be655308'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'655188ef-856a-4498-a824-08f489a47fe1'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.367' WHERE BloodProductGuid=N'656cbf17-173e-4ae6-b194-266f817fc91c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'65700213-b47f-498e-ba7c-2dcc89a9a87a'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'657e202b-3322-4c08-9617-5c260dcc673c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'65b63c62-1361-4498-9552-095a5e81901f'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.617' WHERE BloodProductGuid=N'65d75d05-0fda-428e-adfd-afd23f902f7f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'65f91bf0-bb48-41d3-8a7d-a9bf737f0dd4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.100' WHERE BloodProductGuid=N'65fa7a08-cca2-4890-b95b-964f0e7c35a0'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=504, LastUpdateDate='20090501 09:29:57.413' WHERE BloodProductGuid=N'66118cec-a840-4dac-92fd-a27b3f1b62f7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.600' WHERE BloodProductGuid=N'662938e0-6816-4a85-b2c4-0c982da270ca'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.913' WHERE BloodProductGuid=N'666d836a-e6f4-499b-9e99-f23120bb3b96'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'66a9df87-19ac-4f9a-aba0-021c5ddc58d8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'66ae0b64-e76e-4060-bc80-493c7d1a7ddc'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'66c74af6-a332-4576-ba65-7ef499cf61e0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'66e89e78-464b-43fb-831c-3027d4f26cd9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'677a5b4f-889d-462f-89b2-6afe5ac6f750'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6784fd54-84bb-4ac5-9a9f-7b79469794dc'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'678f006b-c42c-45b0-b5df-16e2ddf06757'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.257' WHERE BloodProductGuid=N'679eac81-1cac-4716-8372-5434b0c093a3'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'67afcf7e-6b0c-4ed2-984f-ea6e1fdad143'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'67c05062-2814-4a00-8eb1-62cf37055543'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'67d0224f-c2b8-40ee-ba82-9c33871f03af'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.130' WHERE BloodProductGuid=N'6836a277-a82e-4eb3-9a72-7a8eda0e5d09'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'685bd699-141c-45f0-aa63-bf602412278a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'685c66cb-2987-46f5-863c-2c0bf4568a45'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.507' WHERE BloodProductGuid=N'68649281-2782-42c3-bad8-4df654aa945c'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.023' WHERE BloodProductGuid=N'6865b584-ca5a-4cae-aab8-e2b14e425c9e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'68a89272-4754-4da6-9ef3-fe4e28cb4bad'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'68ad3d99-f87e-44e0-a306-df7cdf65311c'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.740' WHERE BloodProductGuid=N'68ad78a5-6596-4110-9b0a-1a8b0af98aa5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6969a673-af0a-4953-8ef7-360eecf0c452'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'69889167-81ed-4a91-963e-93031b0f9b76'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.443' WHERE BloodProductGuid=N'69d38ed5-732a-4b27-9d10-db51f415a2c1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'69d4fe97-aafc-4fe9-8739-2b241f74c45f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'6a18f9c9-5b9f-4c51-8c6a-65224958986e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6a75c85e-21b6-42c5-9686-57348e8adbb7'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6a99f119-9505-4193-9ab7-bb5bd004f8c7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6aac6248-a112-4628-928a-64c1d849acdf'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.507' WHERE BloodProductGuid=N'6aac8ddf-31ed-41d6-bc6f-8985833d5d1f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.820' WHERE BloodProductGuid=N'6ab141d9-acf8-4976-81ab-4b0cae00db89'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.227' WHERE BloodProductGuid=N'6ac37a98-c67a-4e86-8423-844b68382516'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6aecb334-53c4-49f6-ad52-f9939250bf76'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6b462fa9-f46f-474e-819d-44021a4d9299'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6b752dc4-5d95-45bd-b8de-50aa086f7d3e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20090211 08:15:31.933' WHERE BloodProductGuid=N'6b78a6bd-f8da-45e0-9a4a-3e060f7dbbe0'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6b7c04c3-3300-43f6-a058-3a864002a483'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6b8ac5d6-38ab-4ed6-a34b-f63be625264e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20090501 09:29:57.693' WHERE BloodProductGuid=N'6b96df48-5037-4ada-bed7-28e4636e186f'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.803' WHERE BloodProductGuid=N'6ba86f3c-83c5-4bcd-a30b-6eab0f907059'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6bb53cae-f96b-46b9-85c2-1a69901a6755'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.320' WHERE BloodProductGuid=N'6bb979c1-3bed-409f-b965-7057cf41aa8e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.227' WHERE BloodProductGuid=N'6bc9cef4-e5e8-4495-9dea-014096a75b3a'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6c468d50-46ac-4746-bc65-c7bd7edc06f4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6c9e9858-fa7e-432a-a1c0-3f5e486e4dd1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6ca0038a-e55b-43ea-8f83-94a7f4569c04'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=504, LastUpdateDate='20090501 09:29:57.413' WHERE BloodProductGuid=N'6cec12cc-4d74-4bb3-9028-f8eb0467c74f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6d9fa47d-1d15-4643-9909-5423ba4610c3'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6df98cef-205a-4d83-9cde-3d19cd59894c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6dfc5e18-95fe-49d6-bd83-be6de87e6e3c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6dfcfdb2-00bc-4fc7-95f4-c1aeacfb6e88'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6e1c5f62-d465-4d10-bc5b-4226f8ebf04f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6e47eda2-d112-410a-9398-41afd8024b0b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6e4bf38d-7924-424b-bff9-5924ad66bfb2'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6e88b851-cb14-4b15-8495-3c12403dca7f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6ee8ec26-b742-4f6c-b004-d3e71005dd73'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6ef43806-c30f-481c-a0fd-5d1ad237b7c5'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6efac154-ee5c-4e76-bcd0-eb58cf1f8572'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6f32d163-44f3-4a26-a3be-7b82d8bf0f81'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6fc26218-67eb-49b1-a894-27f694516673'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.320', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'6fd58741-8a93-4a48-ae10-5dbf72d91a0b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6fd6c1aa-0727-4bf2-aa57-a61215beae41'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'6ff468d6-747c-4587-9788-dcd355256cc2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'701d5ea5-8917-4e5b-b1af-795862b7ebb4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7046f86d-46de-465f-89c3-c261930a1f18'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.647', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'707c64f9-b0b8-4fbf-b52c-1e486eafd8bd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'70941920-1840-47e3-bca9-9b0015fa48b4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'709dc264-e3e3-4676-b1ab-07e1f4d64225'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'70b2a85e-ebcb-4062-803b-ec02d15f8ddf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'70c7750d-3056-44aa-8158-3e6233aef538'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'70d35f34-308f-4e4c-8644-5ebbd69005bc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'70fdb496-9f5c-4b26-8b8a-800e02efbc83'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'715c85d9-9f88-4a5c-90a5-d84ca3355482'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'71660555-7e60-46bb-a672-0503066a7f4c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.647' WHERE BloodProductGuid=N'716d9c69-9805-4d14-8d70-9831eea3d2c9'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'71d1e040-e468-4dc1-9253-88831cd0433e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20090211 08:15:31.933' WHERE BloodProductGuid=N'71fc669a-97f7-492f-8a6e-39b529f7327d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.727' WHERE BloodProductGuid=N'71ffdaa7-3313-43fe-a3ca-d6abb16cb06f'
UPDATE dbo.BloodProduct SET ProductVolume=15, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'722de1ed-e6ef-4227-87b0-d25207f1f9e0'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'725c0764-36be-419b-ad88-1fb1a2c11ebb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7261e040-9d59-481f-956f-b188f68ec3bd'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.287' WHERE BloodProductGuid=N'732eaa31-bba5-41ef-bfdf-a26b3ad78db2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'733e78a7-b663-4106-b0fb-8fcc86c201d1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.617' WHERE BloodProductGuid=N'734ac4ad-d4e9-4ae2-b44c-332c44715504'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'73513bd0-f3c7-43d7-b326-4863a6c7b63e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7354e2e4-24ea-41c3-8c54-b606a7419913'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.130' WHERE BloodProductGuid=N'73880700-b048-41d3-9399-97cca3e3a1ce'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'738aaa6c-224b-4346-8404-817e6ab5770d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7393267b-4b55-4e99-a648-bc31dcd78da4'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.007' WHERE BloodProductGuid=N'739a16d1-2a4d-4189-8d90-395bbf6f8921'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.083' WHERE BloodProductGuid=N'73dc7df3-9ae1-4d6b-987c-714a7172d8a8'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'73e9bde3-f56a-471f-8992-530dd66bfe58'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.740' WHERE BloodProductGuid=N'73eebb74-aeab-4dbc-9149-dc17299ef3a4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'73fe452f-d3c5-47ce-9e84-2d5e0b6091c6'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'74865135-76d3-47fa-874a-f1c8c55f9a1a'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'748d9fb3-f69e-41ae-ad5b-5dc6d33a3473'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7491af83-97fb-418d-a077-d0bbd8acc672'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'74bf255c-807e-442d-b843-2c349cd7288c'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'74da009f-45ab-4341-a54a-9c888a1a9333'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.647' WHERE BloodProductGuid=N'74dc7aac-deaa-4164-9246-6ea0b77520d3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'74e878fc-0625-4d90-9982-62256985a457'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.990' WHERE BloodProductGuid=N'74ec4040-0ca4-47c7-b3fe-32a2b8f35994'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.227' WHERE BloodProductGuid=N'750a29b3-dc59-488e-bdab-87312f493cd9'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'750f23e8-59e7-4c1b-876d-517e53fb0d5d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.333' WHERE BloodProductGuid=N'754b90a9-4b52-4b1c-8913-d95df2a5bdba'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7575b016-2d0d-4414-ad8a-5de2a863234b'
UPDATE dbo.BloodProduct SET ProductName=N'PLATELETS POOLED -5d LEUKOCYTES REDUCED IRRADIATED', MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.227' WHERE BloodProductGuid=N'75899255-732d-49ea-b9fa-bc8652092481'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'75989ddf-6d53-44c1-a490-088fe8ed7e46'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'759dc056-477c-4233-9e53-079466d6a067'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'75b303ba-d10d-4eff-ad03-1f8ba9220c41'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'75cedcca-e11c-44cf-b13d-960923752182'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'75d7a734-c8f4-4a2e-bfa8-b47d23a08308'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'763a1d4c-2681-4c98-b6ce-b84699db985e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.727' WHERE BloodProductGuid=N'763d29b0-a2d2-488e-972f-2fe5e2759a49'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'76426655-318d-4ba9-a9d4-b85ace6e392e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7668fd6f-116f-4aae-a961-0942e0c9b99b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7672774f-a896-4eb3-b51e-9984ad0729c4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'769a01bb-a931-4221-8d8a-71c7b6ad220c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'76ad931a-b96e-4382-be8b-d904f3d786ee'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'76b36678-ae98-4ff8-94f4-1151ed686780'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.007' WHERE BloodProductGuid=N'76b8e306-744a-48f2-a5f6-1bd06428ccbf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'76bc9483-5c31-4043-9361-f05fbcd577f9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'76c35eb9-6baf-44dc-a7ae-789a6856ff42'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'76f6eb30-02ac-4470-a696-7d1132467c83'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7735198d-7e9b-480d-8e99-8620a38f89cf'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.287' WHERE BloodProductGuid=N'7743486e-9802-479f-b5c3-7847eddc7d7a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7752da29-269a-4c56-9ee4-219109e709aa'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.303' WHERE BloodProductGuid=N'775a9a13-73c2-4706-b363-fe602f5fd373'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'776f5f12-546b-4c01-a96c-b9f217d2e20b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7775b7b5-1841-46e3-90cd-92da67810c9c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'778ee9ab-5ce8-4cbe-a2ba-e3cec2df28eb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7799d988-814c-4e4f-9648-bbb4ce0e9c03'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'77b19854-f281-41c1-9616-5f682c10164b'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'77b8e177-daf7-4fa0-8a98-d139e92daa41'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'77ba6835-5e8d-46c5-93e3-e1a70023b89f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'77ded786-ce30-4706-a075-531309440dce'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.740' WHERE BloodProductGuid=N'780bc3e2-ac37-43f0-82f5-c80f44c829a8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'784a6ea8-670c-440a-965a-2b47f82094d4'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'792793e2-523a-4128-b793-0645fd293e77'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'79535082-a044-402c-99e4-3c9ae93de44d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7953eaf4-cc83-46fb-ac09-5c1828643bb0'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'79640789-05b3-47c6-86b2-3eeee2675630'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'79bb078b-cf23-4b95-8dec-67df0062a940'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7a3b28ad-e14c-4c2b-804b-314576380035'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.943' WHERE BloodProductGuid=N'7a56d698-a37f-4562-aa4a-6a059e8ce2a9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7a5d4a0d-39b3-42af-92a9-f0d0fdbd3a57'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.553' WHERE BloodProductGuid=N'7a6092b9-5a38-4ea1-8f3d-f472db2b41b8'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR NaCit LUKOPR QUAR', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7a75346f-19f9-4d10-8d84-7957ef642a99'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.583' WHERE BloodProductGuid=N'7a8015e8-625d-4945-bc38-a28450ffcea0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7a81cd35-0cf4-49cb-956d-33f9ff57dafc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7a919a9a-757e-41fa-b80c-3111bafc9bae'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7aba70f7-5a6f-4ce2-b5de-16b99f21335a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20090501 09:30:02.303' WHERE BloodProductGuid=N'7ad4023c-9d29-43af-a6f0-8f7b6a2d63ae'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7aee092b-5d5c-43e4-8db8-7d00d5c61e05'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7b24b30c-b628-4e5b-a795-010694720a6b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.210' WHERE BloodProductGuid=N'7b642e0f-81cd-4375-b66c-4ab8f6948905'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7b8c0fe5-90e6-4616-9a31-5c923d8f3df6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7b91422e-8aad-4d75-87d6-9f16ed3351e5'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7b949d8c-6535-4e07-a73e-12be5c86a008'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.820' WHERE BloodProductGuid=N'7ba41706-8a33-4906-9551-10b80e10e304'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7bd2b34c-99e5-49b8-b614-1203b1d16709'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.350' WHERE BloodProductGuid=N'7bdb959d-771b-4bba-94e4-cad01a0a67d3'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7be5d8df-5057-4246-b6fa-d9d444253a7a'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7c4a289e-173e-446d-a3a9-1ea3c41ab98d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.227' WHERE BloodProductGuid=N'7c52838d-b54e-4b76-9e22-bd291e5450ad'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7c5c2e66-0c3f-4ef0-b380-d9a242ac7ce8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7c5d67cf-9ae9-4f10-83c8-92af72153368'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.897' WHERE BloodProductGuid=N'7c71e80c-01d0-44f6-bbcf-c54b72b9f3b7'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7c73df6d-f191-4361-8f0c-7f2957592a89'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7cefdbdb-5faf-4e8b-ba6b-b4c1c84d6c39'
UPDATE dbo.BloodProduct SET ProductName=N'Deglycerolized Apheresis RED BLOOD CELLS|None/XX/refg|Open', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7d072d2d-9c3c-4bf9-bf45-d3b2a9e4b927'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7d0e7b85-69cf-495b-9b4b-8311269b2cc3'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7d171d30-0ac3-42c8-b2dc-504d3278015d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7d38a378-0515-4a77-8a09-5b49e4c78b67'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.037' WHERE BloodProductGuid=N'7d56f1e5-f1da-4100-acd4-82dffa10aacd'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.100' WHERE BloodProductGuid=N'7d771c15-c2d0-45fb-97f5-a53f3d183284'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.303' WHERE BloodProductGuid=N'7d8d6854-ffda-40a3-81b9-19caf7bf9d3b'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7dca1a0b-25cc-420b-a843-e6650255f5f2'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.553' WHERE BloodProductGuid=N'7ddefe5a-c809-4fda-840a-b4269c5a0509'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.803' WHERE BloodProductGuid=N'7dec3eb9-86ea-46eb-b460-3241b14242af'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7e3b5406-e336-4b4f-bd4b-e79992f58b28'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7e46d48d-8e27-43d0-9d9c-8a9c79ac707c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.537' WHERE BloodProductGuid=N'7e90d100-8169-4b35-a750-ff5c422c0b85'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7ee58c1a-e925-4020-b568-52164247ae9a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7efe9a6f-6080-456f-b85a-dfa9fcad53f2'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.913', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'7f17db7e-bd25-411b-9d65-c14fe8edc335'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7f4cd791-a780-4c41-b011-1f2e63fb5048'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7f521cc4-f7fa-4950-b8ca-7ad787014e1f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7f5e6c6d-cd8b-4d9e-89c3-7d2356fd331a'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7f654bdb-86ae-4095-a271-4be24a24717e'
UPDATE dbo.BloodProduct SET ProductVolume=15, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7f6e1782-dd29-486c-b0b7-d3cb506cefc6'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7f833292-79e1-4029-a89e-c9ec4fa6716a'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'7fb83d83-c0af-41fd-ad86-998c9eacaaa6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8000efb0-bcfa-4bb4-8e51-d37a8d5c57d4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.490' WHERE BloodProductGuid=N'8046f1b2-a63f-498a-8d8e-4be2661488f1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'808a01d1-9a98-46bd-88f0-82b2b86d263b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.367' WHERE BloodProductGuid=N'80ae1fea-f0d1-42e6-9110-a188db115217'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'80afc768-6153-4f80-8335-2eec319c94cc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8137aabf-7449-48ca-967d-60149389e04f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'815bb490-6fe5-4895-97d3-15b06d3ae819'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20090501 09:29:57.693' WHERE BloodProductGuid=N'815f3cd1-15de-4bb2-b06a-2b3073dfb590'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.943' WHERE BloodProductGuid=N'8170be5f-7c31-4ed6-9a15-9267f078d0dd'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'817edf32-f74a-45d5-8899-fa36b14f26d0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8182144f-f380-4bee-9a41-a9a971cb20b4'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'818eee66-444e-4556-a37b-3ad2c6ae1d89'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8199a9f6-fe0b-44f1-93f1-330927c0dddb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'819b585d-12f2-4f6d-a96a-35f0fffacc29'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.710' WHERE BloodProductGuid=N'81b42184-f890-4402-b49b-0ea3297be7a0'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.647' WHERE BloodProductGuid=N'81c6b233-24ff-4047-b468-0aa8073624b9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'81c9afa9-4690-4239-8074-60b5ff913f9b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'81d0365d-311e-4c89-8884-30d2964968f7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'82025620-7814-4a3b-aada-9d57e28a5338'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'82091158-fef6-45dd-af4c-7c690b0e3d04'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'82587f4b-aa45-43e2-9aac-84b7ef80433f'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.180' WHERE BloodProductGuid=N'825a7420-327c-4b9b-88ed-2ded1b1f4f6f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'827efa9f-5a91-41f9-a581-faf78f029202'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.773' WHERE BloodProductGuid=N'82d1b7e6-2d8a-433e-a53d-b5d07ef5f017'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.803' WHERE BloodProductGuid=N'8353842e-2287-420c-bc41-e02cfa76377c'
UPDATE dbo.BloodProduct SET ProductVolume=150, MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'836b4000-2eaa-4775-b7c9-61db767638e2'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'836b7180-7737-4837-a761-7d6850867f07'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8384428f-9f29-44cd-8990-7fead210fdad'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'83928661-051c-4b4d-9c56-1baa21764dd9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'83d754b6-f3d7-4841-9318-a57fc2957743'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.867' WHERE BloodProductGuid=N'83dcc1fe-9ac1-40c7-b6d4-0afc9e717e6b'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.850' WHERE BloodProductGuid=N'83f6dfdb-a293-4245-8a16-739cb886aaa3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.663' WHERE BloodProductGuid=N'8432388c-d483-4b58-beca-dcd9897f26e5'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'84f35c52-b920-4741-8a33-afd2dce4bc4a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'84f7bab6-95bd-4597-a662-52e2cd17d587'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.350' WHERE BloodProductGuid=N'850632dd-929e-4a98-8774-fa1ace637f10'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'8520c344-b89f-452b-945e-f3344331ed62'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.693' WHERE BloodProductGuid=N'852a9171-e572-4871-b2be-dc1f450d168a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8543802e-caae-4a41-9b8d-28d96fafd43d'
UPDATE dbo.BloodProduct SET ProductName=N'Washed PLATELETS POOLED -5d LEUKOCYTES REDUCED IRRADIATED', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'854e9054-87cc-42fe-a372-a62979c1f423'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'85c37cf1-43de-47ef-b64a-88a5a89efd0b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.833' WHERE BloodProductGuid=N'860c6e12-5190-44c5-a20f-368893ce45a5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'86108c87-a876-4020-a8bd-bbb3332bde15'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'86119cc2-a661-48eb-8c78-6c05be21bc53'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'86255112-f4d9-44eb-9d01-e549b99bc112'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'863388c8-6550-4c8a-b0b6-69bb4de1975c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'866b00d6-7e25-4600-8d86-f046483b2b5a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'86813557-2713-4835-affb-c4fdf7f5c0fd'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.850' WHERE BloodProductGuid=N'87124af4-88e1-4fbd-96b9-587958c91f43'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.617' WHERE BloodProductGuid=N'87170cda-af70-422a-8af4-0b17a114ef47'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:58.037' WHERE BloodProductGuid=N'8756fc5d-b184-4da4-840d-ddb9befc2b7d'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'876027f8-1fea-4045-a0aa-c4a152ef4406'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.787' WHERE BloodProductGuid=N'87787968-0c7d-4c91-b99b-0c8435df6c5a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'878afdfb-7465-433c-b31f-53977835e945'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'878db69e-205b-406e-b356-5a0698824c13'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'87a12af3-8c7b-4da8-a109-940ae8cabb7e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'87c3fc89-3088-42a7-8adc-5c6efd2d3db2'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.773' WHERE BloodProductGuid=N'87f08eab-65d5-451c-9e04-6fb7ea4e5568'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.897' WHERE BloodProductGuid=N'8808aff8-c3ae-4fc2-b443-db2a0bd8b0d4'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'882d51b0-37bf-4d29-b64b-032a249c7b34'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'88478402-016a-4cba-a821-be34cd0279b2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'885217bb-3213-44f3-a60b-d64d327d7fd4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.397', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'8890f4a7-fd45-4b9b-ab68-a902e7e4828a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.913' WHERE BloodProductGuid=N'88d012ec-d656-4698-aa97-850c28325af3'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'88e5f292-6a9f-44f0-bac0-ff85374975bd'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'88fc38c2-00e9-4116-b494-2b8787f5593e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.380' WHERE BloodProductGuid=N'8900e46f-25ff-4ce3-8269-9198670a1662'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.523' WHERE BloodProductGuid=N'8926e70b-9572-435e-a656-d965ac8cfa25'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'892829b1-4ddc-4b30-8298-f4a4fd9a38ee'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'89344d67-b2cc-4647-858e-40d87aee0c2c'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.977', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'8934fca7-d496-4a73-81ae-45a37bcf4d0f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8966b90b-896c-4de5-9048-45e318e0f449'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'89b22ff6-e361-43fb-8899-85ebffceee56'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'89e72dd4-4170-452d-aa1c-bf6c2487a909'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'89ec5c65-2943-421c-b26b-2d20372aa77b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.990' WHERE BloodProductGuid=N'8a0b370a-08eb-4bb3-97ce-91a039b9225f'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.193' WHERE BloodProductGuid=N'8a213698-6df8-41e5-a921-8d3395c7acf1'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.193' WHERE BloodProductGuid=N'8a3447e3-dbea-4259-a6b3-5252dbc5d55e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.727', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'8a605f82-b91d-478c-85ab-d39a95fc06b9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8a8adb97-818d-455d-9852-48c3222d66ec'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8aaeaaf5-1d34-4f18-bb21-363c594f11bd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8ac6c354-1b49-4e1f-b158-02c6e60c62aa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.130' WHERE BloodProductGuid=N'8ae2e24a-b258-41eb-aad6-2286508fa292'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8b0322be-1058-46c9-bafc-e4fa30f2a369'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8b10355e-bddb-46f4-aa94-3c872cc4eb9d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8b164d20-190a-470a-a8a4-9b60f43f3f31'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8b268afc-7467-4c44-8b8b-aa99521c2e7b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8b78972a-586d-4b77-9676-d7daf03233fa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8b7c7dc3-36c7-48b7-8283-77fa987fdb37'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8b8c66a2-4878-4d6f-81f7-1cfe574565b5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8b97f8cc-6283-44ad-9d2e-cef25e56c5bb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8bab43de-8af9-408f-aa19-f1c4532bf51d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.977' WHERE BloodProductGuid=N'8bb5ad3d-ce27-4130-8b3e-42c872e6e3dc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8bb7a081-7f27-43eb-a6f9-9e3653465ab3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8bba2af5-c912-4db0-b5d2-cb8ba86085bc'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8bc25b97-b0c0-4f9f-b518-84554b3c6ef4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8bcd209f-c507-4548-b3bf-5bfbe628b696'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8bd1463c-c253-4a23-9e0a-8757cd3bfbd7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8bea2fb1-a179-4799-a5af-68be972e15b2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8bfb4d6a-735f-43b2-9a81-d9aeac61cf5b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8c3949b3-cc55-4ccb-82d6-04e3fb759101'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8c55ca53-c1f2-4630-a151-f79e4737cadc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8c63cfea-8d09-4788-a4de-ef0d802e600b'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8c8dc64e-8032-4981-9637-de3482c0c260'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.507' WHERE BloodProductGuid=N'8cf46fbc-4d3f-4a57-b219-bd37b0858d1e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8d01125e-d155-4e74-af96-fd68d5a80b49'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8d145ea1-64fe-4792-b1cd-5f0343315347'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8d150a00-25d0-4417-9254-eae42ac67509'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.820' WHERE BloodProductGuid=N'8d5eee64-73c2-495d-8e60-3555641d5981'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8d87722c-0e76-4ae1-b7e8-43da3a51e460'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8d9aeb37-3955-40e8-8fc7-774bca4f460b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8da1e134-e0f7-461f-8b11-d97ed8b25e48'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.490' WHERE BloodProductGuid=N'8ddde28e-cacb-4823-900c-ebb7501bd2fb'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.147' WHERE BloodProductGuid=N'8e16a892-1285-484e-a4e8-989590e3abb0'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.867' WHERE BloodProductGuid=N'8e2a0858-c3cf-4a7b-a6c1-9ed103090ad2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8e40b4a5-589d-4c6c-a823-e5e6055b9b38'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.100' WHERE BloodProductGuid=N'8e570e47-b30a-4e32-8bf2-a8aa4e556e97'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8e5c9c98-32c2-4809-8649-eb60678e13c9'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8e6aa279-ceda-4890-81a9-f98e5740176c'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8e6f34e9-f374-4fb0-b7b6-65bc75df84f0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'8e88150c-5445-420a-9e29-e3ef5ea84aa5'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.617' WHERE BloodProductGuid=N'8e8dad98-7341-4dc5-b1d9-ce0082eede50'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8e9b2980-f73a-4abd-85ee-5b31b1646478'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8eed3f42-9882-4976-9456-95bd55967f35'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8f08ba53-cb3c-4098-a2c1-cfd79e850bb8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.833' WHERE BloodProductGuid=N'8f0a4fb1-d682-4a74-8f96-633a62d2b703'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8f11992d-0771-4668-91b4-967ddf4ababa'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.820' WHERE BloodProductGuid=N'8f193aef-704c-490a-8937-68ef2e0d3e29'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.163' WHERE BloodProductGuid=N'8f2fda9d-8421-4255-a6a3-ba237cb6daa4'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8f605215-6e53-4220-9bed-44ca12c8786d'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8f613485-fbbf-4c32-8104-fbbfe58f1487'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.930' WHERE BloodProductGuid=N'8f883679-5910-44ac-ac68-ff78a579722d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8fb97118-7d60-491a-8e69-a1c81ec92829'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.147' WHERE BloodProductGuid=N'8fcc100d-48dc-4bbe-8a23-dee5464884a4'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'8fe79f5c-b6aa-4af0-beb7-3074d1ac3658'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:57.913' WHERE BloodProductGuid=N'90350d32-99ce-428d-a793-c2003a7cd26e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'903dc4c9-50a0-4b3d-840e-385a7b2f0cf2'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.083' WHERE BloodProductGuid=N'90410b59-fe4f-4426-ae9f-d26bbbbf1e26'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'907edb9d-2127-4dc8-b347-2c4551115fb9'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'90828614-4894-46d3-947e-3c144de55cfb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'918c143a-f27d-43b8-9e3a-80c01a1845af'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'91ff817d-759f-4fc0-8cfb-6f28d2c88b47'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'920f0871-c594-4a9b-b230-a42d3de3abe7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'925cf063-f890-4b38-9113-215b216fd063'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9262bcef-0f4d-43fe-a881-4ae5723b6843'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9267f493-bb06-4c6e-bb35-a6bb84753830'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.617' WHERE BloodProductGuid=N'92c66188-2321-4fea-b1fd-34b56ef1d11c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'92c78ab6-75ec-4ff1-87ca-5ef62a30bfc1'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.850' WHERE BloodProductGuid=N'9350c9ce-fbf1-4233-8334-858c77937f02'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.930' WHERE BloodProductGuid=N'93865c59-ea65-46ab-ad7b-a6654122e87c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'938d64d3-5722-49f4-947b-b8952fee632b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.303' WHERE BloodProductGuid=N'93cc2b45-eedf-45b4-bcb0-0a0e7755f359'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.537' WHERE BloodProductGuid=N'93d34fb2-20b3-4426-926a-1e6c1fd9abc6'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.507' WHERE BloodProductGuid=N'93fd945a-9f55-4739-8b10-f0e872a382fb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.490' WHERE BloodProductGuid=N'93fd96ce-3b02-463d-8331-dd78ec37fd76'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'941d5d12-35cc-4649-80c5-c80375403760'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'94291732-2f33-4d77-8292-21882757b532'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'948c070b-21a4-411c-ac30-234997d91559'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'94aa1381-4c78-47b8-8c6b-817d5b776c19'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'94bcfda7-4e53-47ff-86f6-fcb752c369b9'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.523' WHERE BloodProductGuid=N'94d9fad5-ed91-433f-8026-8fce7c56c6c7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.460' WHERE BloodProductGuid=N'94f709f3-f00e-4a07-9f53-4f4d450f548c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'95154028-f10c-4336-a367-378e956d12e3'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'9519b87a-48d7-48e8-860b-a4f3b870d754'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.477' WHERE BloodProductGuid=N'9580c60d-07a3-450b-9b72-46d8131a8e01'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'958d423e-3d30-4738-9ed8-103a68bf0869'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'95a50161-0365-485c-b9b9-b8a3f1ab3131'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'95e824d8-6f6f-4366-a662-877695f5008a'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'95f8d1a3-da3c-4534-a4cd-5148097e61d8'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9637fb55-6e71-449d-95c3-6b6f1f57d361'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.477' WHERE BloodProductGuid=N'964db408-c95d-4589-b021-ed68b2f2cf63'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'969db5de-d5af-4ba3-b216-54650f20fc05'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'96ed8833-09da-4d2a-82ff-9947a4cf6356'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'96efdbec-0946-4453-9eef-7380aa544951'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'970d656e-0f5d-4b55-a860-8d6d1447838e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.990' WHERE BloodProductGuid=N'97324c29-5b98-418c-ab67-b5b9ec0ec24d'
UPDATE dbo.BloodProduct SET ProductName=N'RED BLOOD CELLS|CPD/450mL/refg|Irradiated|ResLeu:<1log6|Plasma reduced', MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'974992ff-34f1-4389-a854-fe34d8290767'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=672, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9754f6da-739f-4833-a306-9a4a8911f5a5'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'975aecda-18b9-4580-9c27-00d23f0998ec'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'9763424c-7dfb-45ca-8cfc-1f51b6e73f60'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'976a9363-f251-4174-ac45-14300f5098ab'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.710' WHERE BloodProductGuid=N'977271f2-346c-405e-b054-dd8f1670b765'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'977cf507-1d25-49c0-8a00-42fb7b63dde6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'978bb278-8d93-4b21-981e-873c2c48a53e'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'97dbe63c-169f-4a7b-bd2a-84a751a641e2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'97f7ea03-14f6-4284-8170-07b7e403b39c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9857f2fe-a82f-43e9-8dab-770bc9fa6807'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'986acafd-7752-449e-bb55-3414814c9dea'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.757' WHERE BloodProductGuid=N'9881ce9f-deea-4230-9a50-d5421f30bd81'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.210' WHERE BloodProductGuid=N'9890de3f-f605-403f-a6f6-5949e42373ad'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.083' WHERE BloodProductGuid=N'98a38144-2750-4754-8728-623e4b6d24ef'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.727' WHERE BloodProductGuid=N'98e7e5d3-3bec-4ed2-81d1-d4f8af2847ea'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'98eb891c-3ac5-461b-b2ff-6540e7008f0f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'990545be-7578-4a3b-ad18-e9d5ed5411d3'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'991605c5-3140-4a8d-9fce-2e779dbb1e70'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9919397b-ad6e-4299-8331-2d671b0420cc'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9940919b-ceb6-4ca6-bcf2-c428b4c774d1'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'99572fab-35fd-4881-a868-11e0b0d3224c'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.680' WHERE BloodProductGuid=N'99852735-1003-4b6a-bdae-7a4ec3329171'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.943' WHERE BloodProductGuid=N'99cfe380-15f2-4a58-90bc-50fa69aa594e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9a254b3c-12ed-4fdb-b7c9-2f96711c71ab'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.490' WHERE BloodProductGuid=N'9a3a4d9f-b90a-472e-80b9-d693afec0725'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9a68603f-c40e-4bd9-a441-bbde9236dea8'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9a94a1bc-1583-4b71-a34a-0e3e400fb18f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9a9e43ac-eea5-4169-b88e-a01208287e12'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.210' WHERE BloodProductGuid=N'9ab6fc5c-196f-412a-b2c4-36b95b0d648c'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.053' WHERE BloodProductGuid=N'9ae0955f-c932-4bda-bda3-67b2c4a2ff4f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9b1d1016-6046-4c74-b1bc-b425d8c91f85'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9b5bbc23-71df-4736-bb9a-256bc1a4c27e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9b77e22d-dd82-4fe3-a836-511ff8c91805'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9b8cbe89-fed0-4994-9fdd-50833644b254'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9bbfade5-2343-46fa-8c6d-a5d634c850fe'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9c1bc5d7-47f6-49fa-ba26-2bea941b99bf'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9c524a59-3732-4003-b3d6-d3d67ed3c3b4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9c5abcd6-6529-4a90-9ec6-6b7d5d1a488e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.130' WHERE BloodProductGuid=N'9c616eaa-e280-4d3d-8cca-a473633aaacd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9cba94e0-fb5d-44ac-85aa-e60fe7100ffd'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.570' WHERE BloodProductGuid=N'9cbe008c-b2cc-4227-a1b3-f36777e2ac10'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.960' WHERE BloodProductGuid=N'9cd476d2-6241-4222-bf7f-ae6f8b017038'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.083' WHERE BloodProductGuid=N'9cf6444f-244e-4dba-a144-c19076c0d7dd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9d1275a9-38ba-4a3b-b79a-789513e6e24e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.053' WHERE BloodProductGuid=N'9d1d5832-bc44-4d3f-b954-d0d8ddc642ee'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.710' WHERE BloodProductGuid=N'9d539fb4-2219-469c-b3cd-808e7858c30c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9d6ecc1c-7070-4667-858b-ac99fa3287d3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9d79fbfd-71ce-4035-ba6e-b063cbbdf694'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9d9c1371-66b3-48ec-81b9-a2a51377d50b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9d9fb3f6-b2fb-4273-a479-43ad449fb89c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9dad85e8-8ba9-4f04-97e3-bfa6ce00e9ec'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9db7c905-879b-443e-b7db-e238f3f2ae42'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9dddd102-15f8-476d-b8cb-08ec2553eb9a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.820' WHERE BloodProductGuid=N'9de862c0-f0f0-45d3-b863-ec969edfee11'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9dfa676b-25df-4bd5-b67c-0d24c5c7a0b9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9e328648-3e3a-4a38-864e-aec863a76079'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9e33298e-2b3c-4e41-84a2-d392375f3168'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.070' WHERE BloodProductGuid=N'9e5fc2e0-d191-42b6-9937-844891e75bcf'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.100' WHERE BloodProductGuid=N'9e837dac-a0cc-4e93-a5ab-bb2d6780ed41'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9ea757a5-6cb5-420f-ae53-babd76887b0a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.083' WHERE BloodProductGuid=N'9eadd300-400a-41cf-9b2c-08192148a177'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9eaff252-e9b3-4a69-8088-2948864c8e38'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9ee201d2-76b5-4c78-bf23-7d65ee73c586'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9ef0afcc-233f-49d8-8704-ccb9cc4aee23'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.350' WHERE BloodProductGuid=N'9ef74e2b-d608-4c41-b6c5-fafeaa43cd4a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9f1b71eb-a5e5-488d-9676-b25cdabbbcc4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9f41e79b-760d-440d-b1a6-6b0f2dc155b6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.523' WHERE BloodProductGuid=N'9f80e863-96e3-4a8d-956f-80ad9cfc992a'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9f8a1d07-d385-4731-bd14-962d760af1cc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9fa73ab0-f28c-4815-966c-9377e60bc1d1'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.460' WHERE BloodProductGuid=N'9fb4519a-11e9-4909-a138-38c275ab658d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9fcd2123-36d9-48bf-8b7c-896a8f47fc86'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.850' WHERE BloodProductGuid=N'9fe241f6-deb8-4a1f-bcfa-c09c3f8967eb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'9ff87b82-349e-407c-8329-1eba0ca3d98b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a01e4621-deb6-4fbc-8818-f3dabd252324'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.570' WHERE BloodProductGuid=N'a0314968-6185-41df-aaaa-e36bc6fcd05c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a04b365c-3839-4d58-848b-27bdcdf052ed'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.663' WHERE BloodProductGuid=N'a097cde7-59c0-4f11-b0cc-35fe913a99fc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'a0f71c09-fe1a-4d4a-84d8-3c9ca74bea85'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.913' WHERE BloodProductGuid=N'a1163a24-e68c-49aa-a98f-5c4ab7c89f81'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a17015c4-2722-4284-a9d6-b6e4a328feb4'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.757' WHERE BloodProductGuid=N'a1bb087c-de1c-4b7d-aac5-d2bbcc965c7b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a1c6bd7f-4236-44e4-b218-8ed8a6fef2a5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a1dcacad-d8f3-455c-9d5e-67635df32dda'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a207a144-511d-4e39-bad8-fb38a16ca035'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a21ce106-b7e9-45ec-8858-397c195e6473'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR CP2D IRD LUKOPR LowVol', ProductAttributeForm=N'@37 C2 D2 F6', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a2235eac-7e29-49eb-956a-1005b1fdf1d1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a23ca676-5121-4a9a-97d0-250d0a3bcb9f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a2703f75-6b25-4719-9b3a-cc6aedb017c4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a29ad18d-341f-41fa-a5d2-a3b6ae8c9ff4'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a342992f-329e-49b1-87a4-3810c2f3b264'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a34c97dc-13d1-43c6-b9bd-4f6f0c70a67e'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a37c3b31-83b5-427e-8db6-e4fe79059467'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a383258e-5d3a-4974-840d-06f70b2d8f36'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a3d5643a-f102-4cfb-ba05-d8fcd9bc1d4e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a3d92ae3-a2d0-4a96-a42f-c609d9feefe3'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a3df5f68-cd01-4beb-8069-f552cac3e371'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a4569456-cb51-4895-b8e7-4dcbdfc3683e'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a474c015-20d3-44ee-bb66-f2eb0d94dc44'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a47c8e52-836b-4fce-94eb-b67be1c1dcbf'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.913' WHERE BloodProductGuid=N'a49125d6-89af-4a05-a37a-3896bc37ab6d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a4929c9d-7d34-47fa-91a3-31cd692bd497'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a4a116d4-89b5-4c52-9a1e-772359d566e1'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a4a758f0-f0c1-49ff-903e-68c3d57f6080'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a4ea5847-2232-4ca0-b3e2-6cffa4496dee'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a5146b39-d249-4c03-ab56-16601a8a2753'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a55f84ee-9a10-4a15-932d-f5a9e19c47b3'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a58c9cea-23ff-45a0-ac2c-c160dd26518a'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a5f422f7-b2cb-4220-9ab7-065bb5585261'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.727' WHERE BloodProductGuid=N'a60e16bc-df15-410b-af2a-02f7be51455b'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a6227317-9c65-4d5d-8247-9da301d359c7'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a62eaafd-dc37-49cd-a595-8af7c3c6e639'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a64875d3-65ba-4a3f-a89b-1d564d76ce23'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a64ff084-41d8-4cdd-8c8a-fbd57da8c314'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a657d4e3-e94e-44ed-9096-4d1333c9ab4b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a663ce07-07f5-49e6-be7c-fca61c273b01'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a6689c39-02a8-4078-92ef-2b249b163f35'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20090501 09:29:57.430' WHERE BloodProductGuid=N'a686426b-a157-403d-bbf7-d8eee92fe093'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a6a96a62-c458-4a6d-9f6e-618cb819ad56'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a6c61e01-6d38-40c5-ab26-5e7c7a1674c7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a6db0b48-eacc-4278-9256-cfb6a22debf9'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a6e1ea4d-ff18-4029-9683-5282074250cc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a739e42f-fb25-4f46-b126-87212de92df1'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.460' WHERE BloodProductGuid=N'a74790e1-f212-4253-b61d-5165a8437f12'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a759992c-9eee-44c8-813b-3d34487dd86d'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a78870a7-44c8-4793-9363-3a0225997a9c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a78c6048-3113-4d75-af2a-31bd7a4f2235'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a7b9478e-9947-49c2-a4e5-6ce71baa14e9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a7c28ed5-92ee-4821-ac89-1f88afce2bbb'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a7f90895-4102-4874-a211-295fb09146ea'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a80dc102-93c0-4384-a54b-caaa495d6807'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a8294b90-b042-4820-abf3-b4c715ea4161'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a871981f-b8ce-493d-9ec1-420519fe76d6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.240' WHERE BloodProductGuid=N'a87c80ee-493a-42ce-9109-17a9bb73f65f'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.023' WHERE BloodProductGuid=N'a89694b4-7b1f-472f-9820-b094d5fd37ec'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a8f2fbf8-5220-4a7f-8fda-dc69d9cb187d'
UPDATE dbo.BloodProduct SET ProductVolume=150, MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a91e9e5b-b4a8-4b48-88f4-b1d554b87011'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a93de30c-bde4-4f58-9a16-bb070491262b'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.617' WHERE BloodProductGuid=N'a9755f30-220d-4391-8b27-1614c98d2f1b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'a98084b2-7565-45c7-993b-4bdf057d997f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'a99c68ce-82dd-469c-bdd4-32f43334989e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.867', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'a9ceab73-bee6-4356-9bba-10b1aa0e370e'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'aa11ee45-cddb-41c9-b3d6-6ad9c2d32afd'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'aa39ac11-08a5-4c30-b69c-fbac11097e7f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'aa90a7bf-20bb-418e-88e2-2d5d89003e9f'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'aaa1686a-a6da-401b-a390-a5d4dd372cec'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'aaa1aae0-88df-4601-a1a7-a5a0eb08d452'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.430' WHERE BloodProductGuid=N'aada0e3a-f98f-4191-9eb4-dea5d61bea99'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ab74ca22-ebdb-41bb-8d83-16582fb61981'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.490' WHERE BloodProductGuid=N'ab81fbdd-3f1a-40a2-a5da-a02786287b46'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'abadcd5b-6ab6-476c-85c7-954d7ed6c132'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'abbcbe6d-43a6-462a-a541-fef5d7be41e8'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.880' WHERE BloodProductGuid=N'abdd0322-5759-4373-8050-f4c15cf3a41d'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'abe1ad03-3b56-43a7-8626-4f8dc980d4d5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ac37b7e4-b1bd-4c1e-b012-52d4dff6ad86'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ac76c528-9382-4d9f-b521-4ba60f849d96'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'acba69a6-acb0-4f39-ac9f-7cc7068a65ec'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ad3a0500-a50e-434c-8be2-df27b20e9bea'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ad3dd923-2c80-48a1-b483-413fcf2cbc1f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ad42e69e-9d1e-4d25-a369-3a628831b358'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'ad56b518-90fd-4932-b937-834c50fd9fdb'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.803' WHERE BloodProductGuid=N'ad798004-07cb-4eec-b75d-9747a32f92a5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ad9fc5a8-aa0a-4d6c-8594-d914de76476d'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ada01b97-8a7b-48a8-9cd8-f32cade293ad'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'adb43fa5-2eec-4c4a-986c-11a590013f75'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.163' WHERE BloodProductGuid=N'ade49671-430e-41b8-985e-6dc65da94cb5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ae01f33c-77d0-4873-8a72-e9aae58a0096'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.053' WHERE BloodProductGuid=N'ae1ccf82-816c-4f89-bfb1-596a5d20bca3'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ae1e3bc0-a7df-48e7-83a2-d17f5cf7e4ab'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ae662f9f-7298-4ee6-894d-170458e265b5'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.977' WHERE BloodProductGuid=N'ae66ddf4-e272-4df7-89f6-8163ec1864ff'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ae693884-cc54-45c1-bffd-77db9b9a9a18'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ae74547d-9dce-479b-9c13-cfdce20bb3b9'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ae8dcb14-d58c-40e6-ade4-7dcc97a14002'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ae98eafd-3c3b-47fd-ae57-56289e0577dc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'aec05ec1-3c02-40b8-8e7f-3ea34e674e2a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.100' WHERE BloodProductGuid=N'aec1a52e-6750-4cbb-9ba3-45356dbeebf2'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.630' WHERE BloodProductGuid=N'aecfa1f1-8ea5-4441-bb21-0c56506811d1'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'af3eb202-8471-4b90-bc5c-e8d4ab1a8131'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'af5ea588-0de5-474d-b00f-72f6f0336047'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'af6a72f5-6e7c-4223-8432-14c249966cda'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.630' WHERE BloodProductGuid=N'afa338b8-9c58-4937-b43d-ede022f547e8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'afd4f126-193c-4756-a5b2-405fb6ddb4f5'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'afea7dee-48db-4733-8573-4efe2eb10e18'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'affab2ac-cb0c-4e17-87eb-46c931209efa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'b004820b-0dcf-47a8-acb3-887278fba726'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b056c52f-205f-4822-bc65-1cd51dfb4c1b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.130' WHERE BloodProductGuid=N'b10a47c7-a0e3-47a5-8790-71be97fe6c58'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b10d982f-8784-4079-ad81-01841e9aee32'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b1649f17-f670-4c3d-8f62-4579daae014c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b17b0564-f824-47a4-aa72-4836b8a8c6f9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b18db563-04cc-4d00-a6fb-e7b001b4f85f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b1f26a42-a8d3-4d6b-9a17-6c53291fafdc'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b1f6a5db-33f1-4189-bd4b-dad1c105285c'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.710' WHERE BloodProductGuid=N'b258684b-4ff6-40a4-a277-d5d692b2388c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.930' WHERE BloodProductGuid=N'b2985c3a-1eca-436b-bbd5-59de21714645'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.740' WHERE BloodProductGuid=N'b2c8891d-0603-4310-a9d7-70de83441d6c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b2f72adb-56d1-442e-a9f5-424d1a6d7226'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b2f81d57-e78c-4b54-be51-33968c969d50'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b347f9cb-5900-4d34-a16f-cad1b5e0e35a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b34f1722-dc3f-4f0d-98ec-d66e9ce476db'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.147' WHERE BloodProductGuid=N'b35aad53-6695-41cd-bdb2-77a3855b0d62'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.850' WHERE BloodProductGuid=N'b35f4d04-95ad-4228-a1f7-37337cf6b80b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b3878283-a225-4d82-87a6-3d195aa5fcdc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b3e99835-0794-4883-b6a4-3b398f950a38'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b4634117-f9e5-4719-9ead-c85bcc515c3a'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b4795dba-a262-4fc7-b023-6f9c318332fa'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.647' WHERE BloodProductGuid=N'b4844c4b-2186-4649-946f-908a99cf3a81'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.413' WHERE BloodProductGuid=N'b48a957a-0d06-4a64-816d-ccb862a92aa8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b48fd89c-f402-4ab9-ab04-75ab5b02a345'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.990' WHERE BloodProductGuid=N'b4981999-9dbe-49c4-9584-437407543915'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b4b6f94e-8183-4ea7-80ce-82b5074b4772'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'b4d26920-73e3-4dfc-92f0-ec3362c5d5a2'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b4d51ddd-5b59-4ac2-867a-2bf3062be7d7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b53c8a9f-e3da-4567-a2d7-cd13a89eb0c4'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b58e9086-7968-4a86-b040-83b60829c933'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b5bbfd24-4b33-46e4-b140-34c4e4e4d46e'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b5d27aa5-8d72-44d8-b230-8743068bee5c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b5f899d6-024c-435b-91f1-f63bcca93f18'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b642feef-a26c-4ba0-b846-ca3314a8fc1e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b65103db-9ef8-4aad-b884-c468cdd2cfcb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b652e23e-7d8e-4947-9f2b-69b5a05b50fd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'b66f3e4d-81ac-49bd-8cf4-fff1923e821d'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.680' WHERE BloodProductGuid=N'b683d6fb-24b9-447c-8809-0c6489aa1380'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.413' WHERE BloodProductGuid=N'b69f408f-d21c-4fb0-bcc0-89b835a497da'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b6c3558e-94d3-4694-9cf1-9d7d56f73a3b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.037' WHERE BloodProductGuid=N'b6f00165-1c25-4338-a6e7-f080908196b8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b718f791-5c94-4743-b657-385e06a267d0'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.693' WHERE BloodProductGuid=N'b72efb2d-3011-4581-be13-d52219456ae9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.943' WHERE BloodProductGuid=N'b7364106-dffd-45cc-8e1c-50dd77c354c6'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b7704516-2a55-410f-8521-179e7b5ba6ff'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b77ab35d-cf9e-4d99-85d7-bf478bc2ddfa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b7bf6b1f-2695-4566-8507-33aadfed34c6'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.397' WHERE BloodProductGuid=N'b7e67167-395e-4a24-94c3-2af5fa7dcf37'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b7e9f6ba-d745-47a2-bdb8-6c4a03a96f18'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b8094a0d-8990-4cfd-8b10-08d04e5408b7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b83a5719-3376-43c6-b52a-e1ab494102cb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.193' WHERE BloodProductGuid=N'b8527198-f267-4b7a-b3b3-2037647e90c7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b8910215-bba0-41f1-b279-2808e9b6c9f3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b8a4ef4e-0fa4-4e34-b067-4d83f150cac1'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b8a7dd93-c929-4a0a-b008-9b1175bfab92'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b8b7b97b-9dd8-4661-a93c-dd85bb6ac32a'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b8ce8cb9-24db-4c21-8587-d7419900a38b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b8f8a95f-a77a-47ff-ae7e-99be594be743'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b940be40-0295-4e02-8064-ecbfb92c4088'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b94334d4-2847-40f1-8e13-09658199dc78'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b94e8cc3-9dbc-424f-b024-0563d3c49e40'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b94fce78-4412-47f7-8e1d-2f73d22f1bd7'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b953c23d-5894-4622-b6de-48210fc986c4'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b963b50e-3d56-45a4-8dae-4d53d247ab23'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b9ade354-5fbf-4b32-9d89-a210f185beba'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b9d7f364-2b34-4af1-8323-4bf9053d9e17'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b9f160bf-fe03-47cc-bc37-e24c5f071ada'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.490' WHERE BloodProductGuid=N'b9f73a88-1c89-4176-9bdf-4128c8cce58e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'b9fbf7fa-add4-4b37-9184-0771dcaf0be0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ba1f85f5-3b2d-4bd1-b020-fc7fe53cbfc0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ba34d8b4-8f0c-445e-89eb-91feab6a8396'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.303' WHERE BloodProductGuid=N'ba465f2c-c434-4365-9a5c-75aa9ce5a15e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.117' WHERE BloodProductGuid=N'ba57ee8c-5e12-4ba9-a601-b518fde6aac0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.787' WHERE BloodProductGuid=N'ba7b909e-d350-4926-ab26-7b78a54f2654'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'baa9572e-f137-46f6-8050-8276d87c20a4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'baade18a-b638-409e-894c-fa1d6062fbd9'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.583' WHERE BloodProductGuid=N'bac81905-64d6-451a-9d67-4b4be852ae16'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bacad020-1408-47c8-9245-9b076d766837'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bad4893b-ab73-4824-be39-84b097420bd9'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'baf77ac5-06db-4cab-a329-ad1ecd803c06'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bb32e6f4-be25-42f4-b015-c3aa4d81a8b8'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bb596afb-1ba8-4015-b0f7-a28fa0f5560b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.930' WHERE BloodProductGuid=N'bb72a5e0-d8fd-4a0e-8e24-3a28b2f4b39c'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bb8bc438-0339-4070-b41a-d0e7b24e1d25'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bb99a1dc-0d9c-4f4e-b4c0-90920674495a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.477' WHERE BloodProductGuid=N'bbb0b45f-9fe2-4faf-ace8-0cae62e4fede'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.630' WHERE BloodProductGuid=N'bbfa6e73-c436-4b97-b109-527c4dc3d0d4'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.380' WHERE BloodProductGuid=N'bc0c05db-de5b-49f9-9169-538d93bfcb40'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bc300839-6852-44fa-b3c8-eb03b54ccfa2'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'bc31f924-d747-432a-8e70-5c4b064c0b5c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'bc5a7d84-3353-4bc7-822c-db72af7257a4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bc88ee08-451b-4c16-864f-1eebf567ccfa'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bcc1ea1a-ed55-4b86-98b1-056be8fca64c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bce25264-74f1-48c1-899a-72308e507901'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bce4a9c1-7957-43c6-b92b-7f4058ce5962'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.693' WHERE BloodProductGuid=N'bcf5b025-d2b7-49ee-a3ac-7d4612f3e92b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20090501 09:29:58.130' WHERE BloodProductGuid=N'bd38cf4c-6054-4b14-a74b-11b595c08cbd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bd45accc-3410-4040-99ee-5246ad078a75'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bddbe52a-8aaa-482b-abd8-400a2b5e670a'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.773' WHERE BloodProductGuid=N'be025e8d-e75b-479d-bdc6-4d28ad82af59'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'be26d807-bbfe-409f-ada2-4e8193703170'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'be2a7648-1c64-4e59-8a54-84eea1bb284c'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'be72dc98-87f5-4ecd-b9f2-21e183d1a27f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'be7df365-3431-4dc4-8e1c-8a85e104e7e5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'be852f17-0020-4afc-a800-5c00c4a52d20'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'be922ae3-c2fe-427a-86bd-47b04ded5d27'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bebfa1b6-fd1e-49b7-b35b-9a25c3489212'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bec50adb-cf53-4e32-a26f-b020a1e3aa66'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bed09427-51ab-4748-b937-2607a3113f9d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.773' WHERE BloodProductGuid=N'bed18717-b5b6-4e65-aa9e-83824cbe2694'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bf06095d-65e7-4765-ba1a-b2713cb78a66'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.583' WHERE BloodProductGuid=N'bf0a5ead-b5a7-4b94-bc68-05e33fe71356'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bf34afa4-a65e-4dc5-9320-08f560672781'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'bf3baf3d-f1b4-4644-9663-08049fb28de2'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bf815d3c-ef73-46b1-9fd6-95ecce978144'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.647' WHERE BloodProductGuid=N'bf81ed95-290d-4213-a4ef-c7aa7af17b1c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bf8a641b-14b9-48c6-a4de-b416a3938885'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bfcd7a98-38cd-4d4c-8126-0cce57d2c2b4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bfd703f7-95ac-4f64-a074-3e7a5c4b9510'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'bfecf99a-5f8c-441d-9774-9d69415b9fe1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c0534e9e-3d96-4cfc-8a0d-df922ecfb08e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c05a2e85-3735-4afe-b28c-5116295e6858'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c08fb7f1-c2e0-4f6c-a502-ea5260db4f15'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.070' WHERE BloodProductGuid=N'c095b482-33af-4a4b-8f82-95d1cfa51b7b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c0972fad-94ce-47cf-b3cf-6296d2eede06'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c0c60da3-d00d-4e49-9a9b-150b19537be2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c0e21577-c238-4c25-a06c-5cad85d81603'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.490' WHERE BloodProductGuid=N'c0ed1c55-4b01-4ae5-ab80-35d3b837c224'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'c1044242-565b-4910-8270-57421bf6e0d9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c120959c-7154-45a9-ac6d-35be798bb0e9'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c1257b28-1600-4326-b7a7-c035f7c19e38'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c1842fbc-7350-4da7-a70e-8070be2803e0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c188e043-d87f-4fc8-a98f-0798fc2dddbe'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c1bcdc4f-ca68-401f-a3bd-10042ca9e41c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c1e09f6b-6d2f-41dc-a34b-125581015017'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.460' WHERE BloodProductGuid=N'c1e8edc5-744e-4943-859e-5e93ea556d09'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.443' WHERE BloodProductGuid=N'c20f4feb-9a04-494a-827f-c6f6e9793483'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'c21e08ea-a99e-47ed-807e-e9c8b3389452'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c23108ea-5532-4957-a468-0ddab6040450'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'c25e984e-5ee1-471c-be27-87e10b44351a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20090501 09:30:02.273' WHERE BloodProductGuid=N'c260ef12-536e-489d-92e2-24d95117e78d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.490' WHERE BloodProductGuid=N'c2838b43-a9e3-42a2-9c7a-bf9d432cd81a'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c2925078-bb17-435d-81ba-f480bb3aea96'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.147' WHERE BloodProductGuid=N'c295f8d3-57ae-42f9-92a7-6c972fe8735b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.820' WHERE BloodProductGuid=N'c2c838a4-8a91-447c-9e07-eb1fecfd6f5c'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.553' WHERE BloodProductGuid=N'c2fe93c3-cea4-4dde-8b09-cbcef44feeb1'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.960' WHERE BloodProductGuid=N'c31298f5-047e-4d7c-826e-619336266529'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.867' WHERE BloodProductGuid=N'c32f7129-1c37-48c9-8220-348f13d08c94'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.553' WHERE BloodProductGuid=N'c35ab501-d605-43a8-b79f-a13d55c729d0'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c38c3c56-00f5-432b-b46a-7d820fb0e2b4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c3940b8d-a4a4-4ffa-a199-edaf67aed681'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c3e84b0a-f23d-4041-8d90-8dabe6fdc3b4'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c4218885-ee82-4b77-9ecb-9368572ab565'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c425dd42-3ceb-4755-82fc-6f0c7c5ad48c'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c426cbb9-1e61-4492-8cab-2b34c7a54cfa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c438a489-ac2a-4ef2-908f-c930b5385c35'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c47f502a-279d-4cb4-affd-6813b81bde40'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c492f894-e86b-4f95-a1fa-a097934567ff'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.273' WHERE BloodProductGuid=N'c496f5c9-ebdb-40d0-96bb-f40ab1f0a076'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c4fd7d24-915a-4c1b-bc6c-8c500589b7fa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.380' WHERE BloodProductGuid=N'c50a7d7a-bec4-4ea8-bb78-8f84066abe14'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c50fb81a-79b0-4db9-813b-af4aee1e5027'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c51a4221-9166-43bd-8e82-88c967b3d79b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.037' WHERE BloodProductGuid=N'c52e2717-0a4a-4b68-959b-8bbfa9be3fb4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c55f71b8-68e8-4c72-adb8-e2497cdd2a9f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.663' WHERE BloodProductGuid=N'c5923ab0-5f35-4e81-b7c8-ce6f73bd9e11'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.477' WHERE BloodProductGuid=N'c5a5a96d-10d1-4b58-8040-e06772404c25'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c5aa4300-9550-4538-85b9-d1fe5b0bbaf1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c5ad6675-aea7-4286-a487-626f0a01c8a4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c5fd004c-2d9e-45ca-8ca6-59666387e766'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c603c5f3-2150-4429-a57e-5f56d5d5bc85'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.803' WHERE BloodProductGuid=N'c61f7624-af4c-472e-93d7-8bfe5d441297'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c644c0f1-335f-4bc7-bb84-e1369c98c100'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.023' WHERE BloodProductGuid=N'c655e87c-bb95-4b53-a1a1-a15dc5154727'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c6674c80-47d6-41cb-a651-4036be0cafdc'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.367' WHERE BloodProductGuid=N'c69f42fb-c296-42a7-b404-0740519711f3'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c6b04034-83bb-441d-9f43-45d159cad760'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c6dac27c-3774-4d90-b9a6-b6ba7a95b4f7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c79566a9-33c8-4862-9a1c-ea585a9ec3bd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.710' WHERE BloodProductGuid=N'c7ac4d31-4004-4197-9d4d-6784dde0c55b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c7c10099-ddcd-495a-af29-ab82d3d720c4'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.507' WHERE BloodProductGuid=N'c7e6246d-fef7-4855-ad28-1aa11c1dea5e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c8247654-c8d0-4885-9140-78a417e6a514'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c83e0fe6-4e66-4ef8-af24-faf3082797c4'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c8638eee-12bb-47f6-a6f1-a8d09f8dc914'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c8908930-2201-4c43-a64c-c99c32cc0524'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'c897d35b-37d1-40b0-b24f-2cc5a561e007'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.787' WHERE BloodProductGuid=N'c8a5fea1-01cc-4d26-badc-3b7e1eb1c930'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.380' WHERE BloodProductGuid=N'c8b54df7-3018-40e4-bbd4-10318c4a977d'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'c8f56cbf-26dc-488c-8811-c7e1775eb53a'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c92a078c-5ec1-4abd-ba53-947de93c0c42'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c963c069-5bae-408d-93ed-e3dc4feda5af'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.507' WHERE BloodProductGuid=N'c96fc002-1e65-4473-bc66-2aac5b5a6b31'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c97ce3b8-fbcf-4029-80e9-69a9b3dd3386'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'c9f25694-9e44-4beb-8c91-53aa45606ac7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ca259a4c-b8e1-4fdb-aedb-26e14e53c693'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ca4c6bb8-58b4-43a5-8309-990367483a05'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ca5c0f64-8551-45f1-bfc6-c53ad3ca1d74'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ca83d3dc-13ea-4e4e-8757-a0e3c4867a7b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'ca844eef-fec8-4512-8c60-ada28012b1b2'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.163' WHERE BloodProductGuid=N'ca936df5-a9ab-4a3a-b089-cb221f6a4672'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cab545c1-c678-4c53-8787-140a53cd8258'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.757' WHERE BloodProductGuid=N'cabbea73-0ee9-413a-9200-2953d21c9b94'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cacc9ebc-b650-4a19-8e63-a1df82aed7eb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cadd9151-a70a-4b85-8208-a8fba349a6a3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'caf921e1-19ef-4b48-ba60-b0ed58efa925'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP CPDA-1', ProductAttributeForm=N'@BK', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cb6e0bdd-d77e-4e74-b7da-f19e5b139444'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cb80211e-e808-4e4e-b54f-be5ae0a23924'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.430' WHERE BloodProductGuid=N'cb9b99ea-9be4-4b47-b90f-47ce874f7006'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cbb2b9e6-0ed8-45e5-9aa3-178f42d25f36'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cbca5fde-fe2c-4be1-8bc6-59d7b2a82ef6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cc04d855-0533-43e8-9aa0-50290a21dbc3'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cc250336-8202-40ba-83ab-e1b5afc77309'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.897' WHERE BloodProductGuid=N'cc747738-9bbc-40fa-ba5b-ab4de172ad04'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.803' WHERE BloodProductGuid=N'cc9ee733-8480-41eb-b49d-70370b9df3ef'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ccbc1598-1b3f-43f1-98ec-db2af9c41bdc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ccd07366-90d9-4bff-bb6c-55aa159d1359'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:57.943' WHERE BloodProductGuid=N'ccf99f72-1fc5-4e60-9df7-c1462519d565'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cd6df627-a8b8-40b1-83b1-2e8bc9f6bf52'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cd919ed6-28c7-4f41-9185-ad52b5da10d1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cddd2a67-98fd-4789-b24a-6fc93647b2a6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cddd7598-ca58-43f3-8c25-11ab0c691624'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ce0df3de-66ee-4014-9833-b8e48730a6a0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ce394799-291e-4c8f-9ccc-f95b6fc71c15'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ce50e957-1410-4deb-8f25-cea66a2695ff'
UPDATE dbo.BloodProduct SET ProductName=N'Deglycerolized RED BLOOD CELLS|AS3/XX/refg|Irradiated', LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ce543a03-082c-4c6d-a520-f94cd92bc48b'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ce6e79fb-84e7-438b-bda6-cb8bb9f5e5fb'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cec52cc0-04a0-4a80-aecd-586b2a3e0339'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cee3dac6-2b4e-4fb5-84d8-e0bde940d047'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cf1dc61f-9a1d-4a1e-8ad3-18662b26f939'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.130' WHERE BloodProductGuid=N'cf5c593b-64cb-40a0-864a-3061d2ec6325'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cf6ff905-0ec6-4e8e-bead-674638b9cebd'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cfa90187-a44b-4bee-b8b3-cf0e2e41c153'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'cfb16d87-3cc2-417c-87bb-3474ac792e5e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.053' WHERE BloodProductGuid=N'cfeb4953-c1f5-4241-9db4-e2843f13b0da'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.680' WHERE BloodProductGuid=N'd00056d3-3428-43f3-a5c4-2229571242f9'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd0039aec-a22b-4a11-83d6-04d31caa03fb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd00b695f-5a84-4c54-adc8-eb692a87aa5d'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd01f263c-9b3f-40e8-97a5-4094f47a5a9e'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd03d46cb-94c3-4b13-b432-3d1bb9025530'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd0441a6d-3d05-42d5-b77c-3cc7fdc9eb8a'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd04bdc1d-ec34-48fb-be89-edd249af6efe'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd07aa64c-e1a5-42ee-9288-4ebe06a250af'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd088c387-167f-4dcf-9a40-e6278c4fee8d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd092e18c-b289-439d-bf14-874bf60d0efb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd09a741c-9f6b-43d4-895c-be0f7a813181'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.600' WHERE BloodProductGuid=N'd0a050b5-4e20-4632-bc24-285c8c34655f'
UPDATE dbo.BloodProduct SET ProductVolume=15, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd0a1de87-a2ad-4da3-81e2-1d61dee9e231'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.430' WHERE BloodProductGuid=N'd0c17c9a-8dfa-429b-82fa-69dd38b1558d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.897' WHERE BloodProductGuid=N'd11f1be3-ef66-43dd-9f23-dbd9b97e3c08'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd124f170-fd96-49aa-a91a-155f599577af'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd161b0e9-b5ce-4588-b410-e16616c18024'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd1b7c9dc-5632-4aa6-a2b3-51dbad08f6f9'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.430' WHERE BloodProductGuid=N'd25d3d54-f03a-4d7d-b98f-832144895755'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd2670dd0-f79f-4789-9006-0b7709800319'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd269bcae-bade-41db-b051-695f227e90fa'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd2c4f232-092f-437a-91a8-ca75a1dccdab'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'd2e99117-4663-4152-b52e-8fe39f68677c'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd30558af-3380-4bde-8251-60ba3fc958e9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd3195c69-7902-4e38-9339-4b36c997d6b0'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.240' WHERE BloodProductGuid=N'd36dcf5d-aff6-4bfd-8c66-a6d3e4b7378e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd3c3311f-fb52-4990-81dc-cac2ab22f97b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd44491e5-ee83-4120-8d63-ca36c5cbd1de'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd47550e2-2bfc-4150-971b-04f2ad64e8da'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.977' WHERE BloodProductGuid=N'd4a4e557-0bbb-489b-a981-3e84e5d3cb94'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.913' WHERE BloodProductGuid=N'd4e8fcb4-b7af-4db4-87e7-1ee598a17d6d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd4f703d8-3169-4f76-89fe-4fb3d6e10a5c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd5091f43-78ab-4d2b-a3cc-0e20e6e28f1e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.257' WHERE BloodProductGuid=N'd51d3b01-d860-4d85-8439-0a626e789d95'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd51ebc70-ed1f-47d9-94d8-b2ead86701de'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.693' WHERE BloodProductGuid=N'd542eb2f-2d7d-48a8-9d33-8f0a1aed53cb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd54f2638-c29d-4b65-a2b9-8cf9202449e0'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:57.850' WHERE BloodProductGuid=N'd552aae7-279c-41ff-a335-9d745cba2393'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.507' WHERE BloodProductGuid=N'd55f2f64-c91b-4f28-8550-ff3ab015d778'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.680' WHERE BloodProductGuid=N'd58b12f2-3ff7-41b4-9dfb-8d74d5bd4f0d'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd5cf0f0f-a8d5-42d1-9479-2a55e8160d42'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.413' WHERE BloodProductGuid=N'd5ed8188-86f9-4a8d-bfd8-ff816b14ac9a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.617' WHERE BloodProductGuid=N'd612334b-a3b2-4e27-8184-755780d4e666'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.867' WHERE BloodProductGuid=N'd613e45d-aa4b-4c37-9591-031e8d89c299'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd6202da7-a29f-4cd0-8be1-830b19e5441c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd631f52d-6361-4042-88b5-de4b956a1479'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.430' WHERE BloodProductGuid=N'd64902a8-623d-45c6-96e5-cfc459a1de85'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd6576bdf-8de9-45a7-8db0-aedbcee370e7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd67be5c8-106d-4d73-9b47-29e1ad82be3d'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.523' WHERE BloodProductGuid=N'd758ce49-e018-4e45-8391-ee836044f8dd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.180' WHERE BloodProductGuid=N'd75ff5c5-0fab-48c2-b007-1334409234b3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd7845c76-3341-40e0-8fc2-7430c3f0cc29'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.193' WHERE BloodProductGuid=N'd7858ec8-2e73-4d8b-ad50-38e0e51327a2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.210' WHERE BloodProductGuid=N'd79c67da-61a0-4fe6-ac18-af09c9abf443'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.727' WHERE BloodProductGuid=N'd80110c2-1cb9-4b17-9f2e-0b1a317e6a82'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd8056fec-09b2-42d6-a234-5223ed68ef44'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd812ceb0-89e5-473c-87e5-5f891f85db85'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd813c57a-b823-4e1f-9d06-d66ec6f797dd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd8147fbc-ad7d-4209-8b23-0db038317a38'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.443' WHERE BloodProductGuid=N'd834acea-59ae-407a-85ae-a70d225255d5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd83ed327-df79-4150-af45-7e4cfab729cc'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.693' WHERE BloodProductGuid=N'd842d277-9ab2-49fd-ac02-732277ce2e63'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.833' WHERE BloodProductGuid=N'd86cc1bd-8329-439f-acfc-377fba20c57a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.710' WHERE BloodProductGuid=N'd88cfc4d-9d62-45ce-9829-ba61c405010c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd8add11c-bff5-4937-98e1-a5e3cb5334e1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd8dac708-19ab-44d1-a2c7-17833e9b6110'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd8f5e51b-72f9-4c80-9b92-37a8add213de'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd9149045-1aba-4493-8b02-9cf2264fc244'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd91bf091-b248-451d-969d-2acc9d140d6d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.570' WHERE BloodProductGuid=N'd972ccd8-f9df-4b6c-b87e-45ce93e43cfb'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd97b4094-d1e5-48a7-9cd8-b6e48420fc75'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.930' WHERE BloodProductGuid=N'd9897056-f304-4187-b8f3-327d3bacaaf5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd9cc4d09-87ae-4e0b-becf-adb7a09c6614'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd9e2737f-196d-46f0-acd4-c9a8ba2d75d0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'd9eed85e-b5cc-4730-83c4-c5c5f359a1cd'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.023' WHERE BloodProductGuid=N'da121927-2345-4f29-98e3-5571bf002062'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.130' WHERE BloodProductGuid=N'da37bb33-a0ec-48b8-8f00-74723ac67fdc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.273' WHERE BloodProductGuid=N'da3e245a-8d33-46be-84be-6d349b52934c'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'da6064c6-e1bb-4f7a-a464-807e2ec4866d'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'da7d7001-276d-42ec-9c7d-df63f723a82a'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'da8ba88a-c4d2-4fa3-bbd2-727c288de1c9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'da981cfc-5fea-4885-bd35-c8172952d93a'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'daaa519a-82a8-4dd6-b818-f458998664e7'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'db1ab59c-4a6e-405d-b2d0-8e5b0b7dd851'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.630' WHERE BloodProductGuid=N'db4a070f-63c8-453e-bb51-7ffdcfe8751d'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'db81f2c2-4c35-4feb-8c47-9cf8fc329d5d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'db957a22-b61b-40f5-8d67-95dc2aa9c796'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dbbacc76-5859-4d20-9237-668c34ac3bbd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dc17b148-ac73-4bfc-9af3-644adb137842'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.710' WHERE BloodProductGuid=N'dc2b04e5-3a4c-4460-82be-7c59de67e3b8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:57.930' WHERE BloodProductGuid=N'dc797511-ac35-4b86-8b92-ff690f92e7d3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dc7c208c-0f4e-466d-ab5e-87df34184a17'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dcb02279-9b01-4a79-8a49-c8edafca3062'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dcc8b607-c2df-4911-89c4-554541e0af57'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dcca380a-0279-4627-8cf4-3b3b2194fc1e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dcf58410-822a-4be6-bd8c-49b5dc1ad9bf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dd4f4e6f-1ec0-499f-8bdf-cccf0c8622df'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dd52cb0d-9c51-4a8b-b915-3869ddf55ec2'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dd619783-0657-4440-87b4-3399fa2da5e4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dd82c5e7-239d-4a1a-a8a1-59c3510fc69b'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dd9e5375-00dd-40b2-8220-dbeac6e263e0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.367' WHERE BloodProductGuid=N'ddac8c35-c7ba-40e4-8e96-755ba78d9173'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'de071807-9640-4357-81ee-53a01a0aab38'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.443', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'de4ee120-be5c-432b-8f00-17fcb862567b'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.037' WHERE BloodProductGuid=N'de5a87ad-38de-4237-92be-b1f2dab0b575'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'de5eb70f-82c9-442d-91f9-ebfa38380705'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'de8121d2-2ca3-40c6-ab23-4fa78fc78b16'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'deb5fc85-6c86-498f-89c9-d9bc59a85e33'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.570' WHERE BloodProductGuid=N'dec2fab4-2618-46b0-8f25-61b6a54ce0bd'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ded0ba85-94d2-4e95-810e-84d2bf0bf511'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.413' WHERE BloodProductGuid=N'df0d01cd-6a54-4e4a-b2b6-7aba34ed1393'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'df2227d5-db0f-4c50-bf4c-5a3b58a2be22'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'df2e388f-fe89-46de-87cc-8b0f4511542b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'df3b7754-9c07-4abc-9458-a49d5ba2e942'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'df5ba4de-5abe-433a-a223-704708521641'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'df83ec3f-c811-4366-8076-593ff22190e5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'df8fba1c-2ff9-4ac4-8599-a41971ce534d'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'dfbee4c9-02cf-4885-9530-c568301e7780'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.117' WHERE BloodProductGuid=N'dfbf8995-3992-4fe0-9fc8-ec8a493fec33'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.193' WHERE BloodProductGuid=N'e00d34b0-529a-4c23-aacb-b109d9a7cb46'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.710' WHERE BloodProductGuid=N'e044d8d5-4754-468c-92a4-2a0af0652cb2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.507' WHERE BloodProductGuid=N'e04a61a2-05ec-4cbf-babf-24eed003463a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.053' WHERE BloodProductGuid=N'e056ad4e-8257-409d-9cc0-83363b52708b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e070ac68-73df-44a9-a75e-97bec910245b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.350' WHERE BloodProductGuid=N'e08994a6-a32d-45cb-b504-f6fadae10f87'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.880' WHERE BloodProductGuid=N'e08bcb96-2a94-43d5-a0dd-26dfbd3656b9'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e0aa2bcb-6a63-4ab4-a96c-805c3285e778'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e0d0770f-c880-4323-8c2f-1f3c53554e70'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e0ed8308-b825-40b1-b1a2-ac77b5a33fad'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.117' WHERE BloodProductGuid=N'e13c5f57-ad7e-43fc-8f77-c9feb9372d51'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e18593ab-83a7-4a20-937a-947b437a5144'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.163' WHERE BloodProductGuid=N'e18ab3c2-d22c-421c-b3cc-83175343938a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e18cc34f-26aa-4424-bf0e-3860543e43ff'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e18e0722-31a1-455c-a072-8cffcd2f4c98'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e1a3ee16-520c-49bd-834e-e77957ecc2ee'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e1bcdc82-1d2b-41f0-9535-1d673d2678f4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e1fad4b6-2a52-40d3-9bb3-6bdddce73d99'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.930' WHERE BloodProductGuid=N'e21dec58-bb24-494e-a89a-32d11a481e31'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20090501 09:29:57.397' WHERE BloodProductGuid=N'e272ed86-3d1f-44e3-a61f-0ef87be09b79'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.523' WHERE BloodProductGuid=N'e296b6df-330e-4249-9ce3-31934418a568'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e2ab182f-7ab3-4f34-b2bb-7f99570951f2'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.477' WHERE BloodProductGuid=N'e2cf9c50-ef2b-4308-864a-2b7558bae135'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e3a0d784-b2aa-4000-be93-7280b6835f1e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e3dfa37c-ef4e-46db-a876-d407a5472d98'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e3ee523a-560b-4cba-99d8-5a5268f86d00'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e3fbcd3e-e1f3-4def-8b1e-d569bcbbf0eb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e4041e48-6cba-4f60-a3ed-2ee3d24bbb5e'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.180' WHERE BloodProductGuid=N'e45953e0-50ab-4504-93bf-f714575667c3'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.740' WHERE BloodProductGuid=N'e49ed73e-e6be-4a4d-a7b3-b613596e84e0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e4a04f8e-e2fa-407d-b887-5b0e9f4defe8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e4b88236-c086-4714-8df9-9c9f1e89c975'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e4d7c335-84f9-4099-b568-4e85a7824cf6'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.833' WHERE BloodProductGuid=N'e50df5a4-7664-40ef-8138-97037cb91d67'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e532287f-1c5d-4749-8eb0-a07e9df99304'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.070' WHERE BloodProductGuid=N'e55e71c9-9d64-439e-b537-c4600f55f5cf'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e610fcab-17b9-443c-8976-737b1bf42e2e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e6119f72-2bbe-481c-b27e-8869f2a7c681'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e6258cd1-f447-447e-9d66-a1825ca69953'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e62c548f-431a-4817-94fe-f2abb4a9281c'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'e6327c35-77db-4cee-af22-794439060091'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e64a1a55-100f-443a-bc5b-9fbc0a502f5d'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e653080b-87a9-4c73-b7a1-8c31db466d9f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e701aaff-3812-4833-ae7d-552bd82927d4'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.630' WHERE BloodProductGuid=N'e701e6fe-e98e-48c0-b3d0-2f213a50a10c'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'e7253f81-cda7-442e-b45c-9e64402c3145'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e76f90cb-4bf1-493c-b8e0-165f6d758583'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e7778374-904c-46bf-91dd-69afff7c25ad'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e778b5b6-0ca1-4a04-ad6b-47703a09c856'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e78049dd-141f-4779-8b6d-d97c50905990'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.897' WHERE BloodProductGuid=N'e78fd8be-2d1b-46af-b729-20da09d23674'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e797156d-74ba-4b2d-a99e-d97343e839fd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.163' WHERE BloodProductGuid=N'e7c132d9-824d-44bc-a97b-8e69650d00cb'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.147' WHERE BloodProductGuid=N'e7df202f-4f39-4711-be4b-c574553c6dea'
UPDATE dbo.BloodProduct SET ProductVolume=15, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e8004382-89c3-47f6-8cc1-f0143c456820'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.380' WHERE BloodProductGuid=N'e81710d8-7947-4680-9f3d-5eebd3bfea35'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e81b780c-33ff-4291-b70f-d3cad2e1a24c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e824c684-451b-40ef-961d-b703fc672e80'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e83862b9-436a-4734-a940-40445317717d'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'e8b132f7-6e01-4bf1-ad50-974afeab153c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e8bfcf6e-92e1-4742-b8b2-d9c15ac5af82'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e8cdfde8-aea5-43c6-af81-d09a4d8d578a'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.570' WHERE BloodProductGuid=N'e8e21b35-ec9c-4cae-8f22-098846efdfae'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e8e72e0a-f3a0-4733-add3-971fda644b05'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e8eea9eb-a993-4f75-a2f7-99c4a949606d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e8ffbc37-21f4-43cd-8df9-93765188f2d9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e93d9376-7a92-4f17-be70-03af610cbc95'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.490' WHERE BloodProductGuid=N'e93e553a-99d2-447f-8756-b4380c06b687'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e93f8b57-8592-491a-a44d-8f92037d37d2'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e973ef61-3478-48b9-8855-64d5eea1c49d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.787' WHERE BloodProductGuid=N'e974dd62-ff1f-4e5c-ae64-2b7464596b82'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e97ac05b-a29a-4aad-82f6-4cb483cc43f5'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.727' WHERE BloodProductGuid=N'e98e847e-13c6-48c3-b494-a2ab457d1222'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.240' WHERE BloodProductGuid=N'e9abe521-6bd7-4654-83e7-49540c294aa1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.193' WHERE BloodProductGuid=N'e9b2458d-3efc-404e-a9d9-11da1267d654'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.583' WHERE BloodProductGuid=N'e9b6c3a2-ec65-4b94-b978-fbcb3a13cf1f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e9c8d788-f319-4714-bbc7-c24d2194e83e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'e9e27e7b-26fc-46c3-a025-2c85eba556b2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.210' WHERE BloodProductGuid=N'ea1b4a65-5662-460d-8015-e1631cf04ea8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ea5dcb7d-a170-461a-ae4b-2cf0a747da68'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ea6232cf-4032-4d12-9feb-a6159c4a2eb3'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ea8d8f94-a0f5-4f7b-8d25-4fbdd9ee4cb3'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'eacd8d4e-d672-4c19-aa32-4f43091acae1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'eae0e7ef-58b3-4806-9bfe-3458d8fa2d57'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.147' WHERE BloodProductGuid=N'eae1b739-697d-419c-98cc-8e39b18edd23'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.663' WHERE BloodProductGuid=N'eb23d726-cfaa-4209-a291-83c3b6b56ecc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'eb270f7a-398b-41c4-b683-fbc596acd4fc'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'eb503b47-9da2-4521-9a1b-e98195d184b6'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'eb551f14-7bba-4efe-9fa5-c07ebea97399'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'eb6e9f20-c560-480c-940a-31a5c72e75e1'
UPDATE dbo.BloodProduct SET ProductVolume=150, MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'eb7dc56a-9e94-4ebe-b9d1-99065816d7ca'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.007', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'eb8933a3-3203-4f7c-927f-46b0d6155744'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ec18d6a9-b692-4104-8d1a-597514ebc1f0'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.240' WHERE BloodProductGuid=N'ec6026d5-a25e-492a-82b2-dd251d9d3db8'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ec7fd935-bfd4-4211-9841-17cbab89153c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'ec91b30c-9459-4d9c-928a-e4a2d41d1b49'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ec9a319e-7fe4-4591-8f7e-f0ec619cd350'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ecb3e884-f92c-441c-a524-ebd139e17615'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.147' WHERE BloodProductGuid=N'ecf524d6-c52d-4426-9d02-38f98b1bae82'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.990' WHERE BloodProductGuid=N'ed32f500-4b84-490c-949f-e5febc09ad36'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ed6d6c59-354c-4ef4-aef9-78c2f66c96c0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ed7ddc67-e130-45d7-8a78-31d556d52923'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.273' WHERE BloodProductGuid=N'ed8d52d0-919a-4bb7-80b9-92a96e08831c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ee032aee-ba45-4332-bc94-bba3a02c2ce9'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ee088263-cd71-498c-aaf3-9e6ba9667201'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ee81b8c9-4f1d-44b6-9cd5-48b6abcab805'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.693' WHERE BloodProductGuid=N'ee8e4769-0ef7-43cb-9955-993cd92263e3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.147' WHERE BloodProductGuid=N'ee9039c5-69ed-4849-a3ed-676cd37d4395'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.397' WHERE BloodProductGuid=N'ef18e9fe-25b1-4053-8450-4ed6834c95ca'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ef1a15b6-518a-4e16-9ec3-668f12f5ffe1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20090501 09:29:57.647' WHERE BloodProductGuid=N'ef2c8a47-c2c0-4afc-a727-4542219bad7a'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ef3f9381-8a59-4eef-bbe1-d015cb735f4b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.257' WHERE BloodProductGuid=N'ef5f0594-02aa-491e-8913-75d66c0be2f5'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ef76c9df-6770-476c-950b-dce5a08113c1'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.787' WHERE BloodProductGuid=N'ef782151-9f44-443a-819b-83bfaec233c2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'ef860b72-ae98-4d37-8a6b-89dc8beca269'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'efe72339-3fbe-4d75-9e51-c8ed8c304700'
UPDATE dbo.BloodProduct SET ProductVolume=150, MaximumStorageTime=1008, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'eff93f9f-9dc0-4119-99f6-339aebdf216d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f0337d5d-e140-4991-bbd0-125ebb1be241'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.693' WHERE BloodProductGuid=N'f035cb96-a7e1-4b9b-87a8-7d4f8fb3fc48'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f0976975-4f99-4e95-bc1f-e0c8fa6461a2'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f0a481ac-dbd2-46f1-8882-8dbeed46cca0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f0af45f4-0dea-4b99-8c6a-61582f295529'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f0b9a999-49e4-4b3e-80bc-266b6057ac85'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.663' WHERE BloodProductGuid=N'f0bcdf57-1d17-4cfb-baa4-3c8799946ca6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f0fc3bd7-60fa-4082-bcd6-4d6ae537773e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f1267c2f-6a38-4a7d-8dd9-9590f245fc0c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'f13462a9-39c4-49bd-b997-1f0ce1d0a17c'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.880' WHERE BloodProductGuid=N'f14a6416-ffa5-4153-a030-5c5b5a4dbe8a'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f17277ea-826d-4238-92b1-0e366a352c5a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20090501 09:29:57.680' WHERE BloodProductGuid=N'f174576c-8603-46be-a515-7c45adaa7a19'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f1786400-05e1-4087-955d-181a2a579474'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f1cdacfa-186b-40a8-b113-1f8594891835'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.537' WHERE BloodProductGuid=N'f1e25236-1fd4-4cb9-a079-6ecdb61db395'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.257' WHERE BloodProductGuid=N'f206b1f1-5538-4faa-898a-ae971072da79'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f23ef3a7-c125-496d-a377-5ba78e9c7c65'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=672, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f25859c4-0672-410a-8b9a-2c6b3e54ce22'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f273d6cf-ac94-464b-b220-d3226e5b4995'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f2a3032b-d882-4258-a6bf-3c5983b9dd01'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.960' WHERE BloodProductGuid=N'f2b1f431-c674-4aa5-8402-e1f7f1b34ae4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f2b9b055-0b98-4777-88c5-af7b2bee8762'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f2c81cc0-6c28-461c-bd67-3b01fd587367'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f2f12a12-ab5e-4d23-8f2e-124a6ce5802c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f2fc6fec-7eb2-44d9-a07d-e368d5e80e28'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f32a53e1-7132-4991-9caf-694d1ef7c829'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f3cd7229-6917-4871-adb3-aebd13a4866f'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f3f70d3b-b43f-4db6-beb3-fec363601acd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f416c9e1-dfd8-4a7f-a71c-a99d78fdf29f'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.287' WHERE BloodProductGuid=N'f4349b32-b244-4d2b-9517-1752ab5b8a0f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f45f5c6a-5023-43b7-a878-d9b1c355e908'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f4848705-1883-4e85-852c-38900f8110f2'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f48a416f-d1fa-4575-bd94-01f759d358f3'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f4b61132-de34-4bde-9a65-543a65aded77'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f4b9cfb4-1015-4317-b02d-ef757c8d7e62'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:58.023' WHERE BloodProductGuid=N'f4cd3333-f6eb-40a8-ae77-ff20969d71b5'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.083' WHERE BloodProductGuid=N'f4d6ada9-ce26-4fe2-a8d4-773f542e5797'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f4e784c8-c255-4b4c-9fec-05769510397a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f4f66935-70d7-40e4-87a9-6e0249fdb71f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f506cc78-9c33-4838-803e-a6daa91abfff'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f53e222e-9a69-4ee0-828a-66e69841ec13'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f5413783-f932-40b6-9e4c-13e35723f00b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f5492c72-0d6a-43b5-8aab-bffd171bc80e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f57687e9-8814-4414-afd3-0b137be32249'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f59d8cc2-fc24-4ce4-b5d5-832ac3999e40'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f59eecd6-6984-4a70-b1c8-1f91acad361f'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.380' WHERE BloodProductGuid=N'f5e4f322-8b46-4dec-a92c-d1610e7f8ef5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f6018ecd-2705-4ac0-9c5a-98920cbc8d6c'
UPDATE dbo.BloodProduct SET ProductVolume=350, MaximumStorageTime=840, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f60da0cd-8a70-4133-a919-fd08fd14769c'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f6102d0f-9690-4400-9f75-baa5bd8ab771'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f61b3709-0c93-403e-b375-5bd4d0a334ff'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20090501 09:29:57.977' WHERE BloodProductGuid=N'f62d001c-b104-4c12-9f97-32f0b7af7305'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f63c0a87-1b8d-4b6c-8970-c7235520c1fa'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f63fdcc5-688a-482f-b230-d3d1445e0dcf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f64ce0ca-9c5a-4bc8-873c-e6ee65c9bd94'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f6605c2d-8178-4240-8edf-5682e0f0da69'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f66b56a2-6fe0-4360-9e46-5b381e43b2af'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f685f78a-fe7e-4760-8ab1-13c9832480a6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.413' WHERE BloodProductGuid=N'f68ef4c1-9bc4-4f67-b375-1a90a65e4a98'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:02.180' WHERE BloodProductGuid=N'f6a05e4b-9dfc-4d8b-9d0e-39cb13b5f019'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f6ba9fc9-99fc-4e60-a142-f7e74962f1c2'
UPDATE dbo.BloodProduct SET ProductName=N'PLATELETS POOLED -5d LEUKOCYTES REDUCED', MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.210' WHERE BloodProductGuid=N'f6e57ee5-2faf-46a3-9efb-c49b3095039c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f711519f-a879-4076-af92-9b068c6814ff'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f7391ca6-3e60-4165-86e4-60e0cb01e755'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f7467155-8e3b-472b-82af-4f652194ea28'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f7593345-ddfb-419d-9e81-0e9ed7c71778'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f790e7cc-7f34-4cca-97ff-a7486d0345f3'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f7bbb84d-9439-47dd-b65b-26cbb385d72f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f83ac8d8-1769-474d-a8a3-9bf1e0e8f2a0'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f847c47c-38a3-4db2-90ec-915a25e7c545'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f891673f-0c38-41bb-8df6-a39953023b27'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f89fb596-e011-430f-b0cf-d9e1f61294e2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f8a536fe-da76-43aa-858e-4b0f912fc0a5'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f8a804e2-6544-41bf-a362-46de48174107'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.180' WHERE BloodProductGuid=N'f8b674e6-8b16-45e9-9088-92ca4a125373'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f8d7bf8a-84c3-4c0f-ab3c-0102025c396a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f8fb625f-0fdb-4551-8bf7-a09144728f3f'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f945c4e3-4c1b-408d-a8f2-abdedeea59aa'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f947c4ce-f035-431a-94cf-dc68d2f257ee'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f958f4ad-88df-46a6-a293-6d0181e295d7'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:30:00.037' WHERE BloodProductGuid=N'f95b4108-713c-4779-8323-e7e67e18119d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f979dbb3-5342-48e3-91d1-abb0f56c1a00'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f9892aad-c3f1-4972-a8f1-20ff20ef3344'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'f9947ba4-2f94-4ddb-a1d9-3acd0442912a'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f9cd3c34-9d8a-4e1e-a441-0a2239266a2c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'f9e17782-c2fa-4375-a685-82614524badb'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'fa1bc7b4-9e5b-4397-97aa-e7bcaea6e4f5'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fa3aba14-2aac-4df3-a6dc-c848ab168bf0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fa498ab5-6127-492b-9d14-b64a97a01c67'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fa6bfe1f-a75d-4759-8bae-53f9634ddcc6'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fa7c2325-a8a8-4ae4-a8ee-71873ad7b465'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.397' WHERE BloodProductGuid=N'fa7decea-f88c-4f05-91b0-e15ffe7ab73f'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.880' WHERE BloodProductGuid=N'fa8c4443-3d1d-4fc2-acf7-74f75d760f06'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fa931e84-4d09-452c-84c2-769a056b138c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20090501 09:30:01.287' WHERE BloodProductGuid=N'fab02e08-5404-4982-b0de-64239c74cbd2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'faeb0a92-0f18-43c8-8f29-1a7eec3c230c'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fb52bd60-6870-4af9-b318-162fed99770e'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fb6e4baf-64ca-4aba-8943-d08406410bdf'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.803' WHERE BloodProductGuid=N'fb89f11d-778f-409e-8f59-0aa6ec8ae395'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.210' WHERE BloodProductGuid=N'fbbfcc10-b2c8-41f6-b146-4a266e14bb43'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fbc0c356-d113-4ff0-afaf-6b32a93b4c57'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fc05b463-bc5a-41cf-a0b9-9cf8f08c4de0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fc0dad1e-865b-451b-a54d-cbe4b7dec8e0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fc2588c0-8fe9-429c-b82d-76d1401a0c35'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fc3cf28f-1e81-4cca-87d5-6a3416ead923'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:02.240' WHERE BloodProductGuid=N'fc404169-2368-4881-a987-608cfeb19f34'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fc4325e5-4eb7-444a-a9d2-31f059d645d4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fc850d0b-5ab4-4b43-a163-86fbf9f9d71a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fce16035-52f7-48cd-a5d9-2e0d787c2b2f'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.600' WHERE BloodProductGuid=N'fce442ec-f56d-4b35-bd83-a1fe6c3aa6eb'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=24, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fce822a7-6029-4396-8ac9-9626c3016aad'
UPDATE dbo.BloodProduct SET ProductVolume=200, MaximumStorageTime=4, LastUpdateDate='20090501 09:30:00.663' WHERE BloodProductGuid=N'fceb5ad0-fd1f-4cec-a78f-99cd058d80f6'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=504, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fcec290c-27a1-4d3c-ba61-840c261793c1'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fcf59eb5-8ed3-46eb-badd-87cb0a80556d'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fd077403-c207-4c49-ac7c-d78c3916a04c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20090501 09:30:01.117' WHERE BloodProductGuid=N'fd182553-cbd0-4ca9-b7b7-5250ef2c7584'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fd6d084f-f7de-4b67-b32f-89dc2f6cb5df'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fd8c9a4e-a215-47c0-9f92-81ccd2061c76'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fdb46d66-6d98-4a79-b6fa-930afb3e34db'
UPDATE dbo.BloodProduct SET MaximumStorageTime=336, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fdb7dc0b-9e88-432c-8854-57d740670982'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fe26e586-c356-4d55-9dad-334942fa054a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.960' WHERE BloodProductGuid=N'fe28fd73-e34a-4715-b4c0-7578c9e7f781'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fe4c1af0-2430-4858-9bfc-046c6cc8c51a'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.880' WHERE BloodProductGuid=N'fe670c21-bf0f-49fa-ac3b-0bd82985e908'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'feb7c4ef-b23b-4eda-81cc-b28e9c4cd956'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'fee6c847-8509-4cbd-a05a-7fabb34e6282'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ff211bda-3afb-4193-9e66-bf7dc1d15eef'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ff2eeb87-8976-4e8b-9850-63de043ed012'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.320' WHERE BloodProductGuid=N'ff30828d-0378-4c5e-80b8-ca5a194c60d1'
UPDATE dbo.BloodProduct SET ProductVolume=225, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ff74cad9-52e9-4924-81a7-e01861c53527'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20081201 15:03:53.193' WHERE BloodProductGuid=N'ff9d0325-1068-43af-ba88-d928cd6ed695'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:59.460' WHERE BloodProductGuid=N'ffc04628-4562-405b-bfe6-26bd0d3ad026'
UPDATE dbo.BloodProduct SET LastUpdateDate='20090501 09:29:58.680' WHERE BloodProductGuid=N'ffe3fb1e-db75-4067-8e49-6cffd76aad23'


-- Add 13 rows to [dbo].[ProductAttribute]
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CJ', N'DMSO/XX/<-30C', N'DMSO', 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CK', N'DMSO/NS/<-80C', N'DMSO', 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CL', N'CPD>SAGM/XX/refg', N'CPD>SAGM', 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CM', N'CPD>SAGM/500mL/refg', N'CPD>SAGM', 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CN', N'CPD>AS3/500mL/refg', N'CPD>AS3', 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CO', N'CPD/450mL/<37C', N'CPD', 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CP', N'DMSO/XX/<-80C', N'DMSO', 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CQ', N'NaCitrate/XX/<-25C', N'NaCit', 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CR', N'CPD/500mL/<=-20C', N'CPD', 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CS', N'CP2D/500mL/<=-20C', N'CP2D', 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CT', N'CPDA-1/500mL/<=-20C', N'CPDA-1', 0, '20081201 15:49:48.000', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'EF ', N'Complement Inactivated', NULL, 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'GE ', N'Frozen <=26h', NULL, 0, '20081201 15:49:48.483', N'vhaishsmithm', 0)


-- Add 332 rows to dbo.BloodProduct
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'007fc421-72b9-400d-885c-cdfaa90fb94e', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Irradiated|ResLeu:<5log6|Supernat rem/Plasma added', N'RBC AFR ACD-A>AS3 IRD LUKOPR SR/PA ', N'E009', N'@AZ C2 D4 E8', 350, N'E5850', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'013d66b5-cf80-40bf-9ce9-2d63a6ef9f3c', N'Washed RED BLOOD CELLS|None/XX/refg', N'RBC Wash None ', N'E003', N'@AS ', 200, N'E5904', 336, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'028f5f05-14e2-46d6-9c52-d854c958c03b', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Open|ResLeu:<5log6|Supernat reduced|2nd container', N'RBC AFR ACD-A>AS3 OPN LUKOPR SUPRed ', N'E009', N'@AZ B2 D4 EA H4', 350, N'E5837', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'02e7e58a-cd93-4c06-8c08-aa4e4182e70d', N'POOLED PLATELETS|PASII/XX/20-24C|Irradiated|ResLeu:<1log6', N'PLT Pool PASII IRD LUKOPR ', N'E022', N'@AE C2 D5', 200, N'E6015', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'044e5423-e072-4509-90a5-da0e31d67dac', N'Thawed Apheresis FRESH FROZEN PLASMA|CP2D/XX/refg|Irradiated', N'FFP AFR Thaw CP2D IRD ', N'E013', N'@13 C2', 225, N'E6002', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'049dfb33-7f67-4cf5-9f9b-24b3f370551c', N'POOLED FRESH FROZEN PLASMA|CPD/XX/<-30C|Not for tx or mnf|ResLeu:<1log6|>=600mL|From 3 donors', N'FFP Pool CPD NMT LUKOPR LowVol 3DNR ', N'E010', N'@A4 A4 D5 F7 J3', 225, N'E5882', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'04b583e0-6527-4d82-97d0-a8d341f4c8e0', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced/Albumin added|3rd container', N'PLT AFR ACD-A OPN IRD LUKOPR PLS Red/ALB Add ', N'E024', N'@73 B2 C2 D4 EB H5', 200, N'E5903', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'05a9c6c1-2f14-4ebe-8c83-805c87dc197f', N'POOLED PLATELETS|NS/XX/20-24C|Open|Plasma reduced|From 6 donors', N'PLT Pool NS OPN PLS Red 6DNR ', N'E022', N'@72 B2 E5 J6', 200, N'E5988', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0659cb5b-3f14-49ae-b65d-8038fdc02cec', N'Deglycerolized RED BLOOD CELLS|None/450mL/refg|ResLeu:<5log6', N'RBC Deg None LUKOPR ', N'E006', N'@17 D4', 200, N'E6029', 336, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'071a8025-84ae-40fa-9b92-cfccb29364ae', N'POOLED PLATELETS|NS/XX/20-24C|Open|Plasma reduced|From 8 donors', N'PLT Pool NS OPN PLS Red 8DNR ', N'E022', N'@72 B2 E5 J8', 200, N'E5990', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'07a5c01d-5a30-4d36-8c6f-a37781a7eed8', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|From 7 donors', N'PLT Pool NS OPN LUKOPR PLS Red 7DNR ', N'E022', N'@72 B2 D4 E5 J7', 200, N'E5982', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'086459e4-3970-4cf3-9f89-3d29f59e52ce', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|From 6 donors', N'PLT Pool NS OPN LUKOPR 6DNR ', N'E022', N'@72 B2 D4 J6', 200, N'E5974', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'089b4aa9-3740-4c4a-9c5d-ac095de683dd', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|From 7 donors', N'PLT Pool NS OPN IRD 7DNR ', N'E022', N'@72 B2 C2 J7', 200, N'E5947', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'08c7cbc7-506c-4916-9e0c-0c1b6417e20b', N'Apheresis LEUKOCYTES|NaCitrate/XX/20-24C|Not for tx or mnf', N'LEUK AFR NaCit NMT ', N'E039', N'@75 A4', 200, N'E6057', 24, 0, 0, 1, N'A', '20090501 09:30:02.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'08eec6e3-19d2-4593-a5d9-4bcc090c7c23', N'Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|4th container|Psoralen-treated', N'PLT AFR PASIII LUKOPR Psoraln ', N'E024', N'@B5 D5 H6 K5', 200, N'E5865', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0acfc159-7f0e-4bf6-9a01-67212e3b3b58', N'POOLED PLATELETS|CPD/XX/20-24C|For mnf:noninjectable', N'PLT Pool CPD MNFNI ', N'E022', N'@A7 A3', 200, N'E6076', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0ad1385f-565c-405f-91e8-087bfab87365', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|From 7 donors', N'PLT Pool NS OPN LUKOPR 7DNR ', N'E022', N'@72 B2 D4 J7', 200, N'E5975', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0c08bb0b-8f14-4ee1-b8ad-4232e5a2b8b8', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|From 4 donors', N'PLT Pool NS OPN LUKOPR 4DNR ', N'E022', N'@72 B2 D4 J4', 200, N'E5972', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0c109b4d-07e4-419f-ba82-b734843f9354', N'WHOLE BLOOD|CPDA-1/XX/refg|Plasma reduced|LowVol:anticoag not adj', N'WB CPDA-1 PLS Red LowVol ', N'E001', N'@10 E5 F3', 250, N'E6047', 840, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0e1379db-4c01-4aba-8f20-c4727636f312', N'LEUKOCYTES|CPD/500mL/20-24C|For mnf:injectable', N'LEUK CPD MNFI ', N'E038', N'@65 A2', 200, N'E6082', 24, 0, 0, 1, N'A', '20090501 09:30:01.867', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0e9c65cc-30d3-468f-84d9-26c3501c24ab', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Irradiated|ResLeu:<5log6|Supernat reduced|1st container', N'RBC AFR ACD-A>AS3 IRD LUKOPR SUPRed ', N'E009', N'@AZ C2 D4 EA H3', 350, N'E6004', 672, 0, 0, 1, N'A', '20090501 09:29:57.727', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0f0d7505-50e1-4182-b776-be61edcb7728', N'RED BLOOD CELLS|CPD>AS5/450mL/refg|Irradiated|ResLeu:<5log6|Supernat reduced', N'RBC CPD>AS5 IRD LUKOPR SUPRed ', N'E002', N'@22 C2 D4 EA', 350, N'E6010', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0f717744-849f-4fdd-84aa-4ec1b34dcfb2', N'RED BLOOD CELLS|CP2D/450mL/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC CP2D OPN IRD LUKOPR PA', N'E002', N'@11 B2 C2 D4 E4', 250, N'E6154', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0f7af412-f833-4f46-a0a2-9480721887f4', N'Deglycerolized Apheresis RED BLOOD CELLS|AS3/XX/refg|ResLeu:<5log6|1st container', N'RBC AFR Deg AS3 LUKOPR ', N'E051', N'@B6 D4 H3', 200, N'E6067', 336, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1074c283-04ed-4e1b-8b3b-4a1a9ee4d5f7', N'POOLED PLATELETS|PASII/XX/20-24C|ResLeu:<1log6', N'PLT Pool PASII LUKOPR ', N'E022', N'@AE D5', 200, N'E6012', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'11203aa5-b52c-461c-96e0-25dd82a0fa13', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|From 4 donors', N'PLT Pool Wash None OPN 4DNR ', N'E023', N'@71 B2 J4', 200, N'E5908', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'121b5dc1-ae15-4742-9887-30db1531cfde', N'Thawed FRESH FROZEN PLASMA|CPDA-1/XX/refg|ResLeu:<5log6', N'FFP Thaw CPDA-1 LUKOPR', N'E011', N'@10 D4', 225, N'E6151', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1316279e-7ec4-4a1a-8998-226f42c908fb', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|From 8 donors', N'PLT Pool Wash None OPN 8DNR ', N'E023', N'@71 B2 J8', 200, N'E5912', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'149a0955-b74a-4152-93d9-dfe5fdf52f81', N'PLASMA|CPD/XX/<=-18C|For mnf:noninjectable|Cryo reduced', N'PLASMA CPD MNFNI CRYORed ', N'E010', N'@35 A3 E3', 225, N'E6056', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'14e12946-970d-467d-bcd6-d26c901d1914', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced|From 4 donors', N'PLT Pool NS OPN IRD LUKOPR PLS Red 4DNR ', N'E022', N'@72 B2 C2 D4 E5 J4', 200, N'E5958', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'15fa5e3e-42a8-40db-9ccf-076a94694dd9', N'Apheresis PLASMA|ACD-A/XX/<=-20C|For mnf:injectable|Open', N'PLASMA AFR ACD-A MNFI OPN ', N'E012', N'@56 A2 B2', 225, N'E6073', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1617270a-384e-4fb4-86cb-c2228677c430', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|From 8 donors', N'PLT Pool Wash None OPN IRD 8DNR ', N'E023', N'@71 B2 C2 J8', 200, N'E5919', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'190dc063-7059-4394-8810-b99978097912', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|Open|ResLeu:<5log6|Supernat rem/Plasma added|1st container', N'RBC AFR ACD-A>AS1 OPN LUKOPR SR/PA ', N'E009', N'@AY B2 D4 E8 H3', 350, N'E5885', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'19ea31d8-a00b-4ceb-aecd-e123842fb167', N'POOLED PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|Psoralen-treated', N'PLT Pool PASIII LUKOPR BUFCT Psoraln ', N'E022', N'@B5 D5 G2 K5', 200, N'E5854', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1a4f67f8-cc2c-4827-a7fb-ff7e79dae509', N'PLASMA|CP2D/XX/<=-20C|For mnf:injectable|Cryo reduced', N'PLASMA CP2D MNFI CRYORed ', N'E010', N'@BS A2 E3', 225, N'E6096', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1aedab22-eaca-4cc6-9caf-4a0a246f05d0', N'PLASMA|CPD/450mL/<=-18C|ResLeu:<1log6,WB filtr', N'PLASMA CPD LUKOPR ', N'E010', N'@AM DA', 225, N'E6111', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1b15c401-5fa1-4656-a392-32f1e5241dc0', N'Apheresis PLATELETS|PASII/XX/20-24C|For mnf:injectable|ResLeu:<1log6|4th container', N'PLT AFR PASII MNFI LUKOPR ', N'E024', N'@AE A2 D5 H6', 200, N'E5861', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1be3c602-ba30-43cf-bf3f-ee076b70fb73', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|From 2 donors', N'PLT Pool NS OPN LUKOPR PLS Red 2DNR ', N'E022', N'@72 B2 D4 E5 J2', 200, N'E5977', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1cc384ed-52d2-43c9-92c5-49b95cf809a7', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced|From 8 donors', N'PLT Pool NS OPN IRD LUKOPR PLS Red 8DNR ', N'E022', N'@72 B2 C2 D4 E5 J8', 200, N'E5962', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1dc523b4-5306-4e58-abc2-5c2e8a5c23b8', N'SERUM|None/XX/<37C|For mnf:injectable', N'SERUM None MNFI ', N'E046', N'@CF A2', 200, N'E6023', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1dd0a140-3810-4860-ab03-eee4ee4ae965', N'Apheresis PLATELETS|PASIII/XX/20-24C|For mnf:injectable|ResLeu:<1log6|3rd container', N'PLT AFR PASIII MNFI LUKOPR ', N'E024', N'@B5 A2 D5 H5', 200, N'E5860', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1dd377f9-2b33-4fc8-95ab-acab123ad519', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Irradiated|ResLeu:<5log6|Supernat reduced', N'RBC AFR ACD-A>AS3 IRD LUKOPR SUPRed ', N'E009', N'@AZ C2 D4 EA', 350, N'E6009', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1e044d5b-6c4b-46ae-b2b2-eb9b704947e3', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Open|Irradiated|ResLeu:<5log6|Supernat reduced|1st container', N'RBC AFR ACD-A>AS3 OPN IRD LUKOPR SUPRed ', N'E009', N'@AZ B2 C2 D4 EA H3', 350, N'E5839', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1f34aed4-ad04-4ec7-998c-6812542f37e5', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|From 3 donors', N'PLT Pool Wash None OPN 3DNR ', N'E023', N'@71 B2 J3', 200, N'E5907', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'20f734a7-6824-4c24-85b0-56a490c7e7f0', N'POOLED PLATELETS|CPD/XX/20-24C|For mnf:noninjectable|ResLeu:<5log6', N'PLT Pool CPD MNFNI LUKOPR ', N'E022', N'@A7 A3 D4', 200, N'E5878', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2158e862-4a65-4aac-ad9c-de3fcca636f8', N'PLASMA|CP2D/XX/<=-20C|For mnf:injectable|Frozen <=72h', N'PLASMA CP2D MNFI ', N'E010', N'@BS A2 GD', 225, N'E5880', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'22045074-3bee-4ef4-ae92-44c0ea93fba1', N'RED BLOOD CELLS|CPD>AS1/450mL/refg|Irradiated|ResLeu:<5log6|Supernat rem/Plasma added', N'RBC CPD>AS1 IRD LUKOPR SR/PA ', N'E002', N'@18 C2 D4 E8', 350, N'E5883', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'238176ef-8cb3-4c05-9f98-e843d8dad318', N'PLASMA|CPD/500mL/<=-18C|ResLeu:NS|Frozen <=72h', N'PLASMA CPD LUKOPR ', N'E010', N'@AN D2 GD', 225, N'E6091', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2560beef-e272-4e73-bb86-a0976e2ce12b', N'POOLED PLATELETS|CPD/XX/20-24C|From 5 donors', N'PLT Pool CPD 5DNR ', N'E022', N'@A7 J5', 200, N'E5829', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'25e3233e-bc53-4ba2-b852-9d97a0a0857e', N'Apheresis FRESH FROZEN PLASMA|ACD-A/XX/<=-18C|50mL', N'FFP AFR ACD-A ', N'E012', N'@47 FA', 225, N'E5991', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'28c285e2-92cb-4a8e-a1ab-6b71a5effa42', N'RED BLOOD CELLS|CP2D/450mL/refg|Open|ResLeu:<5log6|Plasma added', N'RBC CP2D OPN LUKOPR PA', N'E002', N'@11 B2 D4 E4', 250, N'E6152', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2b65d5b3-463f-42f6-9a89-00ff458e5ff9', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<=-18C|Open|Irradiated|>=200mL<400mL', N'FFP AFR NaCit OPN IRD LowVol ', N'E012', N'@48 B2 C2 F5', 225, N'E6062', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2bd40784-2e19-47d8-945c-0c717de73b74', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<5log6', N'PLT Pool CPD LUKOPR ', N'E022', N'@A7 D4', 200, N'E5995', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2ca64757-a432-4952-b65f-2fe5c7dfef89', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|Plasma reduced|From 8 donors', N'PLT Pool NS OPN IRD PLS Red 8DNR ', N'E022', N'@72 B2 C2 E5 J8', 200, N'E5969', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2f2d7375-9ce1-4dfe-908a-5eac1a79ccd9', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|ResLeu:<5log6|Supernat rem/Plasma added', N'RBC AFR ACD-A>AS3 LUKOPR SR/PA ', N'E009', N'@AZ D4 E8', 350, N'E5847', 1008, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2f41d463-8e01-41b8-af7e-bb6747f8eeb5', N'Apheresis PLATELETS|PASIII/XX/20-24C|For mnf:injectable|ResLeu:<1log6|1st container', N'PLT AFR PASIII MNFI LUKOPR ', N'E024', N'@B5 A2 D5 H3', 200, N'E5858', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2f8be5ec-9a4b-4af8-bba8-a06534bf8f70', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<5log6|From 5 donors', N'PLT Pool CPD LUKOPR 5DNR ', N'E022', N'@A7 D4 J5', 200, N'E5831', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2f9838c1-2432-4ada-88e0-cd25cb410185', N'Thawed PLASMA|CPDA-1/XX/refg|For mnf:noninjectable', N'PLASMA Thaw CPDA-1 MNFNI ', N'E011', N'@10 A3', 225, N'E6079', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'304fc786-1907-45cd-9b0c-4f3e98911f5c', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|From 6 donors', N'PLT Pool NS OPN IRD 6DNR ', N'E022', N'@72 B2 C2 J6', 200, N'E5946', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3062b068-b88d-4175-90cc-004d0c5fdf00', N'WHOLE BLOOD|CPDA-1/500mL/refg|Irradiated|Plasma reduced', N'WB CPDA-1 IRD PLS Red ', N'E001', N'@08 C2 E5', 500, N'E6044', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'314584da-7388-4c56-99f4-d906d6a36db3', N'PLASMA|CPD/XX/<=-20C|For mnf:injectable restr use|Frozen <=72h', N'PLASMA CPD MNFRI ', N'E010', N'@BN A6 GD', 225, N'E6106', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'314c7586-a86a-40c4-8fb5-86ac02dc6a73', N'AS-3 RED BLOOD CELLS LEUKOCYTES REDUCED (CPD anticoagulant)', N'RBC CP2D>AS3 LUKOPR', N'E002', N'@33 D2', 350, N'04780', 1008, 0, 0, 0, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'31a817d3-080b-443d-84fa-3be8f77ad810', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<=-18C|Open|Irradiated|<200 mL', N'FFP AFR NaCit OPN IRD LowVol ', N'E012', N'@48 B2 C2 F4', 225, N'E6085', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'321cfea8-0394-4ac0-b924-d2a76090486a', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|From 4 donors', N'PLT Pool Wash None OPN LUKOPR 4DNR ', N'E023', N'@71 B2 D4 J4', 200, N'E5929', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3466afb9-c4c2-4b19-a519-f5b193024f2a', N'POOLED PLATELETS|PASII/XX/20-24C|ResLeu:<1log6|Bacterial test', N'PLT Pool PASII LUKOPR BacTest ', N'E022', N'@AE D5 N3', 200, N'E6014', 4, 0, 0, 1, N'A', '20090501 09:30:00.333', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'34cb1e09-ffba-43b7-bdc9-717a960f46bc', N'Thawed Apheresis FRESH FROZEN PLASMA|CP2D/XX/refg|Open|>=200mL<400mL', N'FFP AFR Thaw CP2D OPN LowVol ', N'E013', N'@13 B2 F5', 225, N'E5894', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'34d4e45b-a391-4f78-96bb-209c3d48b1be', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|Plasma reduced|From 7 donors', N'PLT Pool NS OPN IRD PLS Red 7DNR ', N'E022', N'@72 B2 C2 E5 J7', 200, N'E5968', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'354de31e-68ed-4bac-83af-e5ac3fcf1329', N'Deglycerolized RED BLOOD CELLS|None/450mL/refg|ResLeu:<1log6', N'RBC Deg None LUKOPR ', N'E006', N'@17 D5', 200, N'E6124', 336, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'37acdec8-0c20-4edf-a0d2-fe183ac2c308', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Supernat reduced|2nd container', N'PLT AFR Wash None OPN IRD LUKOPR SUPRed ', N'E027', N'@71 B2 C2 D4 EA H4', 200, N'E5891', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'38debd08-de2e-40b6-a845-a088e0c8bba7', N'Deglycerolized Apheresis RED BLOOD CELLS|None/XX/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC AFR Deg None OPN IRD LUKOPR PA ', N'E051', N'@AS B2 C2 D4 E4', 200, N'E6041', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'39465891-9bc4-41be-a244-dd5afb728a20', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg|ResLeu:<5log6', N'RBC CPD>SAGM LUKOPR ', N'E002', N'@CM D4', 350, N'E6050', 840, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3ab5755d-3f8f-421f-9e99-d04eb33fe676', N'FRESH FROZEN PLASMA|CPD/XX/<-30C|ResLeu:<1log6,WB filtr|LowVol:anticoag adj', N'FFP CPD LUKOPR LowVol ', N'E010', N'@A4 DA F8', 225, N'E6117', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3b738bdd-f9bb-4743-a81d-2269eb5936ce', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC AFR ACD-A>AS1 OPN IRD LUKOPR PA', N'E009', N'@AY B2 C2 G9 D4 E4', 350, N'E6145', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3bc93050-b8c7-4716-8929-964030893ec3', N'Deglycerolized RED BLOOD CELLS|None/450mL/refg|Irradiated', N'RBC Deg None IRD ', N'E006', N'@17 C2', 200, N'E6028', 336, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3c08e65e-2310-43ab-9588-2efa5b6ca204', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|From 2 donors', N'PLT Pool NS OPN LUKOPR 2DNR ', N'E022', N'@72 B2 D4 J2', 200, N'E5970', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3c1d5b44-b89d-4eeb-822a-7faa0ee3926b', N'RED BLOOD CELLS|CP2D/500mL/refg|Open|Irradiated|ResLeu:<5log6|Albumin added', N'RBC CP2D OPN IRD LUKOPR ALB Add ', N'E002', N'@12 B2 C2 D4 E2', 250, N'E6133', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3d055067-9513-4831-9d67-1749ae884f1c', N'FRESH FROZEN PLASMA|CPD/XX/<-30C|ResLeu:<5log6|Methylene blue-treated', N'FFP CPD LUKOPR Methyl Blue ', N'E010', N'@A4 D4 K3', 225, N'E6123', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3d50614f-3f9d-4536-a0cb-f0b64fe539fd', N'Frozen POOLED PLATELETS|DMSO/XX/<-80C|Buffy coat plts prep', N'PLT Pool Froz BUFCT ', N'E025', N'@CP G2', 200, N'E6025', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3e3441c8-9aef-4ff1-b2c8-25d1ab5c54bd', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|From 3 donors', N'PLT Pool Wash None OPN LUKOPR 3DNR ', N'E023', N'@71 B2 D4 J3', 200, N'E5928', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3e3b4d7a-31f5-4bdc-9102-28a93d435b5a', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|ResLeu:<1log6', N'RBC AFR ACD-A>AS1 LUKOPR ', N'E009', N'@AY D5', 350, N'E5827', 1008, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3edef728-cf10-4f3d-bb83-68954d58701b', N'Thawed POOLED PLATELETS|NS/XX/20-24C|Buffy coat plts prep', N'PLT Pool Thaw NS BUFCT ', N'E026', N'@72 G2', 200, N'E6026', 4, 0, 0, 1, N'A', '20090501 09:30:00.367', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3ee21e24-c4fd-4449-9814-ce460a3c1c39', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|Open|ResLeu:<5log6|Supernat reduced|2nd container', N'RBC AFR CP2D>AS3 OPN LUKOPR SUPRed ', N'E009', N'@33 B2 D4 EA H4', 350, N'E5843', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3f0af384-de39-4069-ad78-7a6555764342', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Irradiated|ResLeu:<5log6|Supernat reduced|2nd container', N'RBC AFR ACD-A>AS3 IRD LUKOPR SUPRed ', N'E009', N'@AZ C2 D4 EA H4', 350, N'E6005', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3f7cc88c-ff96-4b44-a639-c6aee054927a', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|Open|Irradiated|ResLeu:<5log6|Albumin added', N'RBC AFR ACD-A>AS1 OPN IRD LUKOPR ALB Add', N'E009', N'@AY B2 C2 D4 E2', 350, N'E6144', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'402cfba2-0516-464f-88ac-be2e72047e53', N'Washed RED BLOOD CELLS|None/XX/refg|Irradiated', N'RBC Wash None IRD ', N'E003', N'@AS C2', 200, N'E5905', 336, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'40cc27ff-b33e-49a7-9af2-b79ea86385fa', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<5log6', N'PLT Pool CPD IRD LUKOPR ', N'E022', N'@A7 C2 D4', 200, N'E5994', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'417381e3-02f1-40e0-8e00-44a9fc4ec88c', N'POOLED PLATELETS|PASII/XX/20-24C|Irradiated|ResLeu:<1log6|Bacterial test', N'PLT Pool PASII IRD LUKOPR BacTest ', N'E022', N'@AE C2 D5 N3', 200, N'E6017', 4, 0, 0, 1, N'A', '20090501 09:30:00.350', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'417bb220-edda-4ced-963e-d0ad314c3ff6', N'POOLED PLATELETS|PASII/XX/20-24C|ResLeu:<1log6|Bacterial monitoring', N'PLT Pool PASII LUKOPR BacMtr ', N'E022', N'@AE D5 N2', 200, N'E6013', 4, 0, 0, 1, N'A', '20090501 09:30:00.320', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'421abb50-a34c-4bf5-9e86-667eeaf1280a', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced|From 5 donors', N'PLT Pool NS OPN IRD LUKOPR PLS Red 5DNR ', N'E022', N'@72 B2 C2 D4 E5 J5', 200, N'E5959', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'42bb9952-7221-4910-8fd1-2a5502fd8090', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Open|ResLeu:<5log6|Supernat reduced', N'RBC AFR ACD-A>AS3 OPN LUKOPR SUPRed ', N'E009', N'@AZ B2 D4 EA', 350, N'E5835', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'430a288f-b69b-4e48-a21d-1d0f41c9c5b9', N'LEUKOCYTES|CPD/500mL/20-24C|Not for tx or mnf', N'LEUK CPD NMT ', N'E038', N'@65 A4', 200, N'E6035', 24, 0, 0, 1, N'A', '20090501 09:30:01.850', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'44edd6a5-a8bd-4a36-bfc9-6ba5f8711b2f', N'POOLED PLATELETS|NS/XX/20-24C|Open|From 5 donors', N'PLT Pool NS OPN 5DNR ', N'E022', N'@72 B2 J5', 200, N'E5938', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'45d643f8-ec29-4ecf-8eb3-0e5241f9fecb', N'Thawed Apheresis PLASMA|NaCitrate/XX/refg|For mnf:noninjectable', N'PLASMA AFR Thaw NaCit MNFNI ', N'E013', N'@55 A3', 225, N'E6103', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'45ebb88c-9b70-4f60-a083-aa2ba6f38ef2', N'Deglycerolized Apheresis RED BLOOD CELLS|AS3/XX/refg|Irradiated|ResLeu:<5log6|2nd container', N'RBC AFR Deg AS3 IRD LUKOPR ', N'E051', N'@B6 C2 D4 H4', 200, N'E6070', 336, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'466bbb57-8ebe-418f-90d4-67230680201e', N'WHOLE BLOOD|CPDA-1/450mL/20-24C', N'WB CPDA-1 ', N'E001', N'@66 ', 450, N'E6024', 840, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4672ddef-bea4-418b-bf8a-2433c920dec7', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|From 3 donors', N'PLT Pool Wash None OPN IRD 3DNR ', N'E023', N'@71 B2 C2 J3', 200, N'E5914', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'46a30cee-9b04-4e12-853e-3588d70da130', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|Irradiated|ResLeu:<5log6|Supernat reduced', N'RBC AFR ACD-A>AS1 IRD LUKOPR SUPRed ', N'E009', N'@AY C2 D4 EA', 350, N'E6006', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'46f49cce-319c-4249-b800-6d54406d87d2', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 8 donors', N'PLT Pool Wash None OPN IRD LUKOPR 8DNR ', N'E023', N'@71 B2 C2 D4 J8', 200, N'E5926', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'47515e5b-4419-4cbb-918c-f324722d0985', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 8 donors', N'PLT Pool NS OPN IRD LUKOPR 8DNR ', N'E022', N'@72 B2 C2 D4 J8', 200, N'E5955', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4787dc67-9e00-47c3-acb5-63caf1fd42e0', N'Deglycerolized Apheresis RED BLOOD CELLS|AS3/XX/refg|Irradiated|ResLeu:<5log6|1st container', N'RBC AFR Deg AS3 IRD LUKOPR ', N'E051', N'@B6 C2 D4 H3', 200, N'E6069', 336, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'48552ad5-4071-4272-bf58-bced3017029b', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|From 3 donors', N'PLT Pool NS OPN LUKOPR 3DNR ', N'E022', N'@72 B2 D4 J3', 200, N'E5971', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'487e551e-ba79-4883-9d3a-dd6fbd041cb6', N'RED BLOOD CELLS|CPD/500mL/refg|Open|Irradiated|ResLeu:<5log6|Albumin added', N'RBC CPD OPN IRD LUKOPR ALB Add ', N'E002', N'@04 B2 C2 D4 E2', 250, N'E6134', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'497fe249-f9f6-422f-89b7-cdcb66d3772e', N'PLASMA|CP2D/500mL/<=-20C|For mnf:injectable|Frozen <=8h', N'PLASMA MNFI ', N'E010', N'@CS A2 GB', 225, N'E6130', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'49f33087-1486-40c2-8235-84f5e039d9f9', N'FRESH FROZEN PLASMA|CPD/450mL/<-25C|ResLeu:<1log6|Quar:>=4m/retested', N'FFP CPD LUKOPR QUAR ', N'E010', N'@A2 D5 I3', 225, N'E6038', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4a135c97-c05a-45fb-aa97-d3b2ab33f4a9', N'PLASMA|CPDA-1/XX/<=-20C|For mnf:injectable restr use|Frozen <=72h', N'PLASMA CPDA-1 MNFRI ', N'E010', N'@BR A6 GD', 225, N'E6108', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4ce9b2df-689a-4bfc-b18c-ad8acd106849', N'POOLED PLATELETS|NS/XX/20-24C|Open|From 7 donors', N'PLT Pool NS OPN 7DNR ', N'E022', N'@72 B2 J7', 200, N'E5940', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4edec9f9-b91c-4a0a-96ce-05aa83c096bb', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|From 8 donors', N'PLT Pool NS OPN LUKOPR PLS Red 8DNR ', N'E022', N'@72 B2 D4 E5 J8', 200, N'E5983', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4f512fe7-f423-460b-a2c4-4a532fb93f2b', N'Thawed Apheresis PLASMA|NaCitrate/XX/refg|ResLeu:<5log6|Cryo reduced|Methylene blue-treated', N'PLASMA AFR Thaw NaCit LUKOPR CRYORed Methyl Blue ', N'E013', N'@55 D4 E3 K3', 225, N'E6114', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'500397b0-2777-4fd9-8a19-006a7fa3d543', N'RED BLOOD CELLS|CPD/500mL/refg|Open|ResLeu:<5log6|Plasma reduced', N'RBC CPD OPN LUKOPR PLS Red ', N'E002', N'@04 B2 D4 E5', 250, N'E6033', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5014a256-0223-4991-9d9b-809636042796', N'Frozen POOLED PLATELETS|DMSO/XX/<-30C|Open|ResLeu:<1log6|Buffy coat plts prep|Psoralen-treated', N'PLT Pool Froz DMSO OPN LUKOPR BUFCT Psoraln ', N'E025', N'@CJ B2 D5 G2 K5', 200, N'E6021', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'51726ffd-6477-4764-bb44-c1c2e2e61992', N'Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|Supernat reduced|4th container|Psoralen-treated', N'PLT AFR PASIII LUKOPR SUPRed Psoraln ', N'E024', N'@B5 D5 EA H6 K5', 200, N'E5869', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'517c6581-6870-4a9a-a887-d4fef43fe578', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|From 2 donors', N'PLT Pool NS OPN IRD 2DNR ', N'E022', N'@72 B2 C2 J2', 200, N'E5942', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'52abbc99-0210-47f0-978b-8191893be34f', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|From 8 donors', N'PLT Pool NS OPN IRD 8DNR ', N'E022', N'@72 B2 C2 J8', 200, N'E5948', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'52c56d8c-5f88-4311-9112-d1b71894b504', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|ResLeu:<5log6|Supernat rem/Plasma added|1st container', N'RBC AFR ACD-A>AS3 LUKOPR SR/PA ', N'E009', N'@AZ D4 E8 H3', 350, N'E5848', 1008, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'531eccd1-d240-44ee-a324-4cfa610381db', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Supernat reduced', N'PLT AFR Wash None OPN IRD LUKOPR SUPRed ', N'E027', N'@71 B2 C2 D4 EA', 200, N'E5889', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'53c74234-af6e-454f-a0d6-6d3620d0daa8', N'Washed POOLED PLATELETS|None/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|Psoralen-treated', N'PLT Pool Wash None LUKOPR BUFCT Psoraln ', N'E023', N'@71 D5 G2 K5', 200, N'E5856', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5471878c-1275-4643-9109-2547b512e7fc', N'WHOLE BLOOD|NS/XX/refg|For mnf:injectable', N'WB NS MNFI ', N'E001', N'@CG A2', 500, N'E6077', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'54dd8741-54fd-47cf-b77b-cc8c2c4a6b14', N'Thawed POOLED FRESH FROZEN PLASMA|CP2D/XX/refg|Open|ResLeu:<5log6', N'FFP Pool Thaw CP2D OPN LUKOPR ', N'E011', N'@13 B2 D4', 500, N'E6042', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'55e12681-1108-4796-a43f-26f68a8dd88b', N'Thawed Apheresis PLASMA|ACD-A/XX/refg|For mnf:noninjectable|<200 mL', N'PLASMA AFR Thaw ACD-A MNFNI LowVol ', N'E013', N'@54 A3 F4', 225, N'E6099', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'56b9cef5-3969-4d5b-b39d-4cb81e7a8aab', N'Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|Supernat reduced|1st container|Psoralen-treated', N'PLT AFR PASIII LUKOPR SUPRed Psoraln ', N'E024', N'@B5 D5 EA H3 K5', 200, N'E5866', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'57327824-abd7-4137-aed9-770e16068951', N'Apheresis FRESH FROZEN PLASMA|CP2D/XX/<=-18C|>=600mL', N'FFP AFR CP2D LowVol ', N'E012', N'@37 F7', 225, N'E5834', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'582b083c-5347-4cb5-be2c-806a486e3e97', N'GRANULOCYTES|CPD/XX/rt|Irradiated', N'GRAN CPD IRD ', N'E034', N'@BT C2', 150, N'E6113', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'585aa77f-7e10-499a-88e0-ec54d9ec4cc2', N'PLASMA|CPD/500mL/<=-20C|For mnf:injectable|Frozen <=8h', N'PLASMA MNFI ', N'E010', N'@CR A2 GB', 225, N'E6131', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5869f28a-a50f-4cb8-839b-20d09d89ba5f', N'POOLED PLATELETS|NS/XX/20-24C|Open|From 2 donors', N'PLT Pool NS OPN 2DNR ', N'E022', N'@72 B2 J2', 200, N'E5935', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'587b1f03-5bba-449d-b2c6-e812daf7b42c', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Supernat reduced|3rd container', N'PLT AFR Wash None OPN IRD LUKOPR SUPRed ', N'E027', N'@71 B2 C2 D4 EA H5', 200, N'E5892', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'58e3d859-4f3b-4a0f-b6b5-335b53d2be8a', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|From 2 donors', N'PLT Pool Wash None OPN LUKOPR 2DNR ', N'E023', N'@71 B2 D4 J2', 200, N'E5927', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5bb9ced8-24fc-4bbd-8341-1fe94c6f0062', N'Washed RED BLOOD CELLS|None/XX/refg|Open|Irradiated|ResLeu:<5log6|Albumin added', N'RBC Wash None OPN IRD LUKOPR ALB Add', N'E003', N'@AS B2 C2 D4 E2', 200, N'E6150', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5bcc79ad-37d1-40ac-802f-9cefae99a4bd', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 6 donors', N'PLT Pool NS OPN IRD LUKOPR 6DNR ', N'E022', N'@72 B2 C2 D4 J6', 200, N'E5953', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5bf2e2d0-2afc-4b27-b064-6544ad9f63c9', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced/Albumin added|3rd container', N'PLT AFR ACD-A OPN LUKOPR PLS Red/ALB Add ', N'E024', N'@73 B2 D4 EB H5', 200, N'E5899', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5bff222d-90ee-4822-ba52-67bb2ffc8bcc', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<-25C|For mnf:injectable|Frozen <=24h', N'FFP AFR MNFI ', N'E012', N'@CQ A2 G7', 225, N'E6127', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5c22d5f1-cd3f-43bd-b314-1c7b09d0147a', N'Apheresis GRANULOCYTES|ACD-A/XX/rt|Open|Irradiated', N'GRAN AFR ACD-A OPN IRD', N'E035', N'@93 B2 C2', 150, N'E6143', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5c4ec475-bd19-4e92-9e1e-4bf097eb4fca', N'POOLED PLATELET-RICH BUFFY COAT|PASII/XX/20-24C|ResLeu:<1log6|Approx 300 log9 plts', N'BUFFY PltRch Pool PASII LUKOPR ', N'E043', N'@AE D5 JC', 200, N'E6039', 4, 0, 0, 1, N'A', '20090501 09:30:02.257', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5d0f7aa8-fbf8-4b8c-982f-749c57a2edc6', N'PLATELETS|CP2D/500mL/20-24C|Open|Irradiated|ResLeu:<8.3log5', N'PLT CP2D OPN IRD LUKOPR ', N'E020', N'@69 B2 C2 D6', 50, N'E6129', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5d3cb176-9c0a-49f1-a657-be1398b4235e', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced/Albumin added|2nd container', N'PLT AFR ACD-A OPN IRD LUKOPR PLS Red/ALB Add ', N'E024', N'@73 B2 C2 D4 EB H4', 200, N'E5902', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5e2f398d-8c11-448e-84f5-5e930ca01561', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|Open|Irradiated|ResLeu:<5log6|Supernat reduced|2nd container', N'RBC AFR CP2D>AS3 OPN IRD LUKOPR SUPRed ', N'E009', N'@33 B2 C2 D4 EA H4', 350, N'E5846', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5e3d4092-1d4c-4f78-8a92-8873dc48b2cb', N'PLASMA|CPDA-1/XX/<=-20C|For mnf:injectable restr use|Frozen <=24h', N'PLASMA CPDA-1 MNFRI ', N'E010', N'@BR A6 G7', 225, N'E6107', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5e5fb7e4-e310-460f-81ae-1c6de1a74062', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced/Albumin added', N'PLT AFR ACD-A OPN LUKOPR PLS Red/ALB Add ', N'E024', N'@73 B2 D4 EB', 200, N'E5896', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'60384ba0-27cd-486f-a69a-b0c80ed3c45f', N'Washed Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|4th container|Psoralen-treated', N'PLT AFR Wash PASIII LUKOPR Psoraln ', N'E027', N'@B5 D5 H6 K5', 200, N'E5877', 4, 0, 0, 1, N'A', '20090501 09:30:01.037', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'60b96202-cdf9-4044-9bc3-8640b1ad4a04', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Supernat reduced', N'PLT Pool Wash None OPN IRD LUKOPR SUPRed ', N'E023', N'@71 B2 C2 D4 EA', 200, N'E5888', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'61d7b81b-b45e-4938-baa3-b178d6831acb', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 3 donors', N'PLT Pool Wash None OPN IRD LUKOPR 3DNR ', N'E023', N'@71 B2 C2 D4 J3', 200, N'E5921', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6344c15b-bec6-4e9e-8ddb-38928f051779', N'FRESH FROZEN PLASMA|CPD/XX/<-30C|LowVol:anticoag adj', N'FFP CPD LowVol ', N'E010', N'@A4 F8', 225, N'E6118', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'636179c9-ec15-4187-baa9-955c084ae066', N'POOLED PLATELETS|NS/XX/20-24C|Open|From 8 donors', N'PLT Pool NS OPN 8DNR ', N'E022', N'@72 B2 J8', 200, N'E5941', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'63731a81-bee5-47b7-a608-1646baefc594', N'PLASMA|CP2D/XX/<=-20C|For mnf:injectable|Cryo reduced|Frozen <=120h', N'PLASMA CP2D MNFI CRYORed ', N'E010', N'@BS A2 E3 G9', 225, N'E5879', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'63f0177f-8bb2-492a-9585-a9600ae8dc9c', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|Open|ResLeu:<5log6|Supernat rem/Plasma added|2nd container', N'RBC AFR ACD-A>AS1 OPN LUKOPR SR/PA ', N'E009', N'@AY B2 D4 E8 H4', 350, N'E5886', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'666755de-7267-4719-8ba7-cce59b660d9b', N'Deglycerolized RED BLOOD CELLS|None/450mL/refg|Irradiated|ResLeu:<5log6', N'RBC Deg None IRD LUKOPR ', N'E006', N'@17 C2 D4', 200, N'E6030', 336, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'668c6063-787b-4de8-939d-06ddc66b3069', N'Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|3rd container|Psoralen-treated', N'PLT AFR PASIII LUKOPR Psoraln ', N'E024', N'@B5 D5 H5 K5', 200, N'E5864', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'668e8656-2f29-4fe3-b440-bcf30b46698b', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 2 donors', N'PLT Pool NS OPN IRD LUKOPR 2DNR ', N'E022', N'@72 B2 C2 D4 J2', 200, N'E5949', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6a929560-f5a1-4034-a907-dc11f82cf821', N'RED BLOOD CELLS|CPD>SAGM/XX/refg|ResLeu:<5log6|LowVol:anticoag not adj', N'RBC CPD>SAGM LUKOPR LowVol ', N'E002', N'@CL D4 F3', 350, N'E6049', 840, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6abd18b0-5b09-420e-9973-6c16d41331ab', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|Plasma reduced|From 6 donors', N'PLT Pool NS OPN IRD PLS Red 6DNR ', N'E022', N'@72 B2 C2 E5 J6', 200, N'E5967', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6b3ee992-9117-4045-921d-3ca51503bbe7', N'Deglycerolized RED BLOOD CELLS|None/XX/refg|Open|Irradiated|ResLeu:<1log6', N'RBC Deg None OPN IRD LUKOPR ', N'E006', N'@AS B2 C2 D5', 200, N'E5826', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6c04ca6b-5400-4729-85b7-8804d28b0675', N'Thawed PLASMA|CPD/XX/refg|For mnf:noninjectable', N'PLASMA Thaw CPD MNFNI ', N'E011', N'@06 A3', 225, N'E6102', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6c4aa020-4dcc-414d-8594-494fd17ac417', N'RED BLOOD CELLS|CPD/250mL/refg|Irradiated|ResLeu:<5log6|Plasma added', N'RBC CPD IRD LUKOPR PA ', N'E002', N'@05 C2 D4 E4', 250, N'E6066', 504, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6d293dc3-ec53-4998-86d8-99dc01c30101', N'Thawed Apheresis PLASMA|CP2D/XX/refg|For mnf:noninjectable', N'PLASMA AFR Thaw CP2D MNFNI ', N'E013', N'@13 A3', 225, N'E6100', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6d32102e-57e0-4e99-8ad4-b5e7a03558f4', N'WHOLE BLOOD|CPDA-1/500mL/refg|Plasma reduced', N'WB CPDA-1 PLS Red ', N'E001', N'@08 E5', 500, N'E6043', 840, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6de44e69-4ae7-444a-8a51-013d7a16e254', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|From 6 donors', N'PLT Pool Wash None OPN LUKOPR 6DNR ', N'E023', N'@71 B2 D4 J6', 200, N'E5931', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6ecc21a3-677c-49b5-ac1b-a57d89b27509', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|From 3 donors', N'PLT Pool NS OPN LUKOPR PLS Red 3DNR ', N'E022', N'@72 B2 D4 E5 J3', 200, N'E5978', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6efaf088-a380-40fb-9dda-6438f97edee2', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 5 donors', N'PLT Pool NS OPN IRD LUKOPR 5DNR ', N'E022', N'@72 B2 C2 D4 J5', 200, N'E5952', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6f7d05e6-4d2c-4d26-bea9-121bf44753af', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<=-18C|Open|Irradiated|>=600mL', N'FFP AFR NaCit OPN IRD LowVol ', N'E012', N'@48 B2 C2 F7', 225, N'E6064', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'70df6913-f782-4204-a5b9-aae74d6285b4', N'Frozen Apheresis PLATELETS|DMSO/XX/<-30C|Open|ResLeu:<1log6|2nd container|Psoralen-treated', N'PLT AFR Froz DMSO OPN LUKOPR Psoraln ', N'E025', N'@CJ B2 D5 H4 K5', 200, N'E6020', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'70f18bed-fa15-439c-aa79-efcd7290612f', N'Apheresis PLASMA|ACD-A/XX/<37C|For mnf:noninjectable', N'PLASMA AFR ACD-A MNFNI', N'E012', N'@59 A3', 225, N'E6140', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'73b4a70f-af29-4596-b70d-674397a06623', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|Open|ResLeu:<5log6|Supernat reduced|1st container', N'RBC AFR CP2D>AS3 OPN LUKOPR SUPRed ', N'E009', N'@33 B2 D4 EA H3', 350, N'E5842', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'73c9f5b2-dc2a-4a64-b31b-0fb581adb1f7', N'LEUKOCYTES|CPDA-1/500mL/20-24C|Not for tx or mnf', N'LEUK CPDA-1 NMT ', N'E038', N'@67 A4', 200, N'E6034', 24, 0, 0, 1, N'A', '20090501 09:30:01.833', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7771ad80-b1e7-4b9e-93a8-826ae1e8ccf9', N'WHOLE BLOOD|CPD/500mL/refg|Irradiated|Plasma reduced', N'WB CPD IRD PLS Red ', N'E001', N'@04 C2 E5', 500, N'E6046', 504, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'78df3972-0919-4ae3-9da4-c9b56365fa73', N'Frozen RED BLOOD CELLS|None/XX/<-65C|Not for tx or mnf|Open|Irradiated|ResLeu:<1log6', N'RBC Froz None NMT OPN IRD LUKOPR ', N'E004', N'@B7 A4 B2 C2 D5', 200, N'E5828', 87600, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'78f9c3f6-9236-4b69-9965-cd41fb25598b', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|From 7 donors', N'PLT Pool Wash None OPN LUKOPR 7DNR ', N'E023', N'@71 B2 D4 J7', 200, N'E5932', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7c0448c9-bc1a-4c36-ae48-f37abd5b157d', N'POOLED PLATELETS|CP2D/XX/20-24C|Irradiated|Plasma reduced', N'PLT Pool CP2D IRD PLS Red ', N'E022', N'@B9 C2 E5', 200, N'E5998', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7d91b49f-353c-4e20-ad16-758074c65051', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|Open|ResLeu:<5log6|Supernat reduced', N'RBC AFR CP2D>AS3 OPN LUKOPR SUPRed ', N'E009', N'@33 B2 D4 EA', 350, N'E5841', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7f5088ed-7595-483a-a27f-29b0ccfccf2f', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Open|ResLeu:<5log6|Supernat reduced|1st container', N'RBC AFR ACD-A>AS3 OPN LUKOPR SUPRed ', N'E009', N'@AZ B2 D4 EA H3', 350, N'E5836', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'80209022-7db1-40b0-b978-38068e2f1cc3', N'FRESH FROZEN PLASMA|CPD/XX/<-30C', N'FFP CPD ', N'E010', N'@A4 ', 225, N'E6119', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8051cdb3-3c53-4078-88e3-9ff137d03c06', N'PLASMA|CPDA-1/XX/<=-18C|For mnf:noninjectable|Cryo reduced', N'PLASMA CPDA-1 MNFNI CRYORed ', N'E010', N'@36 A3 E3', 225, N'E6055', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'805c312d-cfa8-48f5-9081-8e51f484f76a', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|From 5 donors', N'PLT Pool NS OPN LUKOPR PLS Red 5DNR ', N'E022', N'@72 B2 D4 E5 J5', 200, N'E5980', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'814d6a09-43d9-466c-93dc-16ff66bc9aff', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 3 donors', N'PLT Pool NS OPN IRD LUKOPR 3DNR ', N'E022', N'@72 B2 C2 D4 J3', 200, N'E5950', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8156d82b-c7fd-4cb1-9db0-95db39831f60', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|From 2 donors', N'PLT Pool Wash None OPN 2DNR ', N'E023', N'@71 B2 J2', 200, N'E5906', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'81acf1d0-7098-49dd-abf3-15de428eb5eb', N'Thawed CRYOPRECIPITATE|None/XX/rt|Open', N'CRYO Thaw None OPN ', N'E029', N'@83 B2', 15, N'E6136', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'825bfcd0-42be-40e3-b3fd-c8ebffc3f959', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Open|Irradiated|ResLeu:<5log6|Albumin added', N'RBC AFR ACD-A>AS3 OPN IRD LUKOPR ALB Add', N'E009', N'@AZ B2 C2 D4 E2', 350, N'E6146', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8459f908-3517-42e3-b686-a4d4cde06f42', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|Open|ResLeu:<5log6|Supernat rem/Plasma added', N'RBC AFR ACD-A>AS1 OPN LUKOPR SR/PA ', N'E009', N'@AY B2 D4 E8', 350, N'E5884', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'86712844-729e-42d8-8be5-51c7e32320ee', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|Plasma reduced|From 3 donors', N'PLT Pool NS OPN IRD PLS Red 3DNR ', N'E022', N'@72 B2 C2 E5 J3', 200, N'E5964', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'86f6a460-c399-414f-83a3-97614a7ec990', N'Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|Supernat reduced|3rd container|Psoralen-treated', N'PLT AFR PASIII LUKOPR SUPRed Psoraln ', N'E024', N'@B5 D5 EA H5 K5', 200, N'E5868', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'88b917bf-38f5-44db-a460-f898a2cc3f29', N'Thawed Apheresis FRESH FROZEN PLASMA|ACD-A/XX/refg|50mL', N'FFP AFR Thaw ACD-A ', N'E013', N'@54 FA', 225, N'E5992', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8902fdb5-4d39-4d25-8170-1ea261dc4545', N'Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|1st container|Psoralen-treated', N'PLT AFR PASIII LUKOPR Psoraln ', N'E024', N'@B5 D5 H3 K5', 200, N'E5862', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8a42555c-f6c9-4ff6-992a-e1549e5468ed', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|From 5 donors', N'PLT Pool CPD IRD 5DNR ', N'E022', N'@A7 C2 J5', 200, N'E5830', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8a923df8-86c4-4355-af9f-e6b1ca2339e0', N'POOLED PLATELETS|NS/XX/20-24C|Open|Plasma reduced|From 2 donors', N'PLT Pool NS OPN PLS Red 2DNR ', N'E022', N'@72 B2 E5 J2', 200, N'E5984', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8b035051-6406-4a5a-a6f6-a31fcbd8428f', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|Irradiated|ResLeu:<5log6|Supernat reduced|1st container', N'RBC AFR ACD-A>AS1 IRD LUKOPR SUPRed ', N'E009', N'@AY C2 D4 EA H3', 350, N'E6007', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8b642955-2d86-4b0a-af6b-cfd198b00def', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Open|Irradiated|ResLeu:<5log6|Supernat reduced|2nd container', N'RBC AFR ACD-A>AS3 OPN IRD LUKOPR SUPRed ', N'E009', N'@AZ B2 C2 D4 EA H4', 350, N'E5840', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8b89fa6c-4516-4c29-b844-26aa8cd6c5cb', N'Washed Apheresis PLATELETS|None/XX/20-24C|ResLeu:<1log6|2nd container|Psoralen-treated', N'PLT AFR Wash None LUKOPR Psoraln ', N'E027', N'@71 D5 H4 K5', 200, N'E5871', 4, 0, 0, 1, N'A', '20090501 09:30:00.990', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8c84bc25-06c9-4bd4-81b6-00e3b8857610', N'Apheresis PLATELETS|PASIII/XX/20-24C|For mnf:injectable|ResLeu:<1log6|4th container', N'PLT AFR PASIII MNFI LUKOPR ', N'E024', N'@B5 A2 D5 H6', 200, N'E6018', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8cbbd037-6b91-4913-b769-2472d58ec292', N'Apheresis FRESH FROZEN PLASMA|CP2D/XX/<=-18C|<200 mL', N'FFP AFR CP2D LowVol ', N'E012', N'@37 F4', 225, N'E5833', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8cd43b27-b7da-4af9-862b-e69133032342', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 2 donors', N'PLT Pool Wash None OPN IRD LUKOPR 2DNR ', N'E023', N'@71 B2 C2 D4 J2', 200, N'E5920', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8e7c2f27-a4f2-4f89-9244-c2b170434114', N'Thawed PLASMA|CPD/450mL/<-25C|Frozen <=18h', N'PLASMA Thaw CPD ', N'E011', N'@A2 G6', 225, N'E6137', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8f0c0700-66e4-4298-9d90-38787f036cba', N'FRESH FROZEN PLASMA|CPD/450mL/<-25C|For mnf:injectable|Frozen <=18h', N'FFP CPD MNFI ', N'E010', N'@A2 A2 G6', 225, N'E6125', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8f408f1e-12b1-4671-b723-376d109b8e3e', N'Deglycerolized Apheresis RED BLOOD CELLS|AS3/XX/refg|ResLeu:<5log6|2nd container', N'RBC AFR Deg AS3 LUKOPR ', N'E051', N'@B6 D4 H4', 200, N'E6068', 336, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8fc28234-55c9-4a1a-a95f-af238d529ffc', N'Thawed PLASMA|CPD/XX/refg|ResLeu:<5log6|Cryo reduced|Methylene blue-treated', N'PLASMA Thaw CPD LUKOPR CRYORed Methyl Blue ', N'E011', N'@06 D4 E3 K3', 225, N'E6112', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8ff30b06-41a0-4790-9af0-f291e2b0e500', N'Washed Apheresis PLATELETS|None/XX/20-24C|ResLeu:<1log6|1st container|Psoralen-treated', N'PLT AFR Wash None LUKOPR Psoraln ', N'E027', N'@71 D5 H3 K5', 200, N'E5870', 4, 0, 0, 1, N'A', '20090501 09:30:00.977', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9004481f-fe03-44d0-83a7-5caf03257da6', N'POOLED FRESH FROZEN PLASMA|CPD/XX/<-30C|ResLeu:<1log6|>=600mL|From 3 donors|Psoralen-treated', N'FFP Pool CPD LUKOPR LowVol 3DNR Psoraln ', N'E010', N'@A4 D5 F7 J3 K5', 225, N'E5881', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'90078947-5656-4583-a421-c5e07aa982be', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced/Albumin added|1st container', N'PLT AFR ACD-A OPN LUKOPR PLS Red/ALB Add ', N'E024', N'@73 B2 D4 EB H3', 200, N'E5897', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'929d4ea6-71ab-486e-a633-447fd5cc9f40', N'Thawed POOLED CRYOPRECIPITATE|NS/XX/rt|Open|Irradiated', N'CRYO Pool Thaw NS OPN IRD ', N'E031', N'@92 B2 C2', 100, N'E6000', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'938f0e12-9582-41b7-8ada-6246f58dbad6', N'PLASMA|CPD/XX/<=-18C|For mnf:noninjectable|Frozen <=8h', N'PLASMA CPD MNFNI ', N'E010', N'@35 A3 GB', 225, N'E6083', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'93fa8176-ae1f-4bdf-825d-b04fe7927241', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|From 4 donors', N'PLT Pool NS OPN LUKOPR PLS Red 4DNR ', N'E022', N'@72 B2 D4 E5 J4', 200, N'E5979', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'944b8765-cbb3-4ed5-b9e5-ddc43b0eee4e', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Supernat reduced|1st container', N'PLT AFR Wash None OPN IRD LUKOPR SUPRed ', N'E027', N'@71 B2 C2 D4 EA H3', 200, N'E5890', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'96a0f087-6673-4d13-9be4-9f9f8cb7690d', N'RED BLOOD CELLS|CP2D>AS3/450mL/refg|Irradiated|ResLeu:<5log6|Supernat reduced', N'RBC CP2D>AS3 IRD LUKOPR SUPRed ', N'E002', N'@20 C2 D4 EA', 350, N'E6011', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'993a7e63-53e0-44b3-adda-c8a00d3bb759', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|ResLeu:<5log6|Supernat rem/Plasma added|2nd container', N'RBC AFR ACD-A>AS3 LUKOPR SR/PA ', N'E009', N'@AZ D4 E8 H4', 350, N'E5849', 1008, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9af92869-3c6e-4c9c-9ce8-2d8194a2a642', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<=-18C|Open|Irradiated', N'FFP AFR NaCit OPN IRD ', N'E012', N'@48 B2 C2', 225, N'E6061', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9ca67802-61c2-4113-a235-7a083731cd8f', N'RED BLOOD CELLS|CPD>AS5/450mL/refg|Irradiated|ResLeu:<5log6|Supernat rem/Plasma added', N'RBC CPD>AS5 IRD LUKOPR SR/PA ', N'E002', N'@22 C2 D4 E8', 350, N'E6032', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9d08ced6-5505-4f18-8446-20f5ed1ec842', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|From 2 donors', N'PLT Pool Wash None OPN IRD 2DNR ', N'E023', N'@71 B2 C2 J2', 200, N'E5913', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9d1a6142-cec0-4e94-908b-0c15f596ef0c', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 4 donors', N'PLT Pool NS OPN IRD LUKOPR 4DNR ', N'E022', N'@72 B2 C2 D4 J4', 200, N'E5951', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9d292add-0fa3-4b53-a284-8ba908b4b61a', N'FRESH FROZEN PLASMA|CPD/XX/<-30C|ResLeu:<5log6|50mL|Methylene blue-treated', N'FFP CPD LUKOPR Methyl Blue ', N'E010', N'@A4 D4 FA K3', 225, N'E6122', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9d319603-d2c0-4f92-8285-efe9e52cc15f', N'Thawed Apheresis POOLED FRESH FROZEN PLASMA|ACD-A/XX/refg|Open', N'FFP AFR Pool Thaw ACD-A OPN ', N'E013', N'@54 B2', 225, N'E6097', 24, 0, 0, 1, N'A', '20090501 09:30:00.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9d3f1b92-ba7a-4977-a2d7-011b3a3f2ed5', N'LEUKOCYTES|CPD/450mL/rt|Irradiated', N'LEUK CPD IRD ', N'E038', N'@85 C2', 200, N'E6080', 24, 0, 0, 1, N'A', '20090501 09:30:01.850', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9d54fd17-df5e-49d0-a9d3-6d2bd5f9f464', N'Washed Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|2nd container|Psoralen-treated', N'PLT AFR Wash PASIII LUKOPR Psoraln ', N'E027', N'@B5 D5 H4 K5', 200, N'E5875', 4, 0, 0, 1, N'A', '20090501 09:30:01.023', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a171e7e1-d86c-4fef-a760-29588bb2df47', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced|From 7 donors', N'PLT Pool NS OPN IRD LUKOPR PLS Red 7DNR ', N'E022', N'@72 B2 C2 D4 E5 J7', 200, N'E5961', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a17e7843-c2d1-44e1-8fe7-31c016d9ae6d', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|Plasma reduced|From 4 donors', N'PLT Pool NS OPN IRD PLS Red 4DNR ', N'E022', N'@72 B2 C2 E5 J4', 200, N'E5965', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a1d2cd01-d7d3-458e-82b7-aeea20851978', N'POOLED PLATELETS|NS/XX/20-24C|Open|Plasma reduced|From 4 donors', N'PLT Pool NS OPN PLS Red 4DNR ', N'E022', N'@72 B2 E5 J4', 200, N'E5986', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a3169d8b-62e8-40a4-b14f-d346e9c7c7d9', N'RED BLOOD CELLS|CPD>AS5/500mL/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC CPD>AS5 OPN IRD LUKOPR PA', N'E002', N'@23 B2 C2 D4 E4', 350, N'E6149', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a451ff8b-549c-460e-9f17-6228474a18cb', N'Rejuvenated Apheresis RED BLOOD CELLS|None/XX/refg|Open|ResLeu:<5log6', N'RBC AFR Rej None OPN LUKOPR ', N'E052', N'@AS B2 D4', 200, N'E5999', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a49ff3f1-09f7-467d-95ff-b918ecfebc3e', N'POOLED PLATELET-RICH BUFFY COAT|PASIIIMgK/XX/20-24C|ResLeu:<1log6|Approx 300 log9 plts', N'BUFFY PltRch Pool PASIIIMgK LUKOPR ', N'E043', N'@CI D5 JC', 200, N'E6040', 4, 0, 0, 1, N'A', '20090501 09:30:02.257', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a4e08046-7849-49e8-aaff-837787537b83', N'Apheresis PLASMA|ACD-A/XX/<=-20C|For mnf:noninjectable|Open', N'PLASMA AFR ACD-A MNFNI OPN ', N'E012', N'@56 A3 B2', 225, N'E6074', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a5467b61-30df-41e6-a1cd-346c476b506c', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<-30C|ResLeu:<5log6|50mL|Methylene blue-treated', N'FFP AFR NaCit LUKOPR Methyl Blue ', N'E012', N'@CH D4 FA K3', 225, N'E6120', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a5907acf-7f5a-4f1a-9a7c-82b6aaf61059', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|From 5 donors', N'PLT Pool Wash None OPN LUKOPR 5DNR ', N'E023', N'@71 B2 D4 J5', 200, N'E5930', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a6353264-0679-4330-a30d-d74a3edb1103', N'RED BLOOD CELLS|CPD/450mL/refg|ResLeu:<1log6,WB filtr', N'RBC CPD LUKOPR ', N'E002', N'@03 DA', 250, N'E6110', 504, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a64ba3d6-35be-4308-92b6-65fbd8e2c449', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<=-18C|Open|Irradiated|>=400mL<600mL', N'FFP AFR NaCit OPN IRD LowVol ', N'E012', N'@48 B2 C2 F6', 225, N'E6063', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a6d4f5dd-dc41-432f-b4f5-f32a13efb1ce', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|Plasma reduced', N'PLT Pool CPD IRD PLS Red ', N'E022', N'@A7 C2 E5', 200, N'E5996', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a99ca001-3fb8-4753-bfb0-8801584e626b', N'POOLED PLATELETS|PASIII/XX/20-24C|For mnf:injectable|ResLeu:<1log6|Buffy coat plts prep', N'PLT Pool PASIII MNFI LUKOPR BUFCT ', N'E022', N'@B5 A2 D5 G2', 200, N'E5853', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'aa045b21-c40a-4e7c-a7c9-8642802b3259', N'PLASMA|CPD/XX/<=-20C|For mnf:injectable restr use|Frozen <=24h', N'PLASMA CPD MNFRI ', N'E010', N'@BN A6 G7', 225, N'E6105', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'aa09279e-40a5-4686-8c33-834d6b4637fc', N'PLASMA|CPD/500mL/<=-18C|ResLeu:NS|Cryo reduced', N'PLASMA CPD LUKOPR CRYORed ', N'E010', N'@AN D2 E3', 225, N'E6088', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ad03762d-c037-4ae7-85ce-4c92ebf927e8', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|From 5 donors', N'PLT Pool NS OPN LUKOPR 5DNR ', N'E022', N'@72 B2 D4 J5', 200, N'E5973', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ade7ae9e-ddee-4832-b9eb-312b93e95a3c', N'WHOLE BLOOD|CPD/XX/refg|Plasma reduced|LowVol:anticoag not adj', N'WB CPD PLS Red LowVol ', N'E001', N'@06 E5 F3', 250, N'E6048', 504, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'af1bf99c-3333-4d4c-8045-2c1dfc554032', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 7 donors', N'PLT Pool Wash None OPN IRD LUKOPR 7DNR ', N'E023', N'@71 B2 C2 D4 J7', 200, N'E5925', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'af31795e-795f-4ff5-808f-e262d528c68e', N'Washed POOLED PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|Psoralen-treated', N'PLT Pool Wash PASIII LUKOPR BUFCT Psoraln ', N'E023', N'@B5 D5 G2 K5', 200, N'E5857', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'af51996a-c66f-41e4-8793-8a6f6f710a2e', N'POOLED PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|Supernat reduced|Buffy coat plts prep|Psoralen-treated', N'PLT Pool PASIII LUKOPR SUPRed BUFCT Psoraln ', N'E022', N'@B5 D5 EA G2 K5', 200, N'E5855', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'afcb83e1-f3b3-46e8-83e3-e3582d1c2ce7', N'Washed Apheresis PLATELETS|None/XX/20-24C|ResLeu:<1log6|3rd container|Psoralen-treated', N'PLT AFR Wash None LUKOPR Psoraln ', N'E027', N'@71 D5 H5 K5', 200, N'E5872', 4, 0, 0, 1, N'A', '20090501 09:30:00.990', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b084e424-492f-4dce-a901-d8aab637e552', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|Irradiated|ResLeu:<5log6|Supernat reduced|2nd container', N'RBC AFR ACD-A>AS1 IRD LUKOPR SUPRed ', N'E009', N'@AY C2 D4 EA H4', 350, N'E6008', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b08c5a34-c12b-47f2-88bd-18c9cddbc6c5', N'Thawed Apheresis FRESH FROZEN PLASMA|CP2D/XX/refg|>=200mL<400mL', N'FFP AFR Thaw CP2D LowVol ', N'E013', N'@13 F5', 225, N'E5893', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b1961ed7-d390-4c9d-8cf3-de3893872ebc', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Open|Irradiated|ResLeu:<5log6|Supernat reduced', N'RBC AFR ACD-A>AS3 OPN IRD LUKOPR SUPRed ', N'E009', N'@AZ B2 C2 D4 EA', 350, N'E5838', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b492d256-897d-49ca-8aed-8d941d0d97e7', N'RED BLOOD CELLS|CP2D>AS3/450mL/refg|Irradiated|ResLeu:<5log6|Supernat rem/Plasma added', N'RBC CP2D>AS3 IRD LUKOPR SR/PA ', N'E002', N'@20 C2 D4 E8', 350, N'E6031', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b4ef7591-19ef-4612-81d7-5c713dac79e8', N'LEUKOCYTES|CPDA-1/500mL/20-24C|For mnf:injectable', N'LEUK CPDA-1 MNFI ', N'E038', N'@67 A2', 200, N'E6081', 24, 0, 0, 1, N'A', '20090501 09:30:01.867', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b5aec08b-1b13-4075-b47b-d9d8008783c8', N'Frozen Apheresis PLATELETS|DMSO/XX/<-30C|Open|ResLeu:<1log6|1st container|Psoralen-treated', N'PLT AFR Froz DMSO OPN LUKOPR Psoraln ', N'E025', N'@CJ B2 D5 H3 K5', 200, N'E6019', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b6519942-6400-45df-8c8a-df1003e287d5', N'Thawed Apheresis PLASMA|CP2D/XX/refg|For mnf:noninjectable|<200 mL', N'PLASMA AFR Thaw CP2D MNFNI LowVol ', N'E013', N'@13 A3 F4', 225, N'E6101', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b68a4dfe-4f0a-4c1b-82f5-bc1b9fba95e9', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|Plasma reduced|From 2 donors', N'PLT Pool NS OPN IRD PLS Red 2DNR ', N'E022', N'@72 B2 C2 E5 J2', 200, N'E5963', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b6a806da-4a51-4539-82ba-117ad90a0b4d', N'RED BLOOD CELLS|CPD>AS1/450mL/refg|Irradiated|ResLeu:<5log6|Supernat reduced', N'RBC CPD>AS1 IRD LUKOPR SUPRed ', N'E002', N'@18 C2 D4 EA', 350, N'E6003', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b7b82f4b-2c42-4e06-8a6d-aedff3390c93', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced/Albumin added|1st container', N'PLT AFR ACD-A OPN IRD LUKOPR PLS Red/ALB Add ', N'E024', N'@73 B2 C2 D4 EB H3', 200, N'E5901', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b7e59b1b-c51b-4ed6-aed5-478596d6232c', N'PLASMA|CPDA-1/450mL/<=-18C|ResLeu:NS|Frozen <=72h', N'PLASMA CPDA-1 LUKOPR ', N'E010', N'@BK D2 GD', 225, N'E6090', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b92afa3b-21b2-4e2c-aa15-9adf24eb381f', N'RED BLOOD CELLS|CPD>AS5/500mL/refg|Open|Irradiated|ResLeu:<5log6|Albumin added', N'RBC CPD>AS5 OPN IRD LUKOPR ALB Add ', N'E002', N'@23 B2 C2 D4 E2', 350, N'E6135', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b9b9cbef-79b1-4538-9993-abaab3fbd1bb', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|Plasma reduced|From 5 donors', N'PLT Pool NS OPN IRD PLS Red 5DNR ', N'E022', N'@72 B2 C2 E5 J5', 200, N'E5966', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ba11e29c-0776-4b98-b54b-07dc01431bcc', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<=-18C|Open|>=600mL', N'FFP AFR NaCit OPN LowVol ', N'E012', N'@48 B2 F7', 225, N'E6060', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ba53ca22-c00c-4ec9-a00e-359e1244d8b6', N'POOLED PLATELETS|PASII/XX/20-24C|Irradiated|ResLeu:<1log6|Bacterial monitoring', N'PLT Pool PASII IRD LUKOPR BacMtr ', N'E022', N'@AE C2 D5 N2', 200, N'E6016', 4, 0, 0, 1, N'A', '20090501 09:30:00.333', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ba71d261-a2e9-40b1-af6f-28620bb2530c', N'Frozen RED BLOOD CELLS|None/XX/<-65C|For mnf:noninjectable|Open|Irradiated|ResLeu:<1log6', N'RBC Froz None MNFNI OPN IRD LUKOPR ', N'E004', N'@B7 A3 B2 C2 D5', 200, N'E5825', 87600, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bd22de49-8255-4607-b5ad-7bc3f74bc15a', N'Washed Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|3rd container|Psoralen-treated', N'PLT AFR Wash PASIII LUKOPR Psoraln ', N'E027', N'@B5 D5 H5 K5', 200, N'E5876', 4, 0, 0, 1, N'A', '20090501 09:30:01.023', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bd28eeeb-0d5a-4bf7-9075-6d816b7238ae', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<-25C|For mnf:injectable|Frozen <=6h', N'FFP AFR MNFI ', N'E012', N'@CQ A2 G4', 225, N'E6126', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bdb67d46-c6d8-4962-9dd5-158b3cd02ac8', N'Liquid Apheresis PLASMA|CPD-50/XX/refg|For mnf:injectable', N'PLASMA AFR Liq CPD-50 MNFI ', N'E011', N'@AX A2', 225, N'E6139', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bedaca51-3674-4115-ab91-d39c32a5a964', N'CRYOPRECIPITATE|CPD/500mL/<=-18C|ResLeu:NS', N'CRYO CPD LUKOPR ', N'E028', N'@AN D2', 15, N'E6095', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bf3f2d94-08fc-4583-b11e-43d71309cdc5', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|From 5 donors', N'PLT Pool Wash None OPN IRD 5DNR ', N'E023', N'@71 B2 C2 J5', 200, N'E5916', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bf5af1d8-eab1-40c5-a637-093e6ea83792', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|From 6 donors', N'PLT Pool Wash None OPN IRD 6DNR ', N'E023', N'@71 B2 C2 J6', 200, N'E5917', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bffb5eac-7ca1-4f87-b82f-cfb3b4f2dc65', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|From 8 donors', N'PLT Pool NS OPN LUKOPR 8DNR ', N'E022', N'@72 B2 D4 J8', 200, N'E5976', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c03070a7-4023-47b5-bb32-67bbfaaadac9', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|From 8 donors', N'PLT Pool Wash None OPN LUKOPR 8DNR ', N'E023', N'@71 B2 D4 J8', 200, N'E5933', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c040dec9-92ce-4dad-a7af-fb2b3f8c6052', N'RED BLOOD CELLS|CPD>SAGM/XX/refg|LowVol:anticoag not adj', N'RBC CPD>SAGM LowVol ', N'E002', N'@CL F3', 350, N'E6053', 840, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c061be7a-be99-494a-afeb-3f0984c0ddd4', N'PLATELETS|CPD/450mL/<37C|For mnf:noninjectable restr use', N'PLT CPD MNFRNI ', N'E020', N'@CO A5', 50, N'E6109', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c065f8f0-098c-4d24-b19a-bb3f8b3031de', N'RED BLOOD CELLS|CPD/500mL/refg|Irradiated|ResLeu:<5log6|Plasma added', N'RBC CPD IRD LUKOPR PA ', N'E002', N'@04 C2 D4 E4', 250, N'E6065', 504, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c0d8cf37-d6a4-4e74-afb9-094534627abd', N'POOLED PLATELETS|NS/XX/20-24C|Open|From 4 donors', N'PLT Pool NS OPN 4DNR ', N'E022', N'@72 B2 J4', 200, N'E5937', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c1cefe64-2957-46c7-acf4-2eaf1bf9a37c', N'Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|Supernat reduced|2nd container|Psoralen-treated', N'PLT AFR PASIII LUKOPR SUPRed Psoraln ', N'E024', N'@B5 D5 EA H4 K5', 200, N'E5867', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c1ea67fa-8e68-4274-8e12-2e54d6f90ac6', N'POOLED PLATELETS|CPDA-1/XX/20-24C|Irradiated|Plasma reduced', N'PLT Pool CPDA-1 IRD PLS Red ', N'E022', N'@B8 C2 E5', 200, N'E5997', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c2770ea2-f4c0-4c37-86cd-eedf2d4fc10c', N'PLASMA|CPD/500mL/<=-20C|For mnf:injectable|ResLeu:NS|Frozen <=72h', N'PLASMA CPD MNFI LUKOPR ', N'E010', N'@CE A2 D2 GD', 225, N'E6092', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c4363759-6ce5-4a94-bd83-c77763d63ed9', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 5 donors', N'PLT Pool Wash None OPN IRD LUKOPR 5DNR ', N'E023', N'@71 B2 C2 D4 J5', 200, N'E5923', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c79ecd7d-d158-4753-801c-9d519288c33d', N'RED BLOOD CELLS|CPD>AS3/500mL/refg|ResLeu:<5log6', N'RBC CPD>AS3 LUKOPR ', N'E002', N'@CN D4', 350, N'E6054', 1008, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c81987c7-4563-4dd8-8f40-9d3c5f8a4125', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 4 donors', N'PLT Pool Wash None OPN IRD LUKOPR 4DNR ', N'E023', N'@71 B2 C2 D4 J4', 200, N'E5922', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c929141a-154b-4dc2-9e6f-9538ed7b070b', N'Thawed PLASMA|CP2D/XX/refg|For mnf:noninjectable', N'PLASMA Thaw CP2D MNFNI ', N'E011', N'@13 A3', 225, N'E6078', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c99597e1-408f-4095-8671-fb85e5de16c8', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced|From 6 donors', N'PLT Pool NS OPN IRD LUKOPR PLS Red 6DNR ', N'E022', N'@72 B2 C2 D4 E5 J6', 200, N'E5960', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ca063853-bafd-4b55-9df0-d32f1b7fb71c', N'Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|2nd container|Psoralen-treated', N'PLT AFR PASIII LUKOPR Psoraln ', N'E024', N'@B5 D5 H4 K5', 200, N'E5863', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cadfef5e-7e21-4c7b-86b2-d35558f9627b', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<5log6|Buffy coat plts prep|From 4 donors', N'PLT Pool CPD LUKOPR BUFCT 4DNR ', N'E022', N'@A7 D4 G2 J4', 200, N'E6093', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cb91ae1a-cdff-4517-af26-3510e2f5a6a5', N'POOLED PLATELETS|NS/XX/20-24C|Open|From 6 donors', N'PLT Pool NS OPN 6DNR ', N'E022', N'@72 B2 J6', 200, N'E5939', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cbe2727a-adac-424d-affd-ed5688ccbf34', N'POOLED PLATELETS|NS/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|From 6 donors', N'PLT Pool NS OPN LUKOPR PLS Red 6DNR ', N'E022', N'@72 B2 D4 E5 J6', 200, N'E5981', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cc8b6554-f05e-406b-a831-82f95b06efb9', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|From 4 donors', N'PLT Pool NS OPN IRD 4DNR ', N'E022', N'@72 B2 C2 J4', 200, N'E5944', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cccbdce7-0578-4a07-882c-9c7d9852c204', N'WHOLE BLOOD|CPD/XX/refg|Open|LowVol:anticoag adj', N'WB CPD OPN LowVol ', N'E001', N'@06 B2 F8', 250, N'E5895', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ccd56fc8-0c86-4b3c-be2b-60b489c823fd', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<=-18C|Open|<200 mL', N'FFP AFR NaCit OPN LowVol ', N'E012', N'@48 B2 F4', 225, N'E6084', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cd456fbf-eca3-48c8-a885-d782c39235fd', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|From 7 donors', N'PLT Pool Wash None OPN IRD 7DNR ', N'E023', N'@71 B2 C2 J7', 200, N'E5918', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cd7612d6-fb44-4503-bb53-46eea59249a4', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced|From 3 donors', N'PLT Pool NS OPN IRD LUKOPR PLS Red 3DNR ', N'E022', N'@72 B2 C2 D4 E5 J3', 200, N'E5957', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cda7b464-ee27-40a7-bacc-cf26dae40578', N'PLASMA|CPD/450mL/<-30C|For mnf:injectable|Frozen <=26h', N'PLASMA CPD MNFI ', N'E010', N'@A5 A2 GE', 225, N'E6027', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cdbb653a-d17b-4208-b968-a8b9aa5fdbc4', N'RED BLOOD CELLS|SAGM/XX/refg|ResLeu:<1log6|LowVol:anticoag adj', N'RBC SAGM LUKOPR LowVol ', N'E002', N'@A9 D5 F8', 350, N'E6115', 840, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ce76256a-be0e-4660-8efb-258c5e4e979b', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|From 6 donors', N'PLT Pool Wash None OPN 6DNR ', N'E023', N'@71 B2 J6', 200, N'E5910', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cee6b276-4473-4016-b138-741c69da881c', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<5log6|From 5 donors', N'PLT Pool CPD IRD LUKOPR 5DNR ', N'E022', N'@A7 C2 D4 J5', 200, N'E5832', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd0cc1783-ed8c-45e1-bfd5-8b51261216c5', N'Liquid Apheresis PLASMA|CPD-50/XX/refg|Psoralen-treated', N'PLASMA AFR Liq CPD-50 Psoraln ', N'E011', N'@AX K5', 225, N'E6138', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd1edf988-8d00-48fd-ba49-8e3885a38506', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|From 5 donors', N'PLT Pool Wash None OPN 5DNR ', N'E023', N'@71 B2 J5', 200, N'E5909', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd1f1de75-7f53-4037-96c1-b882bf1dd380', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg', N'RBC CPD>SAGM ', N'E002', N'@CM ', 350, N'E6052', 840, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd2efc87e-0329-4387-a6b6-4bea0c0a8d37', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 7 donors', N'PLT Pool NS OPN IRD LUKOPR 7DNR ', N'E022', N'@72 B2 C2 D4 J7', 200, N'E5954', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd4575c01-4943-4633-b835-9b05f5cc64af', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg|Irradiated|ResLeu:<5log6', N'RBC CPD>SAGM IRD LUKOPR ', N'E002', N'@CM C2 D4', 350, N'E6051', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd4704289-b537-4983-8c33-a482fb281aa9', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Irradiated|ResLeu:<5log6|Supernat rem/Plasma added|2nd container', N'RBC AFR ACD-A>AS3 IRD LUKOPR SR/PA ', N'E009', N'@AZ C2 D4 E8 H4', 350, N'E5852', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd69cfd6c-ed62-463a-a55e-dd68fb2b23dd', N'Apheresis GRANULOCYTES|ACD-A/XX/rt|Open', N'GRAN AFR ACD-A OPN', N'E035', N'@93 B2', 150, N'E6142', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd70ae5a3-bbbd-4b5f-8875-571198f10357', N'Washed Apheresis PLATELETS|None/XX/20-24C|ResLeu:<1log6|4th container|Psoralen-treated', N'PLT AFR Wash None LUKOPR Psoraln ', N'E027', N'@71 D5 H6 K5', 200, N'E5873', 4, 0, 0, 1, N'A', '20090501 09:30:01.007', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd8869f80-8bbf-4027-bf39-f19be256b2f9', N'POOLED PLATELETS|NS/XX/20-24C|Open|Plasma reduced|From 3 donors', N'PLT Pool NS OPN PLS Red 3DNR ', N'E022', N'@72 B2 E5 J3', 200, N'E5985', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'da1bbe56-235d-47ca-94bd-e38163d1cc78', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced|From 2 donors', N'PLT Pool NS OPN IRD LUKOPR PLS Red 2DNR ', N'E022', N'@72 B2 C2 D4 E5 J2', 200, N'E5956', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'db21c4cf-5a01-411f-92f8-b936ac314516', N'PLASMA|CP2D/450mL/<=-18C|ResLeu:NS|Frozen <=72h', N'PLASMA CP2D LUKOPR ', N'E010', N'@BJ D2 GD', 225, N'E6089', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'dc799c21-ba00-4983-9543-03cc4c3ea9f5', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|From 7 donors', N'PLT Pool Wash None OPN 7DNR ', N'E023', N'@71 B2 J7', 200, N'E5911', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'dcdbdd69-4311-4e03-ac7b-995d916e9d47', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<5log6|Buffy coat plts prep|From 4 donors', N'PLT Pool CPD IRD LUKOPR BUFCT 4DNR ', N'E022', N'@A7 C2 D4 G2 J4', 200, N'E6094', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'dceeb1db-7b3c-4ec9-bdae-a9200b0c76b6', N'PLATELETS|CPD/450mL/20-24C|Open|Plasma reduced/Plasma added', N'PLT CPD OPN ', N'E020', N'@64 B2 EE', 50, N'E6037', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e05826ca-9fce-459f-a3b0-22eec8e372ea', N'Apheresis PLASMA|NaCitrate/XX/<=-20C|For mnf:injectable|Open', N'PLASMA AFR NaCit MNFI OPN ', N'E012', N'@58 A2 B2', 225, N'E6071', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e0669ed9-a4dd-45fc-990f-4238d4e6b015', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<=-18C|Open|>=200mL<400mL', N'FFP AFR NaCit OPN LowVol ', N'E012', N'@48 B2 F5', 225, N'E6058', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e0a2b2d2-8d04-4e0a-8323-83403a2cb09b', N'Thawed Apheresis PLASMA|CP2D/XX/refg|>=200mL<400mL', N'PLASMA AFR Thaw CP2D LowVol ', N'E013', N'@13 F5', 225, N'E6075', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e0b3f782-18ae-4419-9135-a586751dfdf2', N'Deglycerolized RED BLOOD CELLS|None/450mL/refg|Irradiated|ResLeu:<1log6', N'RBC Deg None IRD LUKOPR ', N'E006', N'@17 C2 D5', 200, N'E6116', 336, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e16fe8b7-fbbe-4c21-9578-0bac909a25ae', N'RED BLOOD CELLS|CP2D/500mL/refg|Open|ResLeu:<5log6|Plasma added', N'RBC CP2D OPN LUKOPR PA', N'E002', N'@12 B2 D4 E4', 250, N'E6153', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e2dc2a83-68bf-4289-a3e8-d18db4475729', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC AFR ACD-A>AS3 OPN IRD LUKOPR PA', N'E009', N'@AZ B2 C2 D4 E4', 350, N'E6147', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e3beed79-3557-466c-b2c1-bf7bf917a9b8', N'POOLED PLATELETS|NS/XX/20-24C|Open|Plasma reduced|From 7 donors', N'PLT Pool NS OPN PLS Red 7DNR ', N'E022', N'@72 B2 E5 J7', 200, N'E5989', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e4793320-91ab-4ba1-8739-31c67d31f6f1', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<5log6|Bacterial test', N'PLT Pool CPD LUKOPR BacTest ', N'E022', N'@A7 D4 N3', 200, N'E6001', 4, 0, 0, 1, N'A', '20090501 09:30:00.320', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e4815924-ed0b-4dd2-b222-f1a0d412caf4', N'Apheresis GRANULOCYTES|ACD-A/XX/rt|Irradiated', N'GRAN AFR ACD-A IRD ', N'E035', N'@93 C2', 150, N'E5934', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e55c2a15-b9a0-4bce-9fb9-ece501459f32', N'Washed Apheresis PLATELETS|PASIII/XX/20-24C|ResLeu:<1log6|1st container|Psoralen-treated', N'PLT AFR Wash PASIII LUKOPR Psoraln ', N'E027', N'@B5 D5 H3 K5', 200, N'E5874', 4, 0, 0, 1, N'A', '20090501 09:30:01.007', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e72d380c-94e2-40e8-b43a-8a187f222d48', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<-30C|ResLeu:<5log6|Methylene blue-treated', N'FFP AFR NaCit LUKOPR Methyl Blue ', N'E012', N'@CH D4 K3', 225, N'E6121', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e80d9a6f-93e7-42e5-a5c3-0c88db90f237', N'Thawed POOLED PLASMA|CPD/XX/refg|Open', N'PLASMA Pool Thaw CPD OPN', N'E011', N'@06 B2', 500, N'E6141', 24, 0, 0, 1, N'A', '20090501 09:29:58.130', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e8c5f842-5440-4c8d-92b8-c64de6a63e27', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<=-18C|Open|>=400mL<600mL', N'FFP AFR NaCit OPN LowVol ', N'E012', N'@48 B2 F6', 225, N'E6059', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e95a08fe-5a17-4053-908d-4b7a600c8780', N'PLASMA|CPDA-1/500mL/<=-20C|For mnf:injectable|Frozen <=8h', N'PLASMA MNFI ', N'E010', N'@CT A2 GB', 225, N'E6132', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e9b044ed-0f4c-44d0-a224-db940c81d38b', N'RED BLOOD CELLS|CP2D>AS3/500mL/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC CP2D>AS3 OPN IRD LUKOPR PA', N'E002', N'@21 B2 C2 D4 E4', 350, N'E6148', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'eb748a03-faf6-459b-9689-b326364e029b', N'RED BLOOD CELLS|CPD>AS1/500mL/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC CPD>AS1 OPN IRD LUKOPR PA ', N'E002', N'@19 B2 C2 D4 E4', 350, N'E6128', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ec68a1fe-9c8b-4a56-b481-c4830767bb06', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced/Albumin added', N'PLT AFR ACD-A OPN IRD LUKOPR PLS Red/ALB Add ', N'E024', N'@73 B2 C2 D4 EB', 200, N'E5900', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ecf538e8-da49-4f2c-ac07-d641609daef8', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|From 6 donors', N'PLT Pool Wash None OPN IRD LUKOPR 6DNR ', N'E023', N'@71 B2 C2 D4 J6', 200, N'E5924', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ed700890-6743-4063-94ac-17c0d92453a2', N'POOLED PLATELETS|NS/XX/20-24C|Open|Plasma reduced|From 5 donors', N'PLT Pool NS OPN PLS Red 5DNR ', N'E022', N'@72 B2 E5 J5', 200, N'E5987', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ee46367a-5765-4cd7-a920-5aad44fb90ce', N'RED BLOOD CELLS|CP2D/500mL/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC CP2D OPN IRD LUKOPR PA', N'E002', N'@12 B2 C2 D4 E4', 250, N'E6155', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ef197bb0-d99c-4c5f-a7c4-64d1fb345d73', N'Thawed Apheresis PLASMA|ACD-A/XX/refg|For mnf:noninjectable', N'PLASMA AFR Thaw ACD-A MNFNI ', N'E013', N'@54 A3', 225, N'E6098', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f0a745d3-a843-47d1-8a46-778947e3fe35', N'Thawed POOLED PLASMA|CP2D/XX/refg|Open', N'PLASMA Pool Thaw CP2D OPN ', N'E011', N'@13 B2', 500, N'E6036', 24, 0, 0, 1, N'A', '20090501 09:29:58.117', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f29a0418-1c9d-4b24-8bf2-bdacc3a37701', N'Thawed Apheresis PLASMA|NaCitrate/XX/refg|For mnf:noninjectable|<200 mL', N'PLASMA AFR Thaw NaCit MNFNI LowVol ', N'E013', N'@55 A3 F4', 225, N'E6104', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f85f4bcd-8101-488d-83f7-37f4c38b8728', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|Open|Irradiated|ResLeu:<5log6|Supernat reduced|1st container', N'RBC AFR CP2D>AS3 OPN IRD LUKOPR SUPRed ', N'E009', N'@33 B2 C2 D4 EA H3', 350, N'E5845', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f87cbf4d-bde8-499c-b2c6-4984479da587', N'Thawed Apheresis PLASMA|CP2D/XX/refg|Irradiated', N'PLASMA AFR Thaw CP2D IRD ', N'E013', N'@13 C2', 225, N'E5887', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f8afe733-e4c6-4384-a500-4dd073375da2', N'Apheresis PLATELETS|PASIII/XX/20-24C|For mnf:injectable|ResLeu:<1log6|2nd container', N'PLT AFR PASIII MNFI LUKOPR ', N'E024', N'@B5 A2 D5 H4', 200, N'E5859', 120, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f90e681b-4ab6-4226-b8c5-d945c8716399', N'WHOLE BLOOD|CPD/500mL/refg|Plasma reduced', N'WB CPD PLS Red ', N'E001', N'@04 E5', 500, N'E6045', 504, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'faafd4bb-9da0-44dc-b186-2f8f9d68ecf7', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|Open|Irradiated|ResLeu:<5log6|Supernat reduced', N'RBC AFR CP2D>AS3 OPN IRD LUKOPR SUPRed ', N'E009', N'@33 B2 C2 D4 EA', 350, N'E5844', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fd229296-0e0e-44fd-be9c-1e010c0393ae', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|From 4 donors', N'PLT Pool Wash None OPN IRD 4DNR ', N'E023', N'@71 B2 C2 J4', 200, N'E5915', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fd5ddc9b-cbfd-4b20-89ed-0011af4030d9', N'PLASMA|CP2D/XX/<=-20C|For mnf:injectable|Frozen <=120h', N'PLASMA CP2D MNFI ', N'E010', N'@BS A2 G9', 225, N'E6022', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fe5cd257-07bc-4cb3-91d8-8e6d3a24ed23', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<=-18C|ResLeu:NS', N'FFP CPDA-1 LUKOPR ', N'E010', N'@BK D2', 225, N'E6087', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fe8cd70e-79a7-4d60-a003-c8ae2c811fb7', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced/Albumin added|2nd container', N'PLT AFR ACD-A OPN LUKOPR PLS Red/ALB Add ', N'E024', N'@73 B2 D4 EB H4', 200, N'E5898', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fe9a7a2d-cc95-4b89-9740-89f3b3d55e17', N'Rejuvenated Apheresis RED BLOOD CELLS|None/XX/refg|Open|Irradiated|ResLeu:<5log6', N'RBC AFR Rej None OPN IRD LUKOPR ', N'E052', N'@AS B2 C2 D4', 200, N'E5993', 24, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fedbf2c2-81d8-479f-8a76-fb432959acf9', N'Apheresis PLASMA|NaCitrate/XX/<=-20C|For mnf:noninjectable|Open', N'PLASMA AFR NaCit MNFNI OPN ', N'E012', N'@58 A3 B2', 225, N'E6072', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fefd88b7-e6c6-481b-84e3-5042e9fc20ca', N'POOLED PLATELETS|NS/XX/20-24C|Open|From 3 donors', N'PLT Pool NS OPN 3DNR ', N'E022', N'@72 B2 J3', 200, N'E5936', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ff3e6a96-e172-4ad3-a095-21dc2cea1bb0', N'PLASMA|CPD/500mL/<=-18C|ResLeu:NS|Frozen <=24h', N'PLASMA CPD LUKOPR ', N'E010', N'@AN D2 G7', 225, N'E6086', 8760, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ff6ef693-1f2b-4a1f-b7ec-e8b796fa83c7', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|Irradiated|ResLeu:<5log6|Supernat rem/Plasma added|1st container', N'RBC AFR ACD-A>AS3 IRD LUKOPR SR/PA ', N'E009', N'@AZ C2 D4 E8 H3', 350, N'E5851', 672, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ff98f251-d148-4089-aa31-d91be323d1d7', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|From 5 donors', N'PLT Pool NS OPN IRD 5DNR ', N'E022', N'@72 B2 C2 J5', 200, N'E5945', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fff2bde3-7a9c-4574-bc5f-839a8528af48', N'POOLED PLATELETS|NS/XX/20-24C|Open|Irradiated|From 3 donors', N'PLT Pool NS OPN IRD 3DNR ', N'E022', N'@72 B2 C2 J3', 200, N'E5943', 4, 0, 0, 1, N'A', '20081201 15:03:53.193', N'vhaishsmithm', 0)

-- Add 1 row to dbo.BrokenRule
INSERT INTO dbo.BrokenRule (FormName, FieldName, ValidationMessage, LastUpdateDate, LastUpdateUser) VALUES (N'VbecsUser', N'DivisionDuzMismatch', N'The divisions do not match the DUZ entered.  Please clear data and re-enter.', '20090203 00:00:00.000', N'vhaishjensec')

-- Add 1 row to dbo.BrokenRuleSet
INSERT INTO dbo.BrokenRuleSet (RuleSet, FormName, FieldName, IsInitiallyBroken, LastUpdateDate, LastUpdateUser) VALUES (N'BaseRuleSet', N'VbecsUser', N'DivisionDuzMismatch', 0, '20090203 00:00:00.000', N'vhaishjensec')

-- Add 2 rows to dbo.RoleFunction
INSERT INTO dbo.RoleFunction (RoleFunctionId, RoleFunctionText, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (40, N'Edit a Patient''s Transfusion Record.', 0, '20081122 00:45:38.767', N'VHAISHASKEWD', 0)
INSERT INTO dbo.RoleFunction (RoleFunctionId, RoleFunctionText, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (41, N'Remove a Blood Unit''s Final Status.', 0, '20081122 00:46:41.687', N'VHAISHASKEWD', 0)

-- Add 2 rows to dbo.UserRoleFunction
INSERT INTO dbo.UserRoleFunction (RoleFunctionId, UserRoleId, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (40, 4, '20081122 00:58:57.883', N'VHAISHASKEWD', 0)
INSERT INTO dbo.UserRoleFunction (RoleFunctionId, UserRoleId, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (41, 4, '20081122 00:58:57.883', N'VHAISHASKEWD', 0)

-- Add 2 rows to dbo.PermittedProductModification
ALTER TABLE dbo.PermittedProductModification DISABLE TRIGGER trMirrorPermittedProductModification

UPDATE PermittedProductModification SET ExpirationDateRule = 4, LastUpdateDate = '2009-04-16 09:35:52.993', LastUpdateUser = 'vhaishsmithm' WHERE PermittedProductModificationGuid = '0F4111F7-1D64-473A-ADC6-3CA215B188E6'
UPDATE PermittedProductModification SET ExpirationDateRule = 4, LastUpdateDate = '2009-04-16 09:35:52.993', LastUpdateUser = 'vhaishsmithm' WHERE PermittedProductModificationGuid = '21A43116-2A91-4C56-8ADF-C456DBA871C6'

ALTER TABLE dbo.PermittedProductModification ENABLE TRIGGER trMirrorPermittedProductModification
GO
								   
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.fnFileManDateTimeConversionToDateTime') and OBJECTPROPERTY(id, N'IsScalarFunction') = 1)
drop function dbo.fnFileManDateTimeConversionToDateTime
GO
/*****************************************************************************************************************
**
**  Desc:   This function converts  a FileMan date and time and time zone to a SQL DateTime
**
**  Author: Brian Tomlin
**
**  Date:   06/15/2004
**
**  Notes:
**		FileMan date time format is YYYMMDD.HHMMSS   (the format can vary slighty by site)
** 		Sample Conversions ---
**	INPUT               OUTPUT
**	-------------		---------------------
**	3090309      2009-03-09 00:00:00.000
**	3090309.     2009-03-09 00:00:00.000
**	3090309.1      2009-03-09 00:00:00.000
**	3090309.12     2009-03-09 12:00:00.000
**	3090309.123     2009-03-09 12:00:00.000
**	3090309.1234    2009-03-09 12:34:00.000
**	3090309.12345      2009-03-09 12:34:00.000
**	3090309.123456     2009-03-09 12:34:56.000
**	3090309.1234567    2009-03-09 12:34:56.000
**
**	3090009.1234567    2009-01-09 12:34:56.000
**	3090300.1234567    2009-03-01 12:34:56.000
**	3090000.000001     2009-01-01 00:00:01.000
**
******************************************************************************************************************
**  Modified:
**  Date        	Name    	Description
**  ---------	----------		-----------------------------------------------------
**  07/07/2005	S. Antropov	** Reviewed for compliance with database standards and recommendations **
**				 reformatted SQL, updated the comment header, removed unused variables
**  03/13/09	Lohse		Addressed CR2416. Corrected rampant REPLACE function and TIME conversion
** 03/19/09	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
******************************************************************************************************************/

CREATE    FUNCTION dbo.fnFileManDateTimeConversionToDateTime
( 
	@sourcedatetime VARCHAR(25)
)

RETURNS DATETIME
AS  

BEGIN

    DECLARE @fmDate VARCHAR(35)
    DECLARE @sqlDate VARCHAR(10)
    DECLARE @fmtyear VARCHAR(4)
    DECLARE @sourceLen INT

    SET @sourceLen = LEN(@sourcedatetime)

    SET @fmtyear = LEFT( @sourcedatetime, 3 ) + 1700
    SET @fmDate = @fmtyear + SUBSTRING(@sourcedatetime, 4, @sourceLen-3)

	
    SET @sqlDate =    SUBSTRING( @fmDate, 1, 4 ) 
                    + '-' 
                    + CASE WHEN SUBSTRING( @fmDate, 5, 2 )  = '00' THEN '01' ELSE  SUBSTRING( @fmDate, 5, 2 ) END
                    + '-' 
	       + CASE WHEN SUBSTRING( @fmDate, 7, 2 )  = '00' THEN '01' ELSE  SUBSTRING( @fmDate, 7, 2 ) END
    


    RETURN
    (
	CASE
		WHEN (@sourceLen < 10) THEN 
			CAST( @sqlDate AS DATETIME )
		WHEN (@sourceLen BETWEEN 10 AND 11) THEN
			CAST(@sqlDate + ' ' + SUBSTRING(@sourcedatetime, 9, 2) + ':00:00' AS DATETIME)
		WHEN (@sourceLen BETWEEN 12 AND 13) THEN
			CAST(@sqlDate + ' ' + SUBSTRING(@sourcedatetime, 9, 2) + ':' + SUBSTRING(@sourcedatetime, 11, 2) + ':00'  AS DATETIME)
		WHEN @sourceLen >= 14 THEN
			CAST(@sqlDate + ' ' + SUBSTRING(@sourcedatetime, 9, 2) + ':' + SUBSTRING(@sourcedatetime, 11, 2)  + ':' + + SUBSTRING( @sourcedatetime, 13, 2 ) AS DATETIME)
		ELSE
			CAST( @sqlDate AS DATETIME )

	END
    )

END
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.fnGetABORhTable') and OBJECTPROPERTY(id, N'IsTableFunction') = 1)
drop function dbo.fnGetABORhTable
GO

SET ANSI_NULLS OFF
GO
/*******************************************************************************************************************************************************************************
**
**	Desc:	Gets the patient's current ABO/Rh and realted information.  This function is composed of two parts: 
**         		The first part retrieves all of the valid and complete specimen tests. Complete means that both the ABO 
**        		 and Rh parts are complete.  If not complete, the test is ignored.
** 
**        		 In part two, the ABO/Rh is calculated.  There are 3 different possibilities:
**         		1) There are no specimen tests, so the ABO/Rh must be retrieved from the Patient record.
**         		2) There is one complete ABO/Rh test.  In this case, it is compared with the Patient record for consistency.
**         		3) There are 2 or more complete ABO/Rh tests.  In this case, the most recent test is compared with the 
**            	previous for consistency. It is not necessary to go back any further since new ABO/Rh tests may 
**            	not be entered when there is an inconsistency.
**
**         		The function accepts the parameter @patientguid - report start date
**		
**         		Output table columns: 
**                               			ABO            	- Patient's current ABO
**                               			Rh             	- Patient's current Rh
**                               			TestDate       	- Date of test (NULL if ABO/Rh from patient record)
**                               			TestDivision   	- Division of test (NULL if ABO/Rh from patient record)
**                               			Justified      	- Indicates if this test result was justified
**                               			Discrepancy    	- Indicates it there is a discrepancy in test results.  If this is true, 
**                                                				the ABO/Rh returned is actually the previous one since the newest one
**                                                				disagrees with the historical record.
**
**	Author:	Carl Jensen
**
**	Date: 	12/8/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**  	12/13/2004  	C. Jensen   	Applied 2 fixes: 1) Added ORDER BY clauses.  2) Added a  counter to the fetch statements.
**  	07/20/2005  	C. Jensen   	Added specimenguid to table so we know where ABO/Rh came from
**  	08/08/2005  	S. Antropov 	** Reviewed for compliance with database standards and recommendations **
**                          			Removed cursors, restructured conditionals, removed duplicate code, added object owner prefix
**                          			to table names, reformatted SQL 
** 	08/12/2005 	C. Jensen   	Added "AND dbo.SpecimenTest.TestResultId IS NOT NULL" to WHERE clauses to fix bug
** 	01/14/2006	D. Askew	Added code to bring back the valid patient guid(s).  Added more code to handle multiple guids,
**					which we will find if the patient in question has a history of merged data
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	03/16/2010	K. Dobranowski	Added check for the completeness of ABO/Rh test to WHERE clause for abo and rh results (CR 2781)
**					This function is unit tested in DAL.Patient in [UnitTestAttribute(5956)] GetPatientABORh_Pass()
**	03/24/2010	M Smith		** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE FUNCTION dbo.fnGetABORhTable
(
   @patientguid UNIQUEIDENTIFIER = NULL
)
RETURNS @bloodType TABLE 
(
	ABO                 		VARCHAR(2),
	Rh                  		VARCHAR(2),
	TestDate            	DATETIME,
	TestDivision        	VARCHAR(5),
	Justified           		BIT,
	Discrepancy         	BIT,
	PatientSpecimenGuid 	UNIQUEIDENTIFIER
)

AS
	
BEGIN
    
	DECLARE @abo TABLE 
	(
		ABO                		VARCHAR(2),
		TestDate 	        	DATETIME,
		TestID 		        	INT,
		Justified		    	BIT,
		TestDivision        	VARCHAR(5),
		OrderedTestGuid     	UNIQUEIDENTIFIER, 
		PatientSpecimenGuid 	UNIQUEIDENTIFIER
	)

	DECLARE @rh TABLE 
	(
		Rh                  		VARCHAR(2),
		TestDate            	DATETIME,
		TestID              		INT,
		Justified           		BIT,
		TestDivision        	VARCHAR(5),
		OrderedTestGuid     	UNIQUEIDENTIFIER,
		PatientSpecimenGuid 	UNIQUEIDENTIFIER
	)

	DECLARE @recordCount         		INT

	--This stores the number of complete ABO/Rh results from the DB
	DECLARE @validRecordCount    	INT

	-- Used for cases where the patient data has been merged to help determine which ABO\Rh record to use
	DECLARE @patientguidcount 		INT 
	DECLARE @validabocount 		INT
	DECLARE @validrhcount 		INT

	DECLARE @TestId              		INT
	DECLARE @Justified           		BIT
	
	DECLARE @TestResult          		VARCHAR(2)
	DECLARE @TestDivision        		VARCHAR(5)

	DECLARE @TestDate            		DATETIME

	DECLARE @PatientSpecimenGuid 	UNIQUEIDENTIFIER
	DECLARE @OrderedTestGuid     	UNIQUEIDENTIFIER


	-- ****************************************************************************************************************************************************************************************************************
	SET @patientguidcount = 
	(
		SELECT 
			COUNT(*) 
		FROM 
			dbo.Patient P 
			JOIN 
				dbo.Patient LinkPatient ON P.PatientMergeGroup = LinkPatient.PatientMergeGroup OR P.PatientGuid = LinkPatient.PatientGuid 
		WHERE 
			LinkPatient.PatientGuid = @patientguid
	)
	-- ****************************************************************************************************************************************************************************************************************
	SET @validabocount = 
	(
		SELECT 
			COUNT(*) 
		FROM 
			dbo.Patient
		WHERE 
			PatientGuid IN
			(
				SELECT 
					P.PatientGuid 
				FROM 
					dbo.Patient P 
					JOIN 
						dbo.Patient LinkPatient ON P.PatientMergeGroup = LinkPatient.PatientMergeGroup OR P.PatientGuid = LinkPatient.PatientGuid 
				WHERE 
					LinkPatient.PatientGuid = @patientguid
			)
			AND BloodTypeCode IN ('A', 'AB', 'B', 'I', 'O')
	)
	-- ****************************************************************************************************************************************************************************************************************
	SET @validrhcount = 
	(
		SELECT 
			COUNT(*) 
		FROM 
			dbo.Patient
		WHERE 
			PatientGuid IN
			(
				SELECT 
					P.PatientGuid 
				FROM 
					dbo.Patient P 
					JOIN 
						dbo.Patient LinkPatient ON P.PatientMergeGroup = LinkPatient.PatientMergeGroup OR P.PatientGuid = LinkPatient.PatientGuid 
				WHERE 
					LinkPatient.PatientGuid = @patientguid
			)
			AND RhFactorCode IN ('I', 'N', 'P')
	)   


-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
--****PART1****PART1****PART1****PART1****PART1****PART1****PART1****PART1****PART1****PART1****PART1****PART1
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	INSERT INTO @abo 
	(       
		ABO, 
		TestDate, 
		TestID, 
		Justified, 
		TestDivision, 
		OrderedTestGuid, 
		PatientSpecimenGuid
	)
	SELECT 
		TestResultId,
		CASE WHEN AboTestDate > RhTestDate THEN AboTestDate ELSE RhTestDate END AS TestDate,
		BloodTestTypeId,
		AboRhChangeIndicator,
		DivisionCode,
		OrderedTestGuid,
		PatientSpecimenGuid
	FROM
	(
		SELECT TOP 2
			TestResultId,
			TestDate AS AboTestDate,
			( 	SELECT  TOP 1 
					TestDate 
				FROM  
					dbo.SpecimenTest AS InlineSpecimenTest
				WHERE   
					InlineSpecimenTest.OrderedTestGuid = dbo.SpecimenTest.OrderedTestGuid
					AND InlineSpecimenTest.TestResultId IS NOT NULL
					AND ( 
					( dbo.SpecimenTest.BloodTestTypeId = 18 AND InlineSpecimenTest.BloodTestTypeId = 21 )
					OR
					( dbo.SpecimenTest.BloodTestTypeId = 65 AND InlineSpecimenTest.BloodTestTypeId = 68 )
					)
			) AS RhTestDate,
			BloodTestTypeId,
			AboRhChangeIndicator,
			dbo.SpecimenTest.DivisionCode,
			OrderedTestGuid,
			dbo.SpecimenTest.PatientSpecimenGuid
		FROM 
			dbo.SpecimenTest
		JOIN 
			dbo.PatientSpecimen ON dbo.SpecimenTest.PatientSpecimenGuid = dbo.PatientSpecimen.PatientSpecimenGuid
		WHERE
			dbo.PatientSpecimen.PatientGuid = @patientguid 
			AND dbo.SpecimenTest.RecordStatusCode = 'A' 
			AND dbo.SpecimenTest.BloodTestTypeId IN (18, 65)
			AND dbo.SpecimenTest.TestResultId IS NOT NULL
			AND dbo.fnIsABORhTestComplete(dbo.SpecimenTest.OrderedTestGuid, dbo.SpecimenTest.BloodTestTypeID) IS NOT NULL
		ORDER BY 
			AboTestDate DESC
		) PF
	WHERE 
		AboTestDate IS NOT NULL
	ORDER BY 
		TestDate DESC
	
	SET @recordCount = @@ROWCOUNT   
  
	-- ****************************************************************************************************************************************************************************************************************
	IF @recordCount > 0 -- if there're no records for ABO, then results are not on file, no point to continue
	BEGIN
		INSERT INTO @rh 
		(       
			RH, 
			TestDate, 
			TestID, 
			Justified, 
			TestDivision, 
			OrderedTestGuid, 
			PatientSpecimenGuid
		)
		SELECT 
			TestResultId,
			CASE WHEN RhTestDate > AboTestDate THEN RhTestDate ELSE AboTestDate END AS TestDate,
			BloodTestTypeId,
			AboRhChangeIndicator,
			DivisionCode,
			OrderedTestGuid,
			PatientSpecimenGuid
		FROM
			(
				SELECT TOP 2
					TestResultId,
					TestDate AS RhTestDate,
					( 	SELECT  TOP 1 
							TestDate 
						FROM  
							dbo.SpecimenTest AS InlineSpecimenTest
						WHERE   
							InlineSpecimenTest.OrderedTestGuid = dbo.SpecimenTest.OrderedTestGuid
							AND InlineSpecimenTest.TestResultId IS NOT NULL
							AND ( 
							( dbo.SpecimenTest.BloodTestTypeId = 21 AND InlineSpecimenTest.BloodTestTypeId = 18 )
							OR
							( dbo.SpecimenTest.BloodTestTypeId = 68 AND InlineSpecimenTest.BloodTestTypeId = 65 )
							)
					) AS AboTestDate,
					BloodTestTypeId,
					AboRhChangeIndicator,
					dbo.SpecimenTest.DivisionCode,
					OrderedTestGuid,
					dbo.SpecimenTest.PatientSpecimenGuid
				FROM 
					dbo.SpecimenTest
					JOIN 
						dbo.PatientSpecimen ON dbo.SpecimenTest.PatientSpecimenGuid = dbo.PatientSpecimen.PatientSpecimenGuid
				WHERE
					dbo.PatientSpecimen.PatientGuid = @patientguid 
					AND dbo.SpecimenTest.RecordStatusCode = 'A' 
					AND dbo.SpecimenTest.BloodTestTypeId IN (21, 68)
					AND dbo.SpecimenTest.TestResultId IS NOT NULL
					AND dbo.fnIsABORhTestComplete(dbo.SpecimenTest.OrderedTestGuid, dbo.SpecimenTest.BloodTestTypeID) IS NOT NULL
				ORDER BY 
					RhTestDate DESC
			) PF
		WHERE 
			RhTestDate IS NOT NULL
		ORDER BY 
			TestDate DESC
		
		SET @validRecordCount = @@ROWCOUNT
	END
    		
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
--****PART2****PART2****PART2****PART2****PART2****PART2****PART2****PART2****PART2****PART2****PART2****PART2
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
	--Situation 1: The patient has no complete ABO/Rh tests on file.  The system must look to the patient record to get the ABO/Rh.

	IF (@validRecordCount IS NULL OR @validRecordCount = 0) AND @patientguidcount <= 1
	BEGIN
		--There is no ABO/Rh in the Patient record / Patient record contains an ABO/Rh (TEST CASE #1, #2, #3)
		INSERT INTO 
			@bloodType( ABO, Rh, TestDate, TestDivision,  Justified, Discrepancy, PatientSpecimenGuid ) 
		SELECT
			BloodTypeCode, RhFactorCode, NULL, NULL, 0, 0, NULL
		FROM 
			dbo.Patient
		WHERE 
			PatientGuid IN
			(
				SELECT 
					P.PatientGuid 
				FROM 
					dbo.Patient P 
						JOIN dbo.Patient LinkPatient ON P.PatientMergeGroup = LinkPatient.PatientMergeGroup OR P.PatientGuid = LinkPatient.PatientGuid 
				WHERE 
					LinkPatient.PatientGuid = @patientguid
			)
			
		IF @@ROWCOUNT = 0 -- Patient not found
			INSERT INTO @bloodType( ABO, Rh, TestDate, TestDivision,  Justified, Discrepancy, PatientSpecimenGuid ) 
			VALUES( NULL, NULL, NULL, NULL, 0, 0, NULL )
		
		RETURN
	END
	-- *************************************************************************************************************************************************************************************************************************************************************************************
	ELSE IF (@validRecordCount IS NULL OR @validRecordCount = 0) AND @patientguidcount > 1 AND @validabocount > 0 AND @validrhcount > 0
	BEGIN
		-- One or more valid ABO\Rh rows for multiple patient guids => merged records, we get the most recent valid one
		--There is no ABO/Rh in the Patient record / Patient record contains an ABO/Rh (TEST CASE #1, #2, #3)
		INSERT INTO 
			@bloodType( ABO, Rh, TestDate, TestDivision,  Justified, Discrepancy, PatientSpecimenGuid ) 
		SELECT TOP 1
			BloodTypeCode, RhFactorCode, NULL, NULL, 0, 0, NULL
		FROM 
			dbo.Patient
		WHERE 
			PatientGuid IN
			(
				SELECT 
					P.PatientGuid 
				FROM 
					dbo.Patient P 
						JOIN dbo.Patient LinkPatient ON P.PatientMergeGroup = LinkPatient.PatientMergeGroup OR P.PatientGuid = LinkPatient.PatientGuid 
				WHERE 
					LinkPatient.PatientGuid = @patientguid
			)
		AND BloodTypeCode IN ('A', 'AB', 'B', 'I', 'O')
		AND RhFactorCode IN ('I', 'N', 'P')
		ORDER BY LastUpdateDate DESC
		
		RETURN
	END
	-- *************************************************************************************************************************************************************************************************************************************************************************************
	ELSE IF (@validRecordCount IS NULL OR @validRecordCount = 0) AND @patientguidcount > 1
	BEGIN
		-- No valid ABO\Rh for multiple patient guids => merged records, we get the most recent one
		--There is no ABO/Rh in the Patient record / Patient record contains an ABO/Rh (TEST CASE #1, #2, #3)
		INSERT INTO 
			@bloodType( ABO, Rh, TestDate, TestDivision,  Justified, Discrepancy, PatientSpecimenGuid ) 
		SELECT TOP 1
			BloodTypeCode, RhFactorCode, NULL, NULL, 0, 0, NULL
		FROM 
			dbo.Patient
		WHERE 
			PatientGuid IN
			(
				SELECT 
					P.PatientGuid 
				FROM 
					dbo.Patient P 
						JOIN dbo.Patient LinkPatient ON P.PatientMergeGroup = LinkPatient.PatientMergeGroup OR P.PatientGuid = LinkPatient.PatientGuid 
				WHERE 
					LinkPatient.PatientGuid = @patientguid
			)
		ORDER BY LastUpdateDate DESC
		
		RETURN
	END

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
	--Situation 2: The patient has one set of complete ABO/Rh tests on file.
	IF @validRecordCount = 1
	BEGIN
		DECLARE @abopatient             VARCHAR(2)
		DECLARE @rhpatient              VARCHAR(2)
		DECLARE @aboSpecimenTestCurrent VARCHAR(2)
		DECLARE @rhSpecimenTestCurrent  VARCHAR(2)
		
		--Specimen test results
		SELECT 
			@aboSpecimenTestCurrent = RTRIM( abo ),
			@TestDivision = TestDivision,
			@TestDate = TestDate, 
			@Justified = Justified,
			@patientSpecimenGuid = PatientSpecimenGuid
		FROM 
			@abo
		
		SELECT 
			@rhSpecimenTestCurrent = RTRIM( rh )
		FROM
			@rh
		
		IF  @patientguidcount = 1
		BEGIN
			SELECT 
				@abopatient = BloodTypeCode, 
				@rhpatient = RhFactorCode
			FROM 
				dbo.Patient
			WHERE
				PatientGuid IN
				(
					SELECT 
						P.PatientGuid 
					FROM 
						dbo.Patient P 
							JOIN dbo.Patient LinkPatient ON P.PatientMergeGroup = LinkPatient.PatientMergeGroup OR P.PatientGuid = LinkPatient.PatientGuid 
					WHERE 
						LinkPatient.PatientGuid = @patientguid
				)
		END
		ELSE
		BEGIN
			-- One or more valid ABO\Rh rows for multiple patient guids => merged records, we get the most recent valid one
			IF @validabocount > 0 AND @validrhcount > 0
				SELECT TOP 1
					@abopatient = BloodTypeCode, 
					@rhpatient = RhFactorCode
				FROM 
					dbo.Patient
				WHERE
					PatientGuid IN
					(
						SELECT 
							P.PatientGuid 
						FROM 
							dbo.Patient P 
								JOIN dbo.Patient LinkPatient ON P.PatientMergeGroup = LinkPatient.PatientMergeGroup OR P.PatientGuid = LinkPatient.PatientGuid 
						WHERE 
							LinkPatient.PatientGuid = @patientguid
					)
					AND BloodTypeCode IN ('A', 'AB', 'B', 'I', 'O')
					AND RhFactorCode IN ('I', 'N', 'P')
				ORDER BY 
					LastUpdateDate DESC
			ELSE
				-- No valid ABO\Rh for multiple patient guids => merged records, we get the most recent one
				SELECT TOP 1
					@abopatient = BloodTypeCode, 
					@rhpatient = RhFactorCode
				FROM 
					dbo.Patient
				WHERE
					PatientGuid IN
					(
						SELECT 
							P.PatientGuid 
						FROM 
							dbo.Patient P 
								JOIN dbo.Patient LinkPatient ON P.PatientMergeGroup = LinkPatient.PatientMergeGroup OR P.PatientGuid = LinkPatient.PatientGuid 
						WHERE 
							LinkPatient.PatientGuid = @patientguid
					)
				ORDER BY 
					LastUpdateDate DESC
		END
		
		IF @justified = 0 AND ( @abopatient IS NOT NULL AND @rhpatient IS NOT NULL ) AND ( ( ISNULL( @aboSpecimenTestCurrent, '' ) != ISNULL( @abopatient, '' ) ) OR ( ISNULL( @rhSpecimenTestCurrent, '' ) != ISNULL( @rhpatient, '' ) ) )
		BEGIN
			--Test results are not consistent with patient record and not justified
			--TEST CASE #7
			INSERT INTO @bloodType (ABO, Rh, TestDate, TestDivision, Justified, Discrepancy, PatientSpecimenGuid) 
			VALUES (@abopatient, @rhpatient, NULL, NULL, @Justified, 1, @PatientSpecimenGuid)
			RETURN
		END
		ELSE
		BEGIN
			--Specimen results are justified or there are no results on patient record
			--TEST CASES #4, #6
			--Test results are consistent with the patient record
			--TEST CASE #5
			INSERT INTO @bloodType (ABO, Rh, TestDate, TestDivision, Justified, Discrepancy, PatientSpecimenGuid) 
			VALUES (@aboSpecimenTestCurrent, @rhSpecimenTestCurrent, @TestDate, @TestDivision, @Justified, 0, @PatientSpecimenGuid)
			RETURN
		END
	END

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
	--Situation 3: The patient has two sets of complete ABO/Rh tests on file
	IF @validRecordCount = 2
	BEGIN
		DECLARE @aboSpecimenTestPrevious     VARCHAR(2)
		DECLARE @rhSpecimenTestPrevious      VARCHAR(2)
		DECLARE @testDivisionPrevious        VARCHAR(5)
		DECLARE @testDatePrevious            DATETIME
		DECLARE @patientSpecimenGuidCurrent  UNIQUEIDENTIFIER
		DECLARE @patientSpecimenGuidPrevious UNIQUEIDENTIFIER
		
		--Most recent specimen test results
		SELECT TOP 1 
			@aboSpecimenTestCurrent = RTRIM( abo ),
			@TestDivision = TestDivision,
			@TestDate = TestDate, 
			@patientSpecimenGuidCurrent = PatientSpecimenGuid,
			@justified = Justified
		FROM 
			@abo
		ORDER BY 
			TestDate DESC
		
		SELECT TOP 1 
			@rhSpecimenTestCurrent = RTRIM( rh )
		FROM 
			@rh
		ORDER BY
			TestDate DESC
		
		SELECT TOP 1 
			@aboSpecimenTestPrevious = RTRIM( abo ),
			@testDivisionPrevious = TestDivision,
			@testDatePrevious = TestDate,
			@patientSpecimenGuidPrevious = PatientSpecimenGuid
		FROM 
			@abo
		ORDER BY 
			TestDate ASC
		
		SELECT TOP 1 
			@rhSpecimenTestPrevious = RTRIM( rh )
		FROM 
			@rh
		ORDER BY
			TestDate ASC
		
		IF @justified = 0 AND ( ( ISNULL( @aboSpecimenTestCurrent, '' ) != ISNULL( @aboSpecimenTestPrevious, '' ) ) OR ( ISNULL( @rhSpecimenTestCurrent, '' ) != ISNULL( @rhSpecimenTestPrevious, '' ) ) )
		BEGIN
			--Current Specimen results are not consistent with previous specimen results and not justified
			--TEST CASE #11
			INSERT INTO @bloodType (ABO, Rh, TestDate, TestDivision,  Justified, Discrepancy, PatientSpecimenGuid) 
			VALUES (@aboSpecimenTestPrevious, @rhSpecimenTestPrevious, @testDatePrevious, @testDivisionPrevious, @justified, 1, @patientSpecimenGuidPrevious)
			RETURN
		END
		ELSE
		BEGIN
			--Current specimen result is justified
			--TEST CASE #10
			--Test results are consistent
			--TEST CASE #9
			INSERT INTO @bloodType (ABO, Rh, TestDate, TestDivision,  Justified, Discrepancy, PatientSpecimenGuid) 
			VALUES (@aboSpecimenTestCurrent, @rhSpecimenTestCurrent, @TestDate, @TestDivision, @justified, 0, @patientSpecimenGuidCurrent)
			RETURN
		END
	END
		
RETURN
END

GO

SET ANSI_NULLS ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.fnCompareProductAttributeForms') and OBJECTPROPERTY(id, N'IsScalarFunction') = 1)
drop function dbo.fnCompareProductAttributeForms
GO
/*******************************************************************************************************************************************************************************
**
**	Desc:		Compare two product attribute forms to determine if they are similar. (CR 2621)
**
**	Use Case(s):	24 - Pooling
**
**	Author: 		D. McHugh
**
**	Date: 		04/02/2009
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	
**	
*******************************************************************************************************************************************************************************/

CREATE FUNCTION dbo.fnCompareProductAttributeForms
(
	@ProductAttributeForm1 VARCHAR(40),
	@ProductAttributeForm2 VARCHAR(40)
)
RETURNS VARCHAR(40)  AS  


BEGIN

    DECLARE @retval INT
    DECLARE @temporaryattribute VARCHAR(3)
    DECLARE @AttributeClassList VARCHAR(20)
    DECLARE @Position INTEGER
    DECLARE @PAFPosition INTEGER
    DECLARE @CurrentAttributeClass CHAR(1)


    SET @retval = 0
    SET @AttributeClassList = 'DEFGHIJKLMN'
    SET @Position = 1




    IF LEFT(@ProductAttributeForm1, 3) = LEFT(@ProductAttributeForm2, 3)
    BEGIN

	WHILE @Position <= LEN(@AttributeClassList)

	BEGIN        

		--Determine the current attribute class to evaluate
		SET @CurrentAttributeClass = SUBSTRING(@AttributeClassList, @Position, 1)

		 --Does the current attribute class exist in PAF1?
		SET @PAFPosition = CHARINDEX(' ' + @CurrentAttributeClass, @ProductAttributeForm1)

		IF @PAFPosition > 0
		BEGIN
			SET @TemporaryAttribute = @CurrentAttributeClass + '_'
			SET @ProductAttributeForm1 = LEFT(@ProductAttributeForm1, @PAFPosition) + @TemporaryAttribute + SUBSTRING(@ProductAttributeForm1, @PAFPosition + 3, LEN(@ProductAttributeForm1) - LEN(@PAFPosition) - 2)
		END

		SET @PAFPosition = CHARINDEX(' ' + @CurrentAttributeClass, @ProductAttributeForm2)

		IF @PAFPosition > 0
		BEGIN
			SET @TemporaryAttribute = @CurrentAttributeClass + '_'
			SET @ProductAttributeForm2 = LEFT(@ProductAttributeForm2, @PAFPosition) + @TemporaryAttribute + SUBSTRING(@ProductAttributeForm2, @PAFPosition + 3, LEN(@ProductAttributeForm2) - LEN(@PAFPosition) - 2)
		END

		--Move on to the next element
		SET @Position = @Position + 1

	END

	IF @ProductAttributeForm1 = @ProductAttributeForm2
		SET @retval = 1

    END

    RETURN @retval

END





GO



/*****************************************************************************************
* 	VIEWS
*****************************************************************************************/
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.V_Suppliers') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_Suppliers
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	List of Suppliers
**
**
**	Author:	N/A
**
**	Date:  	03/03/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	---------------	---------		-----------------
**	10/13/2005	Npaterson	Added comment header and this note regarding LocalSupplier filter per Cameron Taylor's comment:
**	"When blood comes in, there are two facilities that we need to know about - the facility that shipped the unit, which we get from Shipment via the IncomingShipmentGuid.
**	The other is the collection facility, the facility that labelled the blood, this we get from FdaRegistrationNumber because that's what is on the bag"
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	11/28/2008	M. Smith	Added dbo prefix to table names (CR 2503)
**	12/17/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/

CREATE VIEW dbo.V_Suppliers
AS
SELECT     	LocalSupplierGUID, FacilityGUID, FacilityName, FdaRegistrationNumber, IccbbaRegistrationNumber, 
		FacilityPrefix, AddressGUID, LabelUnitIdTrimIndicator, PhoneNumber, FaxNumber, TestingIndicator, 
		CollectionIndicator, DivisionCode, RecordStatusCode, LastUpdateDate, LastUpdateUser, [RowVersion]
FROM         	dbo.LocalSupplier
UNION ALL
SELECT     	NULL AS LocalSupplierGuid, FacilityGUID, FacilityName, FdaRegistrationNumber, IccbbaRegistrationNumber, FacilityPrefix, AddressGUID, 
		LabelUnitIdTrimIndicator, PhoneNumber, FaxNumber, TestingIndicator, CollectionIndicator, NULL AS DivisionCode, RecordStatusCode, 
               	LastUpdateDate, LastUpdateUser, [RowVersion]
FROM         	dbo.Facility F
WHERE 	NOT EXISTS (	SELECT 	'x' 
			FROM 	LocalSupplier LS 
			WHERE 	LS.FdaRegistrationNumber = F.FdaRegistrationNumber )
	AND 	RecordStatusCode != 'X'



GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.vw_ActiveAndInactiveBloodUnits') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.vw_ActiveAndInactiveBloodUnits
GO

/*******************************************************************************************************************************************************************************
**	Name: 	vw_ActiveAndInactiveBloodUnits
**
**	Desc: 	Returns data for a BloodUnit regardless of RecordStatusCode -- (same exact view as vw_BloodUnits
**
**	Author:	David Askew
**
**	Date: 	11/01/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------		---------		------------------
**	04/24/2005	Lohse		Adding BUS columns for vw_ActiveAndInactiveBloodUnitsWithCurrentStatus. Removed BUS logic from vw_ANIBUWCS because
**					it was logic that assumed BUS records were insert and not maintained. Denoted by --01
**	06/21/2005	NPaterson	Modified to use new sql for increasted performance
**	09/07/2005	S. Antropov	Replaced subquery with TOP 1 to BloodUnitShipment with a JOIN to BloodUnitCurrentShipment to increase performance
**	09/08/2005	S. Antropov	Replaced INNER JOIN to Shipment table with LEFT OUTER JOIN to bring all blood unit records
**	10/13/2005	N.Paterson	Added comments regarding LocalSupplier join
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	11/28/2008	M. Smith	Added dbo prefix to BloodUnit table (CR 2503)
**	12/17/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/

CREATE VIEW dbo.vw_ActiveAndInactiveBloodUnits
AS
SELECT     
	BUS.BiohazardousWarningIndicator, 
	BUM.BloodTypeCode, 
	BU.BloodProductGUID, 
	BU.BloodUnitGuid, 
	BF.BloodUnitFinanceGuid,
	BUM.BloodUnitMediaGuid,
	BUS.BloodUnitStatusGuid,
	BUM.Comments, 
	BUM.DirectedPatientGUID, 
	BUS.DiscardCannedCommentGuid, 	--01
	BU.DivisionCode, 
	BU.DonationTypeID, 
	BU.EyeReadableUnitID, 
	CURSHIP.IncomingShipmentGUID, 
	BU.LabelTypeCode,
	BU.LabelUnitID, 
	BU.LastUpdateDate, 
	BU.LastUpdateUser, 
	BU.OriginalVolume, 	                      
	CURSHIP.OutgoingShipmentGUID, 
	BUS.PresumedTransfusedIndicator,
	BU.ProcessingTechID, 
	BUS.QuarantineIndicator, 			--01
	BU.RecordStatusCode, 
	BF.ReturnCreditAmount, 
	RH.RhFactorCode, 
	RH.RhFactorText, 
	BU.RowVersion, 
	BF.SpecialTestingCost, 
	BUM.TestingStatusID, 
	BU.UnitContainerLotNumber, 
	BF.UnitCost,
	BU.UnitDivisionID, 
	BUM.UnitExpirationDate, 
	BU.UnitFdaRegistrationNumber, 
	BF.RowVersion AS UnitFinanceRowVersion, 
	BU.UnitInDate, 
	BUM.RowVersion AS UnitMediaRowVersion, 
	BU.UnitProductCode, 
	BUS.UnitStatusCode, 			--01
	BUS.UnitStatusComments, 		--01
	BUS.RowVersion AS UnitStatusRowVersion, 
	US.UnitStatusText,			--01

	BP.MaximumStorageTime, 
	BP.ProductName, 
	BP.ProductShortName, 
	BP.ProductTypeCode, 
	                      
	DT.DonationTypeCode, 
	DT.DonationTypeText, 

	LS.FacilityName, 

	PT.ComponentClassId, 
	PT.IccbbaComponentClassId, 
	PT.ProductTypeName, 	                      
	PT.SplitAllowedIndicator,

	Ship.ShipmentDate

FROM
    	dbo.BloodUnit BU   
INNER JOIN
	dbo.BloodUnitCurrentShipment CURSHIP  ON BU.BloodUnitGuid = CURSHIP.BloodUnitGuid 
LEFT OUTER JOIN
	dbo.BloodUnitMedia BUM   ON BU.BloodUnitGuid = BUM.BloodUnitGuid 
INNER JOIN
	dbo.BloodProduct BP ON BU.BloodProductGuid = BP.BloodProductGuid 
INNER JOIN
	dbo.DonationType DT ON BU.DonationTypeId = DT.DonationTypeId 
INNER JOIN
	dbo.ProductType PT   ON BP.ProductTypeCode = PT.ProductTypeCode 
LEFT OUTER JOIN
	dbo.Shipment Ship ON CURSHIP.IncomingShipmentGuid = Ship.ShipmentGuid 
LEFT OUTER JOIN
	dbo.BloodUnitStatus BUS ON BU.BloodUnitGuid = BUS.BloodUnitGUID
INNER JOIN
	dbo.UnitStatus US ON BUS.UnitStatusCode = US.UnitStatusCode 
/* Per Cameron Taylor:
"When blood comes in, there are two facilities that we need to know about - the facility that shipped the unit, which we get from Shipment via the IncomingShipmentGuid.
The other is the collection facility, the facility that labelled the blood, this we get from FdaRegistrationNumber because that's what is on the bag"
*/
LEFT OUTER JOIN
	dbo.LocalSupplier LS ON BU.UnitFdaRegistrationNumber = LS.FdaRegistrationNumber AND BU.DivisionCode = LS.DivisionCode
INNER JOIN
	dbo.RhFactor RH ON BUM.RhFactorCode = RH.RhFactorCode
LEFT OUTER JOIN
	dbo.BloodUnitFinance BF ON BU.BloodUnitGuid = BF.BloodUnitGuid 








GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.vw_ActiveAndInactiveBloodUnitsWithCurrentStatus') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.vw_ActiveAndInactiveBloodUnitsWithCurrentStatus
GO

/*******************************************************************************************************************************************************************************
**	Name: 	vw_ActiveAndInactiveBloodUnitsWithCurrentStatus
**
**	Desc: 	Returns data for a BloodUnit regardless of RecordStatusCode.  -- Same exact code as vw_BloodUnitsWithCurrentStatus
**
**	Author:	David Askew
**
**	Date: 	11/01/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------		---------		------------------
**	04/24/2005	Lohse		Removing BUS logic (assumes that the BUS records are inserted, not updated). Denoted by --02
**	05/26/2005	Lohse		Removing PreviouslyPooledIndicator - moved to another BUM table.  Removed PooledUnitsCounts
**					(not needed)
**	10/03/2005	D. Askew	Changed LEFT OUTER join to Patient to select either the FinalMergeToPatient if the patient has one or 
**					more merges (choosing the final merge record) or simply the patient guid if there are none; changed
**					formatting slightly for readibility; removed unused code
**	11/28/2008	M. Smith	Added dbo prefix to vw_ActiveAndInactiveBloodUnits (CR 2503)
**	12/17/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE VIEW dbo.vw_ActiveAndInactiveBloodUnitsWithCurrentStatus
AS
	
	SELECT     
		BU.BiohazardousWarningIndicator, 
		BU.BloodProductGUID, 
		BU.BloodTypeCode, 
		BU.BloodUnitGUID, 
		BU.BloodUnitFinanceGuid,
		BU.BloodUnitMediaGuid,
		BU.BloodUnitStatusGuid,
		BU.Comments, 
		BU.ComponentClassId, 
		BU.DirectedPatientGUID, 
		BU.DiscardCannedCommentGuid, 
		BU.DivisionCode, 
		BU.DonationTypeID, 
		BU.DonationTypeCode, 
		BU.DonationTypeText, 
		BU.EyeReadableUnitID, 
		BU.FacilityName, 
		BU.IccbbaComponentClassId, 
		BU.IncomingShipmentGUID, 
		BU.LabelTypeCode, 
		BU.LabelUnitID, 
		BU.LastUpdateDate, 
		BU.LastUpdateUser, 
		BU.MaximumStorageTime, 
		BU.OriginalVolume, 
		BU.OutgoingShipmentGUID, 
		BU.PresumedTransfusedIndicator,
		BU.ProcessingTechID, 
		BU.ProductName, 
		BU.ProductShortName, 
		BU.ProductTypeCode, 
		BU.ProductTypeName, 
		BU.QuarantineIndicator, 
		BU.RecordStatusCode, 
		BU.ReturnCreditAmount, 
		BU.RhFactorCode, 
		BU.RhFactorText, 
		BU.RowVersion, 
		BU.ShipmentDate,
		BU.SpecialTestingCost, 
		BU.SplitAllowedIndicator, 
		BU.TestingStatusID, 
		BU.UnitContainerLotNumber, 
		BU.UnitCost, 
		BU.UnitDivisionID, 
		BU.UnitExpirationDate, 
		BU.UnitFdaRegistrationNumber, 
		BU.UnitFinanceRowVersion, 
		BU.UnitInDate, 
		BU.UnitMediaRowVersion, 
		BU.UnitProductCode, 
		BU.UnitStatusCode, 
		BU.UnitStatusComments, 
		BU.UnitStatusRowVersion, 
		BU.UnitStatusText,

		P.PatientFirstName, 
		P.PatientMiddleName, 
		P.PatientLastName, 
		P.VistaPatientId, 
		P.PatientSsn, 
		P.DisplayVistaPatientId

	FROM         
		dbo.vw_ActiveAndInactiveBloodUnits BU

	-- This will return the most recent patient data, regardless of how many times the patient has been merged (most likely zero times).
	LEFT OUTER JOIN 	dbo.Patient LinkPatient 	ON BU.DirectedPatientGuid = LinkPatient.PatientGuid
	LEFT OUTER JOIN	dbo.Patient P 		ON P.PatientGuid = COALESCE(LinkPatient.FinalMergeToPatient, LinkPatient.PatientGuid)
	







GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.vw_BloodUnitsWithAntigensIdentified') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.vw_BloodUnitsWithAntigensIdentified
GO
/*********************************************************************************************************************
**
**  Desc:   Returns active blood units with identified antigens
**
**  Author: Stas Antropov
**
**  Date:   07/19/2005
**
*****************************************************************************************************************************************************
**  Modified:
**	Date		Name		Description
**	----------		-------------		--------------------
**	11/28/2008	M. Smith	Added dbo prefix to view name (CR 2503)
**	12/17/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*****************************************************************************************************************************************************/
CREATE VIEW dbo.vw_BloodUnitsWithAntigensIdentified
AS

    SELECT DISTINCT 
            dbo.BloodUnit.BloodUnitGuid,
            dbo.AntigenType.AntigenTypeID,
            dbo.AntigenType.AntigenTypeName + 
            (CASE WHEN dbo.BloodUnitAntigen.Positive = 1 THEN ' Pos' ELSE ' Neg' END) as AntigenTypeName
    FROM
            dbo.BloodUnit
    JOIN
            dbo.BloodUnitAntigen ON dbo.BloodUnit.BloodUnitGuid = dbo.BloodUnitAntigen.BloodUnitGuid
    JOIN
            dbo.AntigenType ON dbo.AntigenType.AntigenTypeID = dbo.BloodUnitAntigen.AntigenTypeID
    WHERE
            dbo.BloodUnitAntigen.RecordStatusCode = 'A'
        AND dbo.BloodUnit.RecordStatusCode = 'A'

    UNION

    SELECT DISTINCT 
            dbo.BloodUnit.BloodUnitGuid,
            dbo.AntigenType.AntigenTypeID,
            dbo.AntigenType.AntigenTypeName + ' ' + dbo.TestResult.TestResultText COLLATE SQL_Latin1_General_CP1_CS_AS as AntigenTypeName
    FROM
            dbo.BloodUnitTest
    JOIN
            dbo.TestResult ON dbo.BloodUnitTest.TestResultID = dbo.TestResult.TestResultID
    JOIN
            dbo.BloodUnit ON dbo.BloodUnitTest.BloodUnitGUID = dbo.BloodUnit.BloodUnitGuid
    JOIN
            dbo.AntiseraWorklistTyping ON dbo.BloodUnitTest.AntiseraWorklistTypingGUID = dbo.AntiseraWorklistTyping.AntiseraWorklistTypingGUID
    JOIN
            dbo.AntigenTest ON dbo.BloodUnitTest.BloodTestTypeID = dbo.AntigenTest.BloodTestTypeID
    JOIN
            dbo.AntigenType ON dbo.AntigenType.AntigenTypeID = dbo.AntigenTest.AntigenTypeID
    WHERE
            dbo.BloodUnitTest.RecordStatusCode = 'A'
        AND dbo.BloodUnit.RecordStatusCode = 'A'







GO

/*****************************************************************************************
* 	STORED PROCEDURES
*****************************************************************************************/

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spHL7PurgeMessagesReadyForPurge') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spHL7PurgeMessagesReadyForPurge
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetAntibodyType') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetAntibodyType
GO

/*******************************************************************************************************************************************************************************
**	Desc:	Returns antibody type from AntibodyType table
**
**	Author:	Cameron Taylor
**
**	Date: 	04/14/2003
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	07/12/2005	N.Paterson	** Reviewed for compliance with database standards and recommendations **
					Removed Name/input/output from comment header, added SET NOCOUNT, formatted SQL, aliased tables
**	11/24/2008	K. Dobranowski Changed JOINs to LEFT JOINs (CR 2489)
**	12/17/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetAntibodyType
(
	@antibodytypeid			INT
)
AS

/*	@ERROR VARIABLE  USED BECAUSE SET NOCOUNT OFF RESETS THE @@ERROR TO ZERO 	*/
DECLARE @ERROR INT

SET NOCOUNT ON

	SELECT 	

		ABT.AntibodyTypeID,
		ABT.AntibodyTypeName,
		ANT.AntigenTypeID,
		ANT.AntigenTypeName,
		ABT.[RowVersion],
		ABT.SortColumn
	
	FROM  

		dbo.AntibodyType ABT

		LEFT JOIN dbo.AntibodyAntigen ABA ON 

			ABA.AntibodyTypeId = ABT.AntibodyTypeId

		LEFT JOIN dbo.AntigenType ANT ON 

			ABA.AntigenTypeId = ANT.AntigenTypeId
		
	WHERE

		ABT.AntibodyTypeID = @antibodytypeid

	ORDER BY

		ABT.sortcolumn

SET @ERROR = @@ERROR

SET NOCOUNT OFF

RETURN(@ERROR)
GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetAuditInterfaceControl') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetAuditInterfaceControl
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	Get Interface Control audit information
**
**	Author: Krzysztof Dobranowski
**
**	Date:   03/18/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name			Description
**	--------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	04/27/2004	M. Jablonski		Call fnTimeZoneConversionDateTime function on all dates
**	07/13/2005	N.Paterson	** Reviewed for compliance with database standards and recommendations **
**					Removed Name/input/output from comment header, added SET NOCOUNT, formatted SQL
**					Changed date filter from => <= to using BETWEEN, placed input paramerters in brackets, error check input dates
**	08/18/2005	N.Paterson	Implemented differences between Review_Start and DEV before porting changes to DEV
**	07/17/2007	K. Dobranowski  Fixed names of two columns InterfaceFacilityId and VbecsFacilityId (was InterfaceFacilityID and VbecsFacilityID) CR 1979
**	07/17/2007	K. Dobranowski	Added InterfaceDomainName to SELECT statement CR 2267
**	11/14/2008	M. Smith	Changed to get the InterfaceName from the new Interface reference table.  CR 2516
**	12/17/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetAuditInterfaceControl
(
	@startdate 	DATETIME,
	@enddate	DATETIME,
	@divisioncode	CHAR(5)
)
 AS

/*	@ERROR VARIABLE  USED BECAUSE SET NOCOUNT OFF RESETS THE @@ERROR TO ZERO 	*/
DECLARE @ERROR INT

SET NOCOUNT ON
--Since all the dates are saved in UTC, start and end data has to be adjusted first for correct comparison
SET @startdate = dbo.fnTimeZoneConversionDateTime(@divisioncode, 1, @startdate)

SET @ERROR = @@ERROR
	IF @ERROR !=0 GOTO SPROC_EXIT

SET @enddate = dbo.fnTimeZoneConversionDateTime(@divisioncode, 1, @enddate)

SET @ERROR = @@ERROR
	IF @ERROR !=0 GOTO SPROC_EXIT


	SELECT

		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.InterfaceControlID,
		I.InterfaceName,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.InterfaceIPAddress,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.InterfacePortNumber,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.InterfaceDomainName,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.InterfaceFacilityId,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.VbecsIPAddress,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.VbecsPortNumber,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.VbecsFacilityId,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.PurgeSuccessfulMessage,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.PurgeUnSuccessfulMessage,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.LogEventsIndicator,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.AckTimeout,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.ReTransmitAttempts,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.InterfaceAdministratorName,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.MirrorId,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.LastUpdateDate) AS MirrorDate,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.LastUpdateUser
	
	FROM
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl
			JOIN dbo.Interface I 
				ON VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.InterfaceId = I.InterfaceId
	WHERE

		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.MirrorDate BETWEEN @startdate  AND  @enddate
		
	ORDER BY
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.InterfaceControlID,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.Source,
		VBECS_V1_TEST_MIRROR.dbo.V_InterfaceControl.MirrorId DESC

SET @ERROR = @@ERROR



SPROC_EXIT:

	SET NOCOUNT OFF
	RETURN(@ERROR)
GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetPatientDemographicHistoryForPatient') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetPatientDemographicHistoryForPatient
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	Get the demographic history for a patient for Patient Record Report (Multi-divisonal)
**
**	Author: Cameron Taylor
**
**	Date: 	08/18/2003
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	07/06/05	N. Paterson	** Reviewed for compliance with database standards and recommendations **
**					Comment Header Adjusted, Added NOCOUNT, Specified table owners, spaced out SQL
**	09/09/05	D. Askew	Removed fnWherePatientGuid via sub-query using new PatientMergeGroup
**	10/11/06	D. Askew	Added UNION statements to retrieve merge-to and merge-from patients from the PatientChange table, not
**					the patient table since we are not actually merging patients in VBECS at this time; removed SELECT for
**					merged patients in OrderedTest query, we simply use the PatientGuid here 
**	10/16/06	D. Askew	Changed LastUpdateDate and LastUpdateUser to use values from PatientChange for merge-from and
**					merge-to data
**	11/20/06	D. Askew	Changed VBECS_V1_TEST_MIRROR.dbo.V_Patient P to dbo.Patient P for the merge data
**	05/25/08	M. Smith	Cast VistaPatientId to VARCHAR(19) for the report (CR 2431).
**	06/04/08	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	06/16/08	M. Smith	Changed RecordStatusCode IN ('A') to RecordStatusCode = 'A'
**	01/08/09 	D. Askew	Changed merge code to handle merge-from or merge-to patient not in VBECS at receipt 
**					of merge message (CR 2566)
**	01/08/09	M. Smith	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetPatientDemographicHistoryForPatient
(
	@patientguid			UNIQUEIDENTIFIER,
	@divisioncode			CHAR(5)
)

AS

DECLARE @ERROR INT

SET @ERROR = 0

SET NOCOUNT ON
	
	SELECT DISTINCT
		P.PatientGuid,
		CAST(P.VistaPatientId AS VARCHAR(19)) AS VistaPatientId,
		P.DisplayVistaPatientId,
		P.PatientLastName,
		P.PatientFirstName,
		P.PatientMiddleName,
		P.PatientIcn,
		P.PatientDob,
		P.PatientDobCode,
		P.BloodTypeCode,
		P.RhFactorCode,
		P.AboRhChangeIndicator,
		P.PatientSexCode,
		P.PatientDeathDate,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, P.PatientMergeDate) AS PatientMergeDate,
		NULL AS MergeFromPatient,
		NULL AS MergeFromPatientLastName,
		NULL AS MergeFromPatientFirstName,
		NULL AS MergeFromPatientMiddleName,
		NULL AS MergeFromDisplayVistaPatientId,
		NULL AS MergeToPatient,
		NULL AS MergeToPatientLastName,
		NULL AS MergeToPatientFirstName,
		NULL AS MergeToPatientMiddleName,
		NULL AS MergeToDisplayVistaPatientId,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, P.LastUpdateDate) AS LastUpdateDate,
		ISNULL(VU.UserName, P.LastUpdateUser) AS LastUpdateUser

	FROM
		VBECS_V1_TEST_MIRROR.dbo.V_Patient P

		LEFT JOIN dbo.VbecsUser VU ON VU.VbecsUserId = P.LastUpdateUser
			
	WHERE
		P.PatientGuid = @patientguid

UNION
-- ****************************************************************************************************************************************************************************************************************************************
-- merge-from patient data
-- ****************************************************************************************************************************************************************************************************************************************
	SELECT DISTINCT
		P.PatientGuid,
		CAST(P.VistaPatientId AS VARCHAR(19)) 								AS VistaPatientId,
		P.DisplayVistaPatientId,
		P.PatientLastName,
		P.PatientFirstName,
		P.PatientMiddleName,
		P.PatientIcn,
		P.PatientDob,
		P.PatientDobCode,
		P.BloodTypeCode,
		P.RhFactorCode,
		P.AboRhChangeIndicator,
		P.PatientSexCode,
		P.PatientDeathDate,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, P.PatientMergeDate) 				AS PatientMergeDate,
		-- ************************************************************************************************************************************************************************************
		CASE WHEN MF.PatientGuid IS NOT NULL THEN
			CAST(MF.VistaPatientId AS VARCHAR(19))
		ELSE
			 CAST(PC.MergeFromVistaPatientId AS VARCHAR(19))	
		END													AS MergeFromPatient,
		-- ************************************************************************************************************************************************************************************
		CASE WHEN MF.PatientGuid IS NOT NULL THEN
			MF.PatientLastName
		ELSE
			PC.FromPatientLastName
		END													AS MergeFromPatientLastName,
		-- ************************************************************************************************************************************************************************************
		CASE WHEN MF.PatientGuid IS NOT NULL THEN
			MF.PatientFirstName
		ELSE
			PC.FromPatientFirstName
		END													AS MergeFromPatientFirstName,
		-- ************************************************************************************************************************************************************************************
		CASE WHEN MF.PatientGuid IS NOT NULL THEN
			MF.PatientMiddleName
		ELSE
			PC.FromPatientMiddleName
		END													AS MergeFromPatientMiddleName,
		-- ************************************************************************************************************************************************************************************
		CASE WHEN MF.PatientGuid IS NOT NULL THEN
			MF.DisplayVistaPatientId
		ELSE
			'Not Available'
		END													AS MergeFromDisplayVistaPatientId,
		-- ************************************************************************************************************************************************************************************
		NULL AS MergeToPatient,
		NULL AS MergeToPatientLastName,
		NULL AS MergeToPatientFirstName,
		NULL AS MergeToPatientMiddleName,
		NULL AS MergeToDisplayVistaPatientId,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, PC.LastUpdateDate) 				AS LastUpdateDate,
		ISNULL(VU.UserName, PC.LastUpdateUser) 								AS LastUpdateUser
	
	FROM
		dbo.Patient P
	
		JOIN dbo.PatientChange PC 
			ON P.PatientGuid = PC.ToPatientGuid 
			AND ( PC.MergeFromVistaPatientId != 0 AND PC.MergeToVistaPatientId != 0 ) 
			AND PC.PatientChangeStatusCode = 'S'
	
		LEFT JOIN dbo.Patient MF ON PC.FromPatientGuid = MF.PatientGuid
	
	
		LEFT JOIN dbo.VbecsUser VU ON VU.VbecsUserId = PC.LastUpdateUser
		
	WHERE
		P.PatientGuid = @patientguid


UNION

-- ****************************************************************************************************************************************************************************************************************************************
-- merge-to patient data
-- ****************************************************************************************************************************************************************************************************************************************
	SELECT DISTINCT
		P.PatientGuid,
		CAST(P.VistaPatientId AS VARCHAR(19)) 								AS VistaPatientId,
		P.DisplayVistaPatientId,
		P.PatientLastName,
		P.PatientFirstName,
		P.PatientMiddleName,
		P.PatientIcn,
		P.PatientDob,
		P.PatientDobCode,
		P.BloodTypeCode,
		P.RhFactorCode,
		P.AboRhChangeIndicator,
		P.PatientSexCode,
		P.PatientDeathDate,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, P.PatientMergeDate) 				AS PatientMergeDate,
		NULL AS MergeFromPatient,
		NULL AS MergeFromPatientLastName,
		NULL AS MergeFromPatientFirstName,
		NULL AS MergeFromPatientMiddleName,
		NULL AS MergeFromDisplayVistaPatientId,
		-- ************************************************************************************************************************************************************************************
		CASE WHEN MT.PatientGuid IS NOT NULL THEN
			CAST(MT.VistaPatientId AS VARCHAR(19))
		ELSE
			 CAST(PC.MergeToVistaPatientId AS VARCHAR(19))	
		END													AS MergeToPatient,
		-- ************************************************************************************************************************************************************************************
		CASE WHEN MT.PatientGuid IS NOT NULL THEN
			MT.PatientLastName
		ELSE
			PC.ToPatientLastName
		END													AS MergeToPatientLastName,
		-- ************************************************************************************************************************************************************************************
		CASE WHEN MT.PatientGuid IS NOT NULL THEN
			MT.PatientFirstName
		ELSE
			PC.ToPatientFirstName
		END													AS MergeToPatientFirstName,
		-- ************************************************************************************************************************************************************************************
		CASE WHEN MT.PatientGuid IS NOT NULL THEN
			MT.PatientMiddleName
		ELSE
			PC.ToPatientMiddleName
		END													AS MergeToPatientMiddleName,
		-- ************************************************************************************************************************************************************************************
		CASE WHEN MT.PatientGuid IS NOT NULL THEN
			SUBSTRING( MT.PatientSsn, 1, 3 ) 
				+ '-' + SUBSTRING( MT.PatientSsn, 4, 2 ) 
				+ '-' + SUBSTRING( MT.PatientSsn, 6, 4 )
		ELSE
			SUBSTRING( PC.ToPatientSsn, 1, 3 ) 
				+ '-' + SUBSTRING( PC.ToPatientSsn, 4, 2 ) 
				+ '-' + SUBSTRING( PC.ToPatientSsn, 6, 4 )
		END													AS MergeToDisplayVistaPatientId,
		-- ************************************************************************************************************************************************************************************
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, PC.LastUpdateDate) 				AS LastUpdateDate,
		ISNULL(VU.UserName, PC.LastUpdateUser) 								AS LastUpdateUser
	
	FROM
		dbo.Patient P
	
		JOIN dbo.PatientChange PC 
			ON P.PatientGuid = PC.FromPatientGuid 
			AND ( PC.MergeFromVistaPatientId != 0 AND PC.MergeToVistaPatientId != 0 ) 
			AND PC.PatientChangeStatusCode = 'S'
		
		LEFT JOIN dbo.Patient MT 
			ON PC.ToPatientGuid = MT.PatientGuid
	
		LEFT JOIN dbo.VbecsUser VU ON VU.VbecsUserId = PC.LastUpdateUser
		
	WHERE
		P.PatientGuid = @patientguid
	
	ORDER BY
		P.LastUpdateDate DESC

	-- ****************************************************************************************************************************************************************************************************************************************

	SET @ERROR = @@ERROR
	IF @ERROR != 0 GOTO ERR_HANDLER

			SELECT
				OT.OrderedTestGuid,
				ABO.TestResultId AS BloodTypeCode,
				RH.TestResultId AS RhFactorCode,
				dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, ABO.TestDate) AS AboTestDate,
				dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, RH.TestDate) AS RhTestDate,
				ABO.RecordStatusCode AS AboRecordStatusCode,
				RH.RecordStatusCode AS RhRecordStatusCode,
				RH.AboRhChangeIndicator,
				RH.AboRhChangeJustification,
				RH.DivisionCode,
				D.DivisionName,
				dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, RH.LastUpdateDate) AS LastUpdateDate,
				ISNULL(VU.UserName,RH.LastUpdateUser) AS LastUpdateUser

			FROM

				dbo.OrderedTest OT

				JOIN dbo.SpecimenTest ABO ON ABO.OrderedTestGuid = OT.OrderedTestGuid AND ABO.BloodTestTypeID IN (18,65) AND ABO.RecordStatusCode = 'A'
	
				JOIN dbo.SpecimenTest RH ON RH.OrderedTestGuid = OT.OrderedTestGuid AND RH.BloodTestTypeID IN (21,68) AND RH.RecordStatusCode = 'A'
	
				LEFT JOIN dbo.PatientSpecimen PS ON PS.PatientSpecimenGuid = OT.PatientSpecimenGuid
	
				LEFT JOIN dbo.VamcDivision D ON D.DivisionCode = OT.DivisionCode
	
				LEFT JOIN dbo.VbecsUser VU ON VU.VbecsUserId = RH.LastUpdateUser

			WHERE

				PS.PatientGuid = @patientguid

			ORDER BY

				RH.TestDate

	SET @ERROR = @@ERROR
	IF @ERROR != 0 GOTO ERR_HANDLER

SET NOCOUNT OFF

RETURN (@ERROR)

ERR_HANDLER:
	SET NOCOUNT OFF
	RETURN(@ERROR)
GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetPendingPatientMerges') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetPendingPatientMerges
GO

/*******************************************************************************************************************************************************************************
**	Desc: 		Returns count of pending patient merges
**
**	Use Case(s):	84
**
**	Author: 		David Askew
**
**	Date: 		04/22/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
** 	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	07/09/04	D. Askew	Added some columns
**	07/06/05	N. Paterson	** Reviewed for compliance with database standards and recommendations **
**	                       			Removed name, input/output from comment header, Added NOCOUNT, Specified table owners, 
**					spaced out SQL
**	07/11/05	N. Paterson  	Removed call to function per request of Stas, because this was the only proc using it, placing inline 
**					instead of original code: dbo.fnRetrieveOrderCountForPatient(PC.FromPatientGuid, @divisioncode) 
**					AS PendingOrdersCount
**  	07/19/05  	S. Antropov 	** Reviewed for compliance with database standards and recommendations **
**                          			Updated SQL formatting
**  	08/18/05  	S. Antropov 	Added error check after the datetime conversion
**	09/12/05	D. Askew	Changed SQL formatting slightly to be more readable
**	01/03/06	D. Askew	Changed PendingOrdersCount to FromPatientPendingOrdersCount
**	01/23/06	M Smith		** Reviewed for compliance with database standards and recommendations **
**	02/14/06 	D. Askew	Changed FromPatientPendingOrdersCount to use same logic as
**					spGetRecentComponentOrdersForPatientCount and spGetRecentTestOrdersForPatientCount - we
**					count both the component and test orders
**	03/07/06	Lohse		Adding TimeZoneConversion for LastUpdateDate
**	04/04/06	Lohse		Updating sproc to conform to Database standards
**	09/27/06	D. Askew	Removed most of the columns from SELECT for performance; we are only concerned if there are any new
**					rows in patient change, not the patient details so the actual updated information was moved to
**					spGetPendingPatientMergeDetails; updated header section
**	11/20/06	D. Askew	Removed @lastchecked, @currentdate
**	02/08/07	D. Askew     	** Reviewed for compliance with database standards and recommendations **
**					Changed COUNT(*) to COUNT(1)
**	01/08/09	D. Askew	Removing JOINs to Patient; added WHERE condition for From or To PatientGuid to be NULL (CR 2566)
**	01/08/09	M. Smith	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE   PROCEDURE dbo.spGetPendingPatientMerges
(
	@divisioncode CHAR(5)
)
	
AS

DECLARE @ERROR INT

SET @ERROR = 0
    
    SET NOCOUNT ON

    SET @ERROR = @@ERROR
    
    IF @ERROR <> 0 GOTO EXIT_SPROC

	SELECT

		COUNT(1) AS PendingPatientMergesCount
	FROM 	
		dbo.PatientChange AS PC 

	WHERE	
		PC.PatientChangeStatusCode = 'P'

		AND PC.MergeFromVistaPatientId != 0 
	
		AND PC.MergeToVistaPatientId != 0 

		AND ( ToPatientGuid <> FromPatientGuid OR ToPatientGuid IS NULL OR FromPatientGuid IS NULL )

    SET @ERROR = @@ERROR
    
EXIT_SPROC:

    SET NOCOUNT OFF

    RETURN (@ERROR)
GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetPendingPatientMergesDetails') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetPendingPatientMergesDetails
GO

/*******************************************************************************************************************************************************************************
**	Desc: 		Returns information for recently deceased patients; implements BR_68.01
**
**			If a patient is in VBECS at the time of the merge message, only the PatientGuid and VistaPatientId are saved to the
**			PatientChange table and the PatientGuid is used to get details for the patient.  If a patient is NOT in VBECS then the 
**			patient information needed to display in VBECS is obtained from the merge HL7 message and saved to the PatientChange
**			table.
**
**			The following data is available from the HL7 message for merge-from patients who are not in VBECS at the time of the message:
**			Patient ICN, DFN and Name
**
**			The following data is available from the HL7 message for merge-to patients who are not in VBECS at the time of the message:
**			Patient ICN, DFN, SSN, DOB, Sex Code and Name
**
**
**	Use Case(s):	68
**
**	Author: 		David Askew
**
**	Date: 		09/27/2006
**
*******************************************************************************************************************************************************************************
**	Modified:
** 	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	10/03/06	D. Askew	Removed function call to fnGetPendingOrderCountForPatient in SELECT; added Pending Test Order 
**					Count to SELECT
**	10/05/06	D. Askew	Added FromPatientLastName, FromPatientFirstName, FromPatientMiddleName, FromDisplayVistaPatientId, 
**					ToPatientLastName, ToPatientFirstName, ToPatientMiddleName, PatientChangeStatusCode to SELECT
**	10/27/06	D. Askew	Removed Pending Test Order Count - this is not needed for merges
**	01/09/09	D. Askew	Changed Patient table JOIN conditions to LEFT types; changed MergeFromVistaPatientId in WHERE
**					clause to accept either from or to as valid; switched ISNULL to check for JOINed patient tables
**					first; added WHERE condition for From or To PatientGuid to be NULL (CR 2566)
**	01/09/09	M. Smith	** Reviewed for compliance with database standards and recommendations **
**	06/22/09	D. Askew	Added NotificationReceivedDate to SELECT (CR 2675)
**	06/24/09	M. Smith	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE   PROCEDURE dbo.spGetPendingPatientMergesDetails
(
	@divisioncode CHAR(5)
)

AS

DECLARE @currentdate		DATETIME
DECLARE @ERROR 		INT
--
SET @currentdate 	= GETUTCDATE()
SET @ERROR 		= 0

    SET NOCOUNT ON

    SET @ERROR = @@ERROR

    IF @ERROR <> 0 GOTO EXIT_SPROC

	SELECT DISTINCT

		-- *********************************************************************************************************************************************************************
		-- ******* 						MERGE-FROM PATIENT
		-- *********************************************************************************************************************************************************************
		PC.FromPatientGuid,
		PC.MergeFromVistaPatientId,
		SUBSTRING( FromPatient.PatientSsn, 1, 3 ) 
			+ '-' + SUBSTRING( FromPatient.PatientSsn, 4, 2 ) 
			+ '-' + SUBSTRING( FromPatient.PatientSsn, 6, 4 )							AS FromDisplayVistaPatientId,
		-- *********************************************************************************************************************************************************************
		CASE WHEN FromPatient.PatientGuid IS NOT NULL THEN
			FromPatient.PatientLastName
		ELSE
			PC.FromPatientLastName
		END													AS FromPatientLastName,
		-- *********************************************************************************************************************************************************************
		CASE WHEN FromPatient.PatientGuid IS NOT NULL THEN
			FromPatient.PatientFirstName
		ELSE
			PC.FromPatientFirstName
		END													AS FromPatientFirstName,
		-- *********************************************************************************************************************************************************************
		CASE WHEN FromPatient.PatientGuid IS NOT NULL THEN
			FromPatient.PatientMiddleName
		ELSE
			PC.FromPatientMiddleName
		END													AS FromPatientMiddleName,
		-- *********************************************************************************************************************************************************************
		-- ******* 						MERGE-TO PATIENT
		-- *********************************************************************************************************************************************************************
		PC.ToPatientGuid,
		PC.MergeToVistaPatientId,
		-- *********************************************************************************************************************************************************************
		CASE WHEN ToPatient.PatientGuid IS NOT NULL THEN
			SUBSTRING( ToPatient.PatientSsn, 1, 3 ) 
				+ '-' + SUBSTRING( ToPatient.PatientSsn, 4, 2 ) 
				+ '-' + SUBSTRING( ToPatient.PatientSsn, 6, 4 )
		ELSE
			SUBSTRING( PC.ToPatientSsn, 1, 3 ) 
				+ '-' + SUBSTRING( PC.ToPatientSsn, 4, 2 ) 
				+ '-' + SUBSTRING( PC.ToPatientSsn, 6, 4 )
		END													AS ToDisplayVistaPatientId,
		-- *********************************************************************************************************************************************************************
		CASE WHEN ToPatient.PatientGuid IS NOT NULL THEN
			ToPatient.PatientLastName
		ELSE
			PC.ToPatientLastName
		END													AS ToPatientLastName,
		-- *********************************************************************************************************************************************************************
		CASE WHEN ToPatient.PatientGuid IS NOT NULL THEN
			ToPatient.PatientFirstName
		ELSE
			PC.ToPatientFirstName
		END													AS ToPatientFirstName,
		-- *********************************************************************************************************************************************************************
		CASE WHEN ToPatient.PatientGuid IS NOT NULL THEN
			ToPatient.PatientMiddleName
		ELSE
			PC.ToPatientMiddleName
		END													AS ToPatientMiddleName,
		-- *********************************************************************************************************************************************************************
		CASE WHEN ToPatient.PatientGuid IS NOT NULL THEN
			ToPatient.PatientSexCode
		ELSE
			PC.ToPatientSexCode
		END													AS ToPatientSexCode,
		-- *********************************************************************************************************************************************************************
		PC.PatientChangeGuid,
		PC.PatientChangeStatusCode,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, NotificationReceivedDate) 				AS NotificationReceivedDate,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, PC.LastUpdateDate) 				AS LastUpdateDate,
		PC.RowVersion
	FROM 	
		dbo.PatientChange AS PC 

		LEFT JOIN dbo.Patient AS ToPatient ON PC.ToPatientGuid = ToPatient.PatientGuid

		LEFT JOIN dbo.Patient AS FromPatient ON PC.FromPatientGuid = FromPatient.PatientGuid

	WHERE	
		PC.MergeFromVistaPatientId != 0 

		AND PC.MergeToVistaPatientId != 0 

		AND ( ToPatientGuid <> FromPatientGuid OR ToPatientGuid IS NULL OR FromPatientGuid IS NULL )

	-- BR_68.01
	ORDER BY PC.LastUpdateDate

    SET @ERROR = @@ERROR

EXIT_SPROC:

    SET NOCOUNT OFF

    RETURN (@ERROR)
GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetVbecsVersion') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetVbecsVersion
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	Gets a VbecsVersion Record
**
**	Author:	Greg Lohse
**
**	Date: 	12/02/2008
**
**	Purpose: Returns a list of VBECS patches applied (in descending order).
**		  This will be used in VBECS/Admin to display the version # in Help->About
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	---------------	---------		-------------------
**	12/02/2008	Greg Lohse	Initial Writing (CR 2465).
**	12/09/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetVbecsVersion

AS

DECLARE @ERROR INT

SET NOCOUNT ON

	SELECT
		VbecsVersionId,
		Version,
		PatchSuccessfulIndicator,
		LastUpdateDate,
		LastUpdateUser		
	FROM
		dbo.VbecsVersion
	ORDER BY 
		LastUpdateDate DESC



SET @ERROR = @@ERROR

SET NOCOUNT OFF

RETURN(@ERROR)
GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spHL7InsertPatientChange') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spHL7InsertPatientChange
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	Inserts a record in the PatientChange table when a Patient Update/Merge event occurs in VistA.
**
**	Author:	Brian Tomlin
**
**	Date: 	04/21/04
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name			Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	01/10/05	D. Askew	Added @lastupdatedate
**	06/29/05	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Comment Header Adjusted, Added NOCOUNT, Specified table owners, did not modify to use single update
**					statement as originally planned, because a review of the logic showed this not possible
**	11/16/05	B. Tomlin	Added PatientSsn update to Patient table when ToPatientSsn is not null.
**					Change made to address CR 1310.
**	11/22/05	B. Tomlin	Added ToPatientSsnPseudoIndicator to address CR 1318.
**	12/17/05	B. Tomlin	Added FromSsnPseudoIndicator and changed ToPatientSsnPseudoIndicator to ToSsnPseudoIndicator to
**					address CR 1355
**	12/07/05	B. Tomlin	Removed all Patient table Updates and modified .NET code to use spHL7UpdatePatient instead.
**	01/23/06	M Smith		** Reviewed for compliance with database standards and recommendations **
**	05/13/08	M. Smith	Changed @MergeFromVistaPatientId and @MergeToVistaPatientId to BIGINT datatype (CR 2431)
**	06/04/08	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	12/18/08 	D. Askew	Made @FromPatientGuid and @ToPatientGuid optional (CR 2566)
**	01/08/09	M. Smith	** Reviewed for compliance with database standards and recommendations **
**	03/31/09	M. Smith	Changed @FromPatientFirstName, @FromPatientLastName, @FromPatientMiddleName, 
**					@ToPatientFirstName, @ToPatientLastName, and @ToPatientMiddleName to VARCHAR(30) (CR 2606)
**	04/06/09	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	06/22/09	D. Askew	Added NotificationReceivedDate to INSERT, using the value of @LastUpdateDate (CR 2675)
**	06/24/09	M. Smith	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spHL7InsertPatientChange
(
	@PatientChangeGuid		UNIQUEIDENTIFIER,
	@FromPatientGuid 		UNIQUEIDENTIFIER	= NULL,
	@FromPatientSsn		CHAR(9)		= NULL,
	@FromSsnPseudoIndicator	BIT 			= NULL,
	@FromPatientIcn		VARCHAR(23)		= NULL, 
	@FromPatientLastName		VARCHAR(30)		= NULL,
	@FromPatientFirstName		VARCHAR(30) 		= NULL,
	@FromPatientMiddleName	VARCHAR(30)		= NULL, 
	@FromPatientDob		DATETIME       	 	= NULL,
	@FromPatientDeathDate		DATETIME		= NULL,
	@FromPatientSexCode		CHAR(1)		= NULL,
	@ToPatientGuid 		UNIQUEIDENTIFIER	= NULL,
	@ToPatientSsn			CHAR(9)		= NULL,
	@ToSsnPseudoIndicator		BIT 			= NULL,
	@ToPatientIcn			VARCHAR(23)		= NULL, 
	@ToPatientLastName		VARCHAR(30)		= NULL,
	@ToPatientFirstName		VARCHAR(30) 		= NULL,
	@ToPatientMiddleName		VARCHAR(30)		= NULL, 
	@ToPatientDob			DATETIME		= NULL,
	@ToPatientDeathDate		DATETIME		= NULL,
	@ToPatientSexCode		CHAR(1)		= NULL,
	@MergeFromVistaPatientId	BIGINT			= NULL,
	@MergeToVistaPatientId		BIGINT			= NULL,
	@PatientChangeStatusCode	CHAR(1),
	@LastUpdateUser		VARCHAR(30),
	@LastUpdateFunctionId		INT,
	@LastUpdateDate		DATETIME
)

AS

SET NOCOUNT ON

DECLARE @ERROR	INT,
	@ROWCOUNT	INT

SET @ERROR = 0

IF NOT EXISTS (SELECT @PatientChangeGuid FROM dbo.PatientChange WHERE PatientChangeGuid = @PatientChangeGuid)
	BEGIN
		INSERT INTO PatientChange
		(
			PatientChangeGuid,
			FromPatientGuid,
			FromPatientSsn,
			FromSsnPseudoIndicator,
			FromPatientIcn,
			FromPatientLastName,
			FromPatientFirstName,
			FromPatientMiddleName,
			FromPatientDob,
			FromPatientDeathDate,
			FromPatientSexCode,
			ToPatientGuid,
			ToPatientSsn,
			ToSsnPseudoIndicator,
			ToPatientIcn,
			ToPatientLastName,
			ToPatientFirstName,
			ToPatientMiddleName,
			ToPatientDob,
			ToPatientDeathDate,
			ToPatientSexCode,
			MergeFromVistaPatientId,
			MergeToVistaPatientId,
			PatientChangeStatusCode,
			NotificationReceivedDate,
			LastUpdateDate, 
			LastUpdateUser,
			LastUpdateFunctionId
		)
		VALUES
		(
			@PatientChangeGuid,
			@FromPatientGuid,
			@FromPatientSsn,
			@FromSsnPseudoIndicator,
			@FromPatientIcn,
			@FromPatientLastName,
			@FromPatientFirstName,
			@FromPatientMiddleName,
			@FromPatientDob,
			@FromPatientDeathDate,
			@FromPatientSexCode,
			@ToPatientGuid,
			@ToPatientSsn,
			@ToSsnPseudoIndicator,
			@ToPatientIcn,
			@ToPatientLastName,
			@ToPatientFirstName,
			@ToPatientMiddleName,
			@ToPatientDob,
			@ToPatientDeathDate,
			@ToPatientSexCode,
			@MergeFromVistaPatientId,
			@MergeToVistaPatientId,
			@PatientChangeStatusCode,
			@LastUpdateDate,
			@LastUpdateDate,
			@LastUpdateUser,
			@LastUpdateFunctionId
		)

		SELECT @ERROR = @@ERROR, @ROWCOUNT = @@ROWCOUNT

		IF (@ERROR = 0)
			IF @ROWCOUNT <> 1	
				SET @ERROR = -1
	END


SET NOCOUNT OFF

RETURN (@ERROR)
GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spHL7GetInterface') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spHL7GetInterface
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	Gets an interface defined in the InterfaceControl table.
**
**	Author: Brian Tomlin	
**
**	Date: 	03/27/2004
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	06/29/05	N. Paterson	** Reviewed for compliance with database standards and recommendations **
**					Comment Header Adjusted, Added NOCOUNT, Specified table owners
**	11/14/08	M. Smith	The InterfaceControl was split into two tables.  Changed to join the new Interface reference table.  CR 2516
**	12/09/08	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	03/05/09	D. Askew	Return all interface parameters to load the Interface object (CR 2606)
*******************************************************************************************************************************************************************************/

CREATE PROCEDURE dbo.spHL7GetInterface
(
	@InterfaceApplicationID		varchar(50),
	@VbecsApplicationID		varchar(50)
)

AS

SET NOCOUNT ON

	SELECT 		
			[InterfaceControlID], 

			[InterfaceName], 
			[FieldSeparator], 
			[EncodingCharacters], 
			[InterfaceApplicationID], 
			[InterfaceFacilityID], 
			[InterfacePortNumber], 
			[InterfaceIPAddress],
			[InterfaceDomainName], 
			[VbecsApplicationID], 
			[VbecsFacilityID], 
			[ProcessingID], 
			[VersionID], 
			[ApplicationAckType], 
			[VbecsPortNumber], 
			[VbecsIPAddress], 
			[AckTimeout], 
			[ReTransmitAttempts], 
			[InterfaceAdministratorName], 
			[PurgeSuccessfulMessage], 
			[PurgeUnSuccessfulMessage], 
			[LogEventsIndicator],
			IC.LastUpdateDate, 
			IC.LastUpdateUser, 
			IC.[RowVersion], 
			IC.LastUpdateFunctionId

	FROM 		dbo.Interface I

			LEFT JOIN dbo.InterfaceControl IC ON I.InterfaceId = IC.InterfaceId

	WHERE	InterfaceApplicationID = @InterfaceApplicationID

	AND	VbecsApplicationID = @VbecsApplicationID

SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spHL7GetInterfaceControlParameters') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spHL7GetInterfaceControlParameters
GO


/*******************************************************************************************************************************************************************************
**	Desc: 	Gets all interfaces defined in the InterfaceControl table.
**
**	Author: Brian Tomlin	
**
**	Date: 	01/31/2004
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	05/17/2004	Stas Antropov	Changed * to list of columns, added VbecsIPAddress
**	01/10/2005	Stas Antropov	Added [LogEventsIndicator]
**	06/29/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Comment Header Adjusted, Added NOCOUNT, Specified table owners, Spaced SQL
**	06/19/2007	B.Tomlin	Added InterfaceDomainName (CR 2269)
**	10/21/2008	M. Smith	The InterfaceControl was split into two tables.  Changed to join the new Interface reference table.  CR 2516
**	12/09/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spHL7GetInterfaceControlParameters
(
	@InterfaceName	VARCHAR(50) = NULL
)
AS

SET NOCOUNT ON

	SELECT 		
			[InterfaceControlID], 
			[InterfaceName], 
			[FieldSeparator], 
			[EncodingCharacters], 
			[InterfaceApplicationID], 
			[InterfaceFacilityID], 
			[InterfacePortNumber], 
			[InterfaceIPAddress],
			[InterfaceDomainName], 
			[VbecsApplicationID], 
			[VbecsFacilityID], 
			[ProcessingID], 
			[VersionID], 
			[ApplicationAckType], 
			[VbecsPortNumber], 
			[VbecsIPAddress], 
			[AckTimeout], 
			[ReTransmitAttempts], 
			[InterfaceAdministratorName], 
			[PurgeSuccessfulMessage], 
			[PurgeUnSuccessfulMessage], 
			[LogEventsIndicator],
			IC.LastUpdateDate, 
			IC.LastUpdateUser, 
			IC.[RowVersion], 
			IC.LastUpdateFunctionId

	FROM 		dbo.Interface I
				LEFT JOIN dbo.InterfaceControl IC
					ON I.InterfaceId = IC.InterfaceId

	WHERE 		( @InterfaceName IS NOT NULL AND InterfaceName = @InterfaceName )

		OR	@InterfaceName IS NULL

SET NOCOUNT OFF
GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spHL7PurgeMessageLog') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spHL7PurgeMessageLog
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	Purges HL7 messages from the MessageLog table based on criteria defined in VBECS Administrator (CR 2519)
**
**	Author:	David Askew
**
**	Date: 	11/22/08
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name			Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spHL7PurgeMessageLog

AS

SET NOCOUNT ON

	DECLARE @RowCount INT
	
	DECLARE @Now DATETIME
	
	SET @RowCount = 0
	
	SET @Now = GETUTCDATE()
	
	DELETE ML
	
	FROM
		dbo.MessageLog ML
		
		JOIN dbo.InterfaceControl IC ON ML.InterfaceControlId = IC.InterfaceControlId
	
	WHERE 
	
		( MessageStatusCode = 3 AND ML.LastUpdateDate <= DATEADD(DAY, -PurgeSuccessfulMessage, @Now ) )
	
		OR 

		( MessageStatusCode IN (2, 6) AND ML.LastUpdateDate <= DATEADD(DAY, -PurgeUnSuccessfulMessage, @Now ) )

	SET @RowCount = @@ROWCOUNT


SET NOCOUNT OFF

RETURN (@RowCount)
GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spVistaUpdateWorkloadEventData') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spVistaUpdateWorkloadEventData
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	Updates entries in the WorkloadEvent table when associated 
**		workload entries in VistA have been updated by Lab
**
**	Author:	Brian Tomlin
**	Date: 	06/16/2004
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	06/29/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Header added, Added NOCOUNT, Specified table owners, Removed comments, UPPERCASED SQL
**					Author wants to Keep Union All, instead of using UNION
**	07/13/07	Lohse		Adding datetime conversion for CR2253.
**	11/21/08	M. Smith	Added check to only update a record if the WorkloadEventStatusCode has changed. (CR 2427)
**	12/09/08	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spVistaUpdateWorkloadEventData
(
	@WorkloadEventGuid AS UNIQUEIDENTIFIER,
	@WorkloadEventStatusCode AS CHAR(1),
	@ProcessedDate AS VARCHAR(25),
	@ErrorText AS VARCHAR(80) = NULL,
	@PceEncounterNumber AS VARCHAR(20) = NULL
)
AS

	SET NOCOUNT ON


	DECLARE @ERROR		INT
	DECLARE @ROWCOUNT	INT


	IF NOT EXISTS(SELECT WorkloadEventGuid FROM dbo.WorkloadEvent WHERE WorkloadEventGuid = @WorkloadEventGuid)

		RAISERROR('WorkloadEventGuid does not exist in WorkloadEvent table', 16, 1 )


	IF NOT EXISTS(SELECT WorkloadEventStatusCode FROM dbo.WorkloadEventStatus WHERE WorkloadEventStatusCode = @WorkloadEventStatusCode)

		RAISERROR('Unsupported WorkloadEventStatusCode: %s', 16, 1, @WorkloadEventStatusCode )

	--There was no way within code to get the divisioncode, so its being retrieved prior to the update call.
	DECLARE @divisioncode 	CHAR(5)
	SELECT @divisioncode = DivisionCode FROM dbo.WorkloadEvent WHERE WorkloadEventGuid = @WorkloadEventGuid 

	BEGIN
		UPDATE
			dbo.WorkloadEvent
		SET
			WorkloadEventStatusCode = @WorkloadEventStatusCode,
			ProcessedDate = dbo.fnTimeZoneConversionDateTime( @divisioncode, 1, dbo.fnFileManDateTimeConversionToDateTime(@ProcessedDate) ),
			ErrorText = @ErrorText,
			PceEncounterNumber = @PceEncounterNumber,
			LastUpdateDate = GETUTCDATE()
		WHERE
			WorkloadEventGuid = @WorkloadEventGuid
		AND	WorkloadEventStatusCode <> @WorkloadEventStatusCode

	END

	SELECT @ERROR = @@ERROR, @ROWCOUNT = @@ROWCOUNT

	IF @ERROR = 0 AND @ROWCOUNT <> 1
	BEGIN
		RAISERROR('Unable to update WorkloadEvent table for Transaction ID.' , 16, 1 )
	END

SET NOCOUNT OFF
RETURN (@ERROR)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spHL7InsertPatient') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spHL7InsertPatient
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	Inserts a record in the patient table.
**		Used in sending VISTA information to VBECS.
**
**	Author:	Brian Tomlin
**
**	Date: 	12/07/2005
*******************************************************************************************************************************************************************************
**	Modified
**	Date		Developer		Comments
**	--------------	-----------------------	-------------------------------------------------------------------------------------------------------------------------------
**	12/15/2005	C. Taylor	Added SsnPrefix as a parameter (for future use)
**					Adding code to set the VistaDisplayPatientId column instead of using a trigger (which creates two audit records)
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	05/13/2008	M. Smith	Changed @VistaPatientID to BIGINT datatype (CR 2431)
**	06/04/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	03/31/2009	M. Smith	Changed @PatientFirstName, @PatientLastName, and @PatientMiddleName to VARCHAR(30) (CR 2606)
**	04/06/2009	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spHL7InsertPatient
(
	@PatientGUID 		UNIQUEIDENTIFIER, 
	@VistaPatientID 	BIGINT,
	@PatientSSN 		CHAR(9) = NULL,
	@SsnPseudoIndicator	BIT = NULL,
	@PatientICN		VARCHAR(23) = NULL,
	@PatientLastName	VARCHAR(30), 
	@PatientFirstName	VARCHAR(30), 
	@PatientMiddleName	VARCHAR(30)= NULL, 
	@PatientDOB		DATETIME= NULL, 
	@PatientDOBCode		CHAR(1), 
	@PatientSexCode		CHAR(1)= NULL,
	@PatientDeathDate	DATETIME = NULL,
	@LastUpdateUser		VARCHAR(30),
	@LastUpdateFunctionId	INT,
	@LastUpdateDate		DATETIME,
	@SsnPrefix			CHAR(2)= NULL
)

AS

SET NOCOUNT ON

DECLARE @ERROR	INT,
	@ROWCOUNT	INT

INSERT INTO dbo.Patient
	(
		PatientGUID, 
		VistaPatientID, 
		PatientSSN, 
		PatientICN, 
		PatientLastName, 
		PatientFirstName, 
		PatientMiddleName, 
		PatientDOB, 
		PatientDOBCode, 
		PatientSexCode,
		SsnPseudoIndicator,
		PatientDeathDate,
		RecordStatusCode, 
		LastUpdateDate, 
		LastUpdateUser,
		LastUpdateFunctionId,
		SsnPrefix,
		DisplayVistaPatientId
	)
	VALUES
	(
		@PatientGUID,
		@VistaPatientID, 
		@PatientSSN,
		@PatientICN,
		@PatientLastName, 
		@PatientFirstName, 
		@PatientMiddleName, 
		@PatientDOB, 
		@PatientDOBCode, 
		@PatientSexCode,
		@SsnPseudoIndicator,
		@PatientDeathDate,
		'A', 
		@LastUpdateDate, 
		@LastUpdateUser,
		@LastUpdateFunctionId,
		@SsnPrefix,
		ISNULL((@SSNPrefix + '/'),'') + SUBSTRING(@PatientSSN,1,3) + '-' + SUBSTRING(@PatientSSN,4,2) + '-' + SUBSTRING(@PatientSSN,6,4) + CASE (ISNULL(@SSNPseudoIndicator,0)) WHEN 1 THEN 'P' ELSE '' END
	)

SELECT @ERROR = @@ERROR, @ROWCOUNT = @@ROWCOUNT

	IF (@ERROR = 0)
		IF @ROWCOUNT <> 1	
			SET @ERROR = -1


SET NOCOUNT OFF

RETURN (@ERROR)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spHL7UpdatePatient') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spHL7UpdatePatient
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	Updates/Inserts a record in the patient table.
**		Used in sending VISTA information to/from VBECS.
**
**	Author:	Luke Meyer
**
**	Date: 	5/7/2003
*******************************************************************************************************************************************************************************
**	Modified
**	Date		Developer		Comments
**	--------------	-----------------------	-------------------------------------------------------------------------------------------------------------------------------
**	01/07/04	Brian Tomlin	Removed Patient Treatment insert because PatientTreatmentGUID
**					wasn't provided and it needs to be done in a separate sproc
**					Use spInsertPatientTreatment
**	01/10/05	D. Askew	Added @lastupdatedate
**	06/29/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Comment Header Adjusted, Added NOCOUNT, Specified table owners
**	11/18/2005	B. Tomlin	Added SsnPseudoIndicator parameter to address CR 1318
**	12/07/2005	B. Tomlin	Removed Insert logic and created a new spHL7InsertPatient sproc
**					to address CR 1354.
**	12/15/2005	C. Taylor	Adding code to set the VistaDisplayPatientId column instead of using a trigger (which creates two audit records)
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	09/21/2006	B. Tomlin	Added PatientDeathDate parameter to address CR 1826 **
**	05/13/2008	M. Smith	Changed @VistaPatientID to BIGINT datatype (CR 2431)
**	06/04/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	03/31/2009	M. Smith	Changed @PatientFirstName, @PatientLastName, and @PatientMiddleName to VARCHAR(30) (CR 2606)
**	04/06/2009	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE   PROCEDURE dbo.spHL7UpdatePatient
(
	@PatientGUID 		UNIQUEIDENTIFIER, 
	@VistaPatientID 	BIGINT,
	@PatientSSN 		CHAR(9) = NULL,
	@SsnPseudoIndicator	BIT = NULL,
	@PatientICN		VARCHAR(23) = NULL,
	@PatientLastName	VARCHAR(30), 
	@PatientFirstName	VARCHAR(30), 
	@PatientMiddleName	VARCHAR(30) = NULL, 
	@PatientDOB		DATETIME = NULL, 
	@PatientDOBCode		CHAR(1),
	@PatientDeathDate	DATETIME = NULL,
	@PatientSexCode		CHAR(1) = NULL, 
	@LastUpdateUser		VARCHAR(30),
	@LastUpdateFunctionId	INT,
	@LastUpdateDate		DATETIME
)

AS

SET NOCOUNT ON

DECLARE @ERROR		INT,
	@ROWCOUNT	INT

UPDATE dbo.Patient

	SET 
		VistaPatientID=@VistaPatientID,
		PatientICN=@PatientICN,
		PatientLastName=@PatientLastName,
		PatientFirstName=@PatientFirstName,
		PatientMiddleName=@PatientMiddleName,
		PatientDOB=@PatientDOB,
		PatientDOBCode=@PatientDOBCode,
		PatientSexCode=@PatientSexCode,
		PatientSSN=@PatientSSN,
		SsnPseudoIndicator=@SsnPseudoIndicator,
		LastUpdateDate=@LastUpdateDate,
		LastUpdateUser=@LastUpdateUser,
		LastUpdateFunctionId=@LastUpdateFunctionId,
		DisplayVistaPatientId=ISNULL((SSNPrefix + '/'),'') + SUBSTRING(@PatientSSN,1,3) + '-' + SUBSTRING(@PatientSSN,4,2) + '-' + SUBSTRING(@PatientSSN,6,4) + CASE (ISNULL(@SSNPseudoIndicator,0)) WHEN 1 THEN 'P' ELSE '' END,
		PatientDeathDate = @PatientDeathDate

	WHERE PatientGUID=@PatientGUID

SELECT @ERROR = @@ERROR, @ROWCOUNT = @@ROWCOUNT

	IF (@ERROR = 0)
		IF @ROWCOUNT <> 1	
			SET @ERROR = -1



SET NOCOUNT OFF

RETURN (@ERROR)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spInsertPatient') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spInsertPatient
GO
/*******************************************************************************************************************************************************************************
**
**	Desc: 	Inserts a record in the patient table.
**		Used in sending VISTA information to/from VBECS.
**
**	Author:	Luke Meyer
**
**	Date: 	5/7/2003
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------------	---------		------------------
**	04/22/2004	M. Jablonski	Call fnTimeZoneConversionDateTime function on all dates
**	06/07/2004	D. Askew	Added @rowversion parameter
**	12/17/2004	B.Tomlin	Removed timezone function converion on DOB
**	01/10/05	D. Askew	Added @lastupdatedate
**	03/03/05	C.VanStedum	Added @patientdeathdate
**	05/26/2005 	D. Askew	** Reviewed for compliance with database standards and recommendations **
**					Changed SQL keywords to caps; renamed parameters to be consistent with database
**					standards; removed NULL default on @patientlastname, @patientfirstname, @rowversion 
**					as columns are not permitted to be NULL; changed syntax to be consistent with database standards; 
**					removed PRINT statements; removed unused parameters @bloodtypecode, @conversionbloodtypecode, 
**					@divisioncode, @number,@primaryeligibility, @record_id, @rhfactorcode, @rowversion, @scpercent, 
**					@sensitive, @serviceconnected, @type, and @veteran; minor changes made to error handling; 
**					verified NO COUNT is ON/OFF
**	06/28/2005 	D. Askew	Comments updated
**	06/30/2005	D. Askew	Added back unused parameters @bloodtypecode, @conversionbloodtypecode, @divisioncode, 
**					@number,@primaryeligibility, @record_id, @rhfactorcode, @rowversion, @scpercent, @sensitive, 
**					@serviceconnected, @type, @veteran and default NULL for @rowversion to minimize code impact
**	07/18/2005	Lohse		redefined @patienticn as varchar(23), redefined @patientlocation as varchar(30)
**	07/29/2005	Lohse		Removeed PatientTreatment Insert logic, and EXISTS logic, and all unused parameters
**	11/18/2005	B. Tomlin	Added SsnPseudoIndicator to address CR 1318 - defaulting to null
**	12/15/2005	C. Taylor	Added SsnPrefix as a parameter (for future use)
**						Adding code to set the VistaDisplayPatientId column instead of using a trigger (which creates two audit records)
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	05/13/2008	M. Smith	Changed @VistaPatientID to BIGINT datatype (CR 2431)
**	06/04/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	03/31/2009	M. Smith	Changed @PatientFirstName, @PatientLastName, and @PatientMiddleName to VARCHAR(30) (CR 2606)
**	04/06/2009	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/

CREATE PROCEDURE dbo.spInsertPatient
(
	@patientguid 			UNIQUEIDENTIFIER, 
	@vistapatientid 			BIGINT, 
	@patientssn 			CHAR(9),
	@patienticn			VARCHAR(23) 		= NULL,
	@patientlastname		VARCHAR(30),
	@patientfirstname		VARCHAR(30),
	@patientmiddlename		VARCHAR(30)		= NULL, 
	@patientdob			DATETIME		= NULL, 
	@patientdobcode		CHAR(1), 
	@patientsexcode		CHAR(1)		= NULL, 
	@patientdeathdate		DATETIME 		= NULL,
	@aborhchangeindicator		BIT 			= NULL,
	@recordstatuscode		CHAR,
	@ssnpseudoindicator		BIT = NULL,
	@lastupdateuser		VARCHAR(30),
	@lastupdatefunctionid		INT,
	@lastupdatedate		DATETIME,
	@SsnPrefix			CHAR(2)= NULL
)

AS

SET NOCOUNT ON

DECLARE @error	INT
DECLARE @rowcount	INT

		INSERT INTO dbo.Patient
		(
			PatientGuid, 
			VistaPatientId, 
			PatientSsn, 
			PatientIcn, 
			PatientLastName, 
			PatientFirstName, 
			PatientMiddleName, 
			PatientDob, 
			PatientDobCode, 
			PatientDeathDate,
			PatientSexCode, 
			AboRhChangeIndicator,
			RecordStatusCode, 
			SsnPseudoIndicator,
			LastUpdateDate, 
			LastUpdateUser,
			LastUpdateFunctionId,
			SsnPrefix,
			DisplayVistaPatientId
		)

		VALUES
		(
			@patientguid,
			@vistapatientid, 
			@patientssn,
			@patienticn,
			@patientlastname, 
			@patientfirstname, 
			@patientmiddlename, 
			--Do not do time zone conversion as this a historic date
			@patientdob,
			@patientdobcode, 
			@patientdeathdate,
			@patientsexcode, 
			@aborhchangeindicator,
			@recordstatuscode, 
			@ssnpseudoindicator,
			@lastupdatedate,
			@lastupdateuser,
			@lastupdatefunctionid,
			@SsnPrefix,
			ISNULL((@SSNPrefix + '/'),'') + SUBSTRING(@PatientSSN,1,3) + '-' + SUBSTRING(@PatientSSN,4,2) + '-' + SUBSTRING(@PatientSSN,6,4) + CASE (ISNULL(@SSNPseudoIndicator,0)) WHEN 1 THEN 'P' ELSE '' END
		)

	SELECT @error = @@ERROR, @rowcount = @@ROWCOUNT

	IF @rowcount <> 1 RAISERROR( 50003, 16, 1, 'Patient', @rowcount )


SET NOCOUNT OFF

RETURN(@error)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spPatientSearch') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spPatientSearch
GO

SET QUOTED_IDENTIFIER OFF
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	Searches for Patient information based on either the patient last 
**		name, the patient last name and last four characters of
**		the SSN, the full SSN, the last four characters of the SSN, or the 
**		accession number.
**
**	Author: 	Cameron Taylor
**
**	Date: 	10/9/2001
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	4/14/2003	C. Jensen	This stored procedure doesn't work correctly with the new FillSchema method in StoredProcdure.  Five
**					tables are returned instead of one.  I have temporarily commented out parts of the sproc until I can fix it.
**	5/8/2003	L. Meyer	Added in the previously commented lines	except for accession number.  Not sure which field/where this 
**					is now
**	8/14/2003	C. Taylor	Re-applied AccessionNumber search
**	11/24/2003	C. Jensen	Added functions to retrieve ABO/Rh.
**	01/13/2004	C. Taylor	Added DisplayVistaPatientId
**	04/22/2004	M. Jablonski	Call fnTimeZoneConversionDateTime function on all dates
**	04/23/2004	C. Taylor	Removed wild cards at start of PatientLastName and removed search on PatientFirstName -- see BR_3.20.
**	04/27/2004	C. Jensen	Commented out functions that retrieve ABO/Rh.  This will now be done in the code.
**	05/05/2004	C. Taylor	Replaced PatientAccessionNumber with Specimenuid
**	06/03/2004	C. Taylor	Added AboRhChangeIndicator
**	12/10/2004	C. Jensen	Changed ABO/Rh processing - Added new and improved fnGetABO and fnGetRh back ito sproc
**	01/24/2005	C. Taylor	Removed wild cards at end of PatientSSN -- see BR_3.20
**	01/25/2005	C. Taylor	Added PatientDeathDate
**	07/15/2005	N. Paterson	** Reviewed for compliance with database standards and recommendations **
**					Removed Name/input/output from comment header, added SET NOCOUNT, formatted SQL
**					Placed input parameters in brackets, specified object owner
**	01/17/2006	D. Askew	Added code to not bring back data for merged patients 
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	02/07/2006	D. Askew	Removed BloodTypeCode, RhFactorCode, ConversionBloodTypeCode and ConversionRhFactorCode
**					from SELECT in order to improve performance
**	02/11/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	03/15/2006	C. Jensen	Added conversion ABO/Rh back.
**	03/22/2006 	Lohse		** Reviewed for compliance with database standards and recommendations **
**	03/31/2009	M. Smith	Changed @PatientLastName to VARCHAR(31) (CR 2606)
**	04/06/2009	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spPatientSearch
(
	@PatientLastName	VARCHAR(31)	= NULL,
	@PatientSSN		VARCHAR(9)	= NULL,
	@specimenuid		VARCHAR(21) 	= NULL,
	@DivisionCode		CHAR(5)
)

AS

DECLARE @error	INT
SET @error = 0

SET NOCOUNT ON

	IF LEN(@patientssn) = 4

	SET @patientssn = '%' + @patientssn

	SELECT	
		P.PatientGuid,
		P.FinalMergeToPatient,
		P.VistaPatientId,
		P.PatientSsn,
		P.DisplayVistaPatientId,
		P.PatientLastName,
		P.PatientFirstName,
		P.PatientMiddleName,
		P.PatientDob,
		P.PatientSexCode,
		P.PatientDobCode,
		P.PatientDeathDate,
		P.AboRhChangeIndicator,
		P.BloodTypeCode AS ConversionBloodTypeCode,
		P.RhFactorCode AS ConversionRhFactorCode,
		P.[RowVersion]

	FROM
		dbo.Patient P

	WHERE 
		( 
			(	@patientlastname IS NOT NULL AND

			    	(	@patientlastname LIKE P.PatientLastName + '%' OR

					P.PatientLastName LIKE @patientlastname + '%' ) AND

					( @patientssn IS NULL OR ( @patientssn IS NOT NULL AND PatientSSN LIKE @patientssn)
			 	)
			)

			OR

			(	@specimenuid IS NOT NULL AND

				( 	SELECT
						COUNT(1) 

					FROM 		
						dbo.PatientSpecimen PS

					WHERE 	

						P.PatientGUID = PS.PatientGUID 
					AND 	PS.Specimenuid LIKE @specimenuid + '%' 
				) > 0  
			) 

			OR

			(	
				@patientssn IS NOT NULL 
			AND	@patientlastname IS NULL 
			AND	PatientSSN LIKE @patientssn
			) 
		)	

		AND P.RecordStatusCode != 'X'

		-- do not bring back data for merged patients
		AND P.PatientGuid NOT IN
		(
			SELECT 
				MergeFromPatient 

			FROM 
				dbo.Patient 

			WHERE 
				MergeFromPatient IS NOT NULL
		)


SET @error = @@ERROR

SET NOCOUNT OFF
RETURN(@error)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spSingleBloodProductModification') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spSingleBloodProductModification
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	Returns all possible target BloodProducts for a given modification
**
**	Author:	Dan McHugh
**
**	Date: 	10/14/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	10/14/04	D. McHugh	Created
**	11/15/04	D. McHugh	Added logic to handle pooling
**	12/06/04	D. McHugh	Added logic for Codabar Thaw rule (explained below)
**	01/27/05	D. McHugh	Let's ignore some attributes when pooling
**	06/01/05	D. McHugh	Now choosing from BloodProduct only when RecordStatusCode = 'A'
**	07/13/05	D. McHugh	DR1430 - Allowing Leukoreduce to map to any D_ attribute (except D0, D1)
**	07/18/05	D. McHugh	DR1602 - Revised Truth table
**					Modified code to determine ISBT vs Codabar to use 'E' or 'F' as ISBT
**					Added SET NOCOUNTs
**	07/12/2005	N.Paterson	** Secondary review for compliance with database standards and recommendations **
					Modified comment header, specified object owners, formatted SQL
	02/22/2006	D. McHugh	Fixed line 345 - Making the list of exclusions agree with the list in the preface to TT_26
**	04/19/2006	D. McHugh	CR1661  - allow blood products with a RecordStatusCode = 'L' to be modified
**						- allow the procedure to add more targets to match multiple D_ targets for Leukoreduce (using LIKE)
**	04/01/2009	D. McHugh	CR2621 - Changed how the product attribute forms are compared by removing the calls to function
**						fnRemoveAttributes and adding calls to function fnCompareProductAttributeForms
**						Commented out code for pooling/thawpooling that was handling C2/D_ attributes
*******************************************************************************************************************************************************************************/

CREATE PROCEDURE dbo.spSingleBloodProductModification (
	@pBloodProductGuid 		UNIQUEIDENTIFIER = NULL,	-- Making BloodProductGuid, ProductTypeCode, ProductCode all optional
	@pProductTypeCode 		VARCHAR(4) = '',
	@pProductCode 		VARCHAR(5) = '',
	@pProductModificationCode 	CHAR(1),		-- The modification being done
	@pMethodSelect 		INTEGER = -1,			-- 1 = opened, 0 = closed, -1 = either
	@pPooledProductTypeCode 	VARCHAR(4) = '',	-- The "Pooled" parameters only are used if the ModificationCode is 'P' or 'U',
	@pPooledProductCode 		VARCHAR(5) = '',		--	and even then, the Pooled parameters are optional.
	@BloodProductModification 	CURSOR VARYING OUTPUT	-- Need to declare a cursor in any procedure calling this one to hold the results
)

AS


SET NOCOUNT ON

/*******************************************************************************************************************************************************************************
**
**	The process of determining the correct ToProductCode is a fun one!!
**
**	1.  Find the ProductAttributeForm in BloodProduct matching the parameter ProductCode, ProductTypeCode, BloodProductGuid
**		save this value as FromProductAttributeForm
**	2.  Use the truth table PermittedProductModification to determine the new ToProductAttributeForm(s)
**		(Since a single modification can map to multiple core conditions, it's possible to return
**		 more than one ToProductAttributeForm)
**	3.  Apply all special rules
**		- Rule 7 - ProductAttributeForm cannot contain A2, A3, or A4
**		- Rule 9 - Target ProductAttributeForm can't contain B2 when Method is closed
**		- Do not include where ProductModificationCode = 'I' and the FromProductAttributeForm has 'C2'
**		- Do not include where ProductModificationCode = 'L' and the FromProductAttributeForm has ' D_'
**		- If ProductModificationCode is 'P' or 'U', and there's a Pool going (parameters @pPooledProductTypeCode
**			and @pPooledProductCode), then adjust the ToProductAttributeForm for the pool.
**		- Codabar Thaw rule - If thawing a Codabar unit of FFP or Cryo, the ToProductCode must = the FromProductCode
**	4.  Find the ProductCode(s) on BloodProduct matching the ToProductTypeCode(s) & ToProductAttributeForm(s)
**		The ToProductTypeCode(s) come directly from the truth table, based on the incoming data
**	5.  Remove any incomplete records.
**		The truth table lists all possible modifications.  Not every modification has actually been
**		performed, so not every possible ProductCode exists on BloodProduct
**	6.  Return all remaining records
**
*******************************************************************************************************************************************************************************/

DECLARE @FromProductCode VARCHAR(5)		--From BP
DECLARE @ToProductCode VARCHAR(5)		--Calculated from TT/BP
DECLARE @FromProductTypeCode VARCHAR(4)		--From TT
DECLARE @ToProductTypeCode VARCHAR(4)		--From TT
DECLARE @FromProductAttributeForm VARCHAR(20)	--From BP
DECLARE @ToProductAttributeForm VARCHAR(20)	--Calculated from TT/BP
DECLARE @FromCoreCondition VARCHAR(3)		--From TT
DECLARE @ToCoreCondition VARCHAR(3)		--From TT
DECLARE @ProductModificationCode CHAR(1)	--From TT
DECLARE @MethodSelect INTEGER			--From TT
DECLARE @AddTargetAttribute VARCHAR(20)		--From TT, must be empty, or formatted like '__ __ __ __ ...etc...'

DECLARE @Attribute CHAR(2)			--calculated from @AddTargetAttribute
DECLARE @Counter INTEGER			--simple counter

DECLARE @Rows INTEGER				--Number of rows in resulting cursor
DECLARE @PooledProductAttributeForm VARCHAR(20)	--Calculated from parameters @PooledProductTypeCode, @PooledProductCode
DECLARE @ModifiedPooledProductAttributeForm VARCHAR(20)	--Wanted a long variable name, holds the "D2" version of @PooledProductAttributeForm
DECLARE @TargetLabelType VARCHAR(20)		--Shooting for a Codabar or ISBT?

DECLARE @AttributeClassList As varchar(40)	--A list of attribute classes that can be excluded from target products
DECLARE @Position As INTEGER			--For navigating through the list of excludable attribute classes
DECLARE @CurrentAttributeClass AS CHAR(2)	--The current entry from the list of attribute classes being considered

--This was used to help debug things, only useful when you can see the Print statement (like from Query Analyzer)
DECLARE @ShowFilteredRecords INTEGER		--  1 = Showing records being filtered out, 0 = only show final result
SET @ShowFilteredRecords = 0

SET @Rows = 0


IF (@pBloodProductGuid IS NULL AND @pProductCode = '') AND (@pProductModificationCode IN ('P', 'U'))
	BEGIN
		--Can't attempt to pool without specifying a productcode / guid
		PRINT 'Need to have at least either BloodProductGuid or ProductCode if attempting to Pool'
		RETURN 0
	END


--Using this temp table to keep all ProductModificationCode, ProductTypeCode, ProductCode, ProductAttributeForm data (before & after mod'd)
Declare @BPMTemp TABLE (
	ProductModificationCode CHAR(1),	--From TT
	MethodSelect 		INTEGER,			--From TT
	AddTargetAttribute 	VARCHAR(20),		--From TT
	FromBloodProductGuid 	UNIQUEIDENTIFIER,	--From BP
	FromProductTypeCode 	VARCHAR(4),		--From TT
	FromProductCode 	VARCHAR(5),		--From BP
	FromCoreCondition 	VARCHAR(3),		--From BP
	FromProductAttributeForm VARCHAR(20),	--From BP
	ToBloodProductGuid 	UNIQUEIDENTIFIER,	--From BP
	ToProductTypeCode 	VARCHAR(4),		--From TT
	ToProductCode 		VARCHAR(5),		--From BP based on ToProductAttributeForm
	ToCoreCondition 	VARCHAR(3),		--From TT
	ToProductAttributeForm 	VARCHAR(20),	--Calculated from FromProductAttributeForm, ToCoreCondition, AddTargetAttribute
	ExpirationDateRule 	INTEGER		--From TT
)


IF @pProductModificationCode IN ('P', 'U') AND ISNULL(@pPooledProductTypeCode, '') = '' AND ISNULL(@pPooledProductCode, '') = ''
--Insert related data from BloodProduct & PermittedProductModification

	BEGIN
	INSERT INTO @BPMTemp
		SELECT 	TT.ProductModificationCode,
			TT.MethodSelect,
			ISNULL(TT.AddTargetAttribute, ''), 
			BP.BloodProductGuid,
			TT.FromProductTypeCode,
			BP.ProductCode,
			Left(BP.ProductAttributeForm, 3),
			BP.ProductAttributeForm,
			BP.BloodProductGuid,
			BP.ProductTypeCode,
			BP.ProductCode, 
			LEFT(ProductAttributeForm, 3),
			BP.ProductAttributeForm,
			TT.ExpirationDateRule
	
		FROM dbo.PermittedProductModification TT JOIN dbo.BloodProduct BP
		ON 	(BP.ProductTypeCode = TT.FromProductTypeCode)
	
		WHERE TT.ProductModificationCode = @pProductModificationCode AND
			(TT.MethodSelect = @pMethodSelect OR @pMethodSelect = -1) AND
			(BP.BloodProductGuid = @pBloodProductGuid OR @pBloodProductGuid IS NULL) AND
			(TT.FromProductTypeCode = @pProductTypeCode OR @pProductTypeCode = '') AND
			(BP.ProductCode = @pProductCode OR @pProductCode = '') AND
			(TT.FromCoreCondition = 'Any' OR TT.FromCoreCondition = LEFT(BP.ProductAttributeForm, 3)) AND
			(BP.RecordStatusCode IN ('A', 'L'))

--Remove a defined set of core conditions & attributes (defined in introductory text to TT_26.02)
	DELETE FROM @BPMTemp 
	WHERE
		(FromProductAttributeForm LIKE ('% A[234]%') OR ToProductAttributeForm LIKE ('% A[234]%')) OR
		(FromProductTypeCode = 'E006' AND FromCoreCondition = '@B6') OR
		(FromCoreCondition IN ('@24', '@25', '@27', '@96', '@A9', '@AE', '@AV', '@B0'))

	GOTO THEEND
	END
ELSE

	--Insert related data from BloodProduct & PermittedProductModification
	INSERT INTO @BPMTemp
	
		SELECT 	TT.ProductModificationCode,
			TT.MethodSelect,
			ISNULL(TT.AddTargetAttribute, ''), 
			BP.BloodProductGuid,
			TT.FromProductTypeCode,
			BP.ProductCode,
			Left(BP.ProductAttributeForm, 3),
			BP.ProductAttributeForm,
			NULL, --still need more info before calculating ToBloodProductGuid
			TT.ToProductTypeCode,
			'', --still need more info before calculating ToProductCode
			TT.ToCoreCondition,
			'', --next step will be to calculate this value, the ToProductAttributeForm
			TT.ExpirationDateRule
	
		FROM dbo.PermittedProductModification TT JOIN dbo.BloodProduct BP
		ON 	(BP.ProductTypeCode = TT.FromProductTypeCode)
	
		WHERE TT.ProductModificationCode = @pProductModificationCode AND
			(TT.MethodSelect = @pMethodSelect OR @pMethodSelect = -1) AND
			(BP.BloodProductGuid = @pBloodProductGuid OR @pBloodProductGuid IS NULL) AND
			(TT.FromProductTypeCode = @pProductTypeCode OR @pProductTypeCode = '') AND
			(BP.ProductCode = @pProductCode OR @pProductCode = '') AND
			(TT.FromCoreCondition = 'Any' OR TT.FromCoreCondition = LEFT(BP.ProductAttributeForm, 3)) AND
			(BP.RecordStatusCode IN ('A', 'L'))

--Since on the truth table, a FromCoreCondition can map to more than one ToCoreCondition,
-- the table @BPMTemp may have more than one record
IF (SELECT COUNT(1) FROM @BPMTemp) = 0
	BEGIN
		--No data, so gonna try to see why (only useful for debugging)
		IF (SELECT COUNT(1)  FROM dbo.BloodProduct 

			WHERE ProductCode = @pProductCode AND 
				(ProductTypeCode = @pProductTypeCode OR RTrim(@pProductTypeCode) = '')) = 0

			PRINT 'The ProductTypeCode <' + @pProductTypeCode + '>, ProductCode <' + @pProductCode + '> not on BloodProduct.'



		ELSE IF(SELECT COUNT(1) FROM dbo.PermittedProductModification

			WHERE ProductModificationCode = @pProductModificationCode AND
 
				(FromProductTypeCode = @pProductTypeCode Or @pProductTypeCode = '')) = 0

			PRINT 'The ProductModificationCode <' + @pProductModificationCode + '>, MethodSelect <' + CAST(@pMethodSelect AS VARCHAR(1)) + '>, FromProductTypeCode <' + @pProductTypeCode + '> not on PermittedProductModification.'
			
		ELSE
			PRINT 'No match'


			RETURN 0

	END

--Some truth table conditions apply to any core condition. So will cheat and take the core condition
-- from the ProductAtrributeForm(s) that were found.
UPDATE @BPMTemp
	SET FromCoreCondition = LEFT(FromProductAttributeForm, 3) 
	WHERE FromCoreCondition = 'Any'


--Takes two steps to determine the new ToProductAttributeForm
-- 1.  Make the core condition change
-- 2.  Add in the AddTargetAttribute
UPDATE @BPMTemp
	SET ToProductAttributeForm = REPLACE(FromProductAttributeForm, FromCoreCondition, ToCoreCondition)
	WHERE ToCoreCondition <> 'Sam'

UPDATE @BPMTemp
	SET ToProductAttributeForm = FromProductAttributeForm
	WHERE ToCoreCondition = 'Sam'


--Handling the extra ProductAttributeForm conversion rules
DECLARE TTCursor CURSOR LOCAL FOR

	SELECT AddTargetAttribute, ToProductAttributeForm

	FROM @BPMTemp 

	WHERE AddTargetAttribute <> ''

OPEN TTCursor

FETCH NEXT FROM TTCursor INTO @AddTargetAttribute, @ToProductAttributeForm

WHILE @@FETCH_STATUS = 0

	BEGIN
		--AddTargetAttribute should be '', '__', '__ __', '__ __ __', etc.
		-- So assuming it's formatted correctly, should be able to nab the attributes easily and
		-- call the stored procedure to update ToProductAttributeForm
		SET @Counter = 2

		WHILE @Counter <= LEN(RTRIM(@AddTargetAttribute))

			BEGIN	
				SET @Attribute = SUBSTRING(@AddTargetAttribute, @Counter - 1, 2)

				IF LEFT(@Attribute, 1) >= 'A' AND LEFT(@Attribute, 1) <= 'N'
					--Call function responsible for logic in adding attributes
					SET @ToProductAttributeForm = dbo.fnAddAttributeToProductAttributeForm(@Attribute, @ToProductAttributeForm)

				SET @Counter = @Counter + 3
			END

		UPDATE @BPMTemp SET ToProductAttributeForm = @ToProductAttributeForm WHERE CURRENT OF TTCursor		
				
		FETCH NEXT FROM  TTCursor INTO @AddTargetAttribute, @ToProductAttributeForm
	END

CLOSE TTCursor
DEALLOCATE TTCursor


--Section TT_26.02, Rule 9 - Target ProductAttributeForm can't contain B2 when Method is closed
IF EXISTS (SELECT 2 FROM @BPMTemp

	WHERE MethodSelect = 0 AND
		ToProductAttributeForm LIKE ('% B2%') AND
		FromProductAttributeForm LIKE ('% B2%'))

	BEGIN

		IF @ShowFilteredRecords = 1		

			SELECT 'Not including for Rule 9 - Target ProductAttributeForm cannot have B2 when Method is closed' AS Reason, * 
			   FROM @BPMTemp
			WHERE MethodSelect = 0 AND
				ToProductAttributeForm LIKE ('% B2%')
	
	
		DELETE FROM @BPMTemp WHERE MethodSelect = 0 AND
			ToProductAttributeForm LIKE ('% B2%') AND
			FromProductAttributeForm NOT LIKE ('% B2%')

	END


--Do not include where ProductModificationCode = 'I' and the FromProductAttributeForm has 'C2'
IF EXISTS (SELECT 5 FROM @BPMTemp

	WHERE ProductModificationCode = 'I' AND FromProductAttributeForm LIKE '% C2%')

	BEGIN
		IF @ShowFilteredRecords = 1

			SELECT 'Not including where ProductModificationCode = I and FromProductAttributeForm has C2' AS Reason, * FROM @BPMTemp

				WHERE ProductModificationCode = 'I' And FromProductAttributeForm LIKE '% C2%'




		DELETE FROM @BPMTemp WHERE ProductModificationCode = 'I' AND FromProductAttributeForm LIKE '% C2%'
	END


--Do not include where ProductModificationCode = 'L' and the FromProductAttributeForm has 'D_'
IF EXISTS (SELECT 27 FROM @BPMTemp 

	WHERE ProductModificationCode = 'L' AND FromProductAttributeForm LIKE '% D_%')

	BEGIN

		IF @ShowFilteredRecords = 1

			SELECT 'Not including where ProductModificationCode = L and FromProductAttributeForm has D_' AS Reason, * FROM @BPMTemp 

			WHERE ProductModificationCode = 'L' AND FromProductAttributeForm LIKE '% D_%'

		DELETE FROM @BPMTemp WHERE ProductModificationCode = 'L' AND FromProductAttributeForm LIKE '% D_%'

	END


--Remove a defined set of core conditions & attributes (defined in introductory text to TT_26.02)
DELETE FROM @BPMTemp 
WHERE
	(FromProductAttributeForm LIKE ('% A[234]%') OR ToProductAttributeForm LIKE ('% A[234]%')) OR
	(FromProductTypeCode = 'E006' AND FromCoreCondition = '@B6') OR
	(FromCoreCondition IN ('@24', '@25', '@27', '@96', '@A9', '@AE', '@AV', '@B0'))


--Determine the target label type
IF @pProductModificationCode IN ('P', 'U') AND @pPooledProductTypeCode <> '' AND @pPooledProductCode <> ''

	BEGIN

		--Based on BR_24.11 & BR_24.12, gonna force the current unit to choose the same label
		-- type as was used so far in the pool
		IF LEFT(@pPooledProductCode, 1) LIKE ('[EF]')
			SET @TargetLabelType = 'ISBT'
		ELSE
			SET @TargetLabelType = 'Codabar'

	END

ELSE

	BEGIN

		IF LEFT(@pProductCode, 1) LIKE ('[EF]')
			SET @TargetLabelType = 'ISBT'
		ELSE IF ISNUMERIC(LEFT(@pProductCode, 1)) = 1
			SET @TargetLabelType = 'Codabar'
		ELSE IF (SELECT COUNT(1) FROM dbo.BloodProduct WHERE BloodProductGuid = @pBloodProductGuid AND LEFT(ProductCode, 1) LIKE ('[EF]')) > 0
			SET @TargetLabelType = 'ISBT'
		ELSE IF (SELECT COUNT(1) FROM dbo.BloodProduct WHERE BloodProductGuid = @pBloodProductGuid AND LEFT(ProductCode, 1) NOT LIKE ('[EF')) > 0
			SET @TargetLabelType = 'Codabar'
		ELSE
			SET @TargetLabelType = 'Either'

	END



--The ToProductAttributeForms should now all be calculated.  Time to look up the corresponding ProductCode
-- Only use a ProductCode that matches the Label type (ISBT vs. Codabar) - so don't go grabbing
-- a Codabar ToProductCode for an ISBT FromProductCode & vice versa
--Pooling / ThawPooling need to also factor out various attributes (see DR1304)
IF @pProductModificationCode In ('P', 'U')

	BEGIN

		--Remove records from BPMTemp where the ToProductTypeCode (which is based off of the first set of blood product parameters)
		-- doesn't match the ToProductTypeCode that's calculated off PermittedProductModification based off of the second set of blood product parameters
		DELETE FROM @BPMTemp WHERE ToProductTypeCode NOT IN 
			(SELECT DISTINCT ToProductTypeCode FROM PermittedProductModification WHERE FromProductTypeCode = @pPooledProductTypeCode AND ProductModificationCode = @pProductModificationCode AND MethodSelect = @pMethodSelect)


		SET @AttributeClassList = 'B2C2D_E_F_G_H_I_J_K_L_M_N_'
		SET @Position = 1
	
		WHILE @Position <= LEN(@AttributeClassList)
			BEGIN
				SET @CurrentAttributeClass = SUBSTRING(@AttributeClassList, @Position, 2)

				--Remove records from BPMTemp where the current attribute isn't correct
				IF @CurrentAttributeClass = 'B2'
					BEGIN

						--Delete records that have a B2 target but shouldn't (closed modification, no parent units have B2)
						DELETE FROM @BPMTemp WHERE ToProductAttributeForm LIKE '% B2%' AND MethodSelect = 0 AND FromProductAttributeForm NOT LIKE '% B2%'

						--Delete records that don't have a B2 target but should because using open modification
						DELETE FROM @BPMTemp WHERE ToProductAttributeForm NOT LIKE '% B2%' AND MethodSelect = 1

						--Update records that don't have a B2 target but should because at least one parent unit has B2
						UPDATE @BPMTemp SET ToProductAttributeForm = dbo.fnAddAttributeToProductAttributeForm('B2', ToProductAttributeForm)
						WHERE ToProductAttributeForm NOT LIKE '% B2%' AND 
							(FromProductAttributeForm LIKE '% B2%' OR 
							(SELECT COUNT(*) FROM dbo.BloodProduct WHERE ProductTypeCode = @pPooledProductTypeCode AND ProductCode = @pPooledProductCode AND ProductAttributeForm LIKE '% B2%') > 0)

					END
				ELSE
					BEGIN

						UPDATE @BPMTemp 
							SET ToProductAttributeForm = REPLACE(ToProductAttributeForm, ' ' + SUBSTRING(ToProductAttributeForm, CHARINDEX(' ' + LEFT(@CurrentAttributeClass, 1), ToProductAttributeForm) + 1, 2), '')
							FROM @BPMTemp 
							WHERE (ToProductAttributeForm LIKE '% ' + @CurrentAttributeClass + '%') AND 
							((FromProductAttributeForm NOT LIKE '% ' + @CurrentAttributeClass + '%') OR
							(SELECT COUNT(*) FROM dbo.BloodProduct WHERE ProductTypeCode = @pPooledProductTypeCode AND ProductCode = @pPooledProductCode AND ProductAttributeForm LIKE '% ' + @CurrentAttributeClass + '%') = 0)
					END

			SET @Position = @Position + 2
			END

		--Find all blood products that have an exact match for product type code & product attribute form
		UPDATE @BPMTemp
			SET ToProductCode = BP.ProductCode,
				ToBloodProductGuid = BP.BloodProductGuid
			FROM @BPMTemp TT JOIN dbo.BloodProduct BP
			ON	TT.ToProductTypeCode = BP.ProductTypeCode
			WHERE 	BP.ProductAttributeForm  = TT.ToProductAttributeForm AND
				((LEFT(BP.ProductCode, 1) LIKE ('[EF]') AND @TargetLabelType <> 'Codabar') OR	
				 (LEFT(BP.ProductCode, 1) NOT LIKE ('[EF]') And @TargetLabelType <> 'ISBT'))

		--Find blood products that have a like match for the product attribute form
		UPDATE @BPMTemp
			SET ToProductCode = BP.ProductCode,
				ToBloodProductGuid = BP.BloodProductGuid
			FROM @BPMTemp TT JOIN dbo.BloodProduct BP
			ON	TT.ToProductTypeCode = BP.ProductTypeCode
			WHERE 	TT.ToProductCode = '' AND
				dbo.fnCompareProductAttributeForms(TT.ToProductAttributeForm, BP.ProductAttributeForm) = 1 AND
				((LEFT(BP.ProductCode, 1) LIKE ('[EF]') AND @TargetLabelType <> 'Codabar') OR	
				 (LEFT(BP.ProductCode, 1) NOT LIKE ('[EF]') And @TargetLabelType <> 'ISBT'))

		--Delete all temporary stuff that didn't match
		DELETE FROM @BPMTemp WHERE ToProductCode = ''

		--Insert any other matches
		INSERT INTO @BPMTemp
		SELECT TT.ProductModificationCode, TT.MethodSelect, TT.AddTargetAttribute, 
			TT.FromBloodProductGuid, TT.FromProductTypeCode, TT.FromProductCode, TT.FromCoreCondition, TT.FromProductAttributeForm,
			BP.BloodProductGuid, TT.ToProductTypeCode, BP.ProductCode, TT.ToCoreCondition, TT.ToProductAttributeForm,
			TT.ExpirationDateRule
		FROM @BPMTemp TT JOIN dbo.BloodProduct BP
		ON	TT.ToProductTypeCode = BP.ProductTypeCode
		WHERE 	dbo.fnCompareProductAttributeForms(TT.ToProductAttributeForm, BP.ProductAttributeForm) = 1 AND
				TT.ToProductCode <> BP.ProductCode AND
				((LEFT(BP.ProductCode, 1) LIKE ('[EF]') AND @TargetLabelType <> 'Codabar') OR	
				 (LEFT(BP.ProductCode, 1) NOT LIKE ('[EF]') And @TargetLabelType <> 'ISBT'))

	END
ELSE IF @pProductModificationCode = 'S'

	UPDATE @BPMTemp
		SET ToProductCode = FromProductCode,
			ToBloodProductGuid = FromBloodProductGuid

ELSE

	UPDATE @BPMTemp
		SET ToProductCode = BP.ProductCode,
			ToBloodProductGuid = BP.BloodProductGuid

		FROM @BPMTemp TT JOIN dbo.BloodProduct BP
		ON 	TT.ToProductTypeCode = BP.ProductTypeCode
		WHERE 	((BP.ProductAttributeForm  = TT.ToProductAttributeForm)  OR
			--When matching to Leukoreduce, AddTargetAttribute of 'B2 D_', it cannot return 'B2 D0' or 'B2 D1'
			 (BP.ProductAttributeForm  LIKE TT.ToProductAttributeForm AND TT.ToProductAttributeForm LIKE '%[_]%' AND BP.ProductAttributeForm NOT LIKE '% D[01]%' )) AND
			((LEFT(BP.ProductCode, 1) LIKE ('[EF]') AND @TargetLabelType <> 'Codabar') OR
			 (LEFT(BP.ProductCode, 1) NOT LIKE ('[EF]') And @TargetLabelType <> 'ISBT'))



--Are we doing Codabar?  Cuz if so, it's possible that there are multiple ProductCode's
-- for the given ProductAttributeForm + ProductTypeCode
--Also possible if we're pooling
IF @TargetLabelType = 'ISBT' AND @pProductModificationCode NOT IN ('P', 'U', 'S')

	--Basically repeating that last Update statement, change it into Insert, and filter
	-- out the ProductCode that was already updated
	INSERT INTO @BPMTemp

		SELECT TT.ProductModificationCode, TT.MethodSelect, TT.AddTargetAttribute, 
			TT.FromBloodProductGuid, TT.FromProductTypeCode, TT.FromProductCode, TT.FromCoreCondition, TT.FromProductAttributeForm,
			BP.BloodProductGuid, TT.ToProductTypeCode, BP.ProductCode, TT.ToCoreCondition, TT.ToProductAttributeForm,
			TT.ExpirationDateRule

		FROM @BPMTemp TT JOIN dbo.BloodProduct BP
		ON	TT.ToProductTypeCode = BP.ProductTypeCode
		WHERE 	--dbo.fnCompareProductAttributeForms(TT.ToProductAttributeForm, BP.ProductAttributeForm) <> '' AND
			BP.ProductAttributeForm LIKE TT.ToProductAttributeForm AND
			((@TargetLabelType <> 'ISBT' AND LEFT(BP.ProductCode, 1) NOT LIKE ('[EF]')) OR
			(@TargetLabelType = 'ISBT' AND LEFT(BP.ProductCode, 1) LIKE ('[EF]'))) AND
			TT.ToProductCode <> BP.ProductCode

ELSE IF @TargetLabelType <> 'ISBT' AND @pProductModificationCode NOT IN ('P', 'U', 'S')

	INSERT INTO @BPMTemp

		SELECT TT.ProductModificationCode, TT.MethodSelect, TT.AddTargetAttribute, 

			TT.FromBloodProductGuid, TT.FromProductTypeCode, TT.FromProductCode, TT.FromCoreCondition, TT.FromProductAttributeForm,

			BP.BloodProductGuid, TT.ToProductTypeCode, BP.ProductCode, TT.ToCoreCondition, TT.ToProductAttributeForm,

			TT.ExpirationDateRule

		FROM @BPMTemp TT JOIN dbo.BloodProduct BP
		ON
			TT.ToProductTypeCode = BP.ProductTypeCode

		WHERE 	BP.ProductAttributeForm LIKE TT.ToProductAttributeForm AND

			LEFT(BP.ProductCode, 1) NOT LIKE ('[EF]') AND
			TT.ToProductCode <> BP.ProductCode

-- Codabar Thaw rule - If thawing a Codabar unit of FFP or Cryo, the ToProductCode must = the FromProductCode
IF @pProductModificationCode = 'T'
	BEGIN
		DELETE FROM @BPMTemp

		WHERE FromProductTypeCode IN

			(SELECT DISTINCT ProductTypeCode FROM dbo.ProductType WHERE ProductTypePrintName LIKE '%FFP%' OR ProductTypePrintName LIKE '%Cryo%') AND
			LEFT(FromProductCode, 1) NOT LIKE ('[EF]') AND
			FromProductCode <> ToProductCode			
	END



--Removing records with no matching ToProductCode
--This happens because the truth table allows for a particular modification, but there's no corresponding bloodproduct
IF (SELECT COUNT(1) FROM @BPMTemp WHERE ToProductCode = '') > 0

	BEGIN
		IF @ShowFilteredRecords = 1
			SELECT 'Skipping records with no matching ToProductCode' AS Reason, * FROM @BPMTemp
			WHERE ToProductCode = ''

		DELETE FROM @BPMTemp WHERE ToProductCode = ''
	END


--Remove records where the split modification doesn't match
DELETE FROM @BPMTemp WHERE ProductModificationCode = 'S' AND FromProductCode <> ToProductCode

THEEND:
--All right, let's end this thing already.  Create the cursor to return the results.
IF (SELECT COUNT(1) FROM @BPMTemp) > 0

	BEGIN

		DECLARE BPMCursor CURSOR STATIC LOCAL FOR

		SELECT * FROM  @BPMTemp

		ORDER BY FromProductTypeCode, FromProductCode, ToProductTypeCode, ToProductCode

		OPEN BPMCursor

		SET @Rows = @@Cursor_Rows
		SET @BloodProductModification = BPMCursor

		/*ADDED BY NPATERSON 08/22/05  NOTE: IMPLEMENTING TWO LINES BELOW WILL MAKE THIS PROC NOT WORK !!!*/
		--CLOSE BPMCursor
		--DEALLOCATE BPMCursor

	END

ELSE
	PRINT 'All records filtered out'

SET NOCOUNT OFF

RETURN @Rows

--And we're done!

GO 


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetRecentlyUpdatedPatientDetails') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetRecentlyUpdatedPatientDetails
GO

/*******************************************************************************************************************************************************************************
**	Desc: 		Returns information for recently updated patients
**
**	Use Case(s):	108	
**
**	Author: 		David Askew
**
**	Date: 		09/27/2006
**
*******************************************************************************************************************************************************************************
**	Modified:
** 	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	10/03/06	D. Askew	Removed function call to fnGetPendingOrderCountForPatient in SELECT; added Pending Test Order 
**					Count to SELECT; added ORDER BY clause; removed PC.FromPatientDeathDate IS NULL from WHERE
**	10/23/06	D. Askew	Added code to WHERE clause to ignore deceased patient updates
**	10/27/06	D. Askew	Removed code from WHERE clause to ignore deceased patient updates; any updates to deceased 
**					patients, however unlikely, should be shown here 
**	11/20/06	D. Askew	Added code to WHERE clause to ignore deceased patient updates yet again (if a patient's death date 
**					is removed, then that will show up under deceased updates); changed SELECT for SsnPseudoIndicator
**					columns
**	03/28/07	D. Askew	Added PC.PatientChangeStatusCode (CR 2165); changed LastUpdateDate from FromPatient to 
**					PatientChange (PC) (CR 2165); removed FromPatientPendingOrdersCount subquery and added call to
**					dbo.fnFromPatientPendingOrdersCount
**	03/30/07	D. Askew	Added AND PC.PatientChangeStatusCode <> 'X' in order to exclude updates for patients with expired 
**					orders
**	04/03/07	D. Askew	Added OrderReceivedDateTime to SELECT
**	06/08/09	D. Askew	Changed SELECT, FROM and WHERE clauses to handle insertion of NULL values in PatientChange 
**					for those patient demographics which were not updated (CR 2666).
**	06/22/09	M. Smith	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetRecentlyUpdatedPatientDetails
(
	@divisioncode 	CHAR(5)
)

AS
--
SET NOCOUNT ON
--
DECLARE @currentdate		DATETIME
DECLARE @ERROR 		INT
--
SET @currentdate 	= GETUTCDATE()
SET @ERROR 		= 0
--
	SELECT DISTINCT	

		PC.PatientChangeGuid,
		PC.PatientChangeStatusCode,
		-- ************************************************************************************************************************************************************************************
		PC.FromPatientGuid,

		ISNULL(PC.FromPatientLastName, P.PatientLastName)						AS FromPatientLastName,
		ISNULL(PC.FromPatientFirstName, P.PatientFirstName)						AS FromPatientFirstName,
		ISNULL(PC.FromPatientMiddleName, P.PatientMiddleName)					AS FromPatientMiddleName,
		CASE WHEN PC.FromPatientSsn IS NULL THEN
			SUBSTRING( P.PatientSsn, 1, 3 ) 
				+ '-' + SUBSTRING( P.PatientSsn, 4, 2 ) 
				+ '-' + SUBSTRING( P.PatientSsn, 6, 4 )
		ELSE
			SUBSTRING( PC.FromPatientSsn, 1, 3 ) 
				+ '-' + SUBSTRING( PC.FromPatientSsn, 4, 2 ) 
				+ '-' + SUBSTRING( PC.FromPatientSsn, 6, 4 )
		END 												AS FromDisplayVistaPatientId,
		ISNULL(PC.FromPatientIcn, P.PatientIcn)								AS FromPatientIcn,
		ISNULL(PC.FromPatientDob, P.PatientDob)							AS FromPatientDob,
		ISNULL(PC.FromPatientSexCode, P.PatientSexCode)						AS FromPatientSexCode,
		ISNULL(PC.FromSsnPseudoIndicator, ISNULL(P.SsnPseudoIndicator, 0))				AS FromSsnPseudoIndicator,
		-- ************************************************************************************************************************************************************************************
		ISNULL(PC.ToPatientLastName, P.PatientLastName)						AS ToPatientLastName,
		ISNULL(PC.ToPatientFirstName, P.PatientFirstName)						AS ToPatientFirstName,
		ISNULL(PC.ToPatientMiddleName, P.PatientMiddleName)						AS ToPatientMiddleName,
		CASE WHEN PC.ToPatientSsn IS NULL THEN
			SUBSTRING( P.PatientSsn, 1, 3 ) 
				+ '-' + SUBSTRING( P.PatientSsn, 4, 2 ) 
				+ '-' + SUBSTRING( P.PatientSsn, 6, 4 )
		ELSE
			SUBSTRING( PC.ToPatientSsn, 1, 3 ) 
				+ '-' + SUBSTRING( PC.ToPatientSsn, 4, 2 ) 
				+ '-' + SUBSTRING( PC.ToPatientSsn, 6, 4 )
		END 												AS ToDisplayVistaPatientId,
		ISNULL(PC.ToPatientIcn, P.PatientIcn)								AS ToPatientIcn,
		ISNULL(PC.ToPatientDob, P.PatientDob)								AS ToPatientDob,
		ISNULL(PC.ToPatientSexCode, P.PatientSexCode)						AS ToPatientSexCode,
		ISNULL(PC.ToSsnPseudoIndicator, ISNULL(P.SsnPseudoIndicator, 0))				AS ToSsnPseudoIndicator,
		-- ************************************************************************************************************************************************************************************
		-- *** Pending Test Order Count ****
		dbo.fnFromPatientPendingOrdersCount( PC.FromPatientGuid, @divisioncode, @currentdate ) 	AS FromPatientPendingOrdersCount,
		-- ************************************************************************************************************************************************************************************
		dbo.fnCurrentPatientOrderReceivedDateTime( PC.FromPatientGuid, @divisioncode, @currentdate ) 	AS OrderReceivedDateTime,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, PC.LastUpdateDate) 			AS LastUpdateDate,
		PC.RowVersion	

	FROM 	dbo.PatientChange AS PC 

		JOIN VBECS_V1_TEST_MIRROR.dbo.V_Patient P
				ON PC.FromPatientGuid = P.PatientGuid
				AND PC.LastUpdateDate > P.LastUpdateDate
				AND P.LastUpdateDate = (SELECT MAX(LastUpdateDate)  FROM VBECS_V1_TEST_MIRROR.dbo.V_Patient MP WHERE PC.FromPatientGuid = MP.PatientGuid AND PC.LastUpdateDate > MP.LastUpdateDate)

		JOIN dbo.PatientTreatment AS PT ON FromPatientGuid = PT.PatientGuid

		JOIN dbo.PatientOrder AS PO ON PT.PatientTreatmentGuid = PO.PatientTreatmentGuid

	WHERE	
		PC.ToPatientGuid = PC.FromPatientGuid
		  AND 	PC.FromPatientDeathDate IS NULL 
		  AND 	PC.ToPatientDeathDate IS NULL
		  AND 	PC.PatientChangeStatusCode <> 'X'

	-- BR_68.01
	ORDER BY PC.LastUpdateDate

--
SET @ERROR = @@ERROR
--
SET NOCOUNT OFF
--
RETURN (@ERROR)
GO


if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetReportBloodUnitHistorySummary') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetReportBloodUnitHistorySummary
GO

/*******************************************************************************************************************************************************************************
**	Desc: Retunrs status and testing results for a blood unit
**
**	Author:	David Askew
**
**	Date: 	08/17/2004
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	01/26/05	D. Askew	Added QuarantineIndicator and PresumedTransfusedIndicator to select
**	03/15/05	Lohse		Adding BiohazardousWarningIndicator
**	05/31/2005	D. Askew	Added query to get current antigen info; removed modification info (split into separate procedures)
**	07/07/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Removed name, input/output from comment header, Added NOCOUNT OFF, Specified table owners, 
**					spaced out SQL
**	09/11/2005	D. Askew	Added DiscardDate to Select, changed JOIN SQL to be more readable
**	10/27/2005	D. Askew	Added space to separate patient first and middle names; added '.' to end of middle initals
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	01/24/2006	D. Askew	Added LastUpdateDate; changed formatting for readability
**	06/09/2008	K. Dobranowski Removed period ('.') from the end of the middle name (CR 2652)
**	06/25/2006	M. Smith	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetReportBloodUnitHistorySummary
(
	@bloodunitguid	UNIQUEIDENTIFIER,
	@divisioncode	VARCHAR(5)
)
AS
	
DECLARE @ERROR INT

SET @ERROR = 0

SET NOCOUNT ON

	SELECT DISTINCT
		BU.EyeReadableUnitId,
		-- ********************************************************************************************************************************************************************************************************************************************************
		CASE BU.LabelTypeCode
			WHEN 'I' THEN 
				BU.UnitProductCode + DT.DonationTypeCode COLLATE SQL_Latin1_General_CP1_CS_AS + BU.UnitDivisionId 
			ELSE 
				BU.UnitProductCode
			END 																AS UnitProductCode,
		-- ********************************************************************************************************************************************************************************************************************************************************
		BP.ProductName,
		DT.DonationTypeText,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, BUM.UnitExpirationDate) 								AS UnitExpirationDate,
		-- ********************************************************************************************************************************************************************************************************************************************************
		P.PatientLastName + ', ' +  P.PatientFirstName + (
			CASE WHEN P.PatientMiddleName IS NULL THEN 
				'' 
			ELSE (' ' + P.PatientMiddleName)

			END) 																AS RestrictedFor,
		-- ********************************************************************************************************************************************************************************************************************************************************
		CASE WHEN US.UnitStatusCode = 'D' THEN
			dbo.fnTimeZoneConversionDateTime
			(
				@divisioncode, 0, (SELECT LastUpdateDate FROM BloodUnitStatus WHERE BloodUnitGuid = @bloodunitguid AND UnitStatusCode = 'D')
			)
		ELSE NULL END 															AS DiscardDate,
		-- ********************************************************************************************************************************************************************************************************************************************************
		US.UnitStatusText,
		ISNULL(BUS.QuarantineIndicator, 0) 													AS QuarantineIndicator,
		ISNULL(BUS.BiohazardousWarningIndicator, 0) 												AS BiohazardousWarningIndicator,
		ISNULL(BUS.PresumedTransfusedIndicator, 0) 												AS PresumedTransfusedIndicator,
		BT.BloodTypeCode + ' ' + RH.RhFactorText 												AS AboRh,
		BU.RecordStatusCode,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, BU.LastUpdateDate) 								AS LastUpdateDate

	FROM
		dbo.BloodUnit BU

		LEFT OUTER JOIN dbo.BloodUnitMedia BUM 
		
			ON BU.BloodUnitGuid = BUM.BloodUnitGuid
		
		LEFT OUTER JOIN dbo.BloodType BT 
		
			ON BUM.BloodTypeCode = BT.BloodTypeCode
		
		LEFT OUTER JOIN dbo.RhFactor RH 
		
			ON BUM.RhFactorCode = RH.RhFactorCode
		
		LEFT OUTER JOIN dbo.BloodProduct BP 
		
			ON BU.BloodProductGuid = BP.BloodProductGuid
		
		LEFT OUTER JOIN dbo.BloodUnitStatus BUS 
		
			ON BU.BloodUnitGuid = BUS.BloodUnitGuid
		
		LEFT OUTER JOIN dbo.UnitStatus US 
		
			ON BUS.UnitStatusCode = US.UnitStatusCode
		
		LEFT OUTER JOIN dbo.DonationType DT 
		
			ON BU.DonationTypeId = DT.DonationTypeId
		
		LEFT OUTER JOIN dbo.Patient P 
		
			ON BUM.DirectedPatientGuid = P.PatientGuid

	WHERE 	
		BU.BloodUnitGuid = @bloodunitguid
		AND BU.DivisionCode = @divisioncode

	SET @ERROR = @@ERROR
	IF @ERROR != 0 GOTO ERR_HANDLER

	-- ********************************************************************************************************************************************************************************************************************************************************
	-- Get Current Antigens (From use cases 1, 41 and/or 70)
	--
	SELECT DISTINCT
		(
			CASE 	WHEN BUA.Positive = 1 THEN 
					'Pos'
				WHEN BUA.Positive = 0 THEN 
					'Neg'
				ELSE 
					'' 
				END
		) 							AS Positive,

		ANT.AntigenTypeName 					AS Antigen

	FROM
		dbo.BloodUnit BU

		JOIN dbo.BloodUnitAntigen BUA
			ON BU.BloodUnitGuid = BUA.BloodUnitGuid

		JOIN dbo.AntigenType ANT
			ON ANT.AntigenTypeId = BUA.AntigenTypeId

	WHERE 	
		BU.BloodUnitGuid = @bloodunitguid
		AND BU.DivisionCode = @divisioncode
		AND BUA.RecordStatusCode = 'A'

/*============================== U N I O N =========================================================*/

					UNION

	SELECT DISTINCT
		TR.TestResultText COLLATE SQL_Latin1_General_CP1_CS_AS AS Positive,
		ANT.AntigenTypeName AS Antigen

	FROM
		dbo.BloodUnit BU

		JOIN dbo.BloodUnitTest BUT
			ON BU.BloodUnitGuid = BUT.BloodUnitGuid
	
		JOIN dbo.AntigenTest ANTEST
			ON BUT.BloodTestTypeId = ANTEST.BloodTestTypeId
		
		JOIN dbo.AntigenType ANT
			ON ANTEST.AntigenTypeId = ANT.AntigenTypeId
		
		JOIN dbo.BloodTestType BTT
			ON BUT.BloodTestTypeId = BTT.BloodTestTypeId
		
		JOIN dbo.TestResult TR
			ON BUT.TestResultId = TR.TestResultId

	WHERE 	
		BU.BloodUnitGuid = @bloodunitguid
		AND BU.DivisionCode = @divisioncode
		AND BUT.RecordStatusCode = 'A'

	SET @ERROR = @@ERROR
	IF @ERROR != 0 GOTO ERR_HANDLER

SET NOCOUNT OFF

RETURN(@ERROR)

ERR_HANDLER:

	SET NOCOUNT OFF

	RETURN(@ERROR)
GO


/*****************************************************************************************
*	Grant permissions on tables and views
*****************************************************************************************/
GRANT SELECT ON dbo.Interface TO VbecsAppUser
GRANT SELECT ON dbo.InterfaceControl TO VbecsAppUser
GRANT SELECT ON dbo.VbecsVersion TO VbecsAppUser
GRANT SELECT ON dbo.PatientChange TO VbecsAppUser
GRANT SELECT ON  dbo.V_Suppliers TO VbecsAppUser
GRANT SELECT ON  dbo.vw_ActiveAndInactiveBloodUnits TO VbecsAppUser
GRANT SELECT ON  dbo.vw_ActiveAndInactiveBloodUnitsWithCurrentStatus TO VbecsAppUser
GRANT SELECT ON  dbo.vw_BloodUnitsWithAntigensIdentified TO VbecsAppUser

/*****************************************************************************************
*	Grant permissions on stored procedures and functions
*****************************************************************************************/
GRANT EXECUTE ON  dbo.spGetAntibodyType TO VbecsAppUser
GRANT EXECUTE ON  dbo.spGetAuditInterfaceControl TO VbecsAppUser
GRANT EXECUTE ON  dbo.spGetPatientDemographicHistoryForPatient TO VbecsAppUser
GRANT EXECUTE ON  dbo.spGetPendingPatientMergesDetails TO VbecsAppUser
GRANT EXECUTE ON  dbo.spGetPendingPatientMerges TO VbecsAppUser
GRANT EXECUTE ON  dbo.spGetVbecsVersion TO VbecsAppUser
GRANT EXECUTE ON  dbo.spHL7InsertPatientChange TO VbecsAppUser
GRANT EXECUTE ON  dbo.spHL7GetInterface TO VbecsAppUser
GRANT EXECUTE ON  dbo.spHL7GetInterfaceControlParameters TO VbecsAppUser
GRANT EXECUTE ON  dbo.spHL7PurgeMessageLog TO VbecsAppUser
GRANT EXECUTE ON  dbo.spVistaUpdateWorkloadEventData TO VbecsAppUser
GRANT EXECUTE ON  dbo.spHL7InsertPatient TO VbecsAppUser
GRANT EXECUTE ON  dbo.spHL7UpdatePatient TO VbecsAppUser
GRANT EXECUTE ON  dbo.spInsertPatient TO VbecsAppUser
GRANT EXECUTE ON  dbo.spPatientSearch TO VbecsAppUser
GRANT EXECUTE ON  dbo.spSingleBloodProductModification TO VbecsAppUser
GRANT EXECUTE ON  dbo.fnFileManDateTimeConversionToDateTime TO VbecsAppUser
GRANT EXECUTE ON  dbo.fnCompareProductAttributeForms TO VbecsAppUser
GRANT EXECUTE ON  dbo.spGetRecentlyUpdatedPatientDetails TO VbecsAppUser
GRANT EXECUTE ON  dbo.spGetReportBloodUnitHistorySummary TO VbecsAppUser
GRANT SELECT ON   dbo.fnGetABORhTable TO VbecsAppUser

USE master


/*******************************************************************************************************************
* Copy the VBECS database backups to the L Drive and re-naming the backups to include date time
e.g. "VBECS_V1_TEST.BAK" to " VBECS_V1_TEST_20090205.BAK
 L Drive backup location is L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP 
(CR 2570)
*********************************************************************************************************************/
Use Master
GO
--Create the folders for the backups

DECLARE @Directory	VARCHAR(125)
  
CREATE TABLE #FileExists 
	(IsFile bit, 
	 IsDir bit, 
	 HasParentDir bit)

SET @Directory = 'L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_TEST'
INSERT INTO #FileExists exec master.dbo.xp_fileexist @Directory

IF EXISTS (SELECT * FROM #FileExists WHERE IsDir = 0)
	EXECUTE master.dbo.xp_cmdshell 'mkdir "L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_TEST"'
TRUNCATE TABLE #FileExists

SET @Directory = 'L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_TEST_MIRROR'
INSERT INTO #FileExists exec master.dbo.xp_fileexist @Directory

IF EXISTS (SELECT * FROM #FileExists WHERE IsDir = 0)
	EXECUTE master.dbo.xp_cmdshell 'mkdir "L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_TEST_MIRROR"'
TRUNCATE TABLE #FileExists

SET @Directory = 'L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_PROD'
INSERT INTO #FileExists exec master.dbo.xp_fileexist @Directory

IF EXISTS (SELECT * FROM #FileExists WHERE IsDir = 0)
	EXECUTE master.dbo.xp_cmdshell 'mkdir "L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_PROD"'
TRUNCATE TABLE #FileExists

SET @Directory = 'L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_PROD_MIRROR'
INSERT INTO #FileExists exec master.dbo.xp_fileexist @Directory

IF EXISTS (SELECT * FROM #FileExists WHERE IsDir = 0)
	EXECUTE master.dbo.xp_cmdshell 'mkdir "L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_PROD_MIRROR"'
TRUNCATE TABLE #FileExists

SET @Directory = 'L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\master'
INSERT INTO #FileExists exec master.dbo.xp_fileexist @Directory

IF EXISTS (SELECT * FROM #FileExists WHERE IsDir = 0)
	EXECUTE master.dbo.xp_cmdshell 'mkdir "L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\master"'
TRUNCATE TABLE #FileExists


SET @Directory = 'L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\msdb'
INSERT INTO #FileExists exec master.dbo.xp_fileexist @Directory

IF EXISTS (SELECT * FROM #FileExists WHERE IsDir = 0)
	EXECUTE master.dbo.xp_cmdshell 'mkdir "L:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\msdb"'
DROP TABLE #FileExists


BEGIN TRANSACTION            
  DECLARE @JobID BINARY(16)  
  DECLARE @ReturnCode INT    
  SELECT @ReturnCode = 0     
IF (SELECT COUNT(*) FROM msdb.dbo.syscategories WHERE name = N'[Uncategorized (Local)]') < 1 
  EXECUTE msdb.dbo.sp_add_category @name = N'[Uncategorized (Local)]'

  -- Delete the job with the same name (if it exists)
  SELECT @JobID = job_id     
  FROM   msdb.dbo.sysjobs    
  WHERE (name = N'Copy VBECS DB Backups to L Drive')       
  IF (@JobID IS NOT NULL)    
  BEGIN  
  -- Check if the job is a multi-server job  
  IF (EXISTS (SELECT  * 
              FROM    msdb.dbo.sysjobservers 
              WHERE   (job_id = @JobID) AND (server_id <> 0))) 
  BEGIN 
    -- There is, so abort the script 
    RAISERROR (N'Unable to import job ''Copy VBECS DB Backups to L Drive'' since there is already a multi-server job with this name.', 16, 1) 
    GOTO QuitWithRollback  
  END 
  ELSE 
    -- Delete the [local] job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'Copy VBECS DB Backups to L Drive' 
    SELECT @JobID = NULL
  END 

BEGIN 

  -- Add the job
  EXECUTE @ReturnCode = msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , @job_name = N'Copy VBECS DB Backups to L Drive', @owner_login_name = N'sa', @description = N'Copies VBECS DB backups from D Drive to the L Drive and renames the files to include date time.', @category_name = N'[Uncategorized (Local)]', @enabled = 1, @notify_level_email = 0, @notify_level_page = 0, @notify_level_netsend = 0, @notify_level_eventlog = 2, @delete_level= 0
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job steps
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobstep @job_id = @JobID, @step_id = 1, @step_name = N'Copy Backups to L Drive', @command = N'USE master

declare @sql	varchar(2000)

set @sql = ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_PROD\VBECS_V1_PROD.BAK" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_PROD\VBECS_V1_PROD_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql

set @sql = ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_PROD_MIRROR\VBECS_V1_PROD_MIRROR.BAK" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_PROD_MIRROR\VBECS_V1_PROD_MIRROR_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql

set @sql = ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_TEST\VBECS_V1_TEST.BAK" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_TEST\VBECS_V1_TEST_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql

set @sql= ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_TEST_MIRROR\VBECS_V1_TEST_MIRROR.BAK" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_TEST_MIRROR\VBECS_V1_TEST_MIRROR_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql

set @sql = ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\master\master.bak" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\master\master_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql

set @sql = ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\msdb\msdb.bak" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\msdb\msdb_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql', @database_name = N'master', @server = N'', @database_user_name = N'', @subsystem = N'TSQL', @cmdexec_success_code = 0, @flags = 0, @retry_attempts = 0, @retry_interval = 1, @output_file_name = N'', @on_success_step_id = 0, @on_success_action = 1, @on_fail_step_id = 0, @on_fail_action = 2
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 
  EXECUTE @ReturnCode = msdb.dbo.sp_update_job @job_id = @JobID, @start_step_id = 1 

  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job schedules
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobschedule @job_id = @JobID, @name = N'Copy Backup Schedule', @enabled = 1, @freq_type = 4, @active_start_date = 20090205, @active_start_time = 24000, @freq_interval = 1, @freq_subday_type = 1, @freq_subday_interval = 0, @freq_relative_interval = 0, @freq_recurrence_factor = 0, @active_end_date = 99991231, @active_end_time = 235959
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the Target Servers
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobserver @job_id = @JobID, @server_name = N'(local)' 
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO


-- Script to delete old backup files that are more than 7 days old.

BEGIN TRANSACTION            
  DECLARE @JobID BINARY(16)  
  DECLARE @ReturnCode INT    
  SELECT @ReturnCode = 0     
IF (SELECT COUNT(*) FROM msdb.dbo.syscategories WHERE name = N'[Uncategorized (Local)]') < 1 
  EXECUTE msdb.dbo.sp_add_category @name = N'[Uncategorized (Local)]'

  -- Delete the job with the same name (if it exists)
  SELECT @JobID = job_id     
  FROM   msdb.dbo.sysjobs    
  WHERE (name = N'L Drive Delete old Backup files')       
  IF (@JobID IS NOT NULL)    
  BEGIN  
  -- Check if the job is a multi-server job  
  IF (EXISTS (SELECT  * 
              FROM    msdb.dbo.sysjobservers 
              WHERE   (job_id = @JobID) AND (server_id <> 0))) 
  BEGIN 
    -- There is, so abort the script 
    RAISERROR (N'Unable to import job ''L Drive Delete old Backup files'' since there is already a multi-server job with this name.', 16, 1) 
    GOTO QuitWithRollback  
  END 
  ELSE 
    -- Delete the [local] job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'L Drive Delete old Backup files' 
    SELECT @JobID = NULL
  END 

BEGIN 

  -- Add the job
  EXECUTE @ReturnCode = msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , @job_name = N'L Drive Delete old Backup files', @owner_login_name = N'sa', @description = N'Delete old backup files that are more than 7 days old', @category_name = N'[Uncategorized (Local)]', @enabled = 1, @notify_level_email = 0, @notify_level_page = 0, @notify_level_netsend = 0, @notify_level_eventlog = 2, @delete_level= 0
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job steps
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobstep @job_id = @JobID, @step_id = 1, @step_name = N'delete old files', @command = N'Use Master

CREATE TABLE #BackupFiles 
(FullPathName NVARCHAR(256)) 


DECLARE @Command NVARCHAR(256) 


SET @Command = ''master.dbo.xp_cmdshell ''''DIR ''
   + ''"L:\Program Files\Microsoft SQL Server\MSSQL\Backup\'' + ''*.*" /B /S''''''

INSERT INTO #BackupFiles EXEC (@Command) 


DECLARE @DeleteFiles NVARCHAR(4000) 

DECLARE file_cursor CURSOR FAST_FORWARD FOR 

SELECT  '' exec xp_cmdshell ''''DEL "'' 
       + FullPathName + ''"'''''' +CHAR(13)+CHAR(10) 
FROM #BackupFiles 
WHERE (FullPathName LIKE ''%_%.BAK'') 
   -- Trims punctuation and space from date time string 
     
  AND RIGHT(FullPathName,10) <
      CONVERT(VARCHAR(10),
      DATEADD(DAY, -6, GETDATE()),12)


OPEN file_cursor 
FETCH NEXT FROM file_cursor INTO @DeleteFiles 


WHILE @@FETCH_STATUS = 0 
BEGIN 
   EXEC (@DeleteFiles) 
   FETCH NEXT FROM file_cursor INTO @DeleteFiles 
END 


CLOSE file_cursor 
DEALLOCATE file_cursor 

DROP TABLE #BackupFiles', @database_name = N'master', @server = N'', @database_user_name = N'', @subsystem = N'TSQL', @cmdexec_success_code = 0, @flags = 0, @retry_attempts = 0, @retry_interval = 1, @output_file_name = N'', @on_success_step_id = 0, @on_success_action = 1, @on_fail_step_id = 0, @on_fail_action = 2
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 
  EXECUTE @ReturnCode = msdb.dbo.sp_update_job @job_id = @JobID, @start_step_id = 1 

  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job schedules
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobschedule @job_id = @JobID, @name = N'L Drive Delete old Backup files', @enabled = 1, @freq_type = 4, @active_start_date = 20081201, @active_start_time = 25000, @freq_interval = 1, @freq_subday_type = 1, @freq_subday_interval = 0, @freq_relative_interval = 0, @freq_recurrence_factor = 0, @active_end_date = 99991231, @active_end_time = 235959
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the Target Servers
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobserver @job_id = @JobID, @server_name = N'(local)' 
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO


IF (NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE name = N'VBECSJobMailFailure' AND type='U')) --DROP TABLE [dbo].[VBECSJobMailFailure]
BEGIN
	/************************************************************************************************
	**	Desc: This table holds failure messages when emails are not received by
	**		designated email recipients. For example if the SMTP port number 25 is 
	**		blocked.(CR 2569)	
	**
	**	Author: Kwame Adu-Poku
	**
	**	Date: 03/10/09
	**************************************************************************************************
	**	Modified:
	**	Date		Name		Description
	**************************************************************************************************/
	CREATE TABLE [dbo].[VBECSJobMailFailure] (
		[VbecsJobFailureId] [int] IDENTITY (1, 1) NOT NULL ,
		[DateOfFailure] [datetime] NULL ,
		[Spid] [int] NULL ,
		[EmailFrom] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[EmailTo] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[Subject] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[Body] [varchar] (4000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[iMsg] [int] NULL ,
		[Rc] [int] NULL ,
		[SourceOfFailure] [varchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[DescriptionOfFailure] [varchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[OutputFromFailure] [varchar] (1000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[CommentAboutFailure] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
	) ON [PRIMARY]

	ALTER TABLE dbo.VBECSJobMailFailure 
		ADD CONSTRAINT PK_VBECSJobMailFailure PRIMARY KEY CLUSTERED 
		(
			VbecsJobFailureId
		) WITH FILLFACTOR = 80 ON [PRIMARY]

	exec sp_addextendedproperty N'MS_Description', 'A unique identifier for a job failure.', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'VbecsJobFailureId'
	exec sp_addextendedproperty N'MS_Description', 'The contents of the email.', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'Body'
	exec sp_addextendedproperty N'MS_Description', 'Describes the step(s) where the failure occcured.', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'CommentAboutFailure'
	exec sp_addextendedproperty N'MS_Description', 'The date and time the failure occurred.', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'DateOfFailure'
	exec sp_addextendedproperty N'MS_Description', 'Describes the failure that has occurred.', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'DescriptionOfFailure'
	exec sp_addextendedproperty N'MS_Description', 'The source email address, Microsoft Operation Server .', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'EmailFrom'
	exec sp_addextendedproperty N'MS_Description', 'The recipient email address.', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'EmailTo'
	exec sp_addextendedproperty N'MS_Description', 'Identifies the message object.', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'iMsg'
	exec sp_addextendedproperty N'MS_Description', 'The output of the description of failure .', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'OutputFromFailure'
	exec sp_addextendedproperty N'MS_Description', 'Represents the return code.', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'Rc'
	exec sp_addextendedproperty N'MS_Description', 'The source of failure.', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'SourceOfFailure'
	exec sp_addextendedproperty N'MS_Description', 'The spid is the process identification number, which identifies your connection to SQL Server. ', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'Spid'
	exec sp_addextendedproperty N'MS_Description', 'The subject of the email.', N'user', N'dbo', N'table', N'VBECSJobMailFailure', N'column', N'Subject'

END
GO



if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[spSendVBECSJobMail]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[spSendVBECSJobMail]
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO
/************************************************************************************************
**	Desc: This stored procedure takes the parameters and sends an e-mail. 
**	      All the mail configurations are hard-coded in the stored procedure. 
** 	      References to the CDOSYS objects, search for CDOSysMail in google
**	      spSendCDOSysMail was renamed spSendVBECSJobMail and modified to suit our
**	      development needs.(CR 2569)	
**
**	Author: Kwame Adu-Poku
**
**	Date: 03/10/09
**************************************************************************************************
**	Modified:
**	Date		Name		Description
**************************************************************************************************/
CREATE PROCEDURE [dbo].[spSendVBECSJobMail] 
(
	@from VARCHAR(4000),
	@to VARCHAR(4000),
	@subject VARCHAR(4000)=' ',
	@body VARCHAR(4000) =' ',
	@attachment VARCHAR(4000) = ' '
)

AS

DECLARE @iMsg INT
DECLARE @rc INT
DECLARE @source VARCHAR(255)
DECLARE @description VARCHAR(500)
DECLARE @output VARCHAR(1000)

--************* Create the CDO.Message Object ************************

EXEC @rc = sp_OACreate 'CDO.Message', @iMsg OUT
IF @rc <> 0 
BEGIN
	INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'Failed at sp_OACreate')
	EXEC @rc = sp_OAGetErrorInfo @iMsg, @source OUT, @description OUT
	IF @rc = 0
	BEGIN

		SET @output = '  Description: ' + @description
		    
		INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'sp_OAGetErrorInfo for sp_OACreate')
	END 	       

	RETURN
END

--Configuring the Message Object 

-- This is to configure a remote SMTP server.

EXEC @rc = sp_OASetProperty @iMsg, 'Configuration.fields("http://schemas.microsoft.com/cdo/configuration/sendusing").Value','2'
IF @rc <> 0 
BEGIN
	INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'Failed at sp_OASetProperty sendusing')
	EXEC @rc = sp_OAGetErrorInfo @iMsg, @source OUT, @description OUT
	IF @rc = 0
	BEGIN
	 	     
		SET @output = '  Description: ' + @description
		
		INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'sp_OAGetErrorInfo for sp_OASetProperty sendusing')
	END
	         	      
	GOTO send_vbecsjobmail_cleanup  
END

-- This is to configure the Server Name or IP address. 

-- Replace MailServerName by the name or IP of your SMTP Server.

EXEC @rc = sp_OASetProperty @iMsg, 'Configuration.fields("http://schemas.microsoft.com/cdo/configuration/smtpserver").Value', 'smtp.va.gov' 
IF @rc <>0 
BEGIN
	INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'Failed at sp_OASetProperty smtpserver')
	EXEC @rc = sp_OAGetErrorInfo @iMsg, @source OUT, @description OUT
	IF @rc = 0
	BEGIN
		     
		SET @output = '  Description: ' + @description
		
		INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'sp_OAGetErrorInfo for sp_OASetProperty smtpserver')
	END
	        	      
	GOTO send_vbecsjobmail_cleanup
END
	
-- Save the configurations to the message object.

EXEC @rc = sp_OAMethod @iMsg, 'Configuration.Fields.Update', null
IF @rc <>0 
BEGIN
	INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'Failed at sp_OASetProperty Update')
	EXEC @rc = sp_OAGetErrorInfo @iMsg, @source OUT, @description OUT
	IF @rc = 0
	BEGIN
	    	   
		SET @output = '  Description: ' + @description
		
		INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'sp_OAGetErrorInfo for sp_OASetProperty Update')                 
	END
   	       
	GOTO send_vbecsjobmail_cleanup
END
	
-- Set the e-mail parameters.

EXEC @rc = sp_OASetProperty @iMsg, 'To', @to
IF @rc <>0 
BEGIN
	INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'Failed at sp_OASetProperty To')
	EXEC @rc = sp_OAGetErrorInfo @iMsg, @source OUT, @description OUT
	IF @rc = 0
	BEGIN
	  	      
		SET @output = '  Description: ' + @description
		
		INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'sp_OAGetErrorInfo for sp_OASetProperty To')                 
	END
	       	        
	GOTO send_vbecsjobmail_cleanup
END

EXEC @rc = sp_OASetProperty @iMsg, 'From', @from
IF @rc <>0 
BEGIN
	INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'Failed at sp_OASetProperty From')
	EXEC @rc = sp_OAGetErrorInfo @iMsg, @source OUT, @description OUT
	IF @rc = 0
	BEGIN
	  	        
		SET @output = '  Description: ' + @description
		
		INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'sp_OAGetErrorInfo for sp_OASetProperty From')                 
	END
	        	        
	GOTO send_vbecsjobmail_cleanup
END
	

EXEC @rc = sp_OASetProperty @iMsg, 'Subject', @subject
IF @rc <>0 
BEGIN
	INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'Failed at sp_OASetProperty Subject')
	EXEC @rc = sp_OAGetErrorInfo @iMsg, @source OUT, @description OUT
	IF @rc = 0
	BEGIN
	   	         
		SET @output = '  Description: ' + @description
		
		INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'sp_OAGetErrorInfo for sp_OASetProperty Subject')
	END
	      	         
	GOTO send_vbecsjobmail_cleanup
END


-- Check for Attachment specified and attach if necessary.

IF @attachment IS NOT NULL
BEGIN

	EXEC @rc = sp_OAMethod @iMsg, 'AddAttachment', null, @attachment
END

-- If you are using HTML e-mail, use 'HTMLBody' instead of 'TextBody'.

EXEC @rc = sp_OASetProperty @iMsg, 'TextBody', @body
IF @rc <>0 
BEGIN
	INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'Failed at sp_OASetProperty TextBody')
	EXEC @rc = sp_OAGetErrorInfo @iMsg, @source OUT, @description OUT
	IF @rc = 0
	BEGIN
		        
		SET @output = '  Description: ' + @description
		
		INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'sp_OAGetErrorInfo for sp_OASetProperty TextBody')
	END
	         	      
	GOTO send_vbecsjobmail_cleanup
END


EXEC @rc = sp_OAMethod @iMsg, 'Send', NULL
IF @rc <>0 
BEGIN
	INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'Failed at sp_OAMethod Send')
	EXEC @rc = sp_OAGetErrorInfo @iMsg, @source OUT, @description OUT
	IF @rc = 0
	BEGIN
		         
		SET @output = '  Description: ' + @description
		
		INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'sp_OAGetErrorInfo for sp_OAMethod Send')
	END
	         	      
	GOTO send_vbecsjobmail_cleanup
END
	
-- Clean up the objects created.
send_vbecsjobmail_cleanup:

	IF (@iMsg IS NOT NULL) -- if @iMsg is NOT NULL then destroy it
	BEGIN
		EXEC @rc=sp_OADestroy @iMsg
	
		-- handle the failure of the destroy if needed
		IF @rc <>0 
	     	BEGIN
			INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'Failed at sp_OADestroy')
			EXEC @rc = sp_OAGetErrorInfo @iMsg, @source OUT, @description OUT
	
			-- if sp_OAGetErrorInfo was successful, print errors
			IF @rc = 0
			BEGIN			     
				SET @output = '  Description: ' + @description
			    
				INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, 'sp_OAGetErrorInfo for sp_OADestroy')
		     	END
	        END
	END
	ELSE 
	BEGIN
		
		INSERT INTO [dbo].[VBECSJobMailFailure] VALUES (getdate(), @@spid, @from, @to, @subject, @body, @iMsg, @rc, @source, @description, @output, '@iMsg is NULL, sp_OADestroy skipped')
	END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

USE msdb
GO

IF exists (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[tr_EmailBackgroundJobsFailures]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
DROP TRIGGER [dbo].[tr_EmailBackgroundJobsFailures]
GO

SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS OFF
GO
/************************************************************************************************
**	Desc: 	Adding a trigger (tr_EmailBackgroundJobsFailures) to the sysjobhistory that
**		will send a mail when any of the VBECS Background jobs fails.(CR 2569)
**
**	Author: Kwame Adu-Poku
**
**	Date: 	03/10/09
**************************************************************************************************
**	Modified:
**	Date		Name		Description
**************************************************************************************************/
CREATE TRIGGER [dbo].[tr_EmailBackgroundJobsFailures]

ON [dbo].[sysjobhistory]

FOR INSERT

AS 

DECLARE @emailbody varchar(4000)
DECLARE @attachment varchar(4000)

IF EXISTS (SELECT * FROM inserted WHERE run_status IN (0,3) AND step_name <> '(job outcome)')
BEGIN

	SELECT @emailbody = 

		CONVERT(CHAR(15),'E-mail:') + '*** Please do not reply to this message. If you have any questions, please contact the VA Service Desk 1-888-596 HELP (4357)***' + CHAR(10) +

		CONVERT(char(15),'Server:') + ISNULL(@@servername, '') + char(10) +

		CONVERT(char(15),'Job:') + ISNULL(CONVERT(VARCHAR(50), dbo.sysjobs.name), '') + char(10) +

		CONVERT(char(15),'Step:') + ISNULL(CONVERT(VARCHAR(50), inserted.step_name), '')+ char(10) +

		CONVERT(char(15),'Action:') + CASE run_status WHEN 0 THEN 'FAILED' WHEN 3 THEN 'CANCELED' ELSE '' END + char(10) +

		CONVERT(char(15),'Message:') + ISNULL(CONVERT(VARCHAR(150), inserted.message), '')+ char(10) +

		CONVERT(char(15),'Attachment:') + ISNULL(CONVERT(VARCHAR(150), dbo.sysjobsteps.output_file_name),''),

		@attachment = dbo.sysjobsteps.output_file_name

	FROM inserted 

	JOIN dbo.sysjobs
		ON inserted.job_id = dbo.sysjobs.job_id
	JOIN dbo.sysjobsteps
		ON inserted.job_id = dbo.sysjobsteps.job_id
		AND inserted.step_id = dbo.sysjobsteps.step_id

	WHERE inserted.run_status IN (0,3)



	DECLARE @emailto varchar(1000)
	DECLARE @emailfrom varchar(1000)
	DECLARE @subject varchar(100)

	SET @subject = 'Job Failed'
	SET @emailfrom = '"No Replies" <vhaishops6a@va.gov>'

	CREATE TABLE  #Temp2XML 
	(LineText	VARCHAR(255),
	 Junk	INT)

	INSERT INTO #Temp2XML (LineText, Junk)

	EXEC sp_readerrorlog 1,  'C:\program files\vista\vbecs service monitor\VbecsServiceMonitor.exe.config'

	SELECT @emailto = LineText 
  	FROM #Temp2XML
 	WHERE LineText LIKE '%<add key="EmailRecipients"%'

	DROP TABLE #Temp2XML

	DECLARE @position integer

	SET @position = charindex('value="', @emailto) + len('value="')
	SET @emailto = substring(@emailto, @position, charindex('"', @emailto, @position + 1) - @position)

	EXEC master.dbo.spSendVBECSJobMail @emailfrom, @emailto, @subject, @emailbody, @attachment

END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

IF exists (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[tr_EmailIntegrityJobOutput]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
DROP TRIGGER [dbo].[tr_EmailIntegrityJobOutput]
GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS OFF
GO

/************************************************************************************************
**	Desc:	Adding a trigger(tr_EmailIntegrityJobOutput)to the sysjobhistory that will 
**		send a mail when a Database weekly Integrity 
**		check succeeds. (CR 2569)
**
**	Author: Kwame Adu-Poku
**
**	Date: 03/10/09
**************************************************************************************************
**	Modified:
**	Date		Name		Description
**************************************************************************************************/

CREATE  TRIGGER [dbo].[tr_EmailIntegrityJobOutput]

ON [dbo].[sysjobhistory]

FOR INSERT

AS 

DECLARE @emailbody 	VARCHAR(4000)
DECLARE @attachment VARCHAR(4000)
DECLARE @runstatus 	INT

IF EXISTS (SELECT * FROM inserted JOIN dbo.sysjobs ON inserted.job_id = dbo.sysjobs.job_id where inserted.step_name like '%WeeklyIntegrityCheck')

BEGIN

	SELECT @runstatus = run_status, @emailbody = 
	
		CONVERT(CHAR(15),'E-mail:') + '*** Please do not reply to this message. If you have any questions, please contact the VA Service Desk 1-888-596 HELP(4357)***' + CHAR(10) +
	
		CONVERT(CHAR(15),'Server:') + ISNULL(@@servername, '') + CHAR(10) +

		CONVERT(CHAR(15),'Job:') + ISNULL(CONVERT(VARCHAR(50), dbo.sysjobs.name), '') + CHAR(10) +

		CONVERT(CHAR(15),'Step:') + ISNULL(CONVERT(VARCHAR(50), inserted.step_name), '') + CHAR(10) +

		CONVERT(CHAR(15),'Action:') + CASE run_status WHEN 0 THEN 'FAILED' WHEN 1 THEN 'SUCCEED' WHEN 3 THEN 'CANCELED' ELSE '' END + CHAR(10) +

		CONVERT(CHAR(15),'Message:') + ISNULL(CONVERT(VARCHAR(150), inserted.message), '') + CHAR(10) +
	
		CONVERT(CHAR(15),'Attachment:') + ISNULL(CONVERT(VARCHAR(150), dbo.sysjobsteps.output_file_name),''),

		@attachment = dbo.sysjobsteps.output_file_name 
		
	FROM inserted 

	JOIN dbo.sysjobs
		ON inserted.job_id = dbo.sysjobs.job_id

	JOIN dbo.sysjobsteps
		ON inserted.job_id = [dbo].sysjobsteps.job_id
		AND inserted.step_id = [dbo].sysjobsteps.step_id
	
	WHERE inserted.run_status = '1'

	DECLARE @emailto varchar(1000)
	DECLARE @emailfrom varchar(1000)
	DECLARE @subject varchar(100)
	
	SET @subject = 'Job Succeeded'
	SET @emailfrom = '"No Replies" <vhaishops6a@va.gov>'


	CREATE TABLE  #TempXML 
	(LineText	VARCHAR(255),
	 Junk	INT)

	INSERT INTO #TempXML (LineText, Junk)
	EXEC sp_readerrorlog 1,  'C:\program files\vista\vbecs service monitor\VbecsServiceMonitor.exe.config'


	SELECT @emailto = LineText 
 	 FROM #TempXML
 	WHERE LineText LIKE '%<add key="EmailRecipients"%'

	DROP TABLE #TempXML

	DECLARE @position integer

	SET @position = charindex('value="', @emailto) + len('value="')
	SET @emailto = substring(@emailto, @position, charindex('"', @emailto, @position + 1) - @position)

	EXEC master.dbo.spSendVBECSJobMail @emailfrom, @emailto, @subject, @emailbody, @attachment

END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

USE VBECS_V1_TEST
GO
/*****************************************************
UPDATE VbecsVersion
*****************************************************/
DECLARE @SUser	VARCHAR(45)

SET @SUser = (select suser_sname())

INSERT INTO dbo.VbecsVersion
(Version, PatchSuccessfulIndicator, LastUpdateDate, LastUpdateUser)
VALUES('1.5.0.4', 0, getutcdate(), RIGHT(@SUser, LEN(@SUser) - CHARINDEX('\', @SUser)))